(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    243941,       5894]*)
(*NotebookOutlinePosition[    280811,       7196]*)
(*  CellTagsIndexPosition[    280767,       7192]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Chemical oscillators: the BZ reaction", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "from ",
  StyleBox[ButtonBox["Essential Mathematica for Students of Science",
    Active->False,
    ButtonData:>{
      URL[ 
      "http://www.physics.umd.edu/courses/CourseWare/EssentialMathematica/"], 
      None},
    Active->False,
    ButtonStyle->"Hyperlink"],
    Active->False],
  "\n\[Copyright] James J. Kelly, 1998\nLast revised: January, 2006"
}], "Author",
  Active->True,
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
In 1951, Belousov discovered a chemical reaction in which the concentrations \
of a catalyst and several reactants exhibited stable oscillations and wave \
phenomena, but his paper was rejected.  Although Belousov eventually \
published a brief report in the proceedings of an obscure Russian medical \
conference (1959) and Zhabotinskii continued to study this reaction in the \
sixties and early seventies, its importance was not widely recognized until \
western researchers, such as Field and Noyes, began to investigate its \
spatial and temporal properties in greater detail.  Posthumous recognition \
was finally granted to Belousov with the award of the 1980 Lenin Prize.  This \
reaction, now known as the Belousov-Zhabotinskii or BZ reaction, is now \
considered the prototypical chemical oscillator and is still studied \
actively.\
\>", "Text"],

Cell["\<\
In this notebook we investigate limit-cycle oscillations using a simplified \
model due to Field and Noyes (1974) that faithfully describes the most \
important aspects of the relatively complicated chemical processes that occur \
in the BZ reaction.  The FN model is formulated in terms of a system of 3 \
differential equations \
\>", "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{"\t\t", 
        RowBox[{
          RowBox[{"\[CurlyEpsilon]", " ", 
            RowBox[{
              SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "\[AlignmentMarker]", 
          "\[Equal]", \(\((1 - x[t])\)\ x[t] - y[t]\ x[t] + q\ y[t]\)}]}], 
      TraditionalForm], "\n", 
    FormBox[
      RowBox[{
        RowBox[{"\[Delta]", " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], 
        "\[AlignmentMarker]", 
        "\[Equal]", \(\(-q\)\ y[t] - x[t]\ y[t] + 2\ f\ z[t]\)}], 
      TraditionalForm], "\n", 
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["z", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[AlignmentMarker]", 
        "\[Equal]", \(x[t] - z[t]\)}], TraditionalForm]}], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " represent the concentrations of malonic acid ",
  Cell[BoxData[
      StyleBox[\(HBrO\_2\),
        "InlineInput"]]],
  " and bromide ions ",
  Cell[BoxData[
      StyleBox[\(Br\^-\),
        "InlineInput"]]],
  ", while ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " represents the ratio between the concentrations of the ",
  Cell[BoxData[
      StyleBox[\(Ce\^\(\(4\)\(+\)\)\),
        "InlineInput"]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Ce\^\(\(3\)\(+\)\)\),
          "InlineInput"], InputForm]]],
  " states of the cerium catalyst.  The parameters \[CurlyEpsilon], \[Delta], \
and ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " are related to reaction rates while the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is stoichiometric and is generally taken as 0.5.  Periodic oscillations \
of the catalyst concentrations, coupled to appropriate dyes, produce dramatic \
oscillations of the color of the mixture.  Standing wave patterns can also be \
exhibited but are beyond the scope of this presentation."
}], "Text"],

Cell[CellGroupData[{

Cell["References:", "Subsubsection"],

Cell[TextData[{
  "There is now a vast literature on the BZ reaction and related topics.  We \
base our discussion upon the pertinent chapter of Murray's textbook on ",
  StyleBox["Mathematical Biology",
    FontSlant->"Italic"],
  " and include a few references to original work below.  A larger set of \
references can be obtained from Murray or any recent review article."
}], "Text"],

Cell[TextData[{
  "B.P. Belousov (1951): ",
  StyleBox["A periodic reaction and its mechanism",
    FontSlant->"Italic"],
  " \[LongDash] English translation included in ",
  StyleBox["Oscillations and Travelling Waves in Chemical Systems",
    FontSlant->"Italic"],
  ", edited by R.J. Field and M. Burger (Wiley, New York, 1985).\t"
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "B.P. Belousov (1959): ",
  StyleBox["An oscillating reaction and its mechanism",
    FontSlant->"Italic"],
  ", (Sborn. referat. radiat. med., Medgiz, Moscow), p. 145.\t"
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "A.M. Zhabotinskii, ",
  StyleBox["Periodic processes of the oxidation of malonic acid in solution",
    FontSlant->"Italic"],
  ", Biofizika ",
  StyleBox["9",
    FontWeight->"Bold"],
  ", 306 (1964)."
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "A.M. Zhabotinskii and A.N. Zaikin, ",
  StyleBox["Autowave processes in a distributed chemical system",
    FontSlant->"Italic"],
  ", J. theor. Biol. ",
  StyleBox["40",
    FontWeight->"Bold"],
  ", 45 (1973).\t"
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "R.J. Field and R.M.  Noyes, ",
  StyleBox["Oscillations in chemical systems",
    FontSlant->"Italic"],
  ", J. Chem. Phys. ",
  StyleBox["60",
    FontWeight->"Bold"],
  ", 1877 (1974).\t"
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "J.D. Murray, ",
  StyleBox["Mathematical Biology",
    FontSlant->"Italic"],
  " (Springer-Verlag, Berlin, 1989), ch. 7."
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(\(ClearAll["\<Global`*\>"];\)\), "\n", 
    \(\(Off[General::spell, General::spell1];\)\), "\n", 
    \(\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 12};\)\)}], "Input"],

Cell["\<\
$DefaultFont={\"Times\", 12}; 
$TextStyle={FontFamily\[Rule]\"Times\", \
FontSize\[Rule]12,FontSlant\[Rule]\"Italic\"}; \
\>", "Input"],

Cell[BoxData[{
    \(\(Needs["\<Utilities`Notation`\>"];\)\), "\n", 
    \(Needs["\<Graphics`Graphics`\>"]\)}], "Input"],

Cell[BoxData[
    \(\(Off[Symbolize::"\<boxSymbolExists\>"];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Symbolize", "[", 
        TagBox[\(x\_s\),
          NotationBoxTag,
          Editable->True], "]"}], ";", " ", 
      RowBox[{"Symbolize", "[", 
        TagBox[\(y\_s\),
          NotationBoxTag,
          Editable->True], "]"}], ";", " ", 
      RowBox[{"Symbolize", "[", 
        TagBox[\(z\_s\),
          NotationBoxTag,
          Editable->True], "]"}], ";", "\n", 
      RowBox[{"Symbolize", "[", 
        TagBox[\(x\_0\),
          NotationBoxTag,
          Editable->True], "]"}], ";", " ", 
      RowBox[{"Symbolize", "[", 
        TagBox[\(y\_0\),
          NotationBoxTag,
          Editable->True], "]"}], ";", " ", 
      RowBox[{"Symbolize", "[", 
        TagBox[\(z\_0\),
          NotationBoxTag,
          Editable->True], "]"}]}]], "Input"],

Cell[BoxData[{
    \(\(concentrations[t] = {x[t], y[t], z[t]};\)\), "\n", 
    \(\(rates[t] = D[concentrations[t], t];\)\)}], "Input"],

Cell[BoxData[
    \(\(FNrates[
          t]\  = \ {\(\[CurlyEpsilon]\^\(-1\)\) \((q\ y[t] - x[t]\ y[t] + 
                x[t]\ \((1 - x[t])\))\), \[Delta]\^\(-1\)\ \((\(-q\)\ y[t] - 
                x[t]\ y[t] + 2\ f\ z[t])\), x[t] - z[t]};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FNeqs\  = \ MapThread[Equal, {rates[t], FNrates[t]}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\((1 - x[t])\)\ x[t] + q\ y[t] - 
                x[t]\ y[t]\)\/\[CurlyEpsilon]\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(-q\)\ y[t] - x[t]\ y[t] + 
                2\ f\ z[t]\)\/\[Delta]\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["z", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(x[t] - z[t]\)}]}], "}"}]], "Output"]
}, Closed]],

Cell[BoxData[
    \(\(TypicalParameters\  = \ {f \[Rule] 0.5, \[Delta] \[Rule] 1\/3, 
          q \[Rule] 5\[Times]10\^\(-3\), \ \[CurlyEpsilon] \[Rule] 
            0.01};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Stability of steady states", "Section"],

Cell[CellGroupData[{

Cell["Steady state", "Subsection"],

Cell[TextData[{
  "The following rules represent steady-state conditions in which the \
concentrations ",
  Cell[BoxData[
      \(TraditionalForm\`{x[t], y[t], z[t]}\)]],
  " approach the steady values ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_s, y\_s, z\_s}\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(SteadyStateRules\  = {x[t] \[Rule] x\_s, y[t] \[Rule] y\_s, 
          z[t] \[Rule] z\_s, \[PartialD]\_t x[t] \[Rule] 
            0, \[PartialD]\_t y[t] \[Rule] 0, \ \[PartialD]\_t z[t] \[Rule] 
            0}\ ;\)\)], "Input"],

Cell["Applying these rules yields a set of equations", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SteadyStateEquations = FNeqs\  /. SteadyStateRules\)], "Input"],

Cell[BoxData[
    \({0 \[Equal] \(\((1 - x\_s)\)\ x\_s + q\ y\_s - x\_s\ y\_s\)\/\
\[CurlyEpsilon], 
      0 \[Equal] \(\(-q\)\ y\_s - x\_s\ y\_s + 2\ f\ z\_s\)\/\[Delta], 
      0 \[Equal] x\_s - z\_s}\)], "Output"]
}, Closed]],

Cell["with solutions", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SteadyStates\  = 
      Solve[SteadyStateEquations, {x\_s, y\_s, z\_s}\ ]\  // 
        Simplify\)], "Input"],

Cell[BoxData[
    \({{z\_s \[Rule] 0, y\_s \[Rule] 0, 
        x\_s \[Rule] 0}, {z\_s \[Rule] 
          1\/2\ \((1 - 2\ f - 
                q - \@\(4\ f\^2 + \((1 + q)\)\^2 + 4\ f\ \((\(-1\) + 3\ \
q)\)\))\), 
        y\_s \[Rule] 
          1\/4\ \((1 + 6\ f + 
                q + \@\(4\ f\^2 + \((1 + q)\)\^2 + 4\ f\ \((\(-1\) + 3\ \
q)\)\))\), 
        x\_s \[Rule] 
          1\/2\ \((1 - 2\ f - 
                q - \@\(4\ f\^2 + \((1 + q)\)\^2 + 4\ f\ \((\(-1\) + 3\ \
q)\)\))\)}, {z\_s \[Rule] 
          1\/2\ \((1 - 2\ f - 
                q + \@\(4\ f\^2 + \((1 + q)\)\^2 + 4\ f\ \((\(-1\) + 3\ \
q)\)\))\), 
        y\_s \[Rule] 
          1\/4\ \((1 + 6\ f + 
                q - \@\(4\ f\^2 + \((1 + q)\)\^2 + 4\ f\ \((\(-1\) + 3\ \
q)\)\))\), 
        x\_s \[Rule] 
          1\/2\ \((1 - 2\ f - 
                q + \@\(4\ f\^2 + \((1 + q)\)\^2 + 4\ f\ \((\(-1\) + 3\ \
q)\)\))\)}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SteadyStates /. TypicalParameters\)], "Input"],

Cell[BoxData[
    \({{z\_s \[Rule] 0, y\_s \[Rule] 0, 
        x\_s \[Rule] 0}, {z\_s \[Rule] \(-0.10253124511871248`\), 
        y\_s \[Rule] 1.0512656225593562`, 
        x\_s \[Rule] \(-0.10253124511871248`\)}, {z\_s \[Rule] 
          0.09753124511871247`, y\_s \[Rule] 0.9512343774406438`, 
        x\_s \[Rule] 0.09753124511871247`}}\)], "Output"]
}, Closed]],

Cell["\<\
The first is trivial while the second yields negative concentrations and is \
unphysical, leaving the third solution as the relevant case. \
\>", "Text"],

Cell[BoxData[
    \(\(SteadyState = 
        SteadyStates\[LeftDoubleBracket]3\[RightDoubleBracket];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Stability matrix", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(stabilityMatrix = 
      Outer[D, FNrates[t] /. SteadyStateRules, {x\_s, y\_s, z\_s}]\)], "Input"],

Cell[BoxData[
    \({{\(1 - 2\ x\_s - y\_s\)\/\[CurlyEpsilon], \(q - \
x\_s\)\/\[CurlyEpsilon], 
        0}, {\(-\(y\_s\/\[Delta]\)\), \(\(-q\) - x\_s\)\/\[Delta], \(2\ f\)\/\
\[Delta]}, {1, 0, \(-1\)}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(stabilityMatrix = stabilityMatrix /. SteadyState // Simplify\)], "Input"],

Cell[BoxData[
    \({{\(\(-1\) + 2\ f + 3\ q - 3\ \@\(4\ f\^2 + \((1 + q)\)\^2 + 4\ f\ \
\((\(-1\) + 3\ q)\)\)\)\/\(4\ \[CurlyEpsilon]\), \(-\(\(1 - 2\ f - 
                3\ q + \@\(4\ f\^2 + \((1 + q)\)\^2 + 4\ f\ \((\(-1\) + 3\ q)\
\)\)\)\/\(2\ \[CurlyEpsilon]\)\)\), 
        0}, {\(-\(\(1 + 6\ f + 
                q - \@\(4\ f\^2 + \((1 + q)\)\^2 + 4\ f\ \((\(-1\) + 3\ \
q)\)\)\)\/\(4\ \[Delta]\)\)\), \(-\(\(1 - 2\ f + 
                q + \@\(4\ f\^2 + \((1 + q)\)\^2 + 4\ f\ \((\(-1\) + 3\ \
q)\)\)\)\/\(2\ \[Delta]\)\)\), \(2\ f\)\/\[Delta]}, {1, 
        0, \(-1\)}}\)], "Output"]
}, Closed]],

Cell["\<\
Although it is possible to evaluate the eigenvalues symbolically, the \
resulting expressions are rather unwieldy and the simplification process can \
exhaust the memory of typical desktop computers.  Therefore, we shall be \
content to give numerical values for typical parameters.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[stabilityMatrix /. TypicalParameters]\)], "Input"],

Cell[BoxData[
    \({\(-16.38439277168985`\), \
\(\(0.2235561342634215`\)\(\[InvisibleSpace]\)\) + 
        0.5543426515156582`\ \[ImaginaryI], \(\(0.2235561342634215`\)\(\
\[InvisibleSpace]\)\) - 0.5543426515156582`\ \[ImaginaryI]}\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Limit-cycle oscillations", "Section"],

Cell["\<\
The following function produces and displays solutions to the Field-Noyes \
model of the BZ reaction.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(DisplayBZ::usage = \*"\"\<DisplayBZ[parameters,{\!\(x\_0\),\!\(y\_0\
\),\!\(z\_0\)},{\!\(x\_min\),\!\(y\_min\),\!\(z\_min\)},{\!\(x\_max\),\!\(y\_\
max\),\!\(z\_max\)},\!\(t\_max\)] displays concentration variables for the \
Field-Noyes model of the BZ reaction for time interval {t,0,\!\(t\_max\)} \
assuming initial values {\!\(x\_0\),\!\(y\_0\),\!\(z\_0\)}.  The list of \
parameters must give replacement rules for \[CurlyEpsilon], \[Delta], q, and \
f.  Minimum and maximum values are given for the plot ranges.\>\"";\)\(\n\)
    \)\t\), "\n", 
    \(DisplayBZ[
        parameters_, {\(x\_0\) : _, \(y\_0\) : _, \(z\_\(\(0\)\(\ \)\)\) : \
_}, {xmin_, ymin_, zmin_}, {xmax_, ymax_, zmax_}, tmax_] := 
      Module[{sol, plotx, ploty, plotz}, 
        sol = \(NDSolve[
              Join[FNeqs, {x[0] \[Equal] x\_0, y[0] \[Equal] y\_0, 
                    z[0] \[Equal] z\_0}] /. parameters, {x, y, z}, {t, 0, 
                tmax}, MaxSteps \[Rule] 
                10\^4]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]plotx = 
          LogPlot[Evaluate[x[t] /. sol], \ {t, 0, tmax}, 
            PlotPoints \[Rule] 100, PlotRange \[Rule] {All, {xmin, xmax}}, \ 
            PlotLabel \[Rule] \*"\"\<\!\(HBrO\_2\)\>\"", 
            DisplayFunction \[Rule] Identity]; 
        ploty = LogPlot[Evaluate[y[t] /. sol], \ {t, 0, tmax}, 
            PlotPoints \[Rule] 100, PlotRange \[Rule] {All, {ymin, ymax}}, 
            PlotLabel \[Rule] \*"\"\<\!\(\(Br\^-\)\)\>\"", 
            DisplayFunction \[Rule] Identity]; 
        plotz = LogPlot[Evaluate[z[t] /. sol], \ {t, 0, tmax}, 
            PlotPoints \[Rule] 100, PlotRange \[Rule] {All, {zmin, zmax}}, 
            PlotLabel \[Rule] \*"\"\<\!\(Ce\^\(\(4\)\(+\)\)\)/\!\(Ce\^\(\(3\)\
\(+\)\)\)\>\"", DisplayFunction \[Rule] Identity]; 
        Show[GraphicsArray[{{plotx}, {ploty}, {plotz}}], Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<t  (arb. units)\>", "\<\>"}, 
          PlotLabel \[Rule] "\<BZ reaction\>", 
          DisplayFunction \[Rule] $DisplayFunction]]\)}], "Input"],

Cell["\<\
For example, even when the initial conditions are rather far from the \
unstable fixed point, the system settles upon a stable limit cycle after the \
sometimes dramatic transients have decayed.  The appearance of a periodic \
oscillation after an extended interval of monotonic variation is quite \
remarkable.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayBZ[
        TypicalParameters, {0.0, 1.0, 1.0}, {0.001, 0.5, 0.001}, {0.5, 5.0, 
          0.5}, 100];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -33.5938 -15.6875 ]
[.5 -0.0125 33.5938 0 ]
[ 0 0 -0.125 0 ]
[ 0 1.97771 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.99021 -30.8125 0 ]
[.5 1.99021 30.8125 15.6875 ]
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
gsave
.5 -0.0125 -94.5938 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.563 15.813 moveto
(H) show
76.375 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arb) show
93.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
99.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(units) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
122.375 15.813 moveto
(L) show
126.188 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
0 1.97771 L
s
0 1.97771 m
1 1.97771 L
s
1 0 m
1 1.97771 L
s
gsave
.5 1.99021 -91.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BZ) show
80.813 15.813 moveto
(reaction) show
120.625 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.686966 0.228989 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -8 -15.6875 ]
[.21429 -0.0125 8 0 ]
[.40476 -0.0125 -8 -15.6875 ]
[.40476 -0.0125 8 0 ]
[.59524 -0.0125 -8 -15.6875 ]
[.59524 -0.0125 8 0 ]
[.78571 -0.0125 -8 -15.6875 ]
[.78571 -0.0125 8 0 ]
[.97619 -0.0125 -11 -15.6875 ]
[.97619 -0.0125 11 0 ]
[-0.0125 .16006 -31 -7.84375 ]
[-0.0125 .16006 0 7.84375 ]
[-0.0125 .22899 -25 -7.84375 ]
[-0.0125 .22899 0 7.84375 ]
[-0.0125 .38905 -25 -7.84375 ]
[-0.0125 .38905 0 7.84375 ]
[-0.0125 .45798 -19 -7.84375 ]
[-0.0125 .45798 0 7.84375 ]
[-0.0125 .61803 -19 -7.84375 ]
[-0.0125 .61803 0 7.84375 ]
[.5 .63053 -27.7188 0 ]
[.5 .63053 27.7188 15.6875 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16006 m
.00625 .16006 L
s
gsave
-0.0125 .16006 -92 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
90.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .22899 m
.00625 .22899 L
s
gsave
-0.0125 .22899 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
84.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .38905 m
.00625 .38905 L
s
gsave
-0.0125 .38905 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
84.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .45798 m
.00625 .45798 L
s
gsave
-0.0125 .45798 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
78.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
78.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .06893 m
.00375 .06893 L
s
0 .10926 m
.00375 .10926 L
s
0 .13787 m
.00375 .13787 L
s
0 .17819 m
.00375 .17819 L
s
0 .19352 m
.00375 .19352 L
s
0 .2068 m
.00375 .2068 L
s
0 .21851 m
.00375 .21851 L
s
0 .29792 m
.00375 .29792 L
s
0 .33824 m
.00375 .33824 L
s
0 .36685 m
.00375 .36685 L
s
0 .40718 m
.00375 .40718 L
s
0 .42251 m
.00375 .42251 L
s
0 .43579 m
.00375 .43579 L
s
0 .4475 m
.00375 .4475 L
s
0 .52691 m
.00375 .52691 L
s
0 .56723 m
.00375 .56723 L
s
0 .59584 m
.00375 .59584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -88.7188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Ce) show
76.250 10.938 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
80.563 10.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.813 15.813 moveto
(\\220) show
90.625 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Ce) show
103.875 10.938 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
108.188 10.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
114.438 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03053 .61803 m
.03318 .59087 L
.04339 .48778 L
.05298 .39614 L
.06221 .31883 L
.06735 .28341 L
.07203 .25724 L
.07689 .23646 L
.08148 .22235 L
.08383 .21692 L
.08632 .21228 L
.08866 .20883 L
.09079 .2063 L
.09308 .20417 L
.09553 .20241 L
.0978 .20118 L
.09997 .20031 L
.10229 .19962 L
.10359 .19934 L
.10477 .19913 L
.10587 .19897 L
.10706 .19884 L
.10761 .1988 L
.10819 .19875 L
.10869 .19872 L
.10923 .1987 L
.10984 .19867 L
.11013 .19866 L
.11043 .19865 L
.1107 .19865 L
.111 .19864 L
.11127 .19864 L
.11152 .19864 L
.11182 .19864 L
.11214 .19864 L
.11241 .19864 L
.11271 .19865 L
.11303 .19865 L
.11337 .19866 L
.11399 .19867 L
.11518 .19872 L
.11632 .19878 L
.11843 .19892 L
.12328 .19937 L
.12776 .19989 L
.13731 .20123 L
.14649 .20267 L
.15627 .20432 L
.16568 .206 L
.17569 .20789 L
Mistroke
.18533 .20979 L
.1946 .21172 L
.20447 .21388 L
.21397 .21607 L
.22406 .21853 L
.23379 .22103 L
.24314 .22358 L
.2531 .22645 L
.26268 .22938 L
.2719 .23238 L
.28171 .23578 L
.29116 .23927 L
.3012 .24324 L
.31087 .24736 L
.32017 .25162 L
.33007 .25652 L
.3396 .26165 L
.34877 .267 L
.35853 .27325 L
.36792 .27989 L
.37791 .28775 L
.38752 .29628 L
.39677 .3056 L
.40662 .31706 L
.4161 .33013 L
.42617 .34716 L
.43588 .3683 L
.44521 .39606 L
.45004 .41492 L
.45515 .43934 L
.46434 .49229 L
.46697 .50682 L
.46946 .51895 L
.47189 .52861 L
.47296 .53208 L
.47414 .53531 L
.47519 .53764 L
.47632 .53954 L
.47695 .54031 L
.47722 .54059 L
.47752 .54085 L
.47779 .54103 L
.47807 .54119 L
.47837 .54132 L
.47865 .54139 L
.47881 .54141 L
.47898 .54142 L
.47928 .5414 L
.47945 .54137 L
.47961 .54132 L
Mistroke
.47978 .54125 L
.47997 .54116 L
.48031 .54095 L
.48062 .5407 L
.48122 .54006 L
.4818 .53924 L
.48234 .53831 L
.48356 .53554 L
.48479 .5318 L
.48612 .52664 L
.48854 .51432 L
.49305 .48326 L
.503 .40872 L
.50795 .37662 L
.51257 .35173 L
.51702 .33302 L
.52178 .31863 L
.52425 .31329 L
.52694 .30892 L
.52817 .30737 L
.52947 .306 L
.53069 .30497 L
.53182 .30421 L
.53292 .30363 L
.53409 .30318 L
.5347 .30302 L
.53526 .3029 L
.53558 .30284 L
.53588 .3028 L
.53604 .30279 L
.53622 .30277 L
.53637 .30276 L
.53654 .30275 L
.53682 .30274 L
.53707 .30274 L
.53738 .30274 L
.53766 .30275 L
.53795 .30277 L
.53827 .3028 L
.53885 .30288 L
.53938 .30297 L
.53995 .3031 L
.54097 .30339 L
.54228 .30387 L
.54347 .30441 L
.54618 .30593 L
.55107 .30961 L
.56066 .31948 L
.56988 .33182 L
.5797 .34839 L
Mistroke
.58915 .36909 L
.59397 .3823 L
.59919 .39961 L
.60887 .44315 L
.61358 .47002 L
.61878 .50029 L
.62115 .5127 L
.6237 .52409 L
.62493 .5287 L
.62611 .53247 L
.62724 .53552 L
.62831 .53783 L
.6289 .53886 L
.62953 .53978 L
.63011 .54044 L
.63064 .5409 L
.63093 .54109 L
.63121 .54123 L
.63151 .54133 L
.63168 .54137 L
.63184 .54139 L
.63215 .54139 L
.63233 .54137 L
.63249 .54134 L
.63279 .54123 L
.63311 .54107 L
.63339 .54088 L
.63364 .54068 L
.6342 .54008 L
.6347 .5394 L
.63523 .53852 L
.63635 .53611 L
.63757 .53258 L
.64006 .52239 L
.64232 .50965 L
.6474 .47311 L
.65709 .40134 L
.66153 .37333 L
.66641 .3479 L
.67123 .32891 L
.67386 .32105 L
.67633 .31519 L
.67885 .31057 L
.68124 .30732 L
.68339 .30523 L
.68461 .30437 L
.68574 .30374 L
.68697 .30325 L
.68766 .30305 L
.68799 .30297 L
Mistroke
.6883 .30291 L
.6886 .30287 L
.68886 .30283 L
.68916 .3028 L
.68948 .30278 L
.68978 .30276 L
.68996 .30276 L
.69012 .30276 L
.69041 .30276 L
.69072 .30278 L
.691 .3028 L
.69125 .30282 L
.69183 .3029 L
.69233 .30299 L
.69286 .3031 L
.694 .30342 L
.69523 .30387 L
.69773 .30508 L
.69999 .30649 L
.70507 .31051 L
.71478 .32084 L
.72411 .33369 L
.73404 .35101 L
.7436 .37287 L
.7528 .40189 L
.75752 .42152 L
.76259 .44709 L
.76738 .47481 L
.7726 .50483 L
.77503 .51695 L
.77761 .52759 L
.77982 .53446 L
.78107 .53737 L
.78168 .53851 L
.78225 .53941 L
.78285 .54017 L
.78339 .54071 L
.78369 .54095 L
.78399 .54112 L
.78429 .54127 L
.78447 .54132 L
.78463 .54136 L
.78493 .5414 L
.78521 .54139 L
.78552 .54133 L
.78569 .54127 L
.78585 .54121 L
.78616 .54103 L
.78651 .54078 L
.78714 .54015 L
Mistroke
.78773 .53935 L
.78826 .53844 L
.78946 .5358 L
.79057 .53254 L
.79162 .52874 L
.79399 .51748 L
.79649 .5019 L
.80097 .46866 L
.81017 .40069 L
.8153 .36884 L
.81997 .34531 L
.8223 .33575 L
.82482 .32695 L
.82941 .31499 L
.83169 .3108 L
.8342 .30735 L
.83547 .30603 L
.83683 .30489 L
.83812 .30406 L
.83874 .30374 L
.8393 .30349 L
.83985 .30329 L
.84045 .3031 L
.84108 .30295 L
.84136 .3029 L
.84168 .30285 L
.84194 .30282 L
.84223 .30279 L
.84254 .30277 L
.84283 .30276 L
.84311 .30276 L
.84338 .30276 L
.84362 .30277 L
.84389 .30279 L
.84405 .3028 L
.84423 .30282 L
.84455 .30286 L
.84515 .30295 L
.84585 .3031 L
.84649 .30327 L
.84891 .30417 L
.85127 .3054 L
.85348 .30683 L
.85849 .3109 L
.86794 .32106 L
.87798 .33506 L
.88765 .35226 L
.89696 .37385 L
.90167 .38763 L
.90686 .40602 L
Mistroke
.9164 .45165 L
.92149 .48147 L
.92616 .5078 L
.92846 .51893 L
.93097 .52889 L
.93212 .53256 L
.93334 .53581 L
.9345 .53821 L
.93555 .53983 L
.93611 .54046 L
.93673 .54098 L
.93704 .54116 L
.93721 .54124 L
.93737 .5413 L
.93769 .54137 L
.93798 .5414 L
.93825 .54138 L
.93853 .54132 L
.93878 .54123 L
.93905 .5411 L
.93934 .54091 L
.93965 .54065 L
.94021 .54004 L
.94082 .53918 L
.94149 .53798 L
.94284 .53473 L
.94409 .5307 L
.94526 .52603 L
.9478 .5127 L
.95021 .49676 L
.95472 .46279 L
.96404 .39488 L
.97395 .34108 L
.97619 .33241 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.186047 0.618034 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -8 -15.6875 ]
[.21429 -0.0125 8 0 ]
[.40476 -0.0125 -8 -15.6875 ]
[.40476 -0.0125 8 0 ]
[.59524 -0.0125 -8 -15.6875 ]
[.59524 -0.0125 8 0 ]
[.78571 -0.0125 -8 -15.6875 ]
[.78571 -0.0125 8 0 ]
[.97619 -0.0125 -11 -15.6875 ]
[.97619 -0.0125 11 0 ]
[-0.0125 .18605 -10 -7.84375 ]
[-0.0125 .18605 0 7.84375 ]
[-0.0125 .29488 -19 -7.84375 ]
[-0.0125 .29488 0 7.84375 ]
[-0.0125 .37209 -10 -7.84375 ]
[-0.0125 .37209 0 7.84375 ]
[-0.0125 .48092 -10 -7.84375 ]
[-0.0125 .48092 0 7.84375 ]
[-0.0125 .61803 -10 -7.84375 ]
[-0.0125 .61803 0 7.84375 ]
[.5 .63053 -11.1563 0 ]
[.5 .63053 11.1563 15.6875 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .18605 m
.00625 .18605 L
s
gsave
-0.0125 .18605 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .29488 m
.00625 .29488 L
s
gsave
-0.0125 .29488 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
78.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .37209 m
.00625 .37209 L
s
gsave
-0.0125 .37209 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .48092 m
.00625 .48092 L
s
gsave
-0.0125 .48092 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .21163 m
.00375 .21163 L
s
0 .23498 m
.00375 .23498 L
s
0 .25647 m
.00375 .25647 L
s
0 .27636 m
.00375 .27636 L
s
0 .3122 m
.00375 .3122 L
s
0 .32847 m
.00375 .32847 L
s
0 .34381 m
.00375 .34381 L
s
0 .35833 m
.00375 .35833 L
s
0 .55814 m
.00375 .55814 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -72.1563 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Br) show
75.063 11.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
81.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .18605 m
.02435 .22666 L
.02494 .26162 L
.02599 .31112 L
.02723 .35503 L
.02837 .3856 L
.02955 .4109 L
.03084 .4328 L
.03318 .46228 L
.0344 .47393 L
.03575 .4845 L
.03707 .49297 L
.03849 .50045 L
.03981 .50618 L
.04102 .51054 L
.04339 .51712 L
.04455 .51955 L
.04578 .5217 L
.04799 .52457 L
.04935 .52581 L
.05063 .52668 L
.05178 .52725 L
.05242 .52749 L
.05302 .52766 L
.05361 .5278 L
.05416 .52789 L
.05446 .52792 L
.05461 .52794 L
.05478 .52795 L
.05509 .52797 L
.05538 .52798 L
.05564 .52798 L
.05592 .52797 L
.05618 .52796 L
.05642 .52794 L
.05669 .52792 L
.05699 .52789 L
.05758 .52781 L
.05824 .52769 L
.05883 .52755 L
.06017 .52717 L
.06259 .52625 L
.06724 .52382 L
.07228 .52054 L
.0822 .51309 L
.09175 .50534 L
.10094 .49769 L
.11072 .48946 L
.12013 .48151 L
.13014 .47304 L
Mistroke
.13978 .46488 L
.14905 .45703 L
.15891 .44867 L
.16841 .44061 L
.1785 .43205 L
.18823 .4238 L
.19759 .41586 L
.20754 .4074 L
.21713 .39926 L
.22634 .39142 L
.23616 .38307 L
.2456 .37502 L
.25564 .36646 L
.26531 .35821 L
.27462 .35025 L
.28452 .34177 L
.29405 .33359 L
.30321 .32571 L
.31297 .31729 L
.32236 .30917 L
.33235 .30049 L
.34197 .29208 L
.35122 .28395 L
.36107 .27522 L
.37054 .26672 L
.38062 .25757 L
.39032 .24857 L
.39966 .23968 L
.40959 .22985 L
.41916 .21981 L
.42835 .20924 L
.43815 .1961 L
.44757 .17938 L
.45271 .16675 L
.45759 .15103 L
.462 .13369 L
.46451 .12355 L
.46687 .11509 L
.468 .11178 L
.46918 .10899 L
.4698 .10786 L
.47012 .10736 L
.47047 .1069 L
.4708 .10656 L
.47109 .1063 L
.47138 .10611 L
.47166 .10598 L
.47196 .10591 L
.47212 .1059 L
.47228 .10591 L
Mistroke
.47259 .10598 L
.47277 .10605 L
.47293 .10614 L
.47322 .10634 L
.47353 .10663 L
.4741 .10735 L
.47477 .1085 L
.47548 .11008 L
.47675 .11381 L
.47925 .1242 L
.48195 .13932 L
.48684 .17423 L
.49158 .21044 L
.49409 .2262 L
.49678 .23919 L
.49938 .24835 L
.50174 .25442 L
.50288 .2567 L
.50411 .25879 L
.50636 .26168 L
.50754 .26279 L
.50864 .26361 L
.50985 .26431 L
.51048 .26459 L
.51116 .26484 L
.51183 .26503 L
.51245 .26516 L
.5128 .26522 L
.51311 .26526 L
.51329 .26528 L
.51347 .2653 L
.51365 .26531 L
.51382 .26532 L
.51411 .26533 L
.51427 .26533 L
.51443 .26533 L
.51461 .26533 L
.51477 .26533 L
.51508 .26531 L
.51537 .26529 L
.51564 .26527 L
.51625 .26519 L
.5169 .26508 L
.51749 .26495 L
.51882 .26459 L
.52124 .26368 L
.52576 .26132 L
.53535 .25452 L
.54457 .24674 L
.55439 .23771 L
Mistroke
.56384 .22845 L
.57388 .21786 L
.58356 .20649 L
.59287 .19345 L
.59758 .18538 L
.60277 .17442 L
.60769 .1609 L
.61231 .14461 L
.6168 .12645 L
.61917 .1175 L
.62048 .11331 L
.6217 .11008 L
.62237 .10867 L
.6231 .10745 L
.62342 .10702 L
.62375 .10664 L
.62407 .10636 L
.62436 .10616 L
.62465 .10603 L
.62497 .10595 L
.62526 .10594 L
.62553 .10599 L
.62569 .10604 L
.62586 .10612 L
.62615 .10631 L
.62647 .10659 L
.62682 .10698 L
.62746 .10792 L
.62803 .10904 L
.62934 .11245 L
.63048 .11642 L
.63169 .12151 L
.63648 .14927 L
.64093 .18266 L
.64547 .21629 L
.64803 .23107 L
.65039 .24152 L
.6529 .24981 L
.65428 .25332 L
.65556 .25606 L
.65789 .25987 L
.65912 .26138 L
.66045 .26267 L
.66172 .26363 L
.6629 .2643 L
.66357 .2646 L
.6642 .26482 L
.66492 .26503 L
.66524 .26509 L
.66558 .26516 L
Mistroke
.66587 .2652 L
.66617 .26524 L
.66634 .26526 L
.6665 .26527 L
.6668 .26529 L
.66708 .2653 L
.66738 .26531 L
.66766 .26531 L
.66792 .2653 L
.66822 .26528 L
.66851 .26526 L
.66882 .26522 L
.66915 .26518 L
.66983 .26507 L
.67045 .26494 L
.6716 .26464 L
.67283 .26423 L
.67505 .2633 L
.68007 .2605 L
.69014 .25307 L
.69984 .24469 L
.70918 .23599 L
.7191 .22612 L
.72867 .21585 L
.73786 .20481 L
.74765 .19054 L
.75216 .1823 L
.75707 .17117 L
.76221 .1559 L
.76709 .13746 L
.77178 .11885 L
.77306 .11453 L
.77445 .11066 L
.77509 .10922 L
.77576 .10796 L
.77634 .10711 L
.77666 .10673 L
.77696 .10644 L
.77727 .10621 L
.77743 .10612 L
.7776 .10604 L
.77789 .10596 L
.77821 .10594 L
.77849 .10598 L
.77879 .10609 L
.77908 .10626 L
.77934 .10647 L
.77997 .10718 L
.78032 .10771 L
.78065 .10828 L
Mistroke
.78189 .11117 L
.78305 .11485 L
.78411 .11897 L
.78647 .13058 L
.79114 .16122 L
.79619 .20027 L
.79869 .21776 L
.80102 .23107 L
.80346 .24181 L
.80613 .25045 L
.80734 .25349 L
.80866 .25627 L
.80983 .25831 L
.81106 .26011 L
.81217 .26145 L
.8134 .26264 L
.81443 .26344 L
.81556 .26413 L
.81676 .26467 L
.81741 .26489 L
.81801 .26505 L
.81858 .26516 L
.8191 .26523 L
.81938 .26526 L
.81969 .26529 L
.81998 .2653 L
.82025 .26531 L
.82055 .26531 L
.82086 .2653 L
.82115 .26528 L
.82142 .26526 L
.82174 .26523 L
.82208 .26519 L
.82271 .26509 L
.82406 .26479 L
.82531 .26441 L
.82788 .26337 L
.8303 .26214 L
.83481 .25935 L
.84417 .25221 L
.85413 .24352 L
.86371 .23449 L
.87293 .22526 L
.88275 .21462 L
.89219 .20304 L
.89701 .19627 L
.90224 .18779 L
.90684 .17878 L
.91191 .16617 L
.91671 .15056 L
Mistroke
.92181 .13037 L
.92422 .12085 L
.92651 .11315 L
.92777 .10988 L
.92844 .1085 L
.92915 .10734 L
.92949 .10691 L
.92981 .10657 L
.9301 .10632 L
.93041 .10613 L
.9307 .106 L
.93101 .10594 L
.93128 .10594 L
.93157 .10601 L
.93189 .10615 L
.93218 .10635 L
.9325 .10664 L
.93284 .10703 L
.93341 .10788 L
.93404 .10911 L
.9352 .11211 L
.9363 .11579 L
.93874 .12669 L
.94137 .14201 L
.94612 .17649 L
.94864 .1962 L
.95133 .21553 L
.95394 .2307 L
.9563 .24126 L
.95868 .24924 L
.96093 .25482 L
.96329 .25904 L
.96447 .26065 L
.96578 .26208 L
.96689 .26305 L
.96809 .26387 L
.96922 .26446 L
.97025 .26484 L
.97097 .26504 L
.97136 .26512 L
.97173 .26519 L
.97207 .26523 L
.97225 .26525 L
.97244 .26527 L
.9726 .26528 L
.97278 .26529 L
.97309 .26531 L
.9733 .26531 L
.9735 .26531 L
.97367 .2653 L
Mistroke
.97387 .2653 L
.97408 .26529 L
.9743 .26527 L
.9747 .26524 L
.97506 .26519 L
.97541 .26514 L
.97619 .26499 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.686966 0.228989 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -8 -15.6875 ]
[.21429 -0.0125 8 0 ]
[.40476 -0.0125 -8 -15.6875 ]
[.40476 -0.0125 8 0 ]
[.59524 -0.0125 -8 -15.6875 ]
[.59524 -0.0125 8 0 ]
[.78571 -0.0125 -8 -15.6875 ]
[.78571 -0.0125 8 0 ]
[.97619 -0.0125 -11 -15.6875 ]
[.97619 -0.0125 11 0 ]
[-0.0125 .16006 -31 -7.84375 ]
[-0.0125 .16006 0 7.84375 ]
[-0.0125 .22899 -25 -7.84375 ]
[-0.0125 .22899 0 7.84375 ]
[-0.0125 .38905 -25 -7.84375 ]
[-0.0125 .38905 0 7.84375 ]
[-0.0125 .45798 -19 -7.84375 ]
[-0.0125 .45798 0 7.84375 ]
[-0.0125 .61803 -19 -7.84375 ]
[-0.0125 .61803 0 7.84375 ]
[.5 .63053 -19.0625 0 ]
[.5 .63053 19.0625 15.6875 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16006 m
.00625 .16006 L
s
gsave
-0.0125 .16006 -92 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
90.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .22899 m
.00625 .22899 L
s
gsave
-0.0125 .22899 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
84.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .38905 m
.00625 .38905 L
s
gsave
-0.0125 .38905 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
84.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .45798 m
.00625 .45798 L
s
gsave
-0.0125 .45798 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
78.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
78.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .06893 m
.00375 .06893 L
s
0 .10926 m
.00375 .10926 L
s
0 .13787 m
.00375 .13787 L
s
0 .17819 m
.00375 .17819 L
s
0 .19352 m
.00375 .19352 L
s
0 .2068 m
.00375 .2068 L
s
0 .21851 m
.00375 .21851 L
s
0 .29792 m
.00375 .29792 L
s
0 .33824 m
.00375 .33824 L
s
0 .36685 m
.00375 .36685 L
s
0 .40718 m
.00375 .40718 L
s
0 .42251 m
.00375 .42251 L
s
0 .43579 m
.00375 .43579 L
s
0 .4475 m
.00375 .4475 L
s
0 .52691 m
.00375 .52691 L
s
0 .56723 m
.00375 .56723 L
s
0 .59584 m
.00375 .59584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -80.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(HBrO) show
92.313 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
97.125 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02402 0 m
.02409 .26341 L
.02435 .30744 L
.02465 .3159 L
.02494 .30681 L
.02545 .28127 L
.02599 .26079 L
.02627 .25322 L
.02658 .24652 L
.02713 .23743 L
.02777 .22963 L
.02837 .22407 L
.02899 .21953 L
.02958 .21603 L
.03068 .21094 L
.03188 .20694 L
.03318 .20371 L
.03452 .2012 L
.03574 .19944 L
.03715 .19785 L
.03847 .19667 L
.04083 .19513 L
.04217 .1945 L
.04339 .19402 L
.04453 .19366 L
.04575 .19334 L
.04681 .19312 L
.04795 .19292 L
.0493 .19274 L
.05057 .19261 L
.05118 .19257 L
.05181 .19253 L
.05236 .1925 L
.05296 .19247 L
.05354 .19245 L
.05383 .19244 L
.05415 .19244 L
.05444 .19243 L
.05471 .19243 L
.05498 .19242 L
.05523 .19242 L
.05553 .19242 L
.05585 .19242 L
.05611 .19242 L
.05641 .19243 L
.05673 .19243 L
.05707 .19243 L
.05768 .19245 L
.05825 .19246 L
.05887 .19248 L
Mistroke
.06 .19253 L
.06211 .19264 L
.06689 .19299 L
.07198 .19346 L
.08207 .1946 L
.0918 .19584 L
.10116 .19711 L
.11111 .19854 L
.1207 .19998 L
.12991 .20143 L
.13973 .20305 L
.14917 .20469 L
.15921 .20651 L
.16888 .20835 L
.17819 .21022 L
.18809 .2123 L
.19762 .21441 L
.20678 .21655 L
.21654 .21894 L
.22593 .22138 L
.23592 .22412 L
.24554 .22692 L
.25479 .22977 L
.26463 .233 L
.27411 .23631 L
.28419 .24007 L
.29389 .24396 L
.30323 .24797 L
.31316 .25257 L
.32273 .25736 L
.33192 .26235 L
.34172 .26814 L
.35114 .27424 L
.36116 .28142 L
.37081 .28913 L
.38009 .29745 L
.38997 .30751 L
.39948 .31872 L
.40863 .33138 L
.41837 .34768 L
.42774 .36745 L
.4325 .37973 L
.4377 .39565 L
.4473 .43494 L
.45205 .46079 L
.45713 .49268 L
.46195 .52304 L
.46449 .53672 L
.46588 .54301 L
.46718 .54798 L
Mistroke
.46843 .55184 L
.46958 .5545 L
.47023 .55564 L
.47085 .55646 L
.47119 .5568 L
.4715 .55705 L
.47168 .55716 L
.47185 .55724 L
.47204 .55731 L
.47222 .55735 L
.47249 .55737 L
.47278 .55734 L
.47309 .55723 L
.47338 .55708 L
.47365 .55688 L
.4739 .55665 L
.47445 .55597 L
.47504 .555 L
.47569 .55364 L
.47686 .55033 L
.47804 .5459 L
.47914 .54065 L
.48046 .53287 L
.48166 .5241 L
.48411 .50037 L
.4854 .48411 L
.48676 .46375 L
.48925 .4189 L
.4916 .37649 L
.49371 .3478 L
.4949 .33602 L
.496 .32738 L
.49831 .31414 L
.49948 .30931 L
.50076 .30502 L
.50202 .30161 L
.50338 .2987 L
.50584 .2949 L
.50711 .29351 L
.50829 .29251 L
.50959 .29168 L
.51026 .29135 L
.51097 .29105 L
.51166 .29083 L
.51229 .29067 L
.5129 .29056 L
.5132 .29052 L
.51353 .29048 L
.51383 .29046 L
.51411 .29044 L
Mistroke
.51443 .29043 L
.51473 .29043 L
.51501 .29044 L
.51527 .29045 L
.51555 .29046 L
.51585 .29049 L
.51646 .29056 L
.51704 .29065 L
.51813 .29088 L
.5193 .29121 L
.52058 .29165 L
.52502 .29377 L
.52978 .29684 L
.53487 .30082 L
.54494 .31049 L
.55465 .32194 L
.564 .33525 L
.57393 .35273 L
.5835 .37442 L
.59271 .40265 L
.59743 .42152 L
.6025 .4463 L
.61253 .50809 L
.61496 .52299 L
.61754 .53688 L
.61975 .54636 L
.621 .55056 L
.62218 .55362 L
.62277 .55482 L
.62332 .55573 L
.62389 .55646 L
.62419 .55676 L
.62452 .55702 L
.62479 .55717 L
.62509 .55729 L
.62537 .55734 L
.62564 .55733 L
.62587 .55729 L
.62613 .55719 L
.6264 .55704 L
.62665 .55686 L
.62695 .55658 L
.62728 .5562 L
.62787 .55531 L
.62844 .5542 L
.62898 .55294 L
.63019 .54927 L
.63147 .54402 L
.63277 .5372 L
.63397 .52943 L
Mistroke
.63526 .51922 L
.63667 .50547 L
.63905 .47499 L
.64156 .43217 L
.6442 .38339 L
.6455 .36323 L
.6467 .34817 L
.64894 .32796 L
.65012 .32038 L
.65137 .31396 L
.65249 .30935 L
.65369 .3053 L
.65586 .29979 L
.65712 .29742 L
.65845 .29544 L
.65969 .29398 L
.66081 .29293 L
.66201 .29206 L
.66313 .29144 L
.66432 .29096 L
.66499 .29077 L
.66561 .29064 L
.66586 .29059 L
.66614 .29055 L
.66638 .29052 L
.66664 .2905 L
.66694 .29047 L
.66723 .29046 L
.66751 .29045 L
.66777 .29045 L
.66804 .29046 L
.6683 .29047 L
.66858 .29049 L
.66888 .29051 L
.6695 .29059 L
.67006 .29068 L
.67121 .29092 L
.67243 .29127 L
.67464 .2921 L
.67966 .29476 L
.68482 .29837 L
.68971 .30243 L
.69902 .31167 L
.70893 .32363 L
.71847 .33761 L
.72765 .35417 L
.73741 .37685 L
.74682 .40679 L
.75194 .4284 L
.75681 .4536 L
Mistroke
.76607 .51159 L
.76873 .52748 L
.77124 .5402 L
.77349 .54899 L
.77476 .55265 L
.77532 .55395 L
.77593 .55511 L
.77652 .55603 L
.77706 .55665 L
.77733 .55688 L
.77761 .55708 L
.77788 .55722 L
.77813 .5573 L
.77841 .55734 L
.77868 .55733 L
.77898 .55725 L
.7793 .5571 L
.77961 .55688 L
.77995 .55657 L
.78054 .55582 L
.78112 .55483 L
.78175 .55348 L
.78287 .55031 L
.7842 .5452 L
.78541 .53919 L
.78659 .532 L
.78784 .52272 L
.79007 .50096 L
.79247 .46844 L
.79511 .42166 L
.79753 .37776 L
.79983 .34664 L
.80109 .33447 L
.80247 .32425 L
.80373 .31703 L
.80489 .31167 L
.80613 .30706 L
.80746 .30308 L
.80864 .30025 L
.80988 .29783 L
.811 .29605 L
.81223 .29447 L
.81327 .2934 L
.81439 .29247 L
.81567 .29167 L
.81625 .29138 L
.81687 .29112 L
.81743 .29092 L
.81805 .29075 L
.81861 .29063 L
Mistroke
.81913 .29055 L
.81944 .29051 L
.81961 .2905 L
.81979 .29048 L
.81995 .29047 L
.82011 .29046 L
.82041 .29046 L
.8207 .29045 L
.82101 .29046 L
.8213 .29047 L
.82157 .29049 L
.82189 .29052 L
.82218 .29055 L
.82285 .29064 L
.82351 .29076 L
.82421 .29092 L
.82667 .29171 L
.82935 .2929 L
.83423 .29578 L
.84411 .3037 L
.85362 .31346 L
.86277 .32476 L
.87251 .33932 L
.88188 .35672 L
.89185 .38081 L
.89682 .39612 L
.90145 .41322 L
.91068 .45866 L
.92014 .51823 L
.92262 .53232 L
.92392 .53879 L
.92531 .54475 L
.92652 .54911 L
.92785 .55289 L
.92843 .55419 L
.92906 .55535 L
.92965 .55621 L
.93019 .55678 L
.9305 .55702 L
.9308 .55719 L
.93106 .55729 L
.93135 .55734 L
.93166 .55733 L
.93182 .5573 L
.93199 .55724 L
.9323 .5571 L
.93258 .5569 L
.93287 .55664 L
.93314 .55634 L
.93365 .55563 L
Mistroke
.9342 .55465 L
.9348 .55333 L
.93607 .54961 L
.93741 .54422 L
.93856 .53833 L
.93982 .53032 L
.94228 .50942 L
.94452 .48238 L
.94698 .44247 L
.94958 .39396 L
.95189 .3576 L
.95319 .3427 L
.95437 .33211 L
.95547 .32421 L
.95666 .31732 L
.95882 .30806 L
.96001 .30429 L
.96112 .3014 L
.96244 .2986 L
.96365 .29655 L
.96482 .29494 L
.96611 .29354 L
.96746 .29241 L
.96875 .29162 L
.96972 .29117 L
.97064 .29086 L
.97147 .29066 L
.97193 .29058 L
.97235 .29052 L
.97258 .2905 L
.97282 .29048 L
.97304 .29047 L
.97325 .29046 L
.97349 .29045 L
.97375 .29045 L
.97399 .29046 L
.97422 .29047 L
.97446 .29048 L
.97468 .2905 L
.97518 .29055 L
.97567 .29061 L
.97619 .2907 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{248.75, 491.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005e0002hB000`400?l00000o`00003oo`3ooomf
0?ooo`00o`3ooomf0?ooo`00V`3oool00`3ooml0W4Q809cOo`150?ooo`030?oOW018B9`0gooo08l0
oooo002K0?ooo`030;mdB02Lgol0oooo04H0oooo00<0omnL04Qd_`3oool0SP3oool009X0oooo00<0
gia804RLg`3oool0B03oool00`3OW4P0B9cO0?ooo`2=0?ooo`00V@3oool00`3ookl0M01d0;ooo`19
0?ooo`030?oo_`1d04P0W=oo08d0oooo002:0?ooo`040?noM0000000001809cOo`/0oooo00<0gia8
0018W03Oool00P3oool02`3ogi`0B000000000000000M;oo0=nLB000000004RL0=ooo`2oM00007Bo
00H0oooo00D0gia8000000000000001809cOo`030?ooo`030?oOW0180000M;oo00H0oooo00`0omnL
04P00000000004RL0=ooo`2oM0000000001d_`3oool0gia80018W03Oool20?ooo`030;md00000000
07Bo0080oooo00/0_g@00000000004P0W=oo0?ooo`3o_g@000000000B02Lgol0oono07@000030000
000704RLg`3oool0oooo0?ooo`3ooml0W4P004RLg`2=0?ooo`00RP3oool01@3o_g@0001809cOg`2L
M9`0gooo00X0oooo00<0_g@0001d_`3oool00P3oool0302oM00004RL0=ooo`3oool0_g@007AdM000
07@0_mnL09boo`3o_g@0001d0;ooo`@0oooo00L0omnL04P0M02oool0oooo0?oo_`1d0000B9cO0080
oooo00<0omnL04P0001d_ol01P3oool0303ogi`0B01809cOo`3ogi`0B7Bo0;md0000M;l0oknL09cO
o`3o_g@0001d0;ooo`80oooo01D0gia80018W03O_g@0M;oo0?ooo`3OW4P004RL0=oog`2LM9`0gooo
0?noM00004P0W=oO09adW03Ooml0W4P007Boo`3oool0omnL04P0001d_ol00`3oool00`3OW4P004RL
0=ooo`2<0?ooo`00RP3oool00`3ookl0M00007Boo`0;0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
_g@0001d_`3oool00P3oool01`2oM000000007Boo`3oool0omnL04P0001d_ol0103oool00`3ookl0
M00007Boo`020?ooo`030?oo_`1d0000M;oo00X0oooo00`0oooO09a80018W=l0oooo0?noM01dM7@0
04RL0=ooo`3oool0oono07@00018W=l20?ooo`030?oOW01804P0W=oo0080oooo00<0okmd0000B02L
gol00P3oool00`3ookl0M00007Boo`020?ooo`060;mdM02oool0oooo0?oo_`1d0000M;oo0`3oool0
0`3OW4P0001d0;ooo`2<0?ooo`00R`3oool00`2oM00007Bo0?ooo`0:0?ooo`030?oo_`1d0000M;oo
00<0oooo00<0okmd0000M02oool00P3oool0203ookl0M00004RLg`3oool0oooO09a80000B9`0gooo
103oool00`2oM000B9cO0?ooo`020?ooo`030=nLB000B9`0gooo00X0oooo0100_g@00018W03Oool0
oooo0;md000004P0W=oo0?ooo`3ooml0W4P00000M02oool0oooo0?oog`2LB000B9cO0P3oool00`3o
okl0M00004RLg`030?ooo`030;md0000M;l0oooo00@0oooo00<0gia80000M02oool00`3oool00`3o
_g@0001d0;ooo`2<0?ooo`00R`3oool00`3OW4P004RL0=ooo`0:0?ooo`030?oo_`1d0000M;oo00<0
oooo00<0oono07@0001d_ol00`3oool01`2oM00004RL0=ooo`3oool0_g@004QdM01dW=l0103oool0
0`3OW4P004RL0=ooo`020?ooo`030?oOW01804P0W=oo00X0oooo00L0okmd0000M02oool0oooo0?oo
_`1d0000M;oo0080oooo00<0gia80018B018M;l00P3oool00`2oM00007Bo0?ooo`020?ooo`030;md
0000B9`0gooo0080oooo00<0gia80018W03Oool00`3oool00`3o_g@0001809cOo`040?ooo`030?no
M00004P0W=oo08`0oooo002;0?ooo`030?oOW01804P0W=oo00X0oooo00<0oono07@0001d_ol0103o
ool00`3o_g@0001d0;ooo`020?ooo`080=nLB00007@0_ooo0?ooo`3o_g@004RL0;nLB01d_ol30?oo
o`030?oOW01804P0M;oO0080oooo00<0oono07@0001d_ol02@3oool0103ogml0gono07@0001d_ol2
0?ooo`0<0;md0000M;l0oooo0?ooo`3o_g@0001d0;noM018W=l0oooo0?noM00007@0_ooo0P3oool0
0`3OW4P0001809cOo`020?ooo`030?oOW01804P0W=oo0080oooo00H0omnL04P0B02Lgol0oooo0=nL
M02Lgol20?ooo`030?noM00007@0_ooo08`0oooo002;0?ooo`030?oog`2LB000B9cO00X0oooo00<0
oono07@00018W=l01@3oool05`3OW4P0001d0;ooo`3oool0_g@00000B02Lgol0oooo0?oo_`1d04P0
W=oo0;md001dM7@004RL0=ooo`3ookl0M00004Q8B018W=l0oooo0?noM00004P0W=oo00T0oooo00@0
omnL04Qd_`2oM00007Bo0P3oool0303o_g@004RL0=ooo`3oool0oooO09a8001d_ol0gia8001d_`3o
gi`0B01809cOo`80oooo00<0omnL04P00018W=l00P3oool00`3ooml0W4P004RLg`020?ooo`060?oO
W01804P0W=oo0?oog`2LB000M;oo0P3oool00`3OW4P0001d0;ooo`2<0?ooo`00RP3oool00`3ookl0
M000000000020000000307Boo`3oool0oooo00H0oooo00<0oooO09a80018W=l01P3oool04P3ogi`0
B00000000018W9`0M00004RLg`3ogi`0B0000000001d_ol0oooo0;md000007@0_ooo0?ooo`2oM000
07Bo0=nLB080000000<0B9cO0?ooo`3oool02@3oool00`3o_g@00000001d_`020?ooo`0>0?oOW018
04P0W=oo0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo0?ooo`3o_g@2000000040018
W03Oool0oono07@000<0000000<0M;oo0?ooo`2oM0000`0000001P18W=l0oooo0?ooo`3OW4P004RL
0=oooh`0oooo002<0?ooo`030?noM00007@0_ooo00X0oooo00<0gia80018W03Oool0503oool00`3O
W4P004RL0=ooo`0W0?ooo`030?noM00007@0_ooo00P0oooo00<0oooO09a80018W=l0S@3oool008d0
oooo00<0giad09cOo`3oool02@3oool00`3ookl0M01809cOo`0D0?ooo`030?oOW01804P0W=oo02P0
oooo00<0giad09cOo`3oool01`3oool00`3ookl0M01809cOo`2=0?ooo`00VP3oool00`3OW4P0B9cO
0?ooo`0C0?ooo`030?oo_`1d0000B9cO0280oooo00@0oono07@00000B9`0gooo303oool00`3OW4P0
B9cO0?ooo`2=0?ooo`00V`3oool00`2oM000B9cO0?ooo`0C0?ooo`030=nLB000M;l0oooo0300oooo
00<0okmd001d_`3oool0SP3oool009`0oooo00<0giad09cOo`3oool0403oool01@3ooml0W4P00000
000007@0_ooo02l0oooo00<0oono07Ad_`3oool0S`3oool00?l0ooooMP3oool00?l0ooooMP3oool0
0?l0ooooMP3oool00?l0ooooMP3oool00?l0ooooMP3oool00?l0ooooMP3oool00?l0ooooMP3oool0
0?l0ooooMP3oool000d0ooooo`00001K000000h0oooo000=0?ooo`030000003oool0oooo0?l0oooo
E`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<0
00000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o
0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000
oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=
0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`00
0000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3o
ool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0oooo
E`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<0
00000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`17
0?ooo`040;md00000000000007Boob@0oooo00<0gia80000000000000`0000000`18W=l0oooo0?oo
o`020?ooo`040;md00000000000007Boob80oooo00<0oooO09a80018W=l01@3oool0102oM0000000
0000001d_olP0?ooo`050?oog`2LB000000000000000M;l01@3oool0102oM00000000000001d_olP
0?ooo`060?oo_`1d0000000000000000B9`0gooo103oool0102oM00000000000001d_olK0?ooo`03
0?oo_`1d000000000080000000<0B9cO0?ooo`3oool00`3oool0102oM00000000000001d_ol50?oo
o`040;md00000000000007Booa/0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?oo
o`3oool0AP3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgb@0oooo00<0okmd001d_`3oool00P3o
ool02P2oM7@0_ooo0?ooo`3oool0gia8001d_`3oool0omnL04P00018W=lR0?ooo`030=nLB000B9`0
gooo00<0oooo00H0gia8001d_`3oool0omnL04P00018W=lO0?ooo`070=nLB000M;l0oooo0?oo_`1d
000004RL0=ooo`020?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO7P3oool00`3ookl0M00004RL
g`020?ooo`030=nLB00007@0_ooo0080oooo00H0gia8001d_`3oool0omnL04P00018W=lL0?ooo`03
0?noM0000000M;oo00D0oooo00H0gia8001d_`3oool0omnL04P00018W=l30?ooo`060=nLB000M;l0
oooo0?oOW0180000B9cO6P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`150?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0903oool00`3o_g@007Bo0?oo
o`040?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol08@3oool00`3ogi`0B01809cO
o`020?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol07@3oool00`3ooml0W4P007Bo
o`020?ooo`070?oOW0180000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo01d0
oooo00<0okmd0018W03Oool00`3oool01P2oM000B9cO0?ooo`3ooml0W4P004RLg`80oooo00<0okmd
0000B02Lgol06`3oool00`3ooml0W4P0001d_`040?ooo`030?oog`2LB000B9cO0080oooo00L0okmd
0000B02Lgol0oooo0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol06@3oool00`000000oooo
0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`150?ooo`030?oog`2LB000B9cO0080oooo00@0
oooO09a80000B9`0gooo903oool00`3o_g@007Bo0?ooo`030?ooo`030?oog`2LB000B9cO0080oooo
00@0oooO09a80000B9`0gooo703oool00`3o_g@0000000000004000000050018W03Oool0oooO09a8
0018W=l00P3oool0103ooml0W4P00018W03OoolL0?ooo`030?oo_`1d0000M;oo00<0oooo00H0_g@0
0000M02oool0oooO09a80018W=l20?ooo`040?oog`2LB00004RL0=oooa`0oooo00<0okmd0018W03O
ool00`3oool01P2oM00007Bo0?ooo`3ooml0W4P004RLg`80oooo00@0oooO09a80000B9`0gooo6`3o
ool00`3OW4P004RL0=ooo`030?ooo`030?oog`2LB000B9cO0080oooo00L0oooO09a80000B9`0gooo
0?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo603oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`150?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02L
gol09@3oool00`3o_g@0B9cO0?ooo`020?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02L
gol0703oool00`3ooml0W4Q809cOo`020?ooo`070;md0000M;l0oooo0?ooo`3ooml0W4P0001d_`03
0?ooo`030=nLB00004P0W=oo01`0oooo00<0oooO09a80000M;l00`3oool01P3OW4P0001809cOo`3o
oml0W4P0001d_`<0oooo00<0gia80000B02Lgol0703oool00`3ooml0W4P007Boo`020?ooo`070?oo
_`1d0000B9cO0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo01/0oooo00<0omnL04P0
B02Lgol00`3oool00`3ooml0W4P0001d_`030?ooo`060=nLB00004P0W=oo0?oog`2LB00007Bo0`3o
ool00`3OW4P0001809cOo`0H0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0
oooo04H0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0V0?ooo`030=nLB018W=l0
oooo0080oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0M0?ooo`070?oo_`1d07@0
_ooo0?ooo`3o_g@004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0
7@3oool00`2oM000001d0;ooo`020?ooo`070=nLB00004P0W=oo0?ooo`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO01h0oooo00H0_g@00000B02Lgml0W4P00000M02oool20?ooo`030;md0000
B9`0gooo0080oooo00<0omnL04P00018W=l06`3oool00`3ookl0M00007Boo`040?ooo`030;md0000
B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md0000B9`0gooo0080oooo00<0omnL04P00018
W=l0603oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`160?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l09`3oool01`2oM000M;oo0?ooo`3oool0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`0N0?ooo`060?oOW018B9`0gooo0?oOW01804P0W=oo0P3o
ool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo01d0oooo00`0okmd00000018W=l0oooo
0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol20?ooo`030?oog`2LB00007Bo01l0oooo00D0
oooO09a80000000004RL0=ooo`020?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0
703oool00`2oM00007Bo0?ooo`030?ooo`030=nLB00004P0W=oo0080oooo00L0oooO09a80000M;l0
oooo0=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0603oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`160?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03O
ool09P3oool01`3ogi`0B01d0;ooo`3oool0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0N
0?ooo`050?noM000M;l0oooO09a80018W=l00P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo01`0oooo00<0oooO09a8000000000P0000001`0007@0_ooo0?ooo`3oool0omnL04P00018
W=l00`3oool00`2oM00004RL0=ooo`0N0?ooo`0:0;md000004P0W=oo0?oOW018B9`0gooo0?ooo`3o
gi`0B00004RLg`<0oooo00<0_g@00018W03Oool06`3oool00`3OW4P004RL0=ooo`030?ooo`030?oO
W0180000B9cO00<0oooo00H0_g@00018W03Oool0omnL04P00018W=l30?ooo`030;md0000B9`0gooo
01L0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0AP3oool0103ooml0
W4P00018W03Oool20?ooo`030=nLB000B9`0gooo02H0oooo00P0oooO09a8001d_ol0oooo0?oog`2L
B00004RL0=ooo`80oooo00<0gia80018W03Oool07`3oool0103OW4P0B9cO0;md0000M;l20?ooo`04
0?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool07@3oool00`3ookl0M000001d_`050?oo
o`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool07@3oool00`3ogi`0B00007Boo`02
0?ooo`070?noM018W=l0oooo0?oog`2LB00004RL0=ooo`020?ooo`030=nLB000B9`0gooo01/0oooo
00<0omnL04P0B02Lgol00`3oool0103ooml0W4P00018W03Oool20?ooo`070=nLB000B9`0gooo0?oo
g`2LB00004RL0=ooo`020?ooo`030=nLB000B9`0gooo01L0oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool0A`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo
02H0oooo00<0oono07@00018W=l00P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo
0200oooo00@0gia807AdM00007@0_ooo0P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0
oooo01h0oooo00<0omnL04P00018W=l01@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0
oooo01d0oooo00<0omnL04P0B02Lgol00P3oool01`3o_g@004RL0=ooo`3oool0omnL04P0001d_ol0
0P3oool00`3OW4P007Bo0?ooo`0K0?ooo`030?oo_`1d0000M;oo00@0oooo00<0omnL04P0001d_ol0
0P3oool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0G0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04P0oooo00H0gia80000M02o
ool0oooO09a80018W=lS0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`030?ooo`060=nL
B00007@0_ooo0?oog`2LB000B9cO8P3oool00`2oM000001809cOo`030?ooo`060=nLB00007@0_ooo
0?oog`2LB000B9cO803oool0103ooml0W4P00000M02oool40?ooo`060=nLB00007@0_ooo0?oog`2L
B000B9cO7P3oool00`3ooml0W4P004RLg`020?ooo`030;md0000M;l0oooo0080oooo00H0gia80000
M02oool0oooO09a80018W=lM0?ooo`030;md0000M;l0oooo00@0oooo00H0gia80000M02oool0oooO
09a80018W=l30?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO603oool00`000000oooo0?ooo`0<
0?ooo`003@3oool00`000000oooo0?ooo`190?ooo`040=nLB00000000000001d_bD0oooo00D0omnL
04P000000000000007Boo`050?ooo`040=nLB00000000000001d_b<0oooo00<0oooO09a80018W=l0
103oool0103OW4P0000000000000M;lS0?ooo`040?oo_`1d0000000004RLg`<0oooo00@0gia80000
0000000007Bo803oool01@3ooml0W4P000000000000007Bo00D0oooo00@0gia800000000000007Bo
703oool01@3ookl0M0000000000007@0_ooo00D0oooo00@0gia800000000000007Bo1@3oool0103O
W4P0000000000000M;lI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`03
0000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03o
oooc000001l0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?oo
o`800000o`3ooolA0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo0P00003o0?oo
oa40oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool000d0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303o
ool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0
5`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo00@0oooo00@0_g@000000000
0000M;oo1@3oool0102oM00000000000001d_ol30?ooo`060?oOW0180000000000000000B9`0gooo
2@3oool200000?l0oooo4@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`0F0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`06
0=nLB000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo
00H0okmd0000001d_ol0oooo0?oOW018M;l90?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0E0?ooo`030?oog`2LB000B9cO0080
oooo00<0okmd0000B02Lgol01P3oool00`3ooml0W4P004RLg`020?ooo`070?noM00004P0W=oo0?oo
o`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0okmd04RLg`3oool01`3oool0
0`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?oo
o`3oool05@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0oooO
09a80018W=l00P3oool01`3ooml0W4P00018W03Oool0oooO09a80018W=l00P3oool0103ooml0W4P0
0018W03Oool50?ooo`030?oo_`1d07@0_ooo00L0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo01D0oooo00<0oooO09a80000M;l0
0`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB00007Bo00<0oooo00H0gia80000B02Lgol0
oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8001d_ol01`3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3o
ool05P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0_g@00018W03O
ool00P3oool01`3ogi`0B00004RLg`3oool0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`05
0?ooo`030?oo_`1d0000B9cO00L0oooo0P00003o0?oooa40oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool05P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo
00H0oooo00<0gia80000B02Lgol00P3oool01`3ooml0W4P0001d_`3oool0gia80000B02Lgol00P3o
ool00`3ooml0W4P0001d_`050?ooo`030?noM0000000M;oo00L0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo01H0oooo00<0omnL
04P00018W=l00`3oool00`2oM00004RL0=ooo`050?ooo`030?oOW0180000B9cO00<0oooo00H0_g@0
0018W03Oool0omnL04P00018W=l30?ooo`0:0;md0000B9`0gooo0?ooo`3ogml0gooo0?noM0000000
001d0;ooo`L0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo000=
0?ooo`030000003oool0oooo01H0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=oo
o`050?ooo`040?oog`2LB00004RL0=ooo`80oooo00L0gia80018W03Oool0oooO09a80000B9`0gooo
0080oooo00T0gia80018W03Oool0oooo0?oo_`1d000000000000B02Lgol0203oool00`000000oooo
0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool05`3o
ool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00H0oooo00<0omnL04P0001d_ol00P3o
ool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`020?ooo`03
0=nLW02oool0oooo00T0oooo0P00003o0?oooa40oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0603oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000
M02oool0oooO09a80018W=l30?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO0`3oool00`3ogi`0
M9cO0?ooo`090?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`0I0?ooo`040=nLB00000000000001d_`X0oooo00@0gia800000000
000007Bo1@3oool0103OW4P0000000000000M;l50?ooo`050;md00000000000000000018W=l01P3o
ool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool0A03oool200000?l0oooo4@3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01H0oooo1@00003d0?ooo`03
0000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
503oool3000000@0oooo1`00003]0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo04@0oooo0P00000D0?ooo`030000003oool0oooo00`0oooo1000003Y0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo0200oooo00@0_g@0000000000000M;oo0`3o
ool00`3ogi`0B00007Boo`040?ooo`040;md00000000000007Boo`<0oooo00<0oono07@000000000
0P0000000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4@3oool500000>@0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool07`3o
ool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLg`@0oooo00<0okmd0000001d_ol02P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01H0oooo1@00003O0?ooo`030000003oool0oooo00`0oooo000=0?oo
o`030000003oool0oooo01h0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`060?oo
o`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol00`3oool00`3ooml0W4P0001d_`0:0?oo
o`8000004P3oool00`000000oooo0?ooo`0L0?ooo`@00000f`3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`0N0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000
B9`0gooo1@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`<0oooo00<0gia8
0018W03Oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0200oooo1@00003F
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo01h0oooo00<0oooO09a8
0000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000
B02Lgol00`3oool00`3ogi`0B01809cOo`090?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool09P3oool200000=@0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3o
ool07`3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0_g@00018W03O
ool00P3oool00`3ogi`0B00004RLg`030?ooo`030?oo_`1d0000M;oo00T0oooo0P00000A0?ooo`03
0000003oool0oooo02P0oooo0`00003A0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo01l0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l0103oool00`2oM00007Bo0?ooo`080?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0;03oool400000<d0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool07`3oool00`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo00D0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`030?ooo`030=nLB000
B9`0gooo00P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`<00000bP3o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0O0?ooo`040?oog`2LB000
04RL0=ooo`80oooo00<0gia80018W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`030=nL
B000B9`0gooo00<0oooo00<0omnL04P0B02Lgol0203oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo03<0oooo0P0000380?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo0200oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`060?ooo`030?oOW018
0000M;oo0080oooo00<0gia8001d_`3oool00`3oool00`3ookl0M00007Boo`080?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0=P3oool200000<H0oooo00<000000?ooo`3oool0303o
ool000d0oooo00<000000?ooo`3oool08@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo
00H0gia80000M02oool0oooO09a80018W=l50?ooo`030;md0000M;l0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0h0?ooo`<00000``3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`0R0?ooo`040=nLB00000000000001d_`X0oooo00@0gia80000
0000000007Bo103oool01@3ookl0M0000000000007@0_ooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0k0?ooo`800000`@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`2n0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
0;d0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo03l0oooo0`00002l0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`130?ooo`800000^P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`2g0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0;H0oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`190?ooo`800000
]03oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`8000003P3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0303o
ool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0M0?ooo`D00000803oool500000200oooo1@0000130?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo01/0oooo0P0000040?ooo`030000003oool0oooo01`0
oooo0P0000040?ooo`8000007@3oool2000000@0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo0P00000<0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo000=0?oo
o`030000003oool0oooo0200oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`04
0?ooo`040;md00000000000007Boo`<0oooo00H0omnL04P00000000000000018W03Oool90?ooo`80
0000303oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0O0?ooo`060=nL
B000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`060=nLB000M;l0oooo
0?oOW0180000B9cO0P3oool01P3o_g@0000007Boo`3oool0omnL04Qd_`T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0N0?ooo`030?oo
g`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3ooml0W4P004RLg`020?ooo`030?no
M00004P0W=oo00H0oooo00<0okmd04RLg`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo01h0oooo00<0oooO09a80018W=l00P3o
ool0103ooml0W4P00018W03Oool50?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0
gooo1@3oool00`3ookl0M01d0;ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool07P3oool00`3ooml0W4P0001d_`030?ooo`030=nL
B00004P0W=oo00D0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oo
g`2LB000M;oo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`0O0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3o
ool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00D0oooo00<0oono07@00018W=l01`3o
ool2000000/0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool07`3oool0
0`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00H0oooo00<0gia80000B02Lgol00P3oool0
0`3ooml0W4P0001d_`050?ooo`030?noM0000000M;oo00L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0O0?ooo`030?oOW0180000B9cO
00<0oooo00<0_g@00018W03Oool01@3oool00`3ogi`0B00004RLg`030?ooo`0:0;md0000B9`0gooo
0?ooo`3ogml0gooo0?noM0000000001d0;ooo`L0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0O0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`090=nLB000B9`0gooo
0?ooo`3ookl0M0000000000004P0W=oo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0P0?ooo`030?oOW0180000M;oo0080oooo00<0
gia8001d_`3oool01P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo0080oooo00<0
gibL0;ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo000=
0?ooo`030000003oool0oooo0240oooo00H0gia80000M02oool0oooO09a80018W=l80?ooo`060=nL
B00007@0_ooo0?oog`2LB000B9cO0`3oool00`3ogi`0M9cO0?ooo`090?ooo`8000002`3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0R0?ooo`040=nLB00000000000001d
_`X0oooo00@0gia800000000000007Bo1@3oool01@2oM0000000000000000000B9cO00H0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00`0oooo000=0?ooo`03
0000003oool0oooo04@0oooo0P00000:0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0303o
ool000d0oooo00<000000?ooo`3oool0:@3oool0102oM00000000000001d_ol30?ooo`030?oOW018
0000M;oo0080oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`070?ooo`8000002P3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0X0?ooo`060=nLB000M;l0
oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030?noM0000000M;oo00X0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`0W0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3ooml0W4P0001d
_`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool09`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0
gia80018W03Oool02@3oool2000000T0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool09`3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00P0oooo00<0omnL
04P0B02Lgol02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo000=0?oo
o`030000003oool0oooo02P0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`080?oo
o`030?oo_`1d0000M;oo00T0oooo0P0000090?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo000=0?ooo`03
0000003oool0oooo02P0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`090?ooo`03
0;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1Q0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`0X0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0
203oool00`3OW4P004RL0=ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
H@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool0:03oool0103ooml0W4P00018W03Oool20?ooo`030=nL
B000B9`0gooo00P0oooo00<0omnL04P0B02Lgol0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo02T0oooo00<0omnL04P0001d_ol00P3o
ool00`3OW4P007Bo0?ooo`080?ooo`030?oo_`1d0000M;oo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0Z0?ooo`060=nLB00007@0
_ooo0?oog`2LB000B9cO2P3oool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0:`3oool0103OW4P000000000
0000M;l90?ooo`050?oo_`1d000000000000M02oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0IP3o
ool01@000000oooo0?ooo`3oool0000001l0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0N0?ooo`050000003oool0oooo0?ooo`000000803oool01@000000oooo0?ooo`3oool00000
02`0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo06H0oooo00D000000?ooo`3oool0oooo0000000P0?oo
o`050000003oool0oooo0?ooo`000000803oool01@000000oooo0?ooo`3oool000000200oooo00D0
00000?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1V0?ooo`050000003o
ool0oooo0?ooo`000000803oool01@000000oooo0?ooo`3oool000000200oooo00D000000?ooo`3o
ool0oooo0000000P0?ooo`050000003oool0oooo0?ooo`000000;03oool00`000000oooo0?ooo`0<
0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`8000001`3oool00`000000oooo0?ooo`1V0?oo
o`050000003oool0oooo0?ooo`000000803oool010000000oooo0?ooo`00000Q0?ooo`050000003o
ool0oooo0?ooo`000000803oool01@000000oooo0?ooo`3oool0000002`0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo06H0oooo00@000000?ooo`3oool000008@3oool010000000oooo0?ooo`00000Q0?oo
o`040000003oool0oooo00000280oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`0<
0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0000000R0?ooo`030000003oool000000280oooo00<000000?oo
o`0000008P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo00`0oooo000=0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1W0?ooo`<0
00008P3oool300000280oooo0`00000R0?ooo`<00000;@3oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
o`3oool70?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool0303o
ool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0?l0oooo1`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo203oool00`000000oooo
0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`8000001P3oool00`000000oooo0?oo
o`3o0?ooo`P0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`0<
0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0o`3oool80?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool80?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?oo
o`3oool0:@3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00H0omnL
04P00000000000000018W03Oool90?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooo`P0oooo
00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0:03oool01P3OW4P007Bo0?oo
o`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3oool0omnL
04Qd_`T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool09`3oool00`3ooml0W4P004RLg`020?oo
o`030?noM00004P0W=oo00/0oooo00<0okmd04RLg`3oool01`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`0W0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo2P3oool00`3o
okl0M01d0;ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool90?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo02L0oooo00<0oooO09a80000
M;l00`3oool00`3OW4P0001809cOo`0:0?ooo`030?oog`2LB000M;oo00L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0:03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo
00<0oono07@00018W=l01`3oool2000000D0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo02P0oooo00<0gia80000B02Lgol00P3o
ool00`3ooml0W4P0001d_`0:0?ooo`030?noM0000000M;oo0?l0oooo6P3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`0X0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@0
0018W03Oool01P3oool01P3ogml0gooo0?noM0000000001d0;ooool0oooo6P3oool00`000000oooo
0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0X0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0gia80018W03Oool01P3oool01@3ookl0M0000000000004P0W=oo0?l0oooo6`3oool00`000000
oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0Y0?ooo`030?oOW0180000M;oo0080oooo
00<0gia8001d_`3oool01`3oool00`3OW9`0_ooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool0:P3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0
oooo00<0omnL07BLg`3oool0o`3ooolL0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo02/0oooo00@0gia800000000000007Bo2P3oool01@2oM0000000000000000000B9cO
07/0oooo00<0oooO09a8B02Lgol0VP3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`2j0?ooo`030=nLB018W=l0oooo09T0oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0^P3oool00`3ogi`0B7Bo0?ooo`2I0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo0;X0oooo00<0oono07@0M02oool0V@3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`2I0?ooo`030=nLB000000000000080000000<007Bo
0?ooo`3oool00P3oool01@3OW4P00000000000000000M;oo01<0oooo00<0_g@007Boo`3oool01@3o
ool00`3OW4P000000000000200000003001d_`3oool0oooo0080oooo00D0gia80000000000000000
07Boo`240?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo09L0oooo00@0
oooO09a800000000B9cO0`3oool01`3o_g@0001d0;ooo`3oool0omnL04P0001d_ol00P3oool00`2o
M00007Bo0?ooo`0A0?ooo`030?noM000M;l0oooo00<0oooo00@0oooO09a800000000B9cO0`3oool0
1`3o_g@0001d0;ooo`3oool0omnL04P0001d_ol00P3oool00`2oM00007Bo0?ooo`220?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo09L0oooo00<0gia800000018W=l01@3o
ool01P3ookl0M7Bo0?ooo`3OW4P004RL0=ooo`<0oooo00<0gibL0;ooo`3oool0403oool00`3ookl0
M4RL0=ooo`030?ooo`030=nLB0000000B9cO00D0oooo00H0oono07Ad_`3oool0gia80018W03Oool3
0?ooo`030=nLW02oool0oooo0840oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?oo
o`3oool0UP3oool0103ooml0W4P00000M02oool80?ooo`050?noM0000000000000000018W=l0503o
ool00`3ooml0W4Q809cOo`020?ooo`040?oog`2LB000001d0;ooo`P0oooo00D0okmd000000000000
000004RLg`250?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo09H0oooo
00@0oono07@00000B9`0gooo203oool01`3ookl0M01809cOo`3oool0gia800000018W=l04`3oool0
203OW4P0B9cO0?ooo`3oool0oono07@00000B9`0gooo203oool01`3ookl0M01809cOo`3oool0gia8
00000018W=l0P`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`2F0?oo
o`040?oog`2LB000001d0;ooo`T0oooo00L0okmd0018W03Oool0oooo0?oo_`1d0000B9cO0180oooo
00P0omnL04Q8W03Oool0oooo0?oog`2LB000001d0;ooo`T0oooo00L0okmd0018W03Oool0oooo0?oo
_`1d0000B9cO0880oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0U`3o
ool00`2oM000001809cOo`0:0?ooo`070=nLB00007@0_ooo0?ooo`3OW4P004RL0=ooo`0A0?ooo`03
0?oog`2LB7@0_ooo0080oooo00<0_g@00000B02Lgol02P3oool01`3OW4P0001d0;ooo`3oool0gia8
0018W03Oool0P@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`2G0?oo
o`030?noM000000007Bo00/0oooo00D0omnL04P000000000000007Boo`030?ooo`030;md001d_ol0
oooo00@0oooo00<0okmd07Boo`3oool01P3oool01`2oM000M;oo0?ooo`3oool0okmd00000000M;l0
2`3oool01P3ogi`0B000000000000000M;oo0=nLB0<0000000<0M;oo0?ooo`3oool00P3oool00`3o
_g@0M;oo0?ooo`1f0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo09P0
oooo00<0_g@00000B02Lgol01@3oool00`3ookl0M7Bo0?ooo`0:0?ooo`030?noM000M;l0oooo00@0
oooo00<0okmd07Boo`3oool01P3oool00`3o_g@007Bo0?ooo`020?ooo`030;md000004P0W=oo00D0
oooo00<0oono07Ad_`3oool02`3oool00`2oM7@0_ooo0?ooo`020?ooo`030?noM01d_ol0oooo07H0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0V03oool0103ookl0M000
0000M02oool40?ooo`030?oOW018B9`0gooo00L0oooo00<0okmd0000000000000P0000000`0007@0
_ooo0?ooo`020?ooo`030?noM01d_ol0oooo00H0oooo00<0oono07@0M02oool00P3oool0103ookl0
M0000000M02oool40?ooo`030?oOW018B9`0gooo00/0oooo00<0okmd04RLg`3oool00P3oool00`3o
_g@0M;oo0?ooo`1f0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo09T0
oooo00@0oooO09a800000000M;oo0P3oool0103ooml0W4P00000B02Lgol70?ooo`080?oog`2LB4P0
W=oo0?oog`2LB000M;oo0?ooo`3o_g@60000000307Boo`3oool0oooo00<0oooo00<0_g@007Boo`3o
ool00P3oool0103ooml0W4P00000001d_ol20?ooo`040?oog`2LB000001809cOo`X0oooo00@0oono
07@00000M;l0okmd1P0000000`1d_ol0oooo0?ooo`1b0?ooo`030000003oool0oooo00`0oooo000=
0?ooo`030000003oool0oooo09/0oooo00P0oono07@00000000000000000B02Lgol0okmd07Boo`P0
oooo00D0oooO09a8B02Lgol0gia8001d_`040?ooo`030?noM01d_ol0oooo00L0oooo00<0gia804RL
g`3oool0103oool0203ookl0M000000000000000001809cOo`3o_g@0M;oo203oool01@3ookl0M000
0000000007@0_ooo00<0oooo00<0okmd07Boo`3oool0MP3oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`2/0?ooo`050?oog`2LB4P0W;nL04Q8W03Oool00`3oool00`3o_g@0
M;oo0?ooo`070?ooo`030?oOW018B9`0gooo01H0oooo00<0oono07@0001d_ol00`3oool00`3o_g@0
M;oo0?ooo`1f0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0:d0oooo
00@0oooO09a8000004P0W=oo0`3oool00`3o_g@0M;oo0?ooo`0R0?ooo`060;mdB02Lgol0oooo0?oo
o`3o_g@0M;ooM`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`2^0?oo
o`030?oog`2LB000B9cO02D0oooo00D0okmd07Boo`3ooml0W4P007Boo`1k0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo0:l0oooo00<0oooO09adW03Oool09@3oool0102o
M00000000018W03Ooomk0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`03
0000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3o
oomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`03
0000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3o
oomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`0n0?ooo`040;md00000000000007Boob@0oooo00<0gia8000000000000
0`0000000`18W=l0oooo0?ooo`020?ooo`040;md00000000000007Boob80oooo00<0oooO09a80018
W=l01@3oool0102oM00000000000001d_olP0?ooo`050?oog`2LB000000000000000M;l01@3oool0
102oM00000000000001d_olP0?ooo`060?oo_`1d0000000000000000B9`0gooo103oool0102oM000
00000000001d_olK0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool00`3oool0102o
M00000000000001d_ol50?ooo`040;md00000000000007Boob@0oooo00<000000?ooo`3oool0303o
ool000d0oooo00<000000?ooo`3oool0?@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgb@0oooo
00<0okmd001d_`3oool00P3oool02P2oM7@0_ooo0?ooo`3oool0gia8001d_`3oool0omnL04P00018
W=lR0?ooo`030=nLB000B9`0gooo00<0oooo00H0gia8001d_`3oool0omnL04P00018W=lO0?ooo`07
0=nLB000M;l0oooo0?oo_`1d000004RL0=ooo`020?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO
7P3oool00`3ookl0M00004RLg`020?ooo`030=nLB00007@0_ooo0080oooo00H0gia8001d_`3oool0
omnL04P00018W=lL0?ooo`030?noM0000000M;oo00D0oooo00H0gia8001d_`3oool0omnL04P00018
W=l30?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO8`3oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`0l0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0
903oool00`3o_g@007Bo0?ooo`040?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0
8@3oool00`3ogi`0B01809cOo`020?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0
7@3oool00`3ooml0W4P007Boo`020?ooo`070?oOW0180000B9cO0?ooo`3ooml0W4P004RLg`020?oo
o`030?noM00004P0W=oo01d0oooo00<0okmd0018W03Oool00`3oool01P2oM000B9cO0?ooo`3ooml0
W4P004RLg`80oooo00<0okmd0000B02Lgol06`3oool00`3ooml0W4P0001d_`040?ooo`030?oog`2L
B000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000B9cO0080oooo00<0okmd0000B02L
gol08P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0l0?ooo`030?oo
g`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo903oool00`3o_g@007Bo0?ooo`030?ooo`03
0?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo703oool00`3o_g@00000000000040000
00050018W03Oool0oooO09a80018W=l00P3oool0103ooml0W4P00018W03OoolL0?ooo`030?oo_`1d
0000M;oo00<0oooo00H0_g@00000M02oool0oooO09a80018W=l20?ooo`040?oog`2LB00004RL0=oo
oa`0oooo00<0okmd0018W03Oool00`3oool01P2oM00007Bo0?ooo`3ooml0W4P004RLg`80oooo00@0
oooO09a80000B9`0gooo6`3oool00`3OW4P004RL0=ooo`030?ooo`030?oog`2LB000B9cO0080oooo
00L0oooO09a80000B9`0gooo0?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo8@3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0l0?ooo`030?oog`2LB00007Bo
00<0oooo00<0gia80000B02Lgol09@3oool00`3o_g@0B9cO0?ooo`020?ooo`030?oog`2LB00007Bo
00<0oooo00<0gia80000B02Lgol0703oool00`3ooml0W4Q809cOo`020?ooo`070;md0000M;l0oooo
0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo01`0oooo00<0oooO09a80000M;l00`3o
ool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol0703oool00`3ooml0
W4P007Boo`020?ooo`070?oo_`1d0000B9cO0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB00004P0
W=oo01/0oooo00<0omnL04P0B02Lgol00`3oool00`3ooml0W4P0001d_`030?ooo`060=nLB00004P0
W=oo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`0Q0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo03d0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RL
g`0V0?ooo`030=nLB018W=l0oooo0080oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RL
g`0M0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@004RL0=ooo`020?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l07@3oool00`2oM000001d0;ooo`020?ooo`070=nLB00004P0W=oo0?oo
o`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO01h0oooo00H0_g@00000B02Lgml0W4P00000
M02oool20?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l06`3oool00`3ookl0M000
07Boo`040?ooo`030;md0000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md0000B9`0gooo
0080oooo00<0omnL04P00018W=l08@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`0m0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l09`3oool01`2oM000
M;oo0?ooo`3oool0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0N0?ooo`060?oOW018B9`0
gooo0?oOW01804P0W=oo0P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo01d0oooo
00`0okmd00000018W=l0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol20?ooo`030?oo
g`2LB00007Bo01l0oooo00D0oooO09a80000000004RL0=ooo`020?ooo`030=nLB00004P0W=oo0080
oooo00<0oooO09a80000M;l0703oool00`2oM00007Bo0?ooo`030?ooo`030=nLB00004P0W=oo0080
oooo00L0oooO09a80000M;l0oooo0=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l08@3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0m0?ooo`030?oOW0180000B9cO
00<0oooo00<0_g@00018W03Oool09P3oool01`3ogi`0B01d0;ooo`3oool0omnL04P00018W=l00`3o
ool00`2oM00004RL0=ooo`0N0?ooo`050?noM000M;l0oooO09a80018W=l00P3oool00`3ogi`0B000
04RLg`030?ooo`030;md0000B9`0gooo01`0oooo00<0oooO09a8000000000P0000001`0007@0_ooo
0?ooo`3oool0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0N0?ooo`0:0;md000004P0W=oo
0?oOW018B9`0gooo0?ooo`3ogi`0B00004RLg`<0oooo00<0_g@00018W03Oool06`3oool00`3OW4P0
04RL0=ooo`030?ooo`030?oOW0180000B9cO00<0oooo00H0_g@00018W03Oool0omnL04P00018W=l3
0?ooo`030;md0000B9`0gooo0200oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?oo
o`3oool0?@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo02H0oooo00P0oooO
09a8001d_ol0oooo0?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool07`3oool0103OW4P0
B9cO0;md0000M;l20?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool07@3oool0
0`3ookl0M000001d_`050?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool07@3o
ool00`3ogi`0B00007Boo`020?ooo`070?noM018W=l0oooo0?oog`2LB00004RL0=ooo`020?ooo`03
0=nLB000B9`0gooo01/0oooo00<0omnL04P0B02Lgol00`3oool0103ooml0W4P00018W03Oool20?oo
o`070=nLB000B9`0gooo0?oog`2LB00004RL0=ooo`020?ooo`030=nLB000B9`0gooo0200oooo00<0
00000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0?P3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo02H0oooo00<0oono07@00018W=l00P3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo0200oooo00@0gia807AdM00007@0_ooo0P3oool00`3ogi`0B00007Bo
o`020?ooo`030=nLB000M;l0oooo01h0oooo00<0omnL04P00018W=l01@3oool00`3ogi`0B00007Bo
o`020?ooo`030=nLB000M;l0oooo01d0oooo00<0omnL04P0B02Lgol00P3oool01`3o_g@004RL0=oo
o`3oool0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0K0?ooo`030?oo_`1d0000M;oo00@0
oooo00<0omnL04P0001d_ol00P3oool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d_ol00P3oool0
0`3OW4P007Bo0?ooo`0P0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
03l0oooo00H0gia80000M02oool0oooO09a80018W=lS0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0
001809cOo`030?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO8P3oool00`2oM000001809cOo`03
0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO803oool0103ooml0W4P00000M02oool40?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO7P3oool00`3ooml0W4P004RLg`020?ooo`030;md0000M;l0
oooo0080oooo00H0gia80000M02oool0oooO09a80018W=lM0?ooo`030;md0000M;l0oooo00@0oooo
00H0gia80000M02oool0oooO09a80018W=l30?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO8@3o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`100?ooo`040=nLB0000000
0000001d_bD0oooo00D0omnL04P000000000000007Boo`050?ooo`040=nLB00000000000001d_b<0
oooo00<0oooO09a80018W=l0103oool0103OW4P0000000000000M;lS0?ooo`040?oo_`1d00000000
04RLg`<0oooo00@0gia800000000000007Bo803oool01@3ooml0W4P000000000000007Bo00D0oooo
00@0gia800000000000007Bo703oool01@3ookl0M0000000000007@0_ooo00D0oooo00@0gia80000
0000000007Bo1@3oool0103OW4P0000000000000M;lR0?ooo`030000003oool0oooo00`0oooo000=
0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`00
0000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3o
ool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0oooo
E`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<0
00000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`0k0?oooo<00000:03oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0K`3oool2000002<0oooo0P00000S0?ooo`800000
8`3oool2000003P0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`1^0?ooo`030000003oool000000280oooo0`00000R0?ooo`<000008P3o
ool3000003P0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool000000280oooo00@000000?ooo`00000000008@3o
ool00`000000oooo0000000R0?ooo`040000003oool0oooo000003L0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1]0?ooo`040000003o
ool0oooo00000280oooo00@000000?ooo`3oool000008@3oool010000000oooo0?ooo`00000Q0?oo
o`040000003oool0oooo000003L0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`1]0?ooo`050000003oool0oooo0?ooo`000000803oool0
1@000000oooo0?ooo`3oool000000240oooo00@000000?ooo`3oool000008@3oool010000000oooo
0?ooo`00000g0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0K@3oool01@000000oooo0?ooo`3oool000000200oooo00D000000?ooo`3o
ool0oooo0000000Q0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3oool0oooo0000
000g0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0K@3oool01@000000oooo0?ooo`3oool000000200oooo00D000000?ooo`3oool0oooo
0000000P0?ooo`050000003oool0oooo0?ooo`000000803oool01@000000oooo0?ooo`3oool00000
03L0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`1]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo0000000P0?oo
o`050000003oool0oooo0?ooo`000000=`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool01@00
0000oooo0?ooo`3oool000000200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0K03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0/0?ooo`030?oo_`1d00000000
0080000000<0B9cO0?ooo`3oool01`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`0^0?ooo`030?noM0000000M;oo00X0oooo00<000000?ooo`3oool0JP3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0;P3oool00`3ooml0W4P0001d_`0:0?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo02l0oooo00<0gia80018W03Oool02@3oool00`000000oooo0?oo
o`1Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`0_0?ooo`030?oOW01804P0W=oo00T0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0;`3oool00`3ookl0M00007Boo`090?oo
o`800000103oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0`0?ooo`03
0;md0000M;l0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`0`0?ooo`030=nLB000B9`0gooo00P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0`0?ooo`030?oOW018
04P0W=oo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1Q0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool0
0`000000oooo0?ooo`0`0?ooo`030?oo_`1d0000M;oo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0a0?ooo`030;md0000M;l0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`0_0?ooo`050?oo_`1d000000000000M02oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo0P0000040?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`0k0?ooo`800000103oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0303oool000d0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05H0oooo0P00
000G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo0P00000H
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`060?ooo`8000006P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3o
ool0>`3oool2000000@0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0I0?ooo`80
00001P3oool00`000000oooo0?ooo`0J0?ooo`8000001`3oool00`000000oooo0?ooo`0I0?ooo`80
00001P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool2000001d0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0703oool6000001l0oooo1P00000O0?ooo`H00000803o
ool3000002h0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07`3oool2
000002<0oooo0P00000S0?ooo`8000008`3oool2000002h0oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
04l0oooo0P0000310?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo01h0
oooo00<0oono07@0000000000P0000001`18W=l0oooo0?ooo`3oool0omnL04P0001d_ol00P3oool0
1P3ogi`0B00000000000000004RL0=ooo`T0oooo0P0000040?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`0P0?ooo`030?noM0000000M;oo00@0oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Bo
o`3oool0omnL04Qd_`T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo0<80oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0
803oool00`3ooml0W4P0001d_`0>0?ooo`030?noM018W=l0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool08@3oool00`3OW4P004RL0=ooo`0=0?ooo`030?oo_`1d
07@0_ooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0<@0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool08@3oool0
0`3ogi`0B01809cOo`0=0?ooo`030?oog`2LB000M;oo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool08@3oool00`3ookl0M00007Boo`0=0?ooo`030?oo_`1d0000B9cO
00L0oooo0P0000040?ooo`030000003oool0oooo04P0oooo0P0000380?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo0280oooo00<0_g@0001d_`3oool0303oool00`3o_g@0
000007Boo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0280oooo
00<0gia80018W03Oool02@3oool01P3ogml0gooo0?noM0000000001d0;ooo`L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0<T0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool08P3oool00`3ogi`0B01809cOo`090?ooo`05
0?oo_`1d000000000000B02Lgol0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`0R0?ooo`030?oo_`1d0000M;oo00X0oooo00<0gibL0;ooo`3oool02@3oool2000000@0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo02<0oooo00<0_g@0001d_`3oool02@3oool00`3ogi`0M9cO
0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`3<0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0240oooo00D0
oono07@000000000001d0;ooo`0:0?ooo`050;md00000000000000000018W=l01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0440oooo0P00003?0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0303oool000d0oooo00<0
00000?ooo`3oool0>`3oool2000000@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0=40oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo03/0oooo0P0000050?ooo`030000003oool0oooo03T0oooo0P00003F0?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo02`0oooo00<0gia80000000000000`00
00000`18W=l0oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0
oooo02d0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo02h0oooo00<0okmd001d_`3oool02P3oool20000
00D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo02l0oooo00<0okmd001d_`3oool02@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0f@3oool00`000000
oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0`0?ooo`030?noM018W=l0oooo00P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0=X0oooo
00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0<@3oool00`3OW4P0B9cO0?oo
o`070?ooo`8000001@3oool00`000000oooo0?ooo`0b0?ooo`800000g@3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`0b0?ooo`030;md001d_ol0oooo00H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0=d0oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0<P3oool00`3ogi`0B01d0;ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3N0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0380oooo00<0oooO09a8001d
_ol01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0g`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0b0?ooo`030?oo
_`1d0000B9cO00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0>00oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0;P3o
ool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`0_0?ooo`050?oOW018000000000000001d_ol01`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02/0oooo0P00003T0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0303oool000d0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0i@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3V
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0>L0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0j03oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
903oool200000>/0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0j`3o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`3oool0303oool000d0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`3_0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`800000lP3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo00`0oooo000=0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0m03oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0/0?ooo`030?oo
_`1d000000000080000000<0M;oo0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`0/0?ooo`030?noM000000007Bo0080oooo00<0_gA809cOo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0mP3o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0a0?ooo`030?oOW018B9`0
gooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`800000n@3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0a0?ooo`030?oo_`1d0000M;oo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0?T0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0<@3oool00`3ogi`0
B00007Boo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`3j0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0300oooo
00@0omnL04P0000004P0W=oo1`3oool2000000L0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`3k0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo02h0oooo
00D0omnL04P000000000000007Boo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo0300oooo00<0oono07@00000M;l0203oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`0b0?ooo`030=nLB000M;l0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0=0?ooo`800000o`3oool10?ooo`030000003oool0oooo00`0oooo000=
0?ooo`030000003oool0oooo0380oooo00<0omnL04P0B02Lgol01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo02l0oooo00H0_g@007Boo`3oool0gia80000B02L
gol60?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`3o0?ooo`80oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0<03oool0
102oM000000000000018W=l70?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P00003o
0?ooo`H0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo0P00003o0?ooo`P0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool80?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0203oool2000000<0oooo
00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool02@3oool400000?l0oooo303oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo6@3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
0?l0oooo6@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo6@3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0k0?ooo`800000o`3ooolJ0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo02`0oooo00H0omnL04P00000000000000018W03O
ool90?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool0
0`000000oooo0?ooo`0/0?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo2@3oool00`000000oooo
0?ooo`3o0?oooaT0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0<@3o
ool00`3o_g@0B9cO0?ooo`070?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`0a0?ooo`030?oo_`1d07@0_ooo00L0oooo00<00000
0?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
0340oooo00<0oooO09a8001d_ol01`3oool00`000000oooo0?ooo`3o0?oooaT0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool0<@3oool00`3ookl0M00004RLg`070?ooo`80
0000o`3ooolJ0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0340oooo
00<0okmd0000001d_ol0o`3ooolS0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo02h0oooo00H0omoO0=ooo`3o_g@000000000M02ooooo0?ooob<0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0;P3oool01@3ookl0M0000000000004P0W=oo0?l0
oooo903oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0_0?ooo`030=nL
W02oool0oooo0?l0oooo9@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`0_0?ooo`030?oOW01dW=l0oooo0?l0oooo9@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool0
0`000000oooo0?ooo`0`0?ooo`050;md00000000000000000018W=l0o`3ooolR0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<
0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0
oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo0:D0oooo00<0gia80000000000001@0000001P1d_ol0oooo0?ooo`3oool0_g@0001d
_j<0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0YP3oool02@3ooml0
W4P00018W03Oool0oooo0?oog`2LB0000000001d_`020?ooo`030?noM00007@0_ooo0:80oooo00<0
00000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0Y`3oool00`3o_g@0001d0;ooo`03
0?ooo`070;md00000000M;oo0?ooo`3ogi`0B00007Boo`2R0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo0:L0oooo00<0oono07@0001d_ol00`3oool0203o_g@00000001d
_`3oool0oooO09a80000B9`0goooX@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`2W0?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd00000018W=l00P3oool00`2oM000
B7Ad07BLg`2Q0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0:P0oooo
00P0gia80018W03Oool0oooo0?oo_`1d0000001d0;ooo`80oooo00@0okmd0018W02oW4P0M;ooX03o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`2X0?ooo`030?noM0000000
00000080000000<007Bo0?ooo`3oool00P3oool01`3ookl0M01809cOo`2oM000M7Ad0018W03Oool0
W@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`2X0?ooo`030?oo_`1d
0000M;oo0080oooo00`0okmd00000000M;l0oooo0?oOW0180000000007Boo`3oool0_g@00000M02o
oonM0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0:T0oooo00<0_g@0
001d_`3oool00P3oool00`3o_g@0000007Boo`2U0?ooo`030000003oool0oooo00`0oooo000=0?oo
o`030000003oool0oooo0:T0oooo00<0gia80018W03Oool00P3oool00`3ogi`0B000001d_`2U0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0:T0oooo00<0okmd0000B02L
gol00P3oool00`2oM000000007Boo`070?ooo`030?oOW0180000000000@0000000<0B9cO0?ooo`3o
ool0U03oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`2X0?ooo`030;md
00000000000000@0000000<0M;oo0?ooo`3oool0Y03oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`03
0000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3o
oomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`03
0000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3o
oomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?oo
o`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
04L0oooo00@0_g@0000000000000M;oo903oool00`3OW4P00000000000030000000304RLg`3oool0
oooo0080oooo00@0_g@0000000000000M;oo8P3oool00`3ooml0W4P004RLg`050?ooo`040;md0000
0000000007Boob00oooo00D0oooO09a8000000000000001d_`050?ooo`040;md00000000000007Bo
ob00oooo00H0oono07@00000000000000018W03Oool40?ooo`040;md00000000000007Booa/0oooo
00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`030?ooo`040;md00000000000007Boo`D0
oooo00@0_g@0000000000000M;oo6`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`160?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO903oool00`3o_g@007Bo0?ooo`02
0?ooo`0:0;mdM02oool0oooo0?ooo`3OW4P007Bo0?ooo`3ogi`0B00004RLgb80oooo00<0gia80018
W03Oool00`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgal0oooo00L0gia8001d_`3oool0oono
07@00000B9`0gooo0080oooo00H0gia8001d_`3oool0omnL04P00018W=lN0?ooo`030?oo_`1d0000
B9cO0080oooo00<0gia80000M02oool00P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLga`0oooo
00<0okmd0000001d_ol01@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`<0oooo00H0gia8001d
_`3oool0omnL04P00018W=lJ0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0
oooo04D0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0T0?ooo`030?noM000M;l0
oooo00@0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0Q0?ooo`030?oOW01804P0
W=oo0080oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0M0?ooo`030?oog`2LB000
M;oo0080oooo00L0omnL04P00018W=l0oooo0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0
7@3oool00`3o_g@004RL0=ooo`030?ooo`060;md0018W=l0oooo0?oog`2LB000B9cO0P3oool00`3o
_g@0001809cOo`0K0?ooo`030?oog`2LB00007Bo00@0oooo00<0oooO09a80018W=l00P3oool01`3o
_g@0001809cOo`3oool0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0I0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo04D0oooo00<0oooO09a80018W=l00P3oool0
103ooml0W4P00018W03OoolT0?ooo`030?noM000M;l0oooo00<0oooo00<0oooO09a80018W=l00P3o
ool0103ooml0W4P00018W03OoolL0?ooo`030?noM0000000000000@0000000D004RL0=ooo`3ooml0
W4P004RLg`020?ooo`040?oog`2LB00004RL0=oooa`0oooo00<0oono07@0001d_ol00`3oool01P2o
M000001d0;ooo`3ooml0W4P004RLg`80oooo00@0oooO09a80000B9`0gooo703oool00`3o_g@004RL
0=ooo`030?ooo`060;md0000M;l0oooo0?oog`2LB000B9cO0P3oool0103ooml0W4P00018W03OoolK
0?ooo`030=nLB000B9`0gooo00<0oooo00<0oooO09a80018W=l00P3oool01`3ooml0W4P00018W03O
ool0oooO09a80018W=l00P3oool0103ooml0W4P00018W03OoolH0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo04D0oooo00<0oooO09a80000M;l00`3oool00`3OW4P00018
09cOo`0U0?ooo`030?noM018W=l0oooo0080oooo00<0oooO09a80000M;l00`3oool00`3OW4P00018
09cOo`0L0?ooo`030?oog`2LB4P0W=oo0080oooo00L0_g@0001d_`3oool0oooo0?oog`2LB00007Bo
00<0oooo00<0gia80000B02Lgol0703oool00`3ooml0W4P0001d_`030?ooo`060=nLB00004P0W=oo
0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`0L0?ooo`030?oog`2LB000M;oo0080oooo00L0
oono07@00018W=l0oooo0?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol06`3oool00`3ogi`0
B01809cOo`030?ooo`030?oog`2LB00007Bo00<0oooo00H0gia80000B02Lgol0oooO09a80000M;l3
0?ooo`030=nLB00004P0W=oo01P0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?oo
o`3oool0AP3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO02H0oooo00<0gia804RL
g`3oool00P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO01d0oooo00L0oono07@0
M02oool0oooo0?noM000B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RL
g`0M0?ooo`030;md000007@0_ooo0080oooo00L0gia80000B02Lgol0oooo0;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l07P3oool01P2oM000001809cOg`2LB000001d0;ooo`80oooo00<0_g@0
0018W03Oool00P3oool00`3ogi`0B00004RLg`0K0?ooo`030?oo_`1d0000M;oo00@0oooo00<0_g@0
0018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0_g@00018W03Oool00P3oool00`3ogi`0B000
04RLg`0H0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04H0oooo00<0
gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0W0?ooo`070;md001d_ol0oooo0?ooo`3OW4P0
001809cOo`020?ooo`030?oog`2LB00007Bo01h0oooo00H0omnL04Q8W03Oool0omnL04P0B02Lgol2
0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l07@3oool0303o_g@0000004RLg`3o
ool0oooO09a80000B9`0gooo0?ooo`3OW4P0001809cOo`80oooo00<0oooO09a80000M;l07`3oool0
1@3ooml0W4P000000000B9`0gooo0080oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d
_`0L0?ooo`030;md0000M;l0oooo00<0oooo00<0gia80000B02Lgol00P3oool01`3ooml0W4P0001d
_`3oool0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0H0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo04H0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL
0=ooo`0V0?ooo`070?oOW01807@0_ooo0?ooo`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo
01h0oooo00D0okmd001d_`3ooml0W4P004RLg`020?ooo`030?oOW0180000B9cO00<0oooo00<0_g@0
0018W03Oool0703oool00`3ooml0W4P000000002000000070000M02oool0oooo0?ooo`3ogi`0B000
04RLg`030?ooo`030;md0000B9`0gooo01h0oooo00X0_g@00000B02Lgol0omnL04Q8W03Oool0oooo
0?oOW0180000B9cO0`3oool00`2oM00004RL0=ooo`0K0?ooo`030=nLB000B9`0gooo00<0oooo00<0
omnL04P00018W=l00`3oool01P2oM00004RL0=ooo`3ogi`0B00004RLg`<0oooo00<0_g@00018W03O
ool05`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`160?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool09P3oool0203ooml0W4P007Boo`3oool0oooO
09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0O0?ooo`040=nLB018W=l0_g@0001d_`80oooo
00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0M0?ooo`030?oo_`1d000007Bo00D0
oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0M0?ooo`030?oOW0180000M;oo
0080oooo00L0okmd04RLg`3oool0oooO09a80000B9`0gooo0080oooo00<0gia80018W03Oool06`3o
ool00`3ogi`0B01809cOo`030?ooo`040?oog`2LB00004RL0=ooo`80oooo00L0gia80018W03Oool0
oooO09a80000B9`0gooo0080oooo00<0gia80018W03Oool05`3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`170?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3o
ool09P3oool00`3ookl0M00004RLg`020?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3o
ool0803oool0103OW4P0M7Ad0000M02oool20?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d
_`3oool07P3oool00`3ogi`0B00004RLg`050?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d
_`3oool07@3oool00`3ogi`0B01809cOo`020?ooo`070?noM000B9`0gooo0?ooo`3ogi`0B00007Bo
o`020?ooo`030=nLB000M;l0oooo01/0oooo00<0oono07@0001d_ol0103oool00`3ogi`0B00007Bo
o`020?ooo`070=nLB000M;l0oooo0?ooo`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo01L0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0B03oool01P3OW4P0001d
0;ooo`3ooml0W4P004RLgb<0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00<0oooo00H0
gia80000M02oool0oooO09a80018W=lR0?ooo`030;md000004P0W=oo00<0oooo00H0gia80000M02o
ool0oooO09a80018W=lP0?ooo`040?oog`2LB000001d0;ooo`@0oooo00H0gia80000M02oool0oooO
09a80018W=lN0?ooo`030?oog`2LB000B9cO0080oooo00<0_g@0001d_`3oool00P3oool01P3OW4P0
001d0;ooo`3ooml0W4P004RLgad0oooo00<0_g@0001d_`3oool0103oool01P3OW4P0001d0;ooo`3o
oml0W4P004RLg`<0oooo00H0gia80000M02oool0oooO09a80018W=lH0?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo04T0oooo00@0gia800000000000007Bo9@3oool01@3o
gi`0B000000000000000M;oo00D0oooo00@0gia800000000000007Bo8`3oool00`3ooml0W4P004RL
g`040?ooo`040=nLB00000000000001d_b<0oooo00@0oono07@000000000B9cO0`3oool0103OW4P0
000000000000M;lP0?ooo`050?oog`2LB000000000000000M;l01@3oool0103OW4P0000000000000
M;lL0?ooo`050?oo_`1d000000000000M02oool01@3oool0103OW4P0000000000000M;l50?ooo`04
0=nLB00000000000001d_aT0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3o
ool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0oooo
E`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<0
00000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo04@0ooool`00000O0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool000d0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0
oooo2P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooo`X0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0<
0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3oool:0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2P3oool00`00
0000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo
00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool:
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo0P0000040?oo
o`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool:0?ooo`03
0000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0303oool000d0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2P3o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00`0oooo000=0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oo
o`X0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
o`3oool:0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0303o
ool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo2P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?oo
o`800000103oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0303oool000d0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0
oooo2P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooo`X0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0<
0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3oool:0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool05`3oool0102oM00000000000001d_ol30?ooo`03
0?oOW0180000M;oo00@0oooo00@0_g@0000000000000M;oo1@3oool0102oM00000000000001d_ol3
0?ooo`060?oOW0180000000000000000B9`0gooo2@3oool2000000@0oooo00<000000?ooo`3oool0
o`3oool:0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo01H0oooo00H0
gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00H0gia8001d_`3o
ool0omnL04P00018W=l30?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool01P3o_g@00000
07Boo`3oool0omnL04Qd_`T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oo
o`X0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool05@3oool00`3ooml0
W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0oooO09a80018W=l00P3oool01`3o_g@0
001809cOo`3oool0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?noM018W=l0
oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool05@3oool00`3ooml0W4P004RLg`020?oo
o`040?oog`2LB00004RL0=ooo`D0oooo00<0oooO09a80018W=l00P3oool01`3ooml0W4P00018W03O
ool0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?oo_`1d07@0_ooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool05@3oool00`3ooml0W4P0001d_`030?ooo`030=nL
B00004P0W=oo00D0oooo00<0oooO09a80000M;l00`3oool01P3OW4P0001809cOo`3ooml0W4P0001d
_`<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P007Boo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo00`0oooo000=0?ooo`03
0000003oool0oooo01H0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`03
0;md0000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l01@3oool00`3ookl0M00004RLg`070?ooo`800000103oool00`000000oooo0?ooo`3o
0?ooo`X0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool05P3oool00`3O
W4P0001809cOo`020?ooo`030?oog`2LB00007Bo00H0oooo00<0gia80000B02Lgol00P3oool01`3o
oml0W4P0001d_`3oool0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`050?ooo`030?noM000
0000M;oo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<0
00000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool05P3oool00`3ogi`0B00004RLg`03
0?ooo`030;md0000B9`0gooo00D0oooo00<0omnL04P00018W=l00`3oool01P2oM00004RL0=ooo`3o
gi`0B00004RLg`<0oooo00X0_g@00018W03Oool0oooo0?oOg`3Oool0okmd0000000007@0_ooo1`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`0F0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`070=nLB000B9`0gooo0?oog`2L
B00004RL0=ooo`020?ooo`090=nLB000B9`0gooo0?ooo`3ookl0M0000000000004P0W=oo00P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool05`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000
M;l0oooo00H0oooo00<0omnL04P0001d_ol00P3oool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d
_ol00P3oool00`3OW4P007Bo0?ooo`020?ooo`030=nLW02oool0oooo00T0oooo0P0000040?ooo`03
0000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`0H0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool01P3OW4P0001d0;ooo`3ooml0
W4P004RLg`<0oooo00H0gia80000M02oool0oooO09a80018W=l30?ooo`030?oOW01dW=l0oooo00T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool06@3oool0103OW4P0000000000000M;l:0?ooo`04
0=nLB00000000000001d_`D0oooo00@0gia800000000000007Bo1@3oool01@2oM000000000000000
0000B9cO00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<0
00000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`00
0000oooo0?ooo`140?ooo`800000103oool010000000oooo0?ooo`3oool;00000?d0oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo008000002P3oool700000?H0oooo00<000000?ooo`3oool0303oool000d0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`030?ooo`040000003oool000000000
0180oooo1`00003_0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0
oooo0P0000040?ooo`030000003oool0000001X0oooo1@00003Z0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo0200oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0
B00007Boo`040?ooo`040;md00000000000007Boo`<0oooo00<0oono07@0000000000P0000000`18
W=l0oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo0P00000P0?ooo`@00000iP3oool00`00
0000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0O0?ooo`060=nLB000M;l0oooo0?oO
W0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO
103oool00`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo00<0oooo0P00000T0?ooo`D00000
h@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0N0?ooo`030?oog`2L
B000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3ooml0W4P004RLg`020?ooo`030?noM000
04P0W=oo00<0oooo00<0oooO09a80000M;l02P3oool2000000@0oooo0P00000Y0?ooo`D00000g03o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0N0?ooo`030?oog`2LB000
B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2L
B00004RL0=ooo`<0oooo00<0gia80018W03Oool02@3oool00`000000oooo0?ooo`030?ooo`800000
;P3oool200000=X0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool07P3o
ool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a80000M;l00`3o
ool00`3OW4P0001809cOo`030?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool00`3o
ool200000300oooo1@00003E0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0
oooo01l0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`030;md0000B9`0
gooo0080oooo00<0omnL04P00018W=l00`3oool00`3ookl0M00007Boo`090?ooo`800000103oool2
000003D0oooo0P00003C0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
01l0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`030=nLB00004P0W=oo
0080oooo00<0oooO09a80000M;l0103oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0=P3oool200000=40oooo00<000000?ooo`3oool0303oool000d0
oooo00<000000?ooo`3oool07`3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00D0
oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`030?ooo`030=nLB000B9`0gooo00P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0h0?ooo`D00000c03oool00`000000
oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0O0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo
00<0oooo00<0omnL04P0B02Lgol0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
03d0oooo0P00003:0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0200
oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`060?ooo`030?oOW0180000M;oo0080
oooo00<0gia8001d_`3oool00`3oool00`3ookl0M00007Boo`080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0?`3oool300000<L0oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool08@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000
M02oool0oooO09a80018W=l50?ooo`030;md0000M;l0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`120?ooo`800000a@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool0
0`000000oooo0?ooo`0R0?ooo`040=nLB00000000000001d_`X0oooo00@0gia800000000000007Bo
103oool01@3ookl0M0000000000007@0_ooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0AP3oool300000<00oooo00<0
00000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo04T0oooo0P00002n0?ooo`030000003oool0oooo00`0oooo000=0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0^P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0C@3oool200000;X0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo04l0oooo0P00002h0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo0;D0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool50000
0200oooo1000000Q0?ooo`D00000803oool3000002D0oooo00<000000?ooo`3oool0303oool000d0
oooo00<000000?ooo`3oool0A03oool2000000@0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo0P0000040?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0I0?ooo`8000001P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo
0P00000M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01P3oool2000001X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`8000006@3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`1F0?ooo`800000603oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0303o
ool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0
oooo0P00001R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo06<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`140?ooo`800000I@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0803oool0
102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo00@0oooo00@0_g@0000000000000M;oo
0`3oool01P3ogi`0B00000000000000004RL0=ooo`T0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0303oool000d0
oooo00<000000?ooo`3oool07`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL
04P0001d_ol00`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00H0okmd0000001d_ol0
oooo0?oOW018M;l90?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo01h0
oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?oog`2LB000B9cO0080
oooo00<0okmd0000B02Lgol01P3oool00`3o_g@0B9cO0?ooo`070?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo01h0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P0
0018W03Oool50?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3o
okl0M01d0;ooo`070?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo01h0
oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB00007Bo00<0
oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P007Boo`070?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo01l0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B000
04RLg`060?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01@3oool00`3ookl0M000
04RLg`070?ooo`800000J03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool07`3oool00`3OW4P0001809cO
o`020?ooo`030?oog`2LB00007Bo00H0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d
_`050?ooo`030?noM0000000M;oo00L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool07`3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00D0oooo00<0omnL
04P00018W=l00`3oool02P2oM00004RL0=ooo`3oool0omoO0=ooo`3o_g@000000000M02oool70?oo
o`030000003oool0oooo06L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo01l0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3OW4P004RL0=ooo`050?ooo`040?oog`2LB00004RL0=ooo`80oooo00T0gia8
0018W03Oool0oooo0?oo_`1d000000000000B02Lgol0203oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`0P0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0
1P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo0080oooo00<0gibL0;ooo`3oool0
2@3oool2000006T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0240oooo00H0gia80000M02oool0oooO
09a80018W=l80?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO0`3oool00`3ogi`0M9cO0?ooo`09
0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0280oooo00@0gia80000
0000000007Bo2P3oool0103OW4P0000000000000M;l50?ooo`050;md00000000000000000018W=l0
1P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo0P00001Y0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0:@3oool0102oM0000000
0000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0000000000P0000000`18W=l0
oooo0?ooo`070?ooo`800000JP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0:03oool01P3OW4P007Bo
0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol0103oool00`3o_g@0000007Boo`0:0?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo02L0oooo00<0oooO09a80018
W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?oog`2LB00007Bo00X0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool09`3oool00`3ooml0W4P004RLg`020?ooo`040?oo
g`2LB00004RL0=ooo`P0oooo00<0gia80018W03Oool02@3oool2000006X0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo02L0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`080?ooo`030?oO
W01804P0W=oo00T0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0:03o
ool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00P0oooo00<0oono07@0001d_ol02@3o
ool2000006/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo02P0oooo00<0gia80000B02Lgol00P3oool0
0`3ooml0W4P0001d_`090?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool0:03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo
00P0oooo00<0gia80018W03Oool0203oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`0X0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0203oool00`3o
gi`0B01809cOo`080?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo02T0
oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`080?ooo`030?oo_`1d0000M;oo00P0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0:P3oool01P3OW4P0001d
0;ooo`3ooml0W4P004RLg`X0oooo00<0_g@0001d_`3oool01`3oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`0[0?ooo`040=nLB00000000000001d_`T0oooo00D0oono07@0
00000000001d0;ooo`070?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`1/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo
000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo06`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0K@3oool01@000000oooo0?ooo`3oool0000001l0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool000d0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1]0?ooo`050000003oool0oooo0?oo
o`0000007`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo06d0oooo00D000000?ooo`3oool0oooo0000000P0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0K@3oool01@000000
oooo0?ooo`3oool000000200oooo00D000000?ooo`3oool0oooo0000000P0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool07@3oool01@000000oooo0?ooo`3oool0000002h0oooo00<0
00000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0A03oool2000006h0oooo00D00000
0?ooo`3oool0oooo0000000P0?ooo`050000003oool0oooo0?ooo`000000803oool01@000000oooo
0?ooo`3oool000000200oooo00D000000?ooo`3oool0oooo0000000^0?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0K@3oool01@000000
oooo0?ooo`3oool000000200oooo00D000000?ooo`3oool0oooo0000000P0?ooo`050000003oool0
oooo0?ooo`000000803oool01@000000oooo0?ooo`3oool0000002h0oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1]0?ooo`050000003o
ool0oooo0?ooo`000000803oool01@000000oooo0?ooo`3oool000000240oooo00@000000?ooo`3o
ool00000803oool01@000000oooo0?ooo`3oool0000002h0oooo00<000000?ooo`3oool0303oool0
00d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1]0?ooo`050000003oool0oooo
0?ooo`000000803oool01@000000oooo0?ooo`3oool000000240oooo00@000000?ooo`3oool00000
8@3oool010000000oooo0?ooo`00000^0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0KP3oool010000000oooo0?ooo`00000Q0?ooo`04
0000003oool0oooo00000240oooo00@000000?ooo`3oool000008@3oool010000000oooo0?ooo`00
000^0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0KP3oool00`000000oooo0000000R0?ooo`030000003oool000000280oooo00<00000
0?ooo`0000008P3oool010000000oooo0?ooo`00000^0?ooo`030000003oool0oooo00`0oooo000=
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0000000R
0?ooo`<000008P3oool3000002<0oooo0P00000_0?ooo`030000003oool0oooo00`0oooo000=0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool0K`3oool2000002<0oooo0P00000S0?oo
o`8000008`3oool2000002l0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
303oool000d0oooo00<000000?ooo`3oool0A03oool200000?l0oooo4@3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0<0?ooo`003@3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo403oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0Y0?ooo`040;md000000000000
07Boo`<0oooo00<0omnL04P0001d_ol00P3oool01P3ogi`0B00000000000000004RL0=ooo`T0oooo
0P00003o0?oooa40oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0:03o
ool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0
000007Boo`3oool0omnL04Qd_`T0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo02L0oooo00<0oooO09a80018W=l00P3oool00`3o
_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo00L0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo02L0oooo00<0oooO09a80018
W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`030?oo_`1d07@0_ooo00L0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo02L0
oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`0:0?ooo`030?oog`2LB000M;oo00L0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo02P0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030?oo
_`1d0000B9cO00L0oooo0P00003o0?oooa40oooo00<000000?ooo`3oool0303oool000d0oooo00<0
00000?ooo`3oool0:03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0
okmd0000001d_ol0o`3ooolJ0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0
oooo02P0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`060?oOg`3Oool0
okmd0000000007@0_oooo`3ooolJ0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003o
ool0oooo02P0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`060?ooo`050?oo
_`1d000000000000B02Lgol0o`3ooolK0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo02T0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030=nL
W02oool0oooo0?l0oooo703oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`0Z0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`3ogi`0M9cO0?ooo`3o0?oooa`0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0:`3oool0103OW4P00000
00000000M;l:0?ooo`050;md00000000000000000018W=l0o`3ooolI0?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo0<l0oooo00H0_g@000000000000000000000M02ooon1
0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0=00oooo00D0okmd0018
W03Oool0omnL09boo`210?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo
0=40oooo00<0omnL04Q8W03Oool0PP3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`2R0?ooo`080=nLB000000000000000000004P0W=oo0?ooo`3OW4P3000000030000B02L
gol0gia800L0000000H0M;oo0?ooo`3oool0oooo0;md0000M;l70?ooo`030?oo_`1d000000000080
000000<004RL0=ooo`3oool01P3oool00`3ogi`0B4RL0=ooo`210?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo0:<0oooo00@0oooO09a80000B9`0gooo0`3oool0103ooml0
W4P00018W03Oool20?ooo`090?oog`2LB00004RL0=ooo`3oool0oooO09a80000000007Bo0080oooo
00<0okmd0000M02oool01@3oool0103ogi`0B0000018W03Oool20?ooo`030;md00000000B9cO00L0
oooo00<0omnL07BLg`3oool0P03oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo
0?ooo`2T0?ooo`030?noM00004P0W=oo00@0oooo00<0okmd0000B02Lgol00`3oool00`3o_g@0001d
0;ooo`030?ooo`070;md00000000M;oo0?ooo`3ogi`0B00007Boo`050?ooo`030;md000004P0W=oo
00@0oooo00<0okmd00000000M;l01`3oool00`2oM4P0W=oo0?ooo`1o0?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo0:@0oooo00<0omnL04P0001d_ol0103oool00`3ogi`0
B00007Boo`030?ooo`030?oo_`1d0000M;oo00<0oooo00P0okmd00000000M;l0oooo0?oog`2LB000
04RL0=ooo`<0oooo00@0oooO09a80000B9`0gooo1@3oool00`3OW4P0000004RLg`020?ooo`060?oO
g`3Oool0oooo0?ooo`3OW4P0B9cOP03oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`2T0?ooo`030?oog`2LB00007Bo00@0oooo00<0oooO09a80000M;l00`3oool00`3ooml0
W4P0001d_`030?ooo`030?noM0000000B9cO0080oooo00<0_g@004QdM01dW=l00`3oool0103ookl0
M0000018W03Oool50?ooo`0;0?oo_`1d0000001d0;ooo`3oool0oono07A8W03Oool0oooO09a80018
W=l0P03oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`2U0?ooo`030;md
0000B9`0gooo00@0oooo00<0_g@00018W03Oool00`3oool0203OW4P004RL0=ooo`3oool0oono07@0
000007@0_ooo0P3oool0103o_g@004RL0;nLB01d_ol20?ooo`040?oog`2LB000001809cOo`H0oooo
00<0gia800000018W=l00P3oool01@3ogi`0B00000000000B9`0gooo0800oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0Y@3oool00`3o_g@0000000000005000000030000
B02Lgol0oooo0080oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`020?ooo`0:0?oo
_`1d04P0W=oo0;md001dM7@004RL0=ooo`3OW4P0000004RLg`H0oooo00@0omnL04P00000B9`0gooo
QP3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`2U0?ooo`030?oo_`1d
0000M;oo00@0oooo00<0omnL04P0001d_ol00`3oool00`3ookl0M00007Boo`020?ooo`0@0?noM000
000007Bo0?ooo`3ogi`0B0000000001d_ol0oooo0;md000007@0_ooo0?oo_`1d000004RL0=ooo`D0
oooo00@0oooO09a80000B9`0goooQP3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`2U0?ooo`030?oog`2LB00007Bo00@0oooo00<0oooO09a80000M;l0103oool00`2oM000
07Bo0?ooo`020?ooo`030?noM0000000M;oo00T0oooo00<0okmd00000018W=l01@3oool0103ooml0
W4P00018W03Ooon60?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0:H0
oooo00<0gia80018W03Oool0103oool00`2oM00004RL0=ooo`030?ooo`030=nLB000B9`0gooo0080
oooo00<0omnL04P00000M;l02P3oool00`3OW4P0000007Boo`040?ooo`030?oo_`1d000007Bo08L0
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0YP3oool00`3o_g@00000
07Boo`040?ooo`030?noM0000000M;oo00<0oooo00<0okmd0000B02Lgol00P3oool00`2oM0000000
07Boo`0;0?ooo`030?noM000000007Bo0080oooo00@0oooO09a8000004P0W=ooQ`3oool00`000000
oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`2U0?ooo`080;md00000000000000000000
07@0_ooo0?ooo`2oM003000000030000B02Lgol0_g@000H0000000<0M;oo0?ooo`3oool0303oool0
1P2oM0000000000000000000001d0;ooohP0oooo00<000000?ooo`3oool0303oool000d0oooo00<0
00000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0
oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oo
oeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`03
0000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo
0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303o
ool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?oo
o`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000
oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0
o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`00
3@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<0
00000?ooo`3oool0o`3ooomG0?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0
oooo0?l0ooooE`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oo
oeL0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`03
0000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000000oooo
0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooeL0oooo00<000000?ooo`3oool0303o
ool000d0ooooo`00001K000000h0oooo003o0?ooogH0oooo003o0?ooogH0oooo003o0?ooogH0oooo
003o0?ooogH0oooo003o0?ooogH0oooo003o0?ooogH0oooo003o0?ooogH0oooo003o0?ooogH0oooo
003o0?ooogH0oooo003o0?ooogH0oooo002=0?ooo`030=nLB0000000000000D0000000D0M;oo0?oo
o`3oool0oono07@0000700000003001d_`3oool0oooo00D0oooo00<0_g@0001d_`3oool01@3oool0
1@3OW4P00000000000000000M;oo0080oooo00/0omnL04P000000000000007Boo`3OW4P000000018
W03Oool0oooo0=nLB002000000080000B02Lgol0oooo0?ooo`3o_g@000000000B02Lgol20?ooo`04
0;md00000000001809cOo`80oooo00D0okmd000000000000001809cOo`030?ooo`030=nLB000B9`0
gooo0080oooo00<0_g@000000000M;l0T03oool008h0oooo00T0oooO09a80000B9`0gooo0?ooo`3o
oml0W4P000000000M;l00P3oool0103ogi`0B0000018W03Oool30?ooo`030=nLB00007@0_ooo00H0
oooo00<0okmd0000M02oool0103oool00`3ogi`0B00007Boo`020?ooo`0V0;md0000M;l0oooo0;md
0000B9`0gooo0?ooo`2oM000M7Ad0000M02ogi`0W;oo0?noM0000000M;oo0?ooo`3ooml0W4P004RL
g`3oool0okmd0000B02Lgml0W7BL0=ooo`3oool0gia80018W03Ooml0W7BL0=ooo`3ogi`0B01809cO
o`3oool0omnL04P00000M;l20?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;oo
S`3oool008l0oooo00<0okmd0000M02oool00`3oool00`2oM000000007Boo`020?ooo`030?noM000
000007Bo00@0oooo00<0okmd07Boo`3oool01@3oool00`3ogi`0B00007Boo`040?ooo`030=nLB000
B9`0gooo00<0oooo00@0gibL0;ooo`2oM00007Bo0`3oool01`2oM000000007Boo`3oool0gia80018
W03Oool00`3oool01@3Ogml0oooo0?oo_`1d0000M;oo00<0oooo00<0okmd0000B02Lgol00P3oool0
0`3OW4P004RL0=ooo`020?ooo`070?oOW0180000B9cO0?ooo`3ookl0M00004RLg`020?ooo`030?oO
W01804P0W=oo0900oooo002?0?ooo`030?oo_`1d0000M;oo00<0oooo00<0okmd00000000M;l00`3o
ool00`3OW4P0000004RLg`0;0?ooo`040?oog`2LB00004RL0=ooo`<0oooo00D0okmd000000000000
000004RLg`030?ooo`030?noM00007@0_ooo0080oooo00L0oono07@00018W=l0oooo0?noM00007@0
_ooo00H0oooo00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0
_ooo00<0oooo00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2@0?oo
o`00S`3oool00`3ooml0W4P0001d_`030?ooo`030?noM0000000B9cO00@0oooo00<0_g@00000001d
_ol02`3oool00`2oM000B7Ad07BLg`030?ooo`0;0?oo_`1d04P0W=oo0?ooo`3OW4P0000004RLg`3o
ool0oono07@0001d_ol00`3oool01P2oM00004RL0=ooo`3ookl0M00007Boo`H0oooo00<0gia80018
W03Oool00`3oool01`2oM00004RL0=ooo`3oool0oono07@0001d_ol00`3oool01`3ogi`0B01809cO
o`3oool0gia80018B018M;l00P3oool00`2oM00007Bo0?ooo`2?0?ooo`00T03oool0203OW4P004RL
0=ooo`3oool0oono07@0000007@0_ooo103oool0103ooml0W4P00000B02Lgol:0?ooo`040?noM000
B9`0_ia807Boo`<0oooo00/0okmd0018W03Oool0oooo0?oo_`1d0000B9cO0?ooo`3o_g@0001d0;oo
o`020?ooo`0?0=nLB00007@0_ooo0?ooo`3OW4P0001d0;ooo`3oool0oono07@0001d_ol0oooo0?oO
W01804P0W=oo00<0oooo00<0gia80000B02Lgol00P3oool00`3OW4P0001d0;ooo`020?ooo`0<0?oo
_`1d0000M;oo0?ooo`3o_g@0001d0;noM018W=l0oooo0?noM00007@0_oooS`3oool00900oooo00<0
okmd0000000000000P0000000`00M;l0oooo0?ooo`050?ooo`040?oo_`1d0000001d0;ooo`T0oooo
01L0oono07@0B02Lgol0_g@007AdM000B9`0gooo0?ooo`3OW4P0001d0;ooo`3oool0gia80018W03O
ool0oooo0=nLB00007@0_ooo0?ooo`2oM000001809cOo`020?ooo`0:0;md000007@0_ooo0?ooo`3O
W4P0B9cO0?ooo`3ooml0W4P004RLg`<0oooo00<0omnL04P00018W=l00`3oool0402oM000001d0;oo
o`3oool0okmd0000M02oool0oooo0?oog`2LB000M;oo0=nLB000M;l0omnL04P0B02Lgon?0?ooo`00
T03oool00`3ookl0M00007Boo`020?ooo`030?noM000000007Bo00H0oooo00<0omnL04P00000M;l0
203oool0203ogi`0B0000000001d_ol0oooo0;md000007@0_ooo0P3oool01@3ogi`0B00000000000
0000M;oo00<0oooo00H0omnL04P000000000B9bL07@00018W=l30?ooo`070?oOW018000000000000
B02Lgol0oono07@000030000000607Boo`3o_g@0000000000000B9`0gooo0`3oool03`3o_g@00000
000000000000M;oo0?ooo`3ookl0M00000000018W=l0oooo0?noM0000000001809cOo`2?0?ooo`00
T@3oool00`2oM00007Bo0?ooo`020?ooo`030?noM0000000M;oo00H0oooo00<0okmd00000018W=l0
:@3oool00`3o_g@0001d0;ooo`2W0?ooo`00T@3oool00`3OW4P004RL0=ooo`020?ooo`060?oOW018
000007Bo0?ooo`3ookl0W9cO103oool00`3OW4P0000007Boo`0Y0?ooo`030=nLM02Lgol0oooo0:H0
oooo002A0?ooo`030?noM00004P0W=oo0080oooo00<0_g@00000001d_ol00P3oool00`2oM4P0W=oo
0?ooo`030?ooo`030;md000004P0W=oo02d0oooo00@0oono07@00000B9`0goooX03oool00900oooo
00<0_g@0000000000000100000001@1d_ol0oooo0?ooo`3oool0gia800L0000000<0001d0;ooo`3o
ool0c`3oool00?l0ooooMP3oool00?l0ooooMP3oool00?l0ooooMP3oool00?l0ooooMP3oool00?l0
ooooMP3oool00001\
\>"],
  ImageRangeCache->{{{0, 372.125}, {736.875, 0}} -> {-0.0672043, -0.134312, \
0.00457269, 0.00457269}, {{22, 350.063}, {692.813, 490.063}} -> {-39.0899, \
-4.27379, 0.650523, 0.0270557}, {{22, 350.063}, {469.75, 267.063}} -> \
{-35.2202, -2.26449, 0.650784, 0.0100285}, {{22, 350.063}, {246.75, 44}} -> \
{-39.0899, -12.3195, 0.650523, 0.0270557}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1392, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowCellLabel->False,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}, {
        Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->0.5,
    CellMargins->{{25, 0}, {6, 6}},
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 1, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 103, 2, 81, "Title"],
Cell[1882, 57, 455, 15, 85, "Author"],

Cell[CellGroupData[{
Cell[2362, 76, 31, 0, 83, "Section"],
Cell[2396, 78, 866, 13, 145, "Text"],
Cell[3265, 93, 354, 6, 67, "Text"],
Cell[3622, 101, 1015, 28, 91, "DisplayFormula",
  Evaluatable->False],
Cell[4640, 131, 1224, 38, 119, "Text"],

Cell[CellGroupData[{
Cell[5889, 173, 36, 0, 55, "Subsubsection"],
Cell[5928, 175, 387, 7, 67, "Text"],
Cell[6318, 184, 442, 10, 67, "Text"],
Cell[6763, 196, 297, 7, 41, "Text"],
Cell[7063, 205, 329, 10, 41, "Text"],
Cell[7395, 217, 341, 10, 41, "Text"],
Cell[7739, 229, 316, 10, 41, "Text"],
Cell[8058, 241, 248, 7, 41, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8355, 254, 33, 0, 51, "Section"],
Cell[8391, 256, 221, 4, 125, "Input"],
Cell[8615, 262, 145, 4, 95, "Input"],
Cell[8763, 268, 120, 2, 99, "Input"],
Cell[8886, 272, 75, 1, 73, "Input"],
Cell[8964, 275, 802, 25, 99, "Input"],
Cell[9769, 302, 134, 2, 99, "Input"],
Cell[9906, 306, 256, 4, 74, "Input"],

Cell[CellGroupData[{
Cell[10187, 314, 85, 1, 73, "Input"],
Cell[10275, 317, 743, 19, 75, "Output"]
}, Closed]],
Cell[11033, 339, 187, 3, 96, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11257, 347, 45, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[11327, 351, 34, 0, 68, "Subsection"],
Cell[11364, 353, 287, 9, 41, "Text"],
Cell[11654, 364, 250, 4, 73, "Input"],
Cell[11907, 370, 62, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[11994, 374, 83, 1, 73, "Input"],
Cell[12080, 377, 216, 4, 75, "Output"]
}, Closed]],
Cell[12311, 384, 30, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[12366, 388, 129, 3, 73, "Input"],
Cell[12498, 393, 913, 24, 207, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[13448, 422, 66, 1, 73, "Input"],
Cell[13517, 425, 353, 6, 59, "Output"]
}, Closed]],
Cell[13885, 434, 163, 3, 41, "Text"],
Cell[14051, 439, 115, 2, 73, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14203, 446, 38, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[14266, 450, 118, 2, 73, "Input"],
Cell[14387, 454, 216, 4, 75, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[14640, 463, 93, 1, 73, "Input"],
Cell[14736, 466, 593, 10, 140, "Output"]
}, Closed]],
Cell[15344, 479, 306, 5, 67, "Text"],

Cell[CellGroupData[{
Cell[15675, 488, 82, 1, 73, "Input"],
Cell[15760, 491, 246, 4, 59, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16067, 502, 43, 0, 51, "Section"],
Cell[16113, 504, 125, 3, 41, "Text"],
Cell[16241, 509, 2095, 34, 463, "Input"],
Cell[18339, 545, 335, 6, 67, "Text"],

Cell[CellGroupData[{
Cell[18699, 555, 146, 3, 73, "Input"],
Cell[18848, 560, 225053, 5329, 750, 73312, 3451, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

