(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    108282,       1824]*)
(*NotebookOutlinePosition[    142220,       3047]*)
(*  CellTagsIndexPosition[    142176,       3043]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Inverse Iteration Method for Julia Sets", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "from ",
  StyleBox[ButtonBox["Essential Mathematica for Students of Science",
    Active->False,
    ButtonData:>{
      URL[ 
      "http://www.physics.umd.edu/courses/CourseWare/EssentialMathematica/"], 
      None},
    Active->False,
    ButtonStyle->"Hyperlink"],
    Active->False],
  "\n\[Copyright] James J. Kelly, 1998\nLast revised: January, 2006"
}], "Author",
  Active->True,
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
The inverse iteration method (IIM) is based upon a theorem due to Julia and \
Fatou stating that a Julia set consists of all periodic repelling points of a \
nonlinear mapping function on the complex plane.  To understand how this \
theorem can be used as the basis for algorithms that construct Julia sets, we \
review some of the terminology and properties of iterated dynamical \
systems.\
\>", "Text"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] f[z, c]\)]],
  " represent a mapping of points in the complex plane generated by a \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " with parameter ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ".  Forward iteration of the map beginning with seed ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)]],
  " produces a sequence of points ",
  Cell[BoxData[
      \(TraditionalForm\`{z\_0, \ z\_1, \ \[CenterEllipsis], \ z\_k}\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm
      \`z\_k = \(f[z\_\(k - 1\), c] = 
          \(\(f\^k\)[z\_0, c] = f[\(f\^\(k - 1\)\)[z\_0, c]]\)\)\)]],
  " represents the ",
  Cell[BoxData[
      \(TraditionalForm\`k\^th\)]],
  " iteration of the mapping function.  This sequence of points is known as \
the ",
  StyleBox["forward orbit",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)]],
  ".  Alternatively, the ",
  StyleBox["backward orbit",
    FontSlant->"Italic"],
  " is constructed by inverse iteration ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(f\^\(-k\)\)[z, c] = \(f\^\(-1\)\)[\(f\^\(1 - k\)\)[z, c]]\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\(-1\)\)[z, c]\)]],
  " is the inverse of ",
  StyleBox["f",
    FontSlant->"Italic"],
  ".  However, because the inverse function for interesting systems is \
usually multivalued, the backward orbit has a tree structure in which the \
number of points grows geometrically as the iteration progresses.  This basic \
structure is illustrated below.  The points obtained by inverse iteration are \
described as ",
  StyleBox["pre-images",
    FontSlant->"Italic"],
  " of the initial point."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.228571 0.603319 0.147151 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
4 Mabswid
.5 .60332 Mdot
.27143 .45617 Mdot
.72857 .45617 Mdot
.15714 .30902 Mdot
.38571 .30902 Mdot
.61429 .30902 Mdot
.84286 .30902 Mdot
.08095 .16187 Mdot
.23333 .16187 Mdot
.30952 .16187 Mdot
.4619 .16187 Mdot
.5381 .16187 Mdot
.69048 .16187 Mdot
.76667 .16187 Mdot
.91905 .16187 Mdot
.02381 .01472 Mdot
.1381 .01472 Mdot
.17619 .01472 Mdot
.29048 .01472 Mdot
.25238 .01472 Mdot
.36667 .01472 Mdot
.40476 .01472 Mdot
.51905 .01472 Mdot
.48095 .01472 Mdot
.59524 .01472 Mdot
.63333 .01472 Mdot
.74762 .01472 Mdot
.70952 .01472 Mdot
.82381 .01472 Mdot
.8619 .01472 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{233.563, 144.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004S0000]2000`400?l00000o`00003o203oool2
ooooo`03kooooooooooooooo00?ooooo0`3oool00`7oool0oooo0?ooo`020?ooo`03ooooonoooooo
oooo00Gooooo203oool8ooooo`P0oooo2?ooool30?ooo`032?ooo`3oool0oooo0080oooo0_ooool0
0moooooiooooooooo`03ooooo`<0oooo00<4oooo0?ooo`3oool00P3oool3ooooo`03o_oooooooooo
oooo00;ooooo203oool2ooooo`03oOoooooooooooooo00?ooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool00ooooomoooooooooo`05ooooo`P0oooo2?ooool80?ooo`;ooooo00?noooo
ooooooooool00oooool80?ooo`Sooooo203oool8ooooo`030?oooh3oool0oooo00D0oooo4?ooool8
0?ooo`Sooooo203oool3ooooo`00203oool8ooooo`80oooo00>0oooo0?ooo`3oool00`3oool8oooo
o`03P?ooo`Coool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo0oooool00oOo
ooooooooooooo`02ooooo`P0oooo2?ooool30?ooo`034?ooo`3oool0oooo0080oooo2?ooool30?oo
o`03P?ooo`3oool0oooo0080oooo0oooool00ogoooooooooooooo`02ooooo`P0oooo2?ooool00`3o
oom0oooo1?ooo`050?ooo`?ooooo00?Oooooooooooooool00_ooool00h3oool0oooo@?ooo`050?oo
o`Sooooo203oool00kooooooooooooooo`05ooooo`03P?ooo`3oool0oooo00D0oooo0_ooool00o_o
ooooooooooooo`03ooooo`P0oooo2?ooool00a3oool0oooo0?ooo`050?ooo`Sooooo203oool3oooo
o`03gooooooooooooooo00;ooooo00<0ooooP?ooo`3oool01@3oool8ooooo`<0oooo00060?ooo`80
000000?o0000oooooo_oool01Oooool00`3oool@oooo0?ooo`050?ooo`Sooooo1`3oool01@00003n
0000o`000?ooooo_oooo00Cooooo0P3oool3000000<0oooo0_ooool00nooooooooooooooo`03oooo
o`P0oooo00?o0000m`000?l000001Oooool30?ooo`<000000P3oool8ooooo`P0oooo00Coooooo`00
0?h0003o00001?ooool40?ooo`<0000000<0ooooooooooooool01_ooool80?ooo`;ooooo00?O0000
o`000?l000000oooool30?ooo`030Oooo`3oool00000008000002?ooool80?ooo`Cooooo0ol00000
0oooool0oooo0?ooo`050?ooo`0300000?l0003o000000Kooooo203oool5ooooo`?o00000`3oool0
0`Coool0oooo0?ooo`020?ooo`?o00001Oooool80?ooo`Kooooo0_l000000`000000oooo0?ooo`05
0?ooo`04Ooooool0003k0000o`0000Cooooo203oool8ooooo`P0oooo0_ooool3o`0000?ooooo0`3o
ool000D0oooo0`0000000ol0003n0000ooooo`05ooooo`<0oooo00<4oooo0?ooo`3oool00P3oool8
ooooo`H0oooo0P000002o`000003k`000?oooooooooo00?ooooo00<0oooo0000000000000`000002
0?ooo`;ooooo00?mooooooooooooool00oooool70?ooo`0300000?l0003o000000;o00001?ooool2
0?ooo`D0000000@0oooooooooooooookoooo1Oooool00`Coool1oooo0?ooo`050?ooo`03o`0007l0
003o000000;o00000oooool30?ooo`D000000oooool00nooooooooooooooo`02ooooo`P0oooo00?k
ooooo`000?d000000ol00002ooooo`@0oooo100000000ol0003oooooooooo`05ooooo`P0oooo00?o
ooooOoooooooool01Ol000060?ooo`8000000ol00005ooooo`P0oooo0_ooool00o_oooooooooo`00
0003o`0000030000003oool0oooo00@0oooo00<00000o`000?l000000_l00004ooooo`P0oooo1Ooo
ool3o`00008000001P3oool00ol0003m0000o`000002o`0000?ooooo203oool8ooooo`030?ooo`Co
ool0oooo00D0oooo00?_ooooo`000?/000000ol00002ooooo`48oooo0@3oool10?ooo`001@3oool3
00000004k`000?l0003_oooonoooo`Cooooo203oool00okoooooooooooooo`05ooooo`H0oooo0P00
0003o`0000Gooooo00<0oooo0000000000000`0000020?ooo`Sooooo00<0ooooP?ooo`3oool0103o
ool00`00003g0000o`000002o`0000Cooooo0P3oool5000000040?oooooooooooooonoooo`Gooooo
203oool5o`0000?ooooo0`3oool5000000Sooooo203oool00okooooo0000o`000003o`0000;ooooo
00B0oooo0?ooo`3oool0oooo100000001?l0003ooooooooooo_oool4ooooo`P0oooo0oooool5o`00
00H0oooo0P000003o`0000Gooooo203oool4ooooo`Co000000<000000?ooob3oool0103oool00`00
003o0000o`000002o`0000Cooooo0P3oool00b3oool0oooo0?ooo`030?ooo`Gooooo0ol000020000
00H0oooo0_l000000kl0003o0000o`000003ooooo`P0oooo2?ooool80?ooo`03ooooool0003o0000
00?o00000_ooool30?ooo`001@3oool300000003oP000?l0003ooooo00Gooooo203oool8ooooo`80
oooo00B0oooo0?ooo`3oool0oooo0P000002o`000003n`000?oooooooooo00?ooooo00<0oooo0000
000000000`0000020?ooo`03kooooooooooooooo00Gooooo1`3oool00`00003o0000o`000002o`00
00Cooooo0P3oool5000000030?oooooooomooooo00Kooooo203oool00ol0003n0000o@000002o`00
00?ooooo0`3oool5000000Sooooo203oool00ooooooo0000o`000003o`0000;ooooo103oool40000
0003o`000?oooooooooo00Gooooo203oool00o_ooooooooomoooo`05o`0000040?oooh3oool0oooo
0_ooo`80oooo0P000003o`0000Gooooo203oool017ooooooooooooooooooool4o`0000034000003o
ool0oooo00@0oooo00<00000o`000?l000000_l00004ooooo`P0oooo0_ooool00gooooo_oooooooo
o`03o`00008000001P3oool3o`000003n`000?l0003ooooo00;ooooo203oool00goooooooooooooo
o`05ooooo`P0oooo00?ooooo_`000?l000000ol00002ooooo`<0oooo0006ooooo`;o000000<00000
0?ooo`3oool01@3oool8ooooo`L0oooo00<4ooooooooooooool01Oooool00ol00000000000000006
0?ooo`;ooooo0ol00003ooooo`P0oooo2?ooool3000000D0oooo0oooool3o`0000;ooooo1P3oool0
0d3oool0ooooooooo`06ooooo`03[oooo`3oool0000000800000103oool4ooooo`?o000000?ooooo
0?ooo`3oool01@3oool00h3oool0oooo0?ooo`060?ooo`03oOooooOoooon000000;o00000oooool0
0a3oool0oooo0?ooo`020?ooo`<000000oooool00oOoooooooooooooo`02ooooo`80oooo00<Hoooo
0?ooo`3oool00`3oool4ooooo`?o000000CoooooP?ooo`3oool@oooo103oool00`00003o0000o`00
0006ooooo`03@?ooo`3oool0oooo00D0oooo0_ooool00oOoooooooooooooo`03o`0000P0oooo0ol0
0005ooooo`03P?ooo`3oool0oooo00D0oooo1_ooool2o`0000030000003oool0oooo00D0oooo00Co
ooooo`000?l0003o00001?ooool80?ooo`03oooookoooooooooo00Gooooo203oool00oOooooooooo
o`000002o`0000?ooooo0B3oool10?ooo`40oooo0008ooooo`P0oooo2?ooool80?ooo`Sooooo1@3o
ool00`Cooon0oooo0?ooo`08ooooo`P0oooo2?ooool80?ooo`Oooooo00>_oooo0?ooo`3oool00P3o
ool0183oool0oooo0?ooo`3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool3ooooo`001?ooool01;oooooooooooOooooooool60?ooo`034?oo
o`3ooooooooo00Oooooo203oool8ooooo`P0oooo2?ooool80?ooo`Gooooo00=oooooooooooooool0
203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?koooo0?ooo`3oool01P3oool8ooooo`H0oooo
00<@oooo0?ooooooool01_ooool00o_oool0oooo0?ooo`060?ooo`Sooooo203oool4ooooo`04Oooo
ooooooooooooooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Go
oooo00?_ooooooooooooool0203oool5ooooo`03mooooooooooooooo00P0oooo0oooool000Sooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Kooooo
00?kooooooooo`3oool01`3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`?ooooo0007ooooo`03Ooooo`3oool0oooo00H0oooo2?ooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo1P3oool00aCoool0ooooooooo`07ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo1_ooool00oOooooooooo0?ooo`070?ooo`Sooooo203o
ool3ooooo`002?ooool80?ooo`Sooooo203oool6ooooo`03koooooooool0oooo00L0oooo2?ooool8
0?ooo`Oooooo00?_oooo0?ooo`3oool01P3oool7ooooo`03_oooo`3oool0oooo00H0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?_oooo0?ooo`3oool01P3oool8
ooooo`P0oooo2?ooool80?ooo`Sooooo203oool7ooooo`03moooo`3oool0oooo00H0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo0oooool000Sooooo203oool8ooooo`P0oooo1oooool00ogo
ool0oooo0?ooo`060?ooo`Sooooo203oool7ooooo`03Ooooo`3oool0oooo00H0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`H0oooo00>0oooo0?oo
ooooool01oooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8oooo
o`P0oooo2?ooool80?ooo`?ooooo00080?ooo`?ooooo00?Oooooooooooooool00_ooool80?ooo`So
oooo203oool8ooooo`P0oooo2?ooool80?ooo`;ooooo00?_ooooooooooooool00oooool30?ooo`03
0Oooo`3oool0oooo0080oooo00?oooook_ooooooool01Oooool80?ooo`Sooooo203oool8ooooo`<0
oooo00<8oooo0?ooo`3oool00P3oool2ooooo`03gooooo_ooooooooo00?ooooo0`3oool00`Coool0
oooo0?ooo`020?ooo`?ooooo00?nooooooooooooool00_ooool80?ooo`;ooooo00?moooooooooooo
ool00oooool80?ooo`?ooooo00?_ooooooooooooool00_ooool80?ooo`Sooooo203oool8ooooo`P0
oooo00?oooooOoooooooool01Oooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool30?ooo`00
203oool8ooooo`P0oooo2?ooool80?ooo`;ooooo00?nooooooooooooool00oooool00`3ooon0oooo
0?ooo`050?ooo`Sooooo203oool8ooooo`P0oooo2?ooool00h3oool4oooo0?ooo`050?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool30?ooo`03P?oo
o`3oool0oooo0080oooo0oooool00ogoooooooooooooo`02ooooo`P0oooo2?ooool00`3ooom0oooo
1?ooo`050?ooo`?ooooo00?Oooooooooooooool00_ooool00h3oool0oooo@?ooo`050?ooo`Sooooo
203oool00kooooooooooooooo`05ooooo`03P?ooo`3oool0oooo00D0oooo0_ooool00o_ooooooooo
ooooo`03ooooo`<0oooo00080?ooo`Sooooo00<0oooo1?ooo`3oool01@3oool00noooooooooonooo
o`05ooooo`032?ooo`3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool2ooooo`03nooooooo
oooooooo00?ooooo00<0oooo4?ooo`3oool01@3oool8ooooo`P0oooo00Cnooooooooooooooo_oooo
1?ooool80?ooo`;ooooo00?_ooooooooooooool00oooool80?ooo`03ooooooOooooooooo00Gooooo
00<0oooo4?ooo`3oool01@3oool8ooooo`P0oooo0_ooool00okoooooooooooooo`03ooooo`P0oooo
2?ooool80?ooo`Sooooo0`3oool00`7oool0oooo0?ooo`020?ooo`Sooooo203oool8ooooo`P0oooo
0_ooool00ogoooooooooooooo`03ooooo`P0oooo2?ooool30?ooo`031?ooo`3oool0oooo0080oooo
2?ooool30?ooo`00203oool8ooooo`P0oooo2?ooool80?ooo`?ooooo00?kooooooooooooool00_oo
ool80?ooo`;ooooo00?nooooooooooooool00oooool80?ooo`Sooooo0`3oool00`Coool0oooo0?oo
o`020?ooo`Sooooo203oool2ooooo`03kooooooooooooooo00?ooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`;ooooo00?kooooooooooooool00oooool00`Coool0oooo0?ooo`050?ooo`03ooooogoo
oooooooo00Gooooo203oool3ooooo`03kooooooooooooooo00;ooooo203oool2ooooo`03oOoooooo
oooooooo00?ooooo203oool8ooooo`P0oooo00?oooooOoooooooool01Oooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool30?ooo`00203oool00gooooooooooooooo`05ooooo`P0oooo00?ooooo
_oooooooool01Oooool80?ooo`03ooooomoooooooooo00Gooooo203oool8ooooo`P0oooo00C_oooo
ooooonoooookoooo1?ooool80?ooo`03o_oooooooooooooo00Gooooo0`3oool00`Coool0oooo0?oo
o`020?ooo`Sooooo203oool8ooooo`030?oooh3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool80?ooo`03o_ooonoooooooooo00Gooooo00>0oooo0?ooo`3oool01@3o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`80oooo00<Poooo0?ooo`3oool00`3o
ool8ooooo`80oooo0B3oool000P0oooo00?ooooo_oooooooool01Oooool80?ooo`03mooooogooooo
oooo00Gooooo00<Poooo0?ooo`3oool01@3oool8ooooo`P0oooo2?ooool80?ooo`03o_oooooooooo
oooo00Gooooo203oool8ooooo`P0oooo0_ooool00o_oooooooooooooo`03ooooo`P0oooo00?_oooo
ooooooooool01Oooool80?ooo`Sooooo203oool00ooooomoooooooooo`05ooooo`P0oooo00?ooooo
o_oooogoool01Oooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`03noooooooooog
oooo00Gooooo00@0ooooP?ooo`3oool2oooo103oool8ooooo`P0oooo00=oooooooooooooool01Ooo
ool80?ooo`Sooooo0`3oool000Sooooo203oool8ooooo`P0oooo1_ooool00okoooo_oooo0?ooo`07
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool70?ooo`031?oooooooooooooo00Kooooo203oool8
ooooo`P0oooo2?ooool50?ooo`030_ooo`3oool0oooo00Sooooo203oool7ooooo`03_oooo`3oool0
oooo00H0oooo2?ooool@0?ooo`03oOooooOoooonoooo00Gooooo203oool3ooooo`03mooooooooooo
oooo00;ooooo00<0oooo2?ooo`Soool01@3oool8ooooo`03P?ooo`3oool@oooo00D0oooo2?ooool0
0d3oool0oooo0?ooo`050?ooo`;ooooo00?Gooooooooooooool00oooool20?ooo`038?ooo`3oool0
oooo00<0oooo2?ooool1P?ooo`40oooo0@3oool000Gooooo00?_ooooooooooooool0203oool5oooo
o`03mooooooooooooooo00P0oooo2?ooool70?ooo`031?oooooooooooooo00Kooooo203oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo1@3oool00`Coool0oooo0?ooo`08ooooo`P0oooo2?ooool80?oo
o`Oooooo00>_oooo0?ooo`3oool00P3oool0183oool0oooo0?ooo`3oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`?ooooo0008ooooo`P0oooo2?ooool80?ooo`Oooooo00?moooo0?ooo`3oool01P3oool8oooo
o`P0oooo1?ooool01;oooooooooooOooooooool80?ooo`Sooooo203oool6ooooo`03goooooooool0
oooo00L0oooo2?ooool80?ooo`Gooooo00=oooooooooooooool0203oool8ooooo`P0oooo2?ooool8
0?ooo`Oooooo00?koooo0?ooo`3oool01P3oool8ooooo`H0oooo00<@oooo0?ooooooool01_ooool0
0o_oool0oooo0?ooo`060?ooo`Sooooo203oool4ooooo`04Ooooooooooooooooooooo`P0oooo1ooo
ool00mooool0oooo0?ooo`060?ooo`Sooooo203oool3ooooo`002?ooool80?ooo`Sooooo203oool4
ooooo`04Ooooooooooomooooooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Kooooo00?kooooooooo`3oool01`3o
ool8ooooo`P0oooo0oooool000Sooooo203oool8ooooo`P0oooo1oooool00okoool0oooo0?ooo`06
0?ooo`Sooooo203oool7ooooo`03Ooooo`3oool0oooo00H0oooo2?ooool50?ooo`03P?ooo`3oool0
oooo00Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo1P3oool00aCoool0ooooooooo`07
ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo2?ooool80?ooo`?ooooo0008ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool6ooooo`03koooooooool0oooo00L0oooo2?ooool80?oo
o`Oooooo00?_oooo0?ooo`3oool01P3oool7ooooo`03_oooo`3oool0oooo00H0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?_oooo0?ooo`3oool01P3oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool3ooooo`00203oool8ooooo`P0oooo2?ooool80?ooo`So
oooo00<0ooooP?ooo`3oool01@3oool@ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0
oooo1oooool00gooool0oooo0?ooo`060?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`So
oooo203oool8ooooo`P0oooo2?ooool60?ooo`03P?ooo`3ooooooooo00Oooooo203oool8ooooo`P0
oooo2?ooool80?ooo`?ooooo00080?ooo`03_ooooooooooooooo00Gooooo00>0oooo0?ooo`3oool0
1@3oool2ooooo`03nooooooooooooooo00?ooooo203oool8ooooo`034?ooo`3oool0oooo00D0oooo
2?ooool80?ooo`?ooooo00?Oooooooooooooool00_ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`;ooooo00?_ooooooooooooool00oooool30?ooo`030Oooo`3oool0oooo0080oooo
00?oooookoooooooool01Oooool80?ooo`Sooooo203oool8ooooo`<0oooo00<8oooo0?ooo`3oool0
0P3oool2ooooo`03goooooWooooooooo00?ooooo0`3oool00`Coool0oooo0?ooo`020?ooo`?ooooo
00?nooooooooooooool00_ooool80?ooo`;ooooo00?mooooooooooooool00oooool80?ooo`?ooooo
00?_ooooooooooooool00_ooool80?ooo`Sooooo203oool8ooooo`80oooo0H3oool00003P?ooo`3o
ool0oooo00D0oooo2?ooool30?ooo`031?ooo`3oool0oooo0080oooo2?ooool80?ooo`Sooooo00<0
oooo1?ooo`3oool01@3oool00goooooooooonoooo`05ooooo`P0oooo0_ooool00noooooooooooooo
o`03ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo00>0
oooo1?ooo`3oool01@3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo0`3oool00h3oool0oooo0?ooo`020?ooo`?ooooo00?mooooooooooooool00_oo
ool80?ooo`Sooooo0P3oool11?ooo`00203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool0
0oooooomooooooooo`05ooooo`P0oooo2?ooool00`3oool4oooo0?ooo`050?ooo`03kooooooooook
oooo00Gooooo00<8oooo0?ooo`3oool01@3oool8ooooo`P0oooo2?ooool80?ooo`;ooooo00?koooo
ooooooooool00oooool00`3oool@oooo0?ooo`050?ooo`Sooooo203oool01?koooooooooooooonoo
ool4ooooo`P0oooo0_ooool00nooooooooooooooo`03ooooo`P0oooo00?ooooomoooooooool01Ooo
ool80?ooo`Sooooo203oool2ooooo`03o_oooooooooooooo00?ooooo203oool8ooooo`P0oooo0_oo
ool00mooooooooooooooo`03ooooo`<0oooo00<1oooo0?ooo`3oool00P3oool8ooooo`<0oooo0008
0?ooo`Sooooo203oool8ooooo`80oooo00<Poooo0?ooo`3oool00`3oool8ooooo`P0oooo0_ooool0
0kooooooooooooooo`03ooooo`P0oooo2?ooool80?ooo`Sooooo203oool3ooooo`03nooooooooooo
oooo00;ooooo203oool2ooooo`03o_oooooooooooooo00?ooooo203oool00oooooonooooooooo`05
ooooo`<0oooo00<4oooo0?ooo`3oool00P3oool8ooooo`P0oooo0_ooool00nooooooooooooooo`03
ooooo`P0oooo0_ooool00ogoooooooooooooo`03ooooo`P0oooo0oooool00o_oooooooooooooo`02
ooooo`P0oooo0_ooool00o_oooooooooooooo`03ooooo`031?ooo`7oool0oooo00D0oooo00?ooooo
Ooooooooool01Oooool80?ooo`?ooooo00?_ooooooooooooool00_ooool80?ooo`;ooooo00?moooo
ooooooooool00oooool80?ooo`Sooooo0`3oool000P0oooo00=oooooooooooooool01Oooool00a3o
ool0oooo0?ooo`050?ooo`Sooooo203oool2ooooo`03Ooooonoooooooooo00?ooooo203oool3oooo
o`03nooooooooooooooo00;ooooo203oool017ooooooooooooooonooool4ooooo`P0oooo00=ooooo
_oooooooool01Oooool80?ooo`03ooooomoooooooooo00Gooooo203oool8ooooo`P0oooo00C_oooo
ooooonoooooKoooo1?ooool80?ooo`03o_oooooooooooooo00Gooooo0`3oool00`Coool0oooo0?oo
o`020?ooo`Sooooo203oool8ooooo`030?oooh3oool0oooo00D0oooo00?gooooooooooooool01Ooo
ool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`03o_ooonoooooooooo00Gooooo00>0
oooo0?ooo`3oool01@3oool8ooooo`<0oooo00000d3oool0oooo0?ooo`050?ooo`;ooooo00?Goooo
ooooooooool00oooool20?ooo`038?ooo`3oool0oooo00<0oooo2?ooool00h3oool0oooo0?ooo`05
0?ooo`Sooooo203oool8ooooo`P0oooo00?ooooo_oooooooool01Oooool80?ooo`03mooooogooooo
oooo00Gooooo00<Poooo0?ooo`3oool01@3oool8ooooo`P0oooo2?ooool80?ooo`03o_oooooooooo
oooo00Gooooo203oool8ooooo`P0oooo00?ooooo_ooooo_oool01Oooool80?ooo`03kooooooooooo
oooo00Gooooo203oool8ooooo`P0oooo00?oooooOoooooooool01Oooool80?ooo`03ooooookoooom
oooo00Gooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo0`3oool000Sooooo203oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Kooooo00?nooookooo
o`3oool01`3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo1`3oool00`Coooooooooooooo`06oooo
o`P0oooo2?ooool80?ooo`Sooooo1@3oool00`;oool0oooo0?ooo`08ooooo`H0oooo00=0oooo0?oo
ooooool01_ooool00jooool0oooo0?ooo`060?ooo`Sooooo1`3oool00h3oool0oooo0?ooo`060?oo
o`03oOooooOoooonoooo00Gooooo203oool3ooooo`03mooooooooooooooo00;ooooo0@3oool12?oo
o`4Hoooo0007ooooo`03goooo`3oool0oooo00H0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0
oooo2?ooool80?ooo`Gooooo00?gooooooooooooool0203oool8ooooo`L0oooo00<4oooooooooooo
ool01?ooool00koooooooooo0?ooo`070?ooo`Sooooo203oool8ooooo`P0oooo2?ooool70?ooo`03
4?oooooooooooooo00Kooooo203oool8ooooo`P0oooo1oooool00jooool0oooo0?ooo`020?ooo`04
P?ooo`3oool0oooo0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool3oooo
o`001_ooool00o_ooooooooo0?ooo`040?ooo`03P?ooo`3oool0oooo00Sooooo203oool8ooooo`P0
oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1oooool00ogoool0oooo0?ooo`060?ooo`So
oooo203oool4ooooo`04_oooooooooomooooooooo`P0oooo2?ooool80?ooo`Sooooo203oool8oooo
o`P0oooo1Oooool00gooooooooooooooo`080?ooo`Sooooo203oool8ooooo`P0oooo1oooool00o_o
ool0oooo0?ooo`060?ooo`Sooooo1P3oool00a3oool0ooooooooo`06ooooo`03noooo`3oool0oooo
00H0oooo0oooool000Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool6ooooo`03
moooooooool0oooo00L0oooo2?ooool80?ooo`Cooooo0Wooool00ogooooooooo0?ooo`070?ooo`So
oooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Ko
oooo00?_ooooooooo`3oool01`3oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?Ooooo0?ooo`3o
ool01P3oool8ooooo`P0oooo0oooool000Sooooo203oool8ooooo`P0oooo1oooool00oOoool0oooo
0?ooo`060?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?noooo0?ooo`3oool0
1P3oool8ooooo`P0oooo1oooool00gooool0oooo0?ooo`060?ooo`Sooooo203oool8ooooo`H0oooo
00<4oooo0?ooooooool01oooool80?ooo`Sooooo203oool8ooooo`H0oooo00<Doooo0?ooooooool0
1_ooool00o_oool0oooo0?ooo`060?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`?ooooo
0008ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1_ooool00noooooooooo0?oo
o`070?ooo`Sooooo203oool7ooooo`03koooo`3oool0oooo00H0oooo1oooool00kooool0oooo0?oo
o`060?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool3ooooo`00203oool8
ooooo`P0oooo2?ooool20?ooo`03P?ooo`3oool0oooo00<0oooo00?oooooOoooooooool01Oooool8
0?ooo`Sooooo203oool2ooooo`03o_oooooooooooooo00?ooooo203oool8ooooo`P0oooo2?ooool0
0`3ooon0oooo0?ooo`050?ooo`oooooo00?moooo0?ooo`3oool01P3oool8ooooo`P0oooo1oooool0
0ogoool0oooo0?ooo`060?ooo`Sooooo203oool7ooooo`03Ooooo`3oool0oooo00H0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool3ooooo`000`3oool00h3o
ool0oooo0?ooo`020?ooo`?ooooo00?mooooooooooooool00_ooool80?ooo`Sooooo0P3oool00`Co
ool0oooo0?ooo`030?ooo`?ooooo00?Oooooooooooooool00_ooool00h3oool0oooo@?ooo`050?oo
o`Sooooo203oool00kooooooooooooooo`05ooooo`03P?ooo`3oool0oooo00D0oooo0_ooool00o_o
ooooooooooooo`03ooooo`P0oooo2?ooool00a3oool0oooo0?ooo`050?ooo`Sooooo203oool3oooo
o`03gooooooooooooooo00;ooooo00<0ooooP?ooo`3oool01@3oool8ooooo`P0oooo2?ooool80?oo
o`Sooooo203oool2ooooo`03kooooooooooooooo00?ooooo0`3oool00`7oool0oooo0?ooo`020?oo
o`03ooooonoooooooooo00Gooooo203oool8ooooo`P0oooo2?ooool80?ooo`;ooooo00?OoooooOoo
ooooool00oooool30?ooo`031?ooo`3oool0oooo0080oooo0oooool00okoooooooooooooo`02oooo
o`<0oooo00080?ooo`Sooooo0`3oool00`7oool0oooo0?ooo`020?ooo`Sooooo203oool8ooooo`P0
oooo0_ooool00ogoooooooooooooo`03ooooo`P0oooo2?ooool30?ooo`031?ooo`3oool0oooo0080
oooo2?ooool80?ooo`Sooooo203oool00goooooooooonoooo`05ooooo`P0oooo0_ooool00noooooo
ooooooooo`03ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`So
oooo00>0oooo1?ooo`3oool01@3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool3ooooo`03
mooooooooooooooo00;ooooo0`3oool000P0oooo00?oooooOooooogoool01Oooool80?ooo`Sooooo
203oool00ooooomoooooooooo`05ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`03oooooogooooooooo00Gooooo203oool8ooooo`030?ooo`Coool0oooo00D0oooo
00?_oooooooooo_oool01Oooool00`Soool0oooo0?ooo`050?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool00`3oool@oooo0?ooo`050?ooo`Sooooo203oool01?koooooooooooooonooool4ooooo`P0
oooo0_ooool00nooooooooooooooo`03ooooo`P0oooo00?ooooomoooooooool01Oooool80?ooo`So
oooo0`3oool000P0oooo00?nooooooooooooool01Oooool00h3oool0oooo0?ooo`050?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo0P3oool00b3oool0oooo0?ooo`030?ooo`Sooooo
0P3oool00b3oool0oooo0?ooo`030?ooo`Sooooo203oool2ooooo`03_ooooooooooooooo00?ooooo
203oool00ooooookooooooooo`05ooooo`P0oooo2?ooool80?ooo`?ooooo00?kooooooooooooool0
0_ooool80?ooo`;ooooo00?nooooooooooooool00oooool80?ooo`Sooooo0`3oool00`Coool0oooo
0?ooo`020?ooo`Sooooo203oool2ooooo`03kooooooooooooooo00?ooooo203oool2ooooo`03oOoo
oooooooooooo00?ooooo203oool8ooooo`P0oooo2?ooool11?ooo`41oooo0@3oool000P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`040?oooh3oool0oooo0_ooo`@0oooo2?ooool80?ooo`04Oooo
oooooooooooonoooo`Cooooo203oool8ooooo`P0oooo0_ooool00gooooo_ooooooooo`03ooooo`P0
oooo0oooool00o_oooooooooooooo`02ooooo`P0oooo00Aoooooooooooooooo_oooo1?ooool80?oo
o`03oooookoooooooooo00Gooooo203oool00ooooooOooooooooo`05ooooo`P0oooo2?ooool80?oo
o`04koooooooooo_oooonoooo`Cooooo203oool00okoooooooooooooo`05ooooo`P0oooo2?ooool8
0?ooo`Sooooo00<0ooooP?ooo`3oool01@3oool8ooooo`P0oooo2?ooool30?ooo`00203oool00ogo
ooogooooo_ooo`05ooooo`034?ooo`3oool0oooo00D0oooo2?ooool20?ooo`036?ooo`3oool0oooo
00<0oooo2?ooool00h3oool0oooo4?ooo`050?ooo`Sooooo00=0oooo0?ooo`3oool01@3oool2oooo
o`03eooooooooooooooo00?ooooo203oool8ooooo`03P?ooo`3oool0oooo00D0oooo2?ooool80?oo
o`Sooooo203oool00ooooonoooooooooo`05ooooo`P0oooo00?goooooOooooooool01Oooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool00ooooonooooonoooo`05oooo
o`P0oooo00?_ooooooooooooool01Oooool80?ooo`Sooooo203oool00ooooomoooooooooo`05oooo
o`<0oooo0008ooooo`P0oooo1_ooool2o`0000030000003oool0oooo00D0oooo2?ooool80?ooo`So
oooo203oool3ooooo`?o00000_ooool80?ooo`Sooooo00@0oooo0000000000000000103oool8oooo
o`P0oooo2?ooool80?ooo`Gooooo0ol000080?ooo`Sooooo0`3oool300000080oooo1_ooool00oko
ooo_oooo0?ooo`070?ooo`Sooooo203oool7ooooo`03o`0000000000000000H0oooo2?ooool50?oo
o`03000001000004000000Sooooo203oool8ooooo`P0oooo2?ooool20?ooo`<000000`3oool8oooo
o`P0oooo0oooool000Sooooo1P3oool00a3oool0ooooooooo`04ooooo`;o000000?k000000000000
00001P3oool8ooooo`P0oooo1?ooool017ooooooooooooooooooool80?ooo`;ooooo1Ol000000moo
ool0oooo0?ooo`060?ooo`Kooooo00?mooooooooo`000000100000030?ooo`Sooooo203oool8oooo
o`P0oooo1?ooool4o`0000030000003oool0oooo00D0oooo1Oooool00oOoooooooooooooo`020?oo
o`D0000000<0ooooooooooooool01_ooool70?ooo`031?oooooooooooooo00Kooooo203oool6oooo
o`;o00000`0000050?ooo`Sooooo103oool400000003o`000?oooooooooo00Gooooo203oool8oooo
o`P0oooo2?ooool00`3oool000000000000300000080oooo1oooool00jooool0oooo0?ooo`020?oo
o`04P?ooo`3oool0oooo0?ooo`?ooooo0008ooooo`P0oooo1Oooool3o`00008000001P3oool6oooo
o`03noooooooool0oooo00L0oooo2?ooool80?ooo`;ooooo1?l000000o/0003ooooo0?ooo`040?oo
o`03P?ooo`3oool0oooo00Sooooo1@0000030?ooo`Sooooo203oool8ooooo`P0oooo1?ooool4o`00
00030000003oool0oooo00D0oooo2?ooool20?ooo`D0000000<0ooooooooooooool01Oooool00ogo
ool0oooo0?ooo`060?ooo`Sooooo203oool4ooooo`04_oooooooooom0000o`0000<000000`3oool0
0a3oool0ooooooooo`07ooooo`@0oooo100000000ol0003oooooooooo`05ooooo`P0oooo2?ooool8
0?ooo`Gooooo00Aoooooooooooooool0oooo1@0000020?ooo`Sooooo103oool0143oool0oooo0?oo
o`3oool3ooooo`002?ooool80?ooo`Gooooo0ol00002000000H0oooo2?ooool80?ooo`Sooooo203o
ool2ooooo`Go000000?ooooo0?ooo`3oool01P3oool8ooooo`D000000`3oool8ooooo`P0oooo2?oo
ool80?ooo`Cooooo1?l000000`000000oooo0?ooo`050?ooo`Sooooo0P3oool5000000030?oooooo
oooooooo00Cooooo00?mooooooooo`3oool01`3oool8ooooo`P0oooo1_ooool2o`0000<000001@3o
ool8ooooo`@0oooo100000000ol0003oooooooooo`05ooooo`P0oooo2?ooool80?ooo`Sooooo00<0
oooo0000000000000`0000020?ooo`Kooooo00?_ooooooooo`3oool01`3oool3ooooo`002?ooool8
0?ooo`Kooooo0_l000000`000000oooo0?ooo`050?ooo`Oooooo00?_oooo0?ooo`3oool01P3oool8
ooooo`P0oooo0oooool3o`0000;ooooo203oool8ooooo`040?ooo`0000000000000000@0oooo1ooo
ool00oOoool0oooo0?ooo`060?ooo`Sooooo203oool5ooooo`?o0000203oool8ooooo`<0oooo0`00
00020?ooo`Oooooo00?noooo0?ooo`3oool01P3oool8ooooo`P0oooo1oooool00gl0000000000000
00060?ooo`Sooooo1@3oool00h000000000000000008ooooo`H0oooo00<4oooo0?ooooooool01ooo
ool80?ooo`Sooooo0P3oool3000000<0oooo2?ooool60?ooo`035?ooo`3ooooooooo00;ooooo0008
ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo1_ooool00moooooooooo0?ooo`070?ooo`Kooooo00?_ooooooooo`3oool01`3oool8
ooooo`P0oooo1oooool00nooool0oooo0?ooo`060?ooo`Oooooo00>ooooo0?ooo`3oool01P3oool3
ooooo`000`3oool00`coool0oooo0?ooo`020?ooo`;ooooo00?Ooooonoooooooool00oooool30?oo
o`031?ooo`3oool0oooo0080oooo0oooool00okoooooooooooooo`02ooooo`P0oooo0_ooool00ogo
ooooooooooooo`03ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo00?oooooOooo
ooooool01Oooool80?ooo`Sooooo203oool2ooooo`03o_oooooooooooooo00?ooooo203oool8oooo
o`P0oooo2?ooool00`3ooon0oooo0?ooo`050?oooa3ooooo203oool8ooooo`P0oooo1oooool00ogo
ool0oooo0?ooo`060?ooo`Sooooo203oool7ooooo`03Ooooo`3oool0oooo00H0oooo2?ooool80?oo
o`?ooooo00080?ooo`Sooooo203oool3ooooo`03mooooooooooooooo00;ooooo203oool8ooooo`P0
oooo2?ooool30?ooo`03P?ooo`3oool0oooo0080oooo0oooool00ogoooooooooooooo`02ooooo`P0
oooo2?ooool20?ooo`031?ooo`3oool0oooo00<0oooo0oooool00mooooooooooooooo`02ooooo`03
P?ooo`3ooom0oooo00D0oooo2?ooool80?ooo`03_ooooooooooooooo00Gooooo00>0oooo0?ooo`3o
ool01@3oool2ooooo`03nooooooooooooooo00?ooooo203oool8ooooo`034?ooo`3oool0oooo00D0
oooo2?ooool80?ooo`?ooooo00?Oooooooooooooool00_ooool00`3ooon0oooo0?ooo`050?ooo`So
oooo203oool8ooooo`P0oooo0oooool00okoooooooooooooo`02ooooo`P0oooo0_ooool00noooooo
ooooooooo`03ooooo`<0oooo00<3oooo0?ooo`3oool00P3oool00oooooo^ooooooooo`05ooooo`<0
oooo00080?ooo`03ooooooOooooooooo00Gooooo203oool8ooooo`P0oooo0_ooool00okooooooooo
ooooo`03ooooo`80oooo00<@oooo0?ooo`3oool00`3oool8ooooo`P0oooo0_ooool00moooooooooo
ooooo`03ooooo`<0oooo00<1oooo0?ooo`3oool00P3oool8ooooo`P0oooo2?ooool20?ooo`038?oo
o`3oool0oooo00<0oooo0_ooool00ogoooooooooooooo`03ooooo`P0oooo2?ooool30?ooo`031?oo
o`3oool0oooo0080oooo2?ooool80?ooo`Sooooo00<0oooo1?ooo`3oool01@3oool00goooooooooo
noooo`05ooooo`P0oooo00?ooooogoooooooool01Oooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool8ooooo`60oooo0@Coool10?ooo`00203oool3ooooo`03nooooooo
oooooooo00;ooooo203oool2ooooo`03nooooooooooooooo00?ooooo00<4oooo0?ooo`3oool01@3o
ool00ooooomoooooooooo`05ooooo`P0oooo0oooool00nooooooooooooooo`02ooooo`P0oooo00?k
oooooooooogoool01Oooool80?ooo`Sooooo203oool00ooooomoooooooooo`05ooooo`P0oooo2?oo
ool80?ooo`;ooooo00?kooooooooooooool00oooool80?ooo`Sooooo203oool8ooooo`P0oooo00?o
oooooOooooooool01Oooool80?ooo`Sooooo00<0oooo1?ooo`3oool01@3oool00noooooooooonooo
o`05ooooo`032?ooo`3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool2ooooo`03nooooooo
oooooooo00?ooooo00<0oooo4?ooo`3oool01@3oool8ooooo`44oooo0@3oool10?ooo`0000<0oooo
P?ooo`3oool01@3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo00?noooo
ooooooooool01Oooool00h3oool0oooo0?ooo`050?ooo`Sooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo0P3oool00b3oool0oooo0?ooo`030?ooo`03oooooogooooooooo00Gooooo0P3oool0
0b3oool0oooo0?ooo`030?ooo`Sooooo203oool2ooooo`03_ooooooooooooooo00?ooooo203oool8
ooooo`P0oooo2?ooool80?ooo`?ooooo00?kooooooooooooool00_ooool80?ooo`;ooooo00?noooo
ooooooooool00oooool80?ooo`03ooooookooooooooo00Gooooo0`3oool00`Coool0oooo0?ooo`02
0?ooo`Sooooo0`3oool000P0oooo2?ooool80?ooo`03ooooogoooooooooo00Gooooo203oool00ooo
ooonoooooOooo`05ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo0_ooool00oOo
ooooooooooooo`03ooooo`040?ooohCoool0oooo@_ooo`@0oooo00?oooooOoooooooool01Oooool8
0?ooo`03Oooooooooooooooo00Gooooo203oool8ooooo`P0oooo0_ooool00gooooo_ooooooooo`03
ooooo`P0oooo0oooool00o_oooooooooooooo`02ooooo`P0oooo00Aoooooooooooooooo_oooo1?oo
ool80?ooo`Sooooo203oool00ooooooOooooooooo`05ooooo`P0oooo2?ooool80?ooo`04kooooooo
ooo_oooofoooo`Cooooo203oool00okoooooooooooooo`05ooooo`<0oooo0008ooooo`P0oooo2?oo
ool80?ooo`Oooooo00>_oooo0?ooo`3oool01P3oool8ooooo`L0oooo00>0oooo0?ooo`3oool01P3o
ool00ogoooogooooooooo`05ooooo`034?ooo`3oool0oooo00D0oooo0oooool00oOooooooooooooo
o`02ooooo`030?ooo`Soool8oooo00D0oooo2?ooool00h3oool0oooo4?ooo`050?ooo`Sooooo00=0
oooo0?ooo`3oool01@3oool2ooooo`03eooooooooooooooo00?ooooo0P3oool00b3oool0oooo0?oo
o`030?ooo`Sooooo00>0oooo0?ooo`3oool01@3oool8ooooo`P0oooo2?ooool80?ooo`03oooookoo
oooooooo00Gooooo203oool00oOoooomooooooooo`05ooooo`038?ooo`3oool0oooo00D0oooo2?oo
ool80?ooo`Sooooo203oool00okoooooooooooooo`05ooooo`P0oooo2?ooool30?ooo`002?ooool8
0?ooo`Oooooo00>_oooo0?ooo`3oool00P3oool0183oool0oooo0?ooo`3oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool6ooooo`03o_ooonoo
ool0oooo00L0oooo2?ooool80?ooo`Oooooo00>ooooo0?ooo`3oool01P3oool8ooooo`L0oooo00<4
ooooooooooooool00Oooool000Gooooo00=oooooooooooooool0203oool8ooooo`P0oooo2?ooool8
0?ooo`Oooooo00?koooo0?ooo`3oool01P3oool8ooooo`H0oooo00<@oooo0?ooooooool01_ooool0
0o_oool0oooo0?ooo`060?ooo`Sooooo203oool4ooooo`04Ooooooooooooooooooooo`P0oooo1ooo
ool00mooool0oooo0?ooo`060?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203o
ool5ooooo`03mooooooooooooooo00P0oooo2?ooool70?ooo`031?oooooooooooooo00Cooooo00>o
ooooooooo`3oool01`3oool8ooooo`P0oooo2?ooool80?ooo`?ooooo0008ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`Kooooo00?kooooooooo`3oool0103oool00h3oool0oooo0?ooo`08ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?moooo0?ooo`3oool01P3oool8
ooooo`P0oooo1?ooool01;oooooooooooOooooooool80?ooo`Sooooo203oool3ooooo`002?ooool8
0?ooo`Sooooo1P3oool00aCoool0ooooooooo`07ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo1_ooool00oOooooooooo0?ooo`070?ooo`Sooooo203oool4ooooo`04Ooooooooooom
ooooooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo0oooool000Oooooo00?_oooo
0?ooo`3oool01P3oool7ooooo`03_oooo`3oool0oooo00H0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo2?ooool80?ooo`Oooooo00?_oooo0?ooo`3oool01P3oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool7ooooo`03moooo`3oool0oooo00H0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo1oooool00okoool0oooo0?ooo`060?ooo`Sooooo203oool7ooooo`03Ooooo`3oool0
oooo00H0oooo2?ooool80?ooo`?ooooo0007ooooo`03Ooooo`3oool0oooo00H0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`H0oooo00>0oooo0?oo
ooooool01oooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Kooooo00?Ooooooooo
o`3oool01`3oool3ooooo`00203oool2ooooo`03kooooooooooooooo00?ooooo0`3oool00`?oool0
oooo0?ooo`020?ooo`03ooooonkooooooooo00Gooooo203oool8ooooo`P0oooo2?ooool30?ooo`03
2?ooo`3oool0oooo0080oooo0_ooool00moooooiooooooooo`03ooooo`<0oooo00<4oooo0?ooo`3o
ool00P3oool3ooooo`03o_oooooooooooooo00;ooooo203oool2ooooo`03oOooonoooooooooo00?o
oooo203oool3ooooo`03kooooooooooooooo00;ooooo203oool8ooooo`P0oooo2?ooool80?ooo`03
ooooogoooooooooo00Gooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo00<0ooooP?ooo`3o
ool01@3oool8ooooo`030?oooh3oool0oooo00D0oooo3oooool00ogoool0oooo0?ooo`060?ooo`So
oooo203oool3ooooo`00203oool8ooooo`P0oooo2?ooool00h3oool4oooo0?ooo`050?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool80?ooo`?ooooo00?gooooooooooooool00_ooool80?ooo`Sooooo
203oool8ooooo`<0oooo00>0oooo0?ooo`3oool00P3oool3ooooo`03oOoooooooooooooo00;ooooo
203oool8ooooo`80oooo00<4oooo0?ooo`3oool00`3oool3ooooo`03gooooooooooooooo00;ooooo
00>0oooo0?oood3oool01@3oool8ooooo`P0oooo00>oooooooooooooool01Oooool00h3oool0oooo
0?ooo`050?ooo`;ooooo00?kooooooooooooool00oooool80?ooo`Sooooo00<@oooo0?ooo`3oool0
1@3oool8ooooo`P0oooo0oooool00mooooooooooooooo`02ooooo`030?oooh3oool0oooo00D0oooo
2?ooool30?ooo`00203oool8ooooo`030?oooa3oool0oooo00D0oooo2?ooool80?ooo`?ooooo00?_
ooooooooooooool00_ooool80?ooo`;ooooo00?_ooooooooooooool00oooool80?ooo`Sooooo203o
ool8ooooo`P0oooo0_ooool00okoooooooooooooo`03ooooo`P0oooo2?ooool80?ooo`;ooooo00?O
ooooooooooooool00oooool30?ooo`030Oooo`3oool0oooo0080oooo2?ooool80?ooo`Sooooo203o
ool2ooooo`03oOoooooooooooooo00?ooooo203oool8ooooo`<0oooo00<4oooo0?ooo`3oool00P3o
ool8ooooo`P0oooo2?ooool80?ooo`03Oooooooooookoooo00Gooooo203oool00ooooooOoooooooo
o`05ooooo`P0oooo2?ooool30?ooo`00203oool8ooooo`<0oooo00<4oooo0?ooo`3oool00P3oool8
ooooo`P0oooo0_ooool00nooooooooooooooo`03ooooo`P0oooo2?ooool80?ooo`Sooooo203oool2
ooooo`03nooooooooooooooo00?ooooo00<4oooo0Oooo`3oool01@3oool00ooooomoooooooooo`05
ooooo`P0oooo0oooool00nooooooooooooooo`02ooooo`P0oooo0_ooool00ogoooooooooooooo`03
ooooo`P0oooo2?ooool80?ooo`03ooooogoooooooooo00Gooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo00?ooooooOooooooool01Oooool80?ooo`Sooooo00<0oooo
1?ooo`3oool01@3oool00noooooooooonoooo`05ooooo`48oooo0@3oool10?ooo`00203oool01>oo
oooooooooooooo_oool4ooooo`P0oooo00?nooooooooooooool01Oooool30?ooo`031?ooo`3oool0
oooo0080oooo2?ooool80?ooo`Sooooo00<0ooooP?ooo`3oool01@3oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo00?nooooooooooooool01Oooool00h3oool0oooo0?ooo`05
0?ooo`?ooooo00?kooooooooooooool00_ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool2
0?ooo`038?ooo`3oool0oooo00<0oooo00?ooooooOooooooool01Oooool20?ooo`038?ooo`3oool0
oooo00<0oooo2?ooool80?ooo`;ooooo00>oooooooooooooool00oooool80?ooo`Sooooo203oool8
ooooo`<0oooo00080?ooo`03o_oooooooooooooo00Gooooo203oool8ooooo`80oooo00>0oooo0?oo
o`3oool00`3oool2ooooo`03nooooooooooooooo00?ooooo203oool00nooooomooooooooo`05oooo
o`P0oooo2?ooool80?ooo`03ooooogoooooooooo00Gooooo203oool00ooooomnoooooOooo`05oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo0_ooool00oOoooooooooooooo`03oooo
o`040?oooh3oool0oooo0_ooo`@0oooo00?oooooOoooooooool01Oooool80?ooo`03Oooooooooooo
oooo00Gooooo203oool8ooooo`P0oooo0_ooool00gooooo_ooooooooo`03ooooo`P0oooo0oooool0
0o_oooooooooooooo`02ooooo`P0oooo00=oooooooooooooool01Oooool80?ooo`03Oooookoooooo
oooo00Gooooo0`3oool000Sooooo203oool8ooooo`L0oooo00<4ooooooooooooool01_ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00>ooooo0?ooo`3oool01P3oool8oooo
o`L0oooo00>0oooo0?ooo`3oool01P3oool00ogoooogooooo_ooo`05ooooo`034?ooo`3oool0oooo
00D0oooo2?ooool00`3oool8oooo2?ooo`050?ooo`Sooooo00>0oooo0?oooa3oool01@3oool8oooo
o`03@?ooo`3oool0oooo00D0oooo0_ooool00mOoooooooooooooo`03ooooo`80oooo00<Poooo0?oo
o`3oool00`3oool8ooooo`03P?ooo`3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool8oooo
o`P0oooo00?goooooOooooooool01Oooool18?ooo`40oooo0@3oool000Sooooo203oool8ooooo`P0
oooo2?ooool50?ooo`031?ooo`3oool@oooo00Sooooo203oool8ooooo`P0oooo1oooool00nooool0
oooo0?ooo`020?ooo`04P?ooo`3oool0oooo0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`?ooooo0004ooooo`04_oooooooooomoooooooo
o`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1Oooool00gooooooooooooooo`080?oo
o`Sooooo103oool0143oool0oooo0?ooo`3oool8ooooo`P0oooo1oooool00o_oool0oooo0?ooo`06
0?ooo`Sooooo1P3oool00a3oool0ooooooooo`06ooooo`03noooo`3oool0oooo00H0oooo2?ooool8
0?ooo`Cooooo00Aooooooooooooooooooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool80?ooo`Gooooo00?gooooooooooooool0203oool3ooooo`002?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Kooooo00?kooooooooo`3oool01`3oool8
ooooo`P0oooo1_ooool00o_ooooooooo0?ooo`070?ooo`Oooooo00?noooo0?ooo`3oool01P3oool8
ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo0oooool000Oooooo00=ooooo0?oo
o`3oool01P3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool60?oo
o`035?ooo`3ooooooooo00Oooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8oooo
o`P0oooo2?ooool60?ooo`031?ooo`3ooooooooo00Oooooo203oool8ooooo`P0oooo2?ooool80?oo
o`Sooooo203oool5ooooo`03Oooooooooooooooo00P0oooo1?ooool01?Ooooooooooooooooooool8
0?ooo`?ooooo0008ooooo`P0oooo2?ooool80?ooo`Kooooo00?_ooooooooo`3oool01`3oool8oooo
o`P0oooo1oooool00nooool0oooo0?ooo`060?ooo`Oooooo00>ooooo0?ooo`3oool01P3oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1oooool00nooool0oooo0?ooo`060?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?goooo0?ooo`3oool01P3oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool3ooooo`001oooool00ogoool0oooo0?ooo`060?ooo`So
oooo203oool7ooooo`03oOooo`3oool0oooo00H0oooo2?ooool80?ooo`Oooooo00=ooooo0?ooo`3o
ool01P3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`So
oooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`So
oooo203oool8ooooo`P0oooo0oooool000P0oooo0oooool00mooooooooooooooo`02ooooo`030?oo
oh3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo0_ooool00noooooooooo
ooooo`03ooooo`<0oooo00<1oooo0?ooo`3oool00P3oool00oooooo^ooooooooo`05ooooo`P0oooo
2?ooool80?ooo`Sooooo0`3oool00`coool0oooo0?ooo`020?ooo`;ooooo00?Ooooonoooooooool0
0oooool30?ooo`031?ooo`3oool0oooo0080oooo0oooool00okoooooooooooooo`02ooooo`P0oooo
0_ooool00ogoooooooooooooo`03ooooo`P0oooo0oooool00nooooooooooooooo`02ooooo`P0oooo
2?ooool80?ooo`Sooooo0P3oool00h3oool0oooo0?ooo`030?ooo`03ooooogoooooooooo00Gooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo0`3oool000P0oooo00?ooooogoooooooool01Ooo
ool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`03P?ooo`Co
ool0oooo00D0oooo2?ooool80?ooo`;ooooo00?gooooooooooooool00oooool80?ooo`Sooooo203o
ool3ooooo`03mooooooooooooooo00;ooooo203oool8ooooo`P0oooo2?ooool30?ooo`03P?ooo`3o
ool0oooo0080oooo0oooool00ogoooooooooooooo`02ooooo`P0oooo2?ooool00`3ooom0oooo1?oo
o`050?ooo`?ooooo00?Oooooooooooooool00_ooool00h3oool0oooo@?ooo`050?ooo`Sooooo203o
ool00kooooooooooooooo`05ooooo`03P?ooo`3oool0oooo00D0oooo0_ooool00o_ooooooooooooo
o`03ooooo`<0oooo00080?ooo`Sooooo00<0oooo1?ooo`3oool01@3oool00noooooooooonoooo`05
ooooo`032?ooo`3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool2ooooo`03nooooooooooo
oooo00?ooooo00<0oooo4?ooo`3oool01@3oool8ooooo`P0oooo00Cnooooooooooooooo_oooo1?oo
ool80?ooo`;ooooo00?_ooooooooooooool00oooool80?ooo`03ooooooOooooooooo00Gooooo203o
ool8ooooo`P0oooo0_ooool00okoooooooooooooo`03ooooo`P0oooo2?ooool80?ooo`Sooooo0`3o
ool00`7oool0oooo0?ooo`020?ooo`03kooooooooooooooo00Gooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo0`3oool00`Coool0oooo0?ooo`020?ooo`Sooooo0`3oool000P0oooo00?ooooo
noooooooool01Oooool30?ooo`034?ooo`3oool0oooo0080oooo2?ooool80?ooo`?ooooo00?koooo
ooooooooool00_ooool80?ooo`;ooooo00?nooooooooooooool00oooool80?ooo`03ooooookooooo
oooo00Gooooo0`3oool00`Coool0oooo0?ooo`020?ooo`Sooooo203oool2ooooo`03kooooooooooo
oooo00?ooooo203oool2ooooo`03oOoooooooooooooo00?ooooo203oool8ooooo`P0oooo0_ooool0
0o_oooooooooooooo`03ooooo`031?ooo`7oool0oooo00D0oooo00?oooooOoooooooool01Oooool8
0?ooo`?ooooo00?_ooooooooooooool00_ooool80?ooo`03noooooooooomoooo00Gooooo203oool8
ooooo`P0oooo00?oooooOoooooooool01Oooool80?ooo`Sooooo203oool2ooooo`03nooooooooooo
oooo00?ooooo203oool8ooooo`<0oooo00080?ooo`04Ooooooooooooooookoooo`Cooooo203oool0
0ooooonoooooooooo`05ooooo`P0oooo00?ooooogoooooooool01Oooool80?ooo`Sooooo203oool0
1>ooooooooookooooo[oool4ooooo`P0oooo00?nooooooooooooool01Oooool80?ooo`Sooooo203o
ool8ooooo`030?oooh3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`03o_oooooooooooooo00Gooooo00>0oooo0?ooo`3oool01@3oool3ooooo`03nooooooo
oooooooo00;ooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo0P3oool00b3oool0oooo0?oo
o`030?ooo`Sooooo0P3oool18?ooo`00203oool00ooooonoooooooooo`05ooooo`P0oooo00?ooooo
oOooooooool01Oooool80?ooo`Sooooo203oool8ooooo`P0oooo00?nooooooooooooool01Oooool8
0?ooo`Sooooo203oool00ooooonooooonoooo`05ooooo`P0oooo00?_ooooooooooooool01Oooool8
0?ooo`Sooooo203oool00ooooomoooooooooo`05ooooo`P0oooo00?oooooo_oooogoool01Oooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`03noooooooooogoooo00Gooooo00@0oooo
P?ooo`3oool2oooo103oool8ooooo`P0oooo00=oooooooooooooool01Oooool80?ooo`Sooooo0`3o
ool000Sooooo203oool8ooooo`P0oooo1_ooool00okoooo_oooo0?ooo`070?ooo`Sooooo203oool8
ooooo`P0oooo2?ooool60?ooo`034?ooo`Cooooooooo00Oooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool7ooooo`03_oooo`3oool0oooo00H0oooo2?ooool70?ooo`03P?ooo`3oool0
oooo00H0oooo00?moooomoooookoool01Oooool00a3oool0oooo0?ooo`050?ooo`?ooooo00?goooo
ooooooooool00_ooool20?ooo`036?ooo`3oool0oooo00<0oooo2?ooool00h3oool0oooo4?ooo`05
0?ooo`Sooooo00=0ooooP?ooo`3oool01@3oool2ooooo`03eooooooooooooooo00?ooooo0P3oool0
0b3oool0oooo0?ooo`030?ooo`Sooooo0H3oool10?ooo`40oooo0008ooooo`P0oooo1Oooool00oOo
ooooooooooooo`080?ooo`Sooooo1`3oool00`Coooooooooooooo`04ooooo`03_oooooooool0oooo
00L0oooo2?ooool80?ooo`Sooooo203oool8ooooo`H0oooo00>0oooo0?ooooooool01oooool80?oo
o`Sooooo203oool7ooooo`03koooo`3oool0oooo0080oooo00B0oooo0?ooo`3oool0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool3ooooo`002?ooool80?ooo`Sooooo203oool7ooooo`03oOooo`3oool0oooo
00H0oooo2?ooool80?ooo`Cooooo00Booooooooooogooooooooo203oool8ooooo`P0oooo1_ooool0
0moooooooooo0?ooo`070?ooo`Sooooo203oool5ooooo`03Oooooooooooooooo00P0oooo2?ooool8
0?ooo`Sooooo203oool7ooooo`03noooo`3oool0oooo00H0oooo2?ooool60?ooo`034?ooo`3ooooo
oooo00Kooooo00?koooo0?ooo`3oool01P3oool8ooooo`P0oooo1?ooool017oooooooooooooooooo
ool80?ooo`Oooooo00?Ooooo0?ooo`3oool01P3oool8ooooo`P0oooo0oooool000Kooooo00?goooo
ooooo`3oool01`3oool8ooooo`P0oooo1?ooool017oooooooooooOooooooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203o
ool6ooooo`03noooooooool0oooo00L0oooo2?ooool80?ooo`?ooooo0008ooooo`P0oooo2?ooool8
0?ooo`Oooooo00?noooo0?ooo`3oool01P3oool8ooooo`P0oooo1oooool00gooool0oooo0?ooo`06
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`H0oooo00<Doooo
0?ooooooool01oooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo2?ooool80?ooo`Sooooo203oool3ooooo`002?ooool80?ooo`Sooooo203oool8oooo
o`@0oooo0`0000000`3oooooooooooooo`06ooooo`P0oooo2?ooool80?ooo`Kooooo00?Ooooooooo
o`3oool01`3oool6ooooo`03koooooooool0oooo00H0oooo00<00000o`000?l000001_ooool80?oo
o`Oooooo00?_oooo0?ooo`3oool01P3oool7ooooo`03_oooo`3oool0oooo00H0oooo2?ooool80?oo
o`04ooooool0003o0000o`0000Cooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?_oooo
0?ooo`3oool01P3oool3ooooo`?o00000_ooool80?ooo`Sooooo203oool8ooooo`P0oooo0oooool0
00P0oooo2?ooool80?ooo`Sooooo203oool3ooooo`Go000000<0ooooP?ooo`3oool01@3oool@oooo
o`P0oooo2?ooool80?ooo`Oooooo00?moooo0?ooo`3oool0103oool2000000?o00001Oooool80?oo
o`Oooooo00=ooooo0?ooo`3oool01P3oool8ooooo`P0oooo2?ooool80?ooo`Go00000oooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`;ooooo1Ol000000oooool0oooo0?ooo`060?oo
o`Sooooo203oool8ooooo`P0oooo0oooool000P0oooo00>oooooooooooooool01Oooool00h3oool0
oooo0?ooo`050?ooo`03Oooooooooookoooo00Gooooo203oool3ooooo`Go000000<@oooo0?ooo`3o
ool01@3oool8ooooo`P0oooo0oooool00mooooooooooooooo`02ooooo`P0oooo2?ooool80?ooo`Ko
oooo0_l00003000000D0oooo2?ooool80?ooo`;ooooo00?_ooooooooooooool00oooool30?ooo`03
0Oooo`3oool0oooo0080oooo00?oooook_ooooooool01Oooool80?ooo`Sooooo1@0000030?ooo`So
oooo0`3oool00`Coool0oooo0?ooo`020?ooo`;ooooo00?Oooooooooooooool00oooool30?ooo`03
1?ooo`3oool0oooo0080oooo0oooool00okoooooooooooooo`02ooooo`P0oooo0_ooool00ogoooo_
ooooooooo`03ooooo`80oooo1@0000000`3oooooooooooooo`06ooooo`P0oooo0_ooool00noooooo
ooooooooo`03ooooo`P0oooo2?ooool30?ooo`0000>0oooo0?ooo`3oool01@3oool8ooooo`<0oooo
00<4oooo0?ooo`3oool00P3oool8ooooo`P0oooo0oooool5o`0000P0oooo00=ooooooooooo_oool0
1Oooool80?ooo`Sooooo203oool8ooooo`P0oooo1_ooool2o`0000<000001@3oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo00>0oooo1?ooo`3oool01@3oool8ooooo`D000000`3oool8ooooo`P0oooo
2?ooool80?ooo`?ooooo00?gooooooooooooool00_ooool80?ooo`Sooooo0P3oool5000000030?oo
oooooooooooo00Kooooo0`3oool00h3oool0oooo0?ooo`020?ooo`?ooooo00?mooooooooooooool0
0_ooool80?ooo`Sooooo0@3oool1@?ooo`44oooo00080?ooo`Sooooo203oool8ooooo`P0oooo1?oo
ool3o`000003ooooo`3oool0oooo00H0oooo00?ooooooOooooooool01Oooool80?ooo`Sooooo00<0
oooo1?ooo`3oool01@3oool00noooooooooonoooo`05ooooo`032?ooo`3oool0oooo00D0oooo1ooo
ool00ol000000000000000060?ooo`Sooooo203oool2ooooo`03nooooooooooooooo00?ooooo00<0
oooo4?ooo`3oool01@3oool8ooooo`P0oooo00Cnooooooooooooooo_oooo1?ooool0103oool00000
0000000000040?ooo`;ooooo00?_ooooooooooooool00oooool80?ooo`03ooooooOooooooooo00Go
oooo203oool8ooooo`P0oooo0_ooool00okoooooooooooooo`03ooooo`<0oooo0`0000020?ooo`So
oooo203oool8ooooo`<0oooo00<1oooo0?ooo`3oool00P3oool8ooooo`<0oooo00080?ooo`Sooooo
203oool8ooooo`80oooo00<Poooo0?ooo`3oool00`3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo
203oool8ooooo`P0oooo0oooool00o_oooooooooooooo`02ooooo`P0oooo0_ooool00okooooooooo
ooooo`03ooooo`P0oooo2?ooool30?ooo`031?ooo`3oool0oooo0080oooo2?ooool80?ooo`;ooooo
00?_ooooooooooooool00oooool80?ooo`;ooooo00?mooooooooooooool00oooool80?ooo`Sooooo
203oool2ooooo`03nooooooooooooooo00?ooooo00<4oooo0?ooo`3oool01@3oool00ooooomooooo
ooooo`05ooooo`P0oooo0oooool00nooooooooooooooo`02ooooo`P0oooo0_ooool00ogooooooooo
ooooo`03ooooo`P0oooo2?ooool30?ooo`00203oool00gooooooooooooooo`05ooooo`P0oooo2?oo
ool80?ooo`;ooooo00=oooookoooooooool00oooool80?ooo`Sooooo203oool00goooooooooooooo
o`05ooooo`P0oooo00?ooooo_oooooooool01Oooool80?ooo`03ooooomoooooooooo00Gooooo203o
ool8ooooo`P0oooo00C_ooooooooonoooookoooo1?ooool80?ooo`03o_oooooooooooooo00Gooooo
203oool8ooooo`P0oooo2?ooool00`3ooon0oooo0?ooo`050?ooo`Sooooo203oool2ooooo`03nooo
oooooooooooo00?ooooo00<2oooo0?ooo`3oool01@3oool8ooooo`P0oooo2?ooool80?ooo`03o_oo
oooooooooooo00Gooooo00>0oooo0?ooo`3oool01@3oool8ooooo`<0oooo00000d3oool0oooo0?oo
o`050?ooo`;ooooo00?Gooooooooooooool00oooool80?ooo`Sooooo00>0oooo0?ooo`3oool01@3o
ool8ooooo`P0oooo2?ooool80?ooo`03oooookoooooooooo00Gooooo203oool00oOoooomoooooooo
o`05ooooo`038?ooo`3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool00okooooooooooooo
o`05ooooo`P0oooo2?ooool80?ooo`;ooooo00?kooooooooooooool00oooool80?ooo`03kooooooo
oooooooo00Gooooo203oool8ooooo`P0oooo00?oooooOoooooooool01Oooool80?ooo`03ooooooko
ooomoooo00Gooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo0`3oool000Sooooo203oool8
ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Kooooo00?noooo
koooo`3oool01`3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo1`3oool00`Coooooooooooooo`06
ooooo`P0oooo2?ooool80?ooo`Sooooo1@3oool00`;oool0oooo0?ooo`08ooooo`P0oooo1oooool0
0jooool0oooo0?ooo`060?ooo`Sooooo403oool00ogoooogooooo_ooo`05ooooo`P0oooo0oooool0
0oOoooooooooooooo`02ooooo`80oooo0@Soool000Oooooo00?Ooooo0?ooo`3oool01P3oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1Oooool00oOoooooooooooooo`080?oo
o`Sooooo1`3oool00`Coooooooooooooo`06ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8oooo
o`L0oooo00<@ooooooooooooool01_ooool80?ooo`Sooooo203oool7ooooo`03[oooo`3oool0oooo
0080oooo00B0oooo0?ooo`3oool0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`?ooooo0006ooooo`03noooooooool0oooo00@0oooo00>0oooo0?ooo`3oool02?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool7ooooo`03oOooo`3oool0oooo
00H0oooo2?ooool80?ooo`Cooooo00Booooooooooogooooooooo203oool8ooooo`P0oooo1_ooool0
0moooooooooo0?ooo`070?ooo`Sooooo203oool5ooooo`03Oooooooooooooooo00H0oooo00<8oooo
0?ooooooool01oooool80?ooo`Sooooo203oool7ooooo`03noooo`3oool0oooo00H0oooo2?ooool6
0?ooo`034?ooo`3ooooooooo00Kooooo00?koooo0?ooo`3oool01P3oool3ooooo`002?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1_ooool00ogo
oooooooo0?ooo`070?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?Ooooo0?oo
o`3oool01P3oool8ooooo`P0oooo0oooool000Sooooo203oool8ooooo`P0oooo1oooool00oOoool0
oooo0?ooo`060?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?noooo0?ooo`3o
ool01P3oool8ooooo`P0oooo1oooool00gooool0oooo0?ooo`060?ooo`Sooooo203oool8ooooo`P0
oooo2?ooool80?ooo`Sooooo203oool8ooooo`H0oooo00<Doooo0?ooooooool01oooool80?ooo`So
oooo203oool8ooooo`P0oooo2?ooool80?ooo`?ooooo0008ooooo`P0oooo2?ooool80?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo
203oool8ooooo`P0oooo1_ooool00noooooooooo0?ooo`070?ooo`Sooooo203oool7ooooo`03kooo
o`3oool0oooo00H0oooo1oooool00kooool0oooo0?ooo`060?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool3ooooo`00203oool8ooooo`P0oooo2?ooool80?ooo`03ooooogoo
oooooooo00Gooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`030?oooh3o
ool0oooo00D0oooo4?ooool80?ooo`Sooooo203oool7ooooo`03oOooo`3oool0oooo00H0oooo2?oo
ool80?ooo`Oooooo00=ooooo0?ooo`3oool01P3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool80?ooo`?ooooo00030?ooo`03P?ooo`3oool0oooo0080oooo0oooool0
0ogoooooooooooooo`02ooooo`P0oooo2?ooool20?ooo`031?ooo`3oool0oooo00<0oooo0oooool0
0mooooooooooooooo`02ooooo`03P?ooo`3ooom0oooo00D0oooo2?ooool80?ooo`03_ooooooooooo
oooo00Gooooo00>0oooo0?ooo`3oool01@3oool2ooooo`03nooooooooooooooo00?ooooo203oool8
ooooo`034?ooo`3oool0oooo00D0oooo2?ooool80?ooo`?ooooo00?Oooooooooooooool00_ooool0
0`3ooon0oooo0?ooo`050?ooo`Sooooo203oool8ooooo`P0oooo0oooool00okoooooooooooooo`02
ooooo`P0oooo0_ooool00nooooooooooooooo`03ooooo`<0oooo00<1oooo0?ooo`3oool00P3oool0
0oooooo^ooooooooo`05ooooo`P0oooo2?ooool80?ooo`Sooooo0`3oool00`Soool0oooo0?ooo`02
0?ooo`;ooooo00?Ooooonoooooooool00oooool30?ooo`031?ooo`3oool0oooo0080oooo0oooool0
0okoooooooooooooo`02ooooo`40oooo0H3oool10?ooo`00203oool2ooooo`03gooooooooooooooo
00?ooooo0`3oool00`Goool0oooo0?ooo`020?ooo`Sooooo203oool8ooooo`P0oooo0_ooool00ogo
ooooooooooooo`03ooooo`P0oooo2?ooool30?ooo`031?ooo`3oool0oooo0080oooo2?ooool80?oo
o`Sooooo00<0oooo1?ooo`3oool01@3oool00goooooooooonoooo`05ooooo`P0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`03P?ooo`Coool0oooo
00D0oooo2?ooool80?ooo`;ooooo00?gooooooooooooool00oooool80?ooo`Sooooo203oool3oooo
o`03mooooooooooooooo00;ooooo0`3oool000P0oooo0_ooool00ogoooooooooooooo`03ooooo`P0
oooo2?ooool80?ooo`03ooooogoooooooooo00Gooooo203oool8ooooo`P0oooo2?ooool80?ooo`So
oooo203oool8ooooo`P0oooo00?ooooooOooooooool01Oooool80?ooo`Sooooo00<0oooo1?ooo`3o
ool01@3oool00noooooooooonoooo`05ooooo`032?ooo`3oool0oooo00D0oooo2?ooool80?ooo`So
oooo203oool2ooooo`03nooooooooooooooo00?ooooo00<0oooo4?ooo`3oool01@3oool8ooooo`P0
oooo0oooool00nooooooooooooooo`02ooooo`P0oooo0_ooool00nooooooooooooooo`03ooooo`P0
oooo00?ooooomoooooooool01Oooool80?ooo`Sooooo0`3oool000P0oooo00?nooooooooooooool0
1Oooool00h3oool0oooo0?ooo`050?ooo`?ooooo00?kooooooooooooool00_ooool80?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool20?ooo`038?ooo`3oool0oooo00<0oooo2?ooool20?ooo`038?oo
o`3oool0oooo00<0oooo2?ooool80?ooo`Sooooo203oool00ooooookooooooooo`05ooooo`P0oooo
2?ooool80?ooo`?ooooo00?kooooooooooooool00_ooool80?ooo`;ooooo00?nooooooooooooool0
0oooool80?ooo`03ooooookooooooooo00Gooooo0`3oool00`Coool0oooo0?ooo`020?ooo`Sooooo
203oool2ooooo`03kooooooooooooooo00?ooooo203oool2ooooo`03oOoooooooooooooo00?ooooo
203oool8ooooo`P0oooo0_ooool00o_oooooooooooooo`03ooooo`44oooo0@7oool10?ooo`00203o
ool8ooooo`P0oooo2?ooool80?ooo`;ooooo00?gooooooooooooool00oooool0103ooon0oooo0?oo
o`;oool40?ooo`03ooooogoooooooooo00Gooooo203oool00gooooooooooooooo`05ooooo`P0oooo
2?ooool80?ooo`;ooooo00=oooookoooooooool00oooool80?ooo`?ooooo00?kooooooooooooool0
0_ooool80?ooo`04Ooooooooooooooookoooo`Cooooo203oool00ooooonoooooooooo`05ooooo`P0
oooo00?ooooogoooooooool01Oooool80?ooo`Sooooo203oool01>ooooooooookooooo_oool4oooo
o`P0oooo00?nooooooooooooool01Oooool80?ooo`Sooooo203oool8ooooo`030?oooh3oool0oooo
00D0oooo0oooool00mooooooooooooooo`02ooooo`P0oooo2?ooool30?ooo`00203oool00ogoooog
ooooo_ooo`05ooooo`034?ooo`3oool0oooo00D0oooo0oooool00oOoooooooooooooo`02ooooo`80
oooo00<8oooo0?ooo`3oool00`3oool8ooooo`03P?ooo`3oool@oooo00D0oooo2?ooool00d3oool0
oooo0?ooo`050?ooo`;ooooo00?Gooooooooooooool00oooool20?ooo`038?ooo`3oool0oooo00<0
oooo2?ooool00h3oool0oooo0?ooo`050?ooo`Sooooo203oool8ooooo`P0oooo00?ooooo_ooooooo
ool01Oooool80?ooo`03oooooogooooooooo00Gooooo00<Poooo0?ooo`3oool01@3oool8ooooo`P0
oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo0_ooool00o_oooooooooooooo`03ooooo`P0
oooo00?_oooooOooooooool01Oooool80?ooo`Sooooo203oool00ooooomoooooooooo`05ooooo`<0
oooo0008ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1_ooool00okoooo_oooo
0?ooo`070?ooo`Sooooo203oool8ooooo`P0oooo2?ooool70?ooo`031?oooooooooooooo00Kooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo1P3oool00d3oool0ooooooooo`02ooooo`002?oo
ool60?ooo`034?ooo`3ooooooooo00Kooooo00?koooo0?ooo`3oool01P3oool8ooooo`P0oooo1?oo
ool017ooooooooooooooooooool80?ooo`Oooooo00?Ooooo0?ooo`3oool01P3oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool5ooooo`03kooooooooooooooo00P0oooo1Oooool00oOooooooooo
ooooo`080?ooo`Sooooo1`3oool00`Coooooooooooooo`04ooooo`03_oooooooool0oooo00L0oooo
2?ooool80?ooo`Sooooo203oool8ooooo`L0oooo00<@ooooooooooooool01_ooool80?ooo`Sooooo
203oool7ooooo`03[oooo`3oool0oooo0080oooo00B0oooo0?ooo`3oool0oooo0oooool000Sooooo
203oool8ooooo`P0oooo1_ooool00o_ooooooooo0?ooo`070?ooo`Sooooo203oool6ooooo`03nooo
ooooool0oooo00@0oooo00>0oooo0?ooo`3oool02?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool7ooooo`03oOooo`3oool0oooo00H0oooo2?ooool80?ooo`Cooooo
00Booooooooooogooooooooo1P3oool00a3oool0ooooooooo`07ooooo`P0oooo2?ooool80?ooo`So
oooo203oool5ooooo`03Oooooooooooooooo00P0oooo2?ooool80?ooo`?ooooo0008ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1?ooool2Ooooo`03oOooooooool0oooo00L0oooo
2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
1_ooool00noooooooooo0?ooo`070?ooo`?ooooo0008ooooo`P0oooo2?ooool80?ooo`Oooooo00?_
oooo0?ooo`3oool01P3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool7ooooo`03moooo`3o
ool0oooo00H0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1oooool00okoool0oooo0?oo
o`060?ooo`Sooooo203oool7ooooo`03Ooooo`3oool0oooo00H0oooo2?ooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo1P3oool00aCoool0ooooooooo`02ooooo`002?ooool8
0?ooo`Sooooo203oool8ooooo`H0oooo00>0oooo0?ooooooool01oooool80?ooo`Sooooo203oool8
ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo2?ooool80?ooo`Kooooo00?Oooooooooo`3oool01`3oool8ooooo`P0oooo2?ooool8
0?ooo`Oooooo00?_oooo0?ooo`3oool01P3oool7ooooo`03_oooo`3oool0oooo00H0oooo0oooool0
00<0oooo00<8oooo0?ooo`3oool00P3oool2ooooo`03gooooo_ooooooooo00?ooooo0`3oool00`Co
ool0oooo0?ooo`020?ooo`?ooooo00?nooooooooooooool00_ooool80?ooo`;ooooo00?moooooooo
ooooool00oooool80?ooo`Sooooo203oool2ooooo`03kooooooooooooooo00?ooooo203oool8oooo
o`P0oooo00?oooooOoooooooool01Oooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?oo
o`Sooooo00<0ooooP?ooo`3oool01@3oool?ooooo`03oOooo`3oool0oooo00H0oooo2?ooool80?oo
o`Oooooo00?moooo0?ooo`3oool01P3oool8ooooo`P0oooo1oooool00gooool0oooo0?ooo`060?oo
o`Sooooo203oool3ooooo`00203oool8ooooo`P0oooo0oooool00oOoooooooooooooo`02ooooo`P0
oooo2?ooool80?ooo`Sooooo0`3oool00h3oool0oooo0?ooo`020?ooo`?ooooo00?moooooooooooo
ool00_ooool80?ooo`Sooooo00<0oooo@?ooo`Coool01@3oool3ooooo`03gooooooooooooooo00;o
oooo00>0oooo0?oood3oool01@3oool8ooooo`P0oooo00>oooooooooooooool01Oooool80?ooo`;o
oooo00?kooooooooooooool00oooool80?ooo`Sooooo00<@oooo0?ooo`3oool01@3oool8ooooo`P0
oooo0oooool00mooooooooooooooo`02ooooo`030?oooh3oool0oooo00D0oooo2?ooool80?ooo`So
oooo203oool8ooooo`P0oooo0_ooool00nooooooooooooooo`03ooooo`<0oooo00<3oooo0?ooo`3o
ool00P3oool00oooooo^ooooooooo`05ooooo`<0oooo00080?ooo`03ooooooOooooooooo00Gooooo
203oool8ooooo`P0oooo0_ooool00okoooooooooooooo`03ooooo`P0oooo2?ooool80?ooo`;ooooo
00?Oooooooooooooool00oooool80?ooo`Sooooo203oool8ooooo`P0oooo0_ooool00ogooooooooo
ooooo`03ooooo`P0oooo2?ooool30?ooo`031?ooo`3oool0oooo0080oooo2?ooool80?ooo`Sooooo
203oool00goooooooooonoooo`05ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool8ooooo`60oooo0@Coool10?ooo`00203oool8ooooo`P0oooo0_oo
ool00o_oooooooooooooo`03ooooo`031?ooo`7oool0oooo00D0oooo00?oooooOoooooooool01Ooo
ool80?ooo`?ooooo00?_ooooooooooooool00_ooool80?ooo`;ooooo00?mooooooooooooool00ooo
ool80?ooo`Sooooo203oool00ooooomoooooooooo`05ooooo`P0oooo2?ooool80?ooo`;ooooo00?k
ooooooooooooool00oooool80?ooo`Sooooo203oool8ooooo`P0oooo00?ooooooOooooooool01Ooo
ool80?ooo`Sooooo00<0oooo1?ooo`3oool01@3oool00noooooooooonoooo`05ooooo`032?ooo`3o
ool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool8ooooo`030?oooa3oool0oooo00D0oooo2?oo
ool30?ooo`0000<0ooooP?ooo`3oool01@3oool00oOoooooooooooooo`05ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo00?nooooooooooooool01Oooool00h3oool0oooo0?ooo`05
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`80oooo00<Poooo
0?ooo`3oool00`3oool8ooooo`P0oooo0_ooool00kooooooooooooooo`03ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool3ooooo`03nooooooooooooooo00;ooooo203oool2ooooo`03o_oooooooooo
oooo00?ooooo203oool00oooooonooooooooo`05ooooo`<0oooo00<4oooo0?ooo`3oool00P3oool8
ooooo`<0oooo00080?ooo`Sooooo203oool00ooooomoooooooooo`05ooooo`P0oooo00?oooooo_oo
oogoool01Oooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`;ooooo00?goooooooo
ooooool00oooool0103ooon0oooo0?ooo`;oool40?ooo`03ooooogoooooooooo00Gooooo203oool0
0gooooooooooooooo`05ooooo`P0oooo2?ooool80?ooo`;ooooo00=oooookoooooooool00oooool8
0?ooo`Sooooo203oool00gooooooooooooooo`05ooooo`P0oooo2?ooool80?ooo`03ooooomoooooo
oooo00Gooooo203oool8ooooo`P0oooo00C_ooooooooonoooookoooo1?ooool80?ooo`03o_oooooo
oooooooo00Gooooo0`3oool000Sooooo203oool8ooooo`P0oooo1oooool00jooool0oooo0?ooo`06
0?ooo`Sooooo1`3oool00h3oool0oooo0?ooo`060?ooo`03oOooooOoooonoooo00Gooooo00<@oooo
0?ooo`3oool01@3oool3ooooo`03mooooooooooooooo00;ooooo00<0oooo2?ooo`Soool01@3oool8
ooooo`03P?ooo`3oool@oooo00D0oooo2?ooool00d3oool0oooo0?ooo`050?ooo`;ooooo00?Goooo
ooooooooool00oooool80?ooo`Sooooo00>0oooo0?ooo`3oool01@3oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool00oOoooomooooooooo`05ooooo`038?ooo`3oool0oooo00D0oooo2?ooool8
0?ooo`Sooooo203oool00okoooooooooooooo`05ooooo`P0oooo2?ooool30?ooo`002?ooool80?oo
o`Oooooo00>_oooo0?ooo`3oool00P3oool0183oool0oooo0?ooo`3oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool6ooooo`03o_ooonooool0
oooo00L0oooo2?ooool80?ooo`Oooooo00>ooooo0?ooo`3oool01P3oool8ooooo`L0oooo00<4oooo
ooooooooool00Oooool000Gooooo00=oooooooooooooool0203oool8ooooo`P0oooo2?ooool80?oo
o`Oooooo00?koooo0?ooo`3oool01P3oool8ooooo`H0oooo00<@oooo0?ooooooool01oooool80?oo
o`Sooooo203oool4ooooo`04Ooooooooooooooooooooo`P0oooo1oooool00mooool0oooo0?ooo`06
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool5ooooo`03mooooooooooo
oooo00P0oooo2?ooool70?ooo`031?oooooooooooooo00Cooooo00>oooooooooo`3oool01`3oool8
ooooo`P0oooo2?ooool80?ooo`?ooooo0008ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8oooo
o`P0oooo1oooool00mooool0oooo0?ooo`060?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?oo
o`Sooooo1@3oool00h3oool0oooo0?ooo`08ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8oooo
o`P0oooo2?ooool80?ooo`Oooooo00?moooo0?ooo`3oool01P3oool8ooooo`P0oooo1?ooool01;oo
oooooooooOooooooool60?ooo`034?ooo`3ooooooooo00Oooooo203oool3ooooo`002?ooool80?oo
o`Sooooo1P3oool00aCoool0ooooooooo`06ooooo`03noooo`3oool0oooo00H0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo1_ooool00oOooooooooo0?ooo`070?ooo`Sooooo203oool4oooo
o`04Ooooooooooomooooooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo0oooool0
00Oooooo00?_oooo0?ooo`3oool01P3oool7ooooo`03_oooo`3oool0oooo00H0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?_oooo0?ooo`3oool01P3oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool7ooooo`03moooo`3oool0oooo00H0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo1oooool00okoool0oooo0?ooo`060?ooo`Sooooo203oool7oooo
o`03Ooooo`3oool0oooo00H0oooo2?ooool50?ooo`03P?ooo`3oool0oooo00?ooooo0007ooooo`03
Ooooo`3oool0oooo00H0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`So
oooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`So
oooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Ko
oooo00?Oooooooooo`3oool01`3oool3ooooo`00203oool2ooooo`03kooooooooooooooo00?ooooo
0`3oool00`?oool0oooo0?ooo`020?ooo`03ooooonkooooooooo00Gooooo203oool8ooooo`P0oooo
2?ooool30?ooo`033?ooo`3oool0oooo0080oooo0_ooool00mooooooooooooooo`03ooooo`<0oooo
00<4oooo0?ooo`3oool00P3oool3ooooo`03o_oooooooooooooo00;ooooo203oool2ooooo`03oOoo
onoooooooooo00?ooooo203oool3ooooo`03kooooooooooooooo00;ooooo203oool8ooooo`P0oooo
2?ooool20?ooo`03P?ooo`3oool0oooo00<0oooo00?oooooOoooooooool01Oooool80?ooo`Sooooo
203oool2ooooo`03o_oooooooooooooo00?ooooo203oool8ooooo`P0oooo2?ooool00`3ooon0oooo
0?ooo`050?ooo`oooooo00?moooo0?ooo`3oool01P3oool8ooooo`P0oooo0oooool000P0oooo2?oo
ool80?ooo`Sooooo00>0oooo1?ooo`3oool01@3oool8ooooo`P0oooo0_ooool00oOooooooooooooo
o`03ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool30?ooo`03P?ooo`3o
ool0oooo0080oooo0oooool00ogoooooooooooooo`02ooooo`P0oooo2?ooool00`3ooom0oooo1?oo
o`050?ooo`?ooooo00?Oooooooooooooool00_ooool00h3oool0oooo@?ooo`050?ooo`Sooooo203o
ool00kooooooooooooooo`05ooooo`03P?ooo`3oool0oooo00D0oooo0_ooool00o_ooooooooooooo
o`03ooooo`P0oooo2?ooool00a3oool0oooo0?ooo`050?ooo`Sooooo203oool3ooooo`03gooooooo
oooooooo00;ooooo00<0ooooP?ooo`3oool01@3oool8ooooo`<0oooo00080?ooo`Sooooo00<0oooo
4?ooo`3oool01@3oool8ooooo`P0oooo00Cnooooooooooooooo_oooo1?ooool80?ooo`;ooooo00?_
ooooooooooooool00oooool80?ooo`03ooooooOooooooooo00Gooooo203oool8ooooo`P0oooo0_oo
ool00okoooooooooooooo`03ooooo`P0oooo2?ooool80?ooo`Sooooo0`3oool00`7oool0oooo0?oo
o`020?ooo`Sooooo203oool8ooooo`P0oooo0_ooool00ogoooooooooooooo`03ooooo`P0oooo2?oo
ool30?ooo`031?ooo`3oool0oooo0080oooo2?ooool80?ooo`Sooooo00<0oooo1?ooo`3oool01@3o
ool00goooooooooonoooo`05ooooo`P0oooo00?ooooogoooooooool01Oooool80?ooo`Sooooo0`3o
ool000P0oooo2?ooool30?ooo`031?ooo`3oool0oooo0080oooo2?ooool80?ooo`;ooooo00?_oooo
ooooooooool00oooool80?ooo`;ooooo00?mooooooooooooool00oooool80?ooo`03oooooo_ooooo
oooo00?ooooo0_l000000`000000oooo0?ooo`050?ooo`;ooooo00?kooooooooooooool00oooool0
0`Coool1oooo0?ooo`050?ooo`03ooooogoooooooooo00Gooooo203oool3ooooo`03kooooooooooo
oooo00;ooooo203oool2ooooo`03oOoooooooooooooo00?ooooo203oool8ooooo`P0oooo00?ooooo
Ooooooooool01Oooool80?ooo`Sooooo203oool2ooooo`03nooooooooooooooo00?ooooo0P3oool3
000000<0oooo2?ooool80?ooo`Sooooo203oool00oooooomooooooooo`05ooooo`P0oooo2?ooool0
0`3oool4oooo0?ooo`050?ooo`03kooooooooookoooo00Gooooo0@Soool10?ooo`40oooo00080?oo
o`04kooooooooooooooonoooo`Cooooo203oool00okoooooooooooooo`05ooooo`<0oooo00<4oooo
0?ooo`3oool00P3oool8ooooo`P0oooo2?ooool00`3ooon0oooo0?ooo`050?ooo`Gooooo0ol00002
000000H0oooo2?ooool00`;oool0oooo0?ooo`050?ooo`Sooooo203oool8ooooo`P0oooo00?noooo
ooooooooool01Oooool00h3oool0oooo0?ooo`050?ooo`Sooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo00<0oooo0000020000000`0000020?ooo`03oooooogooooooooo00Gooooo0P3oool0
0b3oool0oooo0?ooo`030?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo0`3oool0
00P0oooo00?nooooooooooooool01Oooool80?ooo`Sooooo0P3oool00h3oool0oooo0?ooo`030?oo
o`03oooookoooookoooo00Gooooo203oool00nooooooooooooooo`05ooooo`P0oooo1Oooool3o`00
008000001P3oool00ooooomoooooooooo`05ooooo`P0oooo00?oooooo_oooogoool01Oooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`03noooooooooogoooo00Gooooo00@0ooooP?oo
o`3oool2oooo103oool00ooooomoooooooooo`05ooooo`P0oooo00=oooooooooooooool01Oooool0
0`3oool000000000000300000080oooo2?ooool80?ooo`;ooooo00=oooookoooooooool00oooool8
0?ooo`?ooooo00?kooooooooooooool00_ooool80?ooo`03Oooooooooooooooo00Gooooo203oool0
0ooooonoooooooooo`05ooooo`<0oooo0008ooooo`P0oooo2?ooool60?ooo`034?ooo`Cooooooooo
00Oooooo203oool8ooooo`P0oooo2?ooool50?ooo`030P0000000000000000;o00001_ooool60?oo
o`03@?ooo`3ooooooooo00Kooooo00>ooooo0?ooo`3oool01P3oool8oooooa00oooo00?moooomooo
ookoool01Oooool00a3oool0oooo0?ooo`050?ooo`?ooooo00?gooooooooooooool00_ooool00`3o
ool8oooo6?ooo`050?ooo`Sooooo00>0oooo0?oooa3oool01@3oool8ooooo`03@?ooo`3oool0oooo
00D0oooo0_ooool00mOoooooooooooooo`03ooooo`030?ooo`000000000000<000000P3oool8oooo
o`03P?ooo`3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool00ooooonoooooooooo`05oooo
o`P0oooo00?goooooOooooooool01Oooool30?ooo`002?ooool80?ooo`Sooooo203oool8ooooo`P0
oooo2?ooool80?ooo`Sooooo1P3oool200000003o`000?oooooooooo00Cooooo00>_oooo0?ooo`3o
ool00P3oool0183oool0oooo0?ooo`3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo0_ooool3o`0000?ooooo203oool8oooo
o`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo0oooool000Cooooo00Booooooooooogo
oooooooo1P3oool00a3oool0ooooooooo`07ooooo`P0oooo1_ooool00moooooooooo0?ooo`070?oo
o`Sooooo203oool5ooooo`03Oooooooooooooooo00P0oooo2?ooool80?ooo`Sooooo203oool7oooo
o`03noooo`3oool0oooo00H0oooo2?ooool60?ooo`034?ooo`3ooooooooo00Kooooo00?koooo0?oo
o`3oool01P3oool8ooooo`P0oooo1?ooool017ooooooooooooooooooool80?ooo`Oooooo00?Ooooo
0?ooo`3oool01P3oool6ooooo`03oOooooooool0oooo00L0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo1Oooool00oOoooooooooooooo`080?ooo`?ooooo0008ooooo`P0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`P0oooo1_ooool00o_ooooooooo0?ooo`070?ooo`Sooooo203oool6oooo
o`03noooooooool0oooo00@0oooo00>0oooo0?ooo`3oool02?ooool80?ooo`Sooooo203oool8oooo
o`P0oooo1Oooool00gooooooooooooooo`080?ooo`Sooooo203oool3ooooo`001oooool00gooool0
oooo0?ooo`060?ooo`Sooooo1@3oool00h3oool0oooo0?ooo`08ooooo`P0oooo2?ooool80?ooo`So
oooo203oool8ooooo`H0oooo00<Doooo0?ooooooool01oooool80?ooo`Sooooo203oool8ooooo`P0
oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0
oooo2?ooool80?ooo`Kooooo00?gooooooooo`3oool01`3oool8ooooo`P0oooo0oooool000Sooooo
203oool6ooooo`03goooooooool0oooo00L0oooo1_ooool00noooooooooo0?ooo`070?ooo`Sooooo
203oool7ooooo`03koooo`3oool0oooo00H0oooo1oooool00kooool0oooo0?ooo`060?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool7ooooo`03koooo`3oool0oooo00H0oooo
2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1oooool00oOoool0oooo0?ooo`060?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool80?ooo`?ooooo0007ooooo`03oOooo`3oool0oooo00H0oooo2?oo
ool80?ooo`Oooooo00?moooo0?ooo`3oool01P3oool8ooooo`P0oooo1oooool00gooool0oooo0?oo
o`060?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?oo
ool60?ooo`03P?ooo`3ooooooooo00Oooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool3ooooo`00203oool3ooooo`03gooooooooooo
oooo00;ooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool2ooooo`03kooooooooooo
oooo00?ooooo0`3oool00`7oool0oooo0?ooo`020?ooo`03ooooonkooooooooo00Gooooo203oool8
ooooo`P0oooo2?ooool30?ooo`031?ooo`3oool0oooo0080oooo0_ooool00moooooiooooooooo`03
ooooo`<0oooo00<4oooo0?ooo`3oool00P3oool3ooooo`03o_oooooooooooooo00;ooooo203oool2
ooooo`03oOooonoooooooooo00?ooooo203oool00ooooomoooooooooo`05ooooo`P0oooo0_ooool0
0nooooooooooooooo`03ooooo`P0oooo2?ooool20?ooo`03P?ooo`3oool0oooo00<0oooo00?ooooo
Ooooooooool01Oooool80?ooo`Sooooo203oool2ooooo`03o_oooooooooooooo00?ooooo203oool8
ooooo`40oooo0H3oool10?ooo`00203oool8ooooo`P0oooo2?ooool80?ooo`;ooooo00?noooooooo
ooooool00oooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool00h3oool4oooo0?ooo`050?oo
o`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool30?oo
o`03P?ooo`3oool0oooo0080oooo0oooool00ogoooooooooooooo`02ooooo`P0oooo2?ooool20?oo
o`031?ooo`3oool0oooo00<0oooo0oooool00mooooooooooooooo`02ooooo`03P?ooo`3ooom0oooo
00D0oooo2?ooool80?ooo`03_ooooooooooooooo00Gooooo00>0oooo0?ooo`3oool01@3oool00goo
oooooooonoooo`05ooooo`<0oooo00080?ooo`Sooooo00<0oooo1?ooo`3oool01@3oool00noooooo
oooonoooo`05ooooo`032?ooo`3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool8ooooo`03
0?oooa3oool0oooo00D0oooo2?ooool80?ooo`?ooooo00?_ooooooooooooool00_ooool80?ooo`;o
oooo00?_ooooooooooooool00oooool80?ooo`03ooooooOooooooooo00Gooooo00<0oooo4?ooo`3o
ool01@3oool8ooooo`P0oooo0_ooool00okoooooooooooooo`03ooooo`P0oooo2?ooool80?ooo`;o
oooo00?Oooooooooooooool00oooool30?ooo`030Oooo`3oool0oooo0080oooo2?ooool80?ooo`So
oooo0P3oool00b3oool0oooo0?ooo`030?ooo`;ooooo00?mooooooooooooool00oooool00h3oool0
oooo0?ooo`050?ooo`Sooooo0`3oool00`Coool0oooo0?ooo`020?ooo`Sooooo0`3oool000P0oooo
2?ooool80?ooo`Sooooo203oool3ooooo`03nooooooooooooooo00;ooooo203oool2ooooo`03o_oo
oooooooooooo00?ooooo203oool00oooooonooooooooo`05ooooo`<0oooo00<4oooo0?ooo`3oool0
0P3oool8ooooo`P0oooo0_ooool00nooooooooooooooo`03ooooo`P0oooo0_ooool00ogooooooooo
ooooo`03ooooo`P0oooo0oooool00o_oooooooooooooo`02ooooo`P0oooo0_ooool00o_ooooooooo
ooooo`03ooooo`031?ooo`3oool0oooo00D0oooo00?oooooOoooooooool01Oooool80?ooo`?ooooo
00?_ooooooooooooool00_ooool80?ooo`03noooooooooomoooo00Gooooo203oool8ooooo`P0oooo
00?oooooOoooooooool01Oooool80?ooo`Sooooo203oool2ooooo`03nooooooooooooooo00?ooooo
203oool8ooooo`<0oooo00080?ooo`03Oooooooooooooooo00Gooooo203oool8ooooo`P0oooo00?o
oooogoooooooool01Oooool80?ooo`Sooooo203oool01>ooooooooookooooo[oool4ooooo`P0oooo
00?nooooooooooooool01Oooool80?ooo`Sooooo203oool8ooooo`030?oooh3oool0oooo00D0oooo
2?ooool80?ooo`Sooooo00<2oooo0?ooo`3oool01@3oool8ooooo`P0oooo2?ooool80?ooo`03o_oo
oooooooooooo00Gooooo00>0oooo0?ooo`3oool01@3oool3ooooo`03nooooooooooooooo00;ooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo0P3oool00b3oool0oooo0?ooo`030?ooo`03oooo
oogooooooooo00Gooooo0P3oool18?ooo`00203oool00ooooonoooooooooo`05ooooo`P0oooo00?g
oooooOooooooool01Oooool00b3oool0oooo0?ooo`050?ooo`Sooooo203oool8ooooo`P0oooo00?n
ooooooooooooool01Oooool80?ooo`Sooooo0P3oool00h3oool0oooo0?ooo`030?ooo`;ooooo00?k
ooooooooooooool00oooool80?ooo`03kooooooooooooooo00Gooooo203oool8ooooo`P0oooo00?o
ooooOoooooooool01Oooool80?ooo`03ooooookoooomoooo00Gooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool00o_ooooooooomoooo`05ooooo`040?oooh3oool0oooo0_ooo`@0oooo
00?oooooOoooooooool01Oooool80?ooo`03Oooooooooooooooo00Gooooo00<@oooo0?ooo`3oool0
1@3oool8ooooo`<0oooo0008ooooo`P0oooo2?ooool80?ooo`Kooooo00?nooookoooo`3oool01`3o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo1`3oool00`Coooooooooooooo`06ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo1oooool00jooool0oooo0?ooo`060?ooo`Sooooo1`3o
ool00h3oool0oooo0?ooo`060?ooo`03oOooooOoooonoooo00Gooooo00@@oooo0?ooo`3oool8oooo
103oool3ooooo`03mooooooooooooooo00;ooooo0P3oool00`Soool0oooo0?ooo`030?ooo`Sooooo
00>0oooo0?oooa3oool01@3oool8ooooo`03@?ooo`3oool0oooo00D0oooo0_ooool00mOooooooooo
ooooo`03ooooo`P0oooo2?ooool1P?ooo`40oooo0@3oool000Sooooo203oool5ooooo`03mooooooo
oooooooo00P0oooo2?ooool70?ooo`031?oooooooooooooo00Kooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00>_oooo0?ooo`3oool00P3o
ool0183oool0oooo0?ooo`3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`?ooooo0008ooooo`P0oooo2?oo
ool80?ooo`Oooooo00?moooo0?ooo`3oool01P3oool8ooooo`P0oooo1?ooool01;oooooooooooOoo
ooooool80?ooo`Sooooo203oool6ooooo`03goooooooool0oooo00L0oooo2?ooool80?ooo`Gooooo
00=oooooooooooooool0203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?koooo0?ooo`3oool0
1P3oool8ooooo`H0oooo00<@oooo0?ooooooool01_ooool00o_oool0oooo0?ooo`060?ooo`Sooooo
203oool4ooooo`04Ooooooooooooooooooooo`P0oooo1oooool00mooool0oooo0?ooo`060?ooo`So
oooo203oool3ooooo`001_ooool00oOooooooooo0?ooo`070?ooo`Sooooo203oool6ooooo`03oOoo
ooooool0oooo00L0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo
203oool6ooooo`03noooooooool0oooo00L0oooo2?ooool80?ooo`Kooooo00?kooooooooo`3oool0
103oool00h3oool0oooo0?ooo`08ooooo`P0oooo0oooool000Sooooo203oool8ooooo`P0oooo1ooo
ool00okoool0oooo0?ooo`060?ooo`Sooooo203oool7ooooo`03Ooooo`3oool0oooo00H0oooo2?oo
ool80?ooo`Sooooo1P3oool00`Coool0ooooooooo`07ooooo`P0oooo2?ooool80?ooo`Sooooo1P3o
ool00aCoool0ooooooooo`07ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`?ooooo0008ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool6ooooo`03koooooooool0
oooo00L0oooo2?ooool80?ooo`Oooooo00?_oooo0?ooo`3oool01P3oool7ooooo`03_oooo`3oool0
oooo00H0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?_oooo
0?ooo`3oool01P3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool3ooooo`00203oool2oooo
o`03o_oooooooooooooo00?ooooo203oool8ooooo`P0oooo2?ooool00`3ooon0oooo0?ooo`050?oo
oa3ooooo203oool8ooooo`P0oooo1oooool00ogoool0oooo0?ooo`060?ooo`Sooooo203oool7oooo
o`03Ooooo`3oool0oooo00H0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?oo
o`Sooooo203oool8ooooo`H0oooo00>0oooo0?ooooooool01oooool80?ooo`Sooooo203oool8oooo
o`P0oooo0oooool000P0oooo00>oooooooooooooool01Oooool00h3oool0oooo0?ooo`050?ooo`03
Oooooooooookoooo00Gooooo203oool8ooooo`034?ooo`3oool0oooo00D0oooo2?ooool80?ooo`?o
oooo00?Oooooooooooooool00_ooool00`3ooon0oooo0?ooo`050?ooo`Sooooo203oool8ooooo`P0
oooo2?ooool80?ooo`;ooooo00?_ooooooooooooool00oooool30?ooo`030Oooo`3oool0oooo0080
oooo00?oooookoooooooool01Oooool80?ooo`Sooooo203oool8ooooo`<0oooo00<8oooo0?ooo`3o
ool00P3oool2ooooo`03gooooooooooooooo00?ooooo0`3oool00`Coool0oooo0?ooo`020?ooo`?o
oooo00?nooooooooooooool00_ooool00`3ooon0oooo0?ooo`050?ooo`;ooooo00?mooookooooooo
ool00oooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool30?ooo`0000>0oooo0?ooo`3oool0
1@3oool8ooooo`<0oooo00<4oooo0?ooo`3oool00P3oool8ooooo`P0oooo2?ooool00`3oool4oooo
0?ooo`050?ooo`03Oooooooooookoooo00Gooooo203oool00ooooooOooooooooo`05ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo00>0oooo1?ooo`3oool0
1@3oool8ooooo`P0oooo0_ooool00oOoooooooooooooo`03ooooo`P0oooo2?ooool80?ooo`?ooooo
00?gooooooooooooool00_ooool80?ooo`Sooooo203oool8ooooo`<0oooo00>0oooo0?ooo`3oool0
0P3oool3ooooo`03oOoooooooooooooo00;ooooo203oool8ooooo`40oooo0D3oool11?ooo`00203o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool00oooooomooooooooo`05ooooo`P0oooo2?oo
ool00`3oool4oooo0?ooo`050?ooo`03kooooooooookoooo00Gooooo00<8oooo0?ooo`3oool01@3o
ool8ooooo`P0oooo2?ooool80?ooo`;ooooo00?kooooooooooooool00oooool00`3oool@oooo0?oo
o`050?ooo`Sooooo203oool01?koooooooooooooonooool4ooooo`P0oooo0_ooool00noooooooooo
ooooo`03ooooo`P0oooo00?ooooomoooooooool01Oooool80?ooo`Sooooo203oool2ooooo`03o_oo
oooooooooooo00?ooooo203oool8ooooo`P0oooo0_ooool00mooooooooooooooo`03ooooo`<0oooo
00<1oooo0?ooo`3oool00P3oool8ooooo`<0oooo00080?ooo`Sooooo0P3oool00b3oool0oooo0?oo
o`030?ooo`03mooooooooooooooo00Gooooo0P3oool00b3oool0oooo0?ooo`030?ooo`Sooooo203o
ool2ooooo`03_ooooooooooooooo00?ooooo203oool8ooooo`P0oooo2?ooool80?ooo`?ooooo00?k
ooooooooooooool00_ooool80?ooo`;ooooo00?nooooooooooooool00oooool80?ooo`03ooooooko
oooooooo00Gooooo0`3oool00`Coool0oooo0?ooo`020?ooo`Sooooo203oool2ooooo`03kooooooo
oooooooo00?ooooo203oool2ooooo`03oOoooooooooooooo00?ooooo203oool3ooooo`03nooooooo
oooooooo00;ooooo203oool2ooooo`03nooooooooooooooo00?ooooo00<4oooo0?ooo`3oool01@3o
ool00ooooomoooooooooo`05ooooo`P0oooo0oooool00nooooooooooooooo`02ooooo`P0oooo00?k
oooooooooogoool01Oooool80?ooo`Sooooo0`3oool000P0oooo00=oooooooooooooool01Oooool0
0a3oool0oooo0?ooo`050?ooo`Sooooo203oool2ooooo`03Ooooonoooooooooo00?ooooo203oool0
1?oooomooooooooooo_oool4ooooo`P0oooo00Aoooooooooooooooo_oooo1?ooool80?ooo`03oooo
okoooooooooo00Gooooo203oool00ooooooOooooooooo`05ooooo`P0oooo2?ooool80?ooo`04kooo
ooooooo_oooon_ooo`Cooooo203oool00okoooooooooooooo`05ooooo`<0oooo00<4oooo0?ooo`3o
ool00P3oool8ooooo`P0oooo2?ooool00`3ooon0oooo0?ooo`050?ooo`Sooooo203oool8ooooo`03
0_ooo`3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool00okoooooooooooooo`05ooooo`03
P?ooo`3oool0oooo00D0oooo0oooool00o_oooooooooooooo`02ooooo`<0oooo00000d3oool0oooo
0?ooo`050?ooo`;ooooo00?Gooooooooooooool00oooool80?ooo`Sooooo00>0oooo0?ooo`3oool0
1@3oool8ooooo`P0oooo2?ooool80?ooo`03oooookoooooooooo00Gooooo203oool00oOoooomoooo
ooooo`05ooooo`038?ooo`3oool0oooo00D0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`;ooooo00?kooooooooooooool00oooool80?ooo`03kooooooooooooooo00Gooooo
203oool8ooooo`P0oooo00?oooooOoooooooool01Oooool80?ooo`03ooooogkoooomoooo00Gooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo0`3oool000Sooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Kooooo00?nooookoooo`3oool01`3o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo1`3oool00`Coooooooooooooo`06ooooo`P0oooo2?oo
ool80?ooo`Sooooo1@3oool00`;oool0oooo0?ooo`08ooooo`H0oooo00=0oooo0?ooooooool01_oo
ool00jooool0oooo0?ooo`060?ooo`Sooooo1`3oool00h3oool0oooo0?ooo`060?ooo`03oOooooOo
ooonoooo00Gooooo00@@oooo0?ooo`3oool8oooo103oool3ooooo`03mooooooooooooooo00;ooooo
0P3oool12?ooo`001oooool00mooool0oooo0?ooo`060?ooo`Sooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool5ooooo`03mooooooooooooooo00P0oooo2?ooool70?ooo`031?oooooo
oooooooo00Kooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo1`3oool00a3ooooooooooooo
o`06ooooo`P0oooo2?ooool80?ooo`Oooooo00?_oooo0?ooo`3oool00P3oool0183oool0oooo0?oo
o`3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo0oooool000Sooooo1@3o
ool00h3oool0oooo0?ooo`08ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?oo
ool80?ooo`Oooooo00?moooo0?ooo`3oool01P3oool8ooooo`P0oooo1?ooool01;oooooooooooOoo
ooooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Gooooo00=oooooooooooooool0
203oool8ooooo`P0oooo2?ooool80?ooo`Oooooo00?koooo0?ooo`3oool01P3oool8ooooo`H0oooo
00<@oooo0?ooooooool01_ooool00o_oool0oooo0?ooo`060?ooo`?ooooo0008ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Cooooo00Cgoooooooooooooooooooo
203oool5ooooo`03Oooooogooooooooo00P0oooo2?ooool80?ooo`Sooooo203oool6ooooo`03mooo
ooooool0oooo00L0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool3ooooo`002?ooool70?ooo`038?oooooo
oooooooo00Kooooo203oool7ooooo`03moooo`3oool0oooo00H0oooo2?ooool80?ooo`Sooooo203o
ool8ooooo`P0oooo1oooool00okoool0oooo0?ooo`060?ooo`Sooooo203oool7ooooo`03Ooooo`3o
ool0oooo00H0oooo2?ooool50?ooo`03P?ooo`3oool0oooo00Sooooo1P3oool00`Coool0oooooooo
o`07ooooo`P0oooo2?ooool80?ooo`Sooooo1P3oool00aCoool0ooooooooo`07ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool8ooooo`P0oooo0oooool000Sooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool8
0?ooo`Kooooo00?Oooooooooo`3oool01`3oool6ooooo`03koooooooool0oooo00L0oooo2?ooool8
0?ooo`Oooooo00?_oooo0?ooo`3oool01P3oool7ooooo`03_oooo`3oool0oooo00H0oooo2?ooool8
0?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`?ooooo00080?ooo`Sooooo203oool8oooo
o`P0oooo00?oooooOoooooooool01Oooool80?ooo`Sooooo203oool2ooooo`03o_oooooooooooooo
00?ooooo203oool8ooooo`030?oooh3oool0oooo00D0oooo2?ooool00`3ooon0oooo0?ooo`050?oo
oa3ooooo203oool8ooooo`P0oooo1oooool00ogoool0oooo0?ooo`060?ooo`Sooooo203oool7oooo
o`03Ooooo`3oool0oooo00H0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?oo
o`Sooooo203oool3ooooo`000`3oool00h3oool0oooo0?ooo`020?ooo`?ooooo00?moooooooooooo
ool00_ooool80?ooo`Sooooo00<0oooo@?ooo`3oool01@3oool3ooooo`03gooooooooooooooo00;o
oooo00>0oooo0?oood3oool01@3oool8ooooo`P0oooo00>oooooooooooooool01Oooool00h3oool0
oooo0?ooo`050?ooo`03Oooooooooookoooo00Gooooo203oool8ooooo`034?ooo`3oool0oooo00D0
oooo2?ooool80?ooo`?ooooo00?Oooooooooooooool00_ooool00`3ooon0oooo0?ooo`050?ooo`So
oooo203oool8ooooo`P0oooo2?ooool80?ooo`;ooooo00?_ooooooooooooool00oooool30?ooo`03
0oooo`3oool0oooo0080oooo00?oooook_ooooooool01Oooool80?ooo`Sooooo203oool8ooooo`<0
oooo00<8oooo0?ooo`3oool00P3oool2ooooo`03goooooWooooooooo00?ooooo0`3oool00`Coool0
oooo0?ooo`020?ooo`?ooooo00?nooooooooooooool00_ooool30?ooo`00203oool2ooooo`03gooo
oooooooooooo00?ooooo0`3oool00`7oool0oooo0?ooo`020?ooo`Sooooo203oool8ooooo`80oooo
00<Poooo0?ooo`3oool00`3oool2ooooo`03oOoooooooooooooo00?ooooo203oool8ooooo`<0oooo
00<4oooo0?ooo`3oool00P3oool8ooooo`P0oooo2?ooool80?ooo`03Oooooooooookoooo00Gooooo
203oool8ooooo`P0oooo2?ooool80?ooo`;ooooo00?nooooooooooooool00oooool80?ooo`Sooooo
203oool8ooooo`P0oooo2?ooool00h3oool4oooo0?ooo`050?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`?ooooo00?gooooooooooooool00_ooool30?ooo`00203oool00o_ooooooooooOoo
o`05ooooo`P0oooo2?ooool80?ooo`03ooooogoooooooooo00Gooooo203oool8ooooo`P0oooo0_oo
ool00o_oooooooooooooo`03ooooo`P0oooo2?ooool80?ooo`Sooooo203oool00oooooomoooooooo
o`05ooooo`P0oooo2?ooool00`3oool4oooo0?ooo`050?ooo`03kooooooooookoooo00Gooooo00<8
oooo0?ooo`3oool01@3oool8ooooo`P0oooo2?ooool80?ooo`;ooooo00?kooooooooooooool00ooo
ool00`3oool@oooo0?ooo`050?ooo`Sooooo203oool01?koooooooooooooonooool4ooooo`P0oooo
0_ooool00nooooooooooooooo`03ooooo`P0oooo00?ooooomoooooooool01Oooool80?ooo`Sooooo
0`3oool000P0oooo00?nooookoooooooool01Oooool00h3oool0oooo0?ooo`050?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo0P3oool00b3oool0oooo0?ooo`030?ooo`Sooooo0P3o
ool00b3oool0oooo0?ooo`030?ooo`Sooooo203oool00ooooomooooo_oooo`05ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool3ooooo`03nooooooooooooooo00;ooooo203oool2ooooo`03o_oooooo
oooooooo00?ooooo203oool00oooooonooooooooo`05ooooo`<0oooo00<4oooo0?ooo`3oool00P3o
ool8ooooo`P0oooo0_ooool00nooooooooooooooo`03ooooo`P0oooo0_ooool00ogooooooooooooo
o`03ooooo`P0oooo2?ooool80?ooo`;ooooo00?kooooooooooooool00oooool11?ooo`40oooo0@3o
ool000P0oooo2?ooool80?ooo`Sooooo203oool2ooooo`03mooooooooooooooo00?ooooo00@0oooo
P?ooo`3oool2oooo103oool00ooooomoooooooooo`05ooooo`P0oooo00=oooooooooooooool01Ooo
ool80?ooo`Sooooo203oool2ooooo`03Ooooonoooooooooo00?ooooo203oool3ooooo`03nooooooo
oooooooo00;ooooo203oool00gooooooooooooooo`05ooooo`P0oooo00?ooooo_oooooooool01Ooo
ool80?ooo`03ooooomoooooooooo00Gooooo203oool8ooooo`P0oooo00C_ooooooooonooooojoooo
1?ooool80?ooo`03o_oooooooooooooo00Gooooo0`3oool00`Coool0oooo0?ooo`020?ooo`Sooooo
203oool8ooooo`030?oooh3oool0oooo00D0oooo2?ooool80?ooo`;ooooo00?kooooooooooooool0
0oooool30?ooo`00203oool00ogoooogooooo_ooo`05ooooo`044?ooo`3oool0oooo2?ooo`@0oooo
0oooool00oOoooooooooooooo`02ooooo`030?ooo`SooolHoooo00D0oooo2?ooool00h3oool0oooo
4?ooo`050?ooo`Sooooo00=0oooo0?ooo`3oool01@3oool2ooooo`03eooooooooooooooo00?ooooo
0P3oool00b3oool0oooo0?ooo`030?ooo`Sooooo00>0oooo0?ooo`3oool01@3oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool00oOoooomooooooooo`05ooooo`038?ooo`3oool0oooo00D0oooo
2?ooool80?ooo`Sooooo203oool00okoooooooooooooo`05ooooo`P0oooo2?ooool80?ooo`03oooo
okoooookoooo00Gooooo203oool00nooooooooooooooo`05ooooo`P0oooo2?ooool80?ooo`03oooo
ogoooooooooo00Gooooo0`3oool000Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`?o00001Ooo
ool80?ooo`Kooooo00?nooookoooo`3oool01`3oool8ooooo`P0oooo2?ooool80?ooo`Sooooo1`3o
ool00`Coooooooooooooo`06ooooo`P0oooo2?ooool80?ooo`Sooooo1@3oool00`;oool0oooo0?oo
o`08ooooo`P0oooo0oooool000Sooooo1P3oool00a3oool0ooooooooo`06ooooo`03noooo`3oool0
oooo00H0oooo2?ooool80?ooo`Cooooo00Aooooooooooooooooooooo203oool7ooooo`03goooo`3o
ool0oooo00H0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1Oooool00noooooooooooooo
o`070?ooo`0300000?l0003o000000;o000000Cooooomooooooooooooooo203oool8ooooo`L0oooo
00<4ooooooooooooool01_ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo
203oool8ooooo`P0oooo1oooool00jooool0oooo0?ooo`020?ooo`04P?ooo`3oool0oooo0?ooo`?o
oooo0008ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1_ooool00o_ooooooooo
0?ooo`040?ooo`03P?ooo`3oool0oooo00Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo
1`3oool00`00003o0000o`000002o`0000Cooooo203oool7ooooo`03oOooo`3oool0oooo00H0oooo
2?ooool80?ooo`Cooooo00Booooooooooogooooooooo1P3oool00a3oool0ooooooooo`07ooooo`P0
oooo1_ooool00moooooooooo0?ooo`070?ooo`Sooooo203oool5ooooo`03Oooooooooooooooo00H0
oooo00<8oooo0?ooooooool01oooool80?ooo`?ooooo0008ooooo`P0oooo1Oooool00goooooooooo
ooooo`080?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`Kooooo00?gooooooooo`3oool01P3oool00`00003o0000o`000002o`0000Cooooo
203oool6ooooo`03oOooooooool0oooo00L0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo
2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo1_ooool00noooooooooo0?ooo`070?ooo`?ooooo
0008ooooo`P0oooo2?ooool80?ooo`Oooooo00?_oooo0?ooo`3oool01P3oool8ooooo`P0oooo2?oo
ool80?ooo`Sooooo203oool7ooooo`03moooo`3oool0oooo00H0oooo2?ooool80?ooo`Sooooo203o
ool3o`0000Gooooo203oool7ooooo`03o_ooo`3oool0oooo00H0oooo2?ooool80?ooo`Oooooo00=o
oooo0?ooo`3oool01P3oool8ooooo`D0oooo00>0oooo0?ooo`3oool02?ooool80?ooo`Sooooo203o
ool8ooooo`P0oooo2?ooool60?ooo`035?ooo`3ooooooooo00;ooooo0008ooooo`P0oooo2?ooool8
0?ooo`Sooooo1P3oool00h3oool0ooooooooo`07ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8ooooo`P0oooo2?ooool80?ooo`Sooooo203oool8
ooooo`P0oooo1_ooool00moooooooooo0?ooo`070?ooo`Kooooo00?_ooooooooo`3oool01`3oool8
ooooo`P0oooo1oooool00nooool0oooo0?ooo`060?ooo`Oooooo00>ooooo0?ooo`3oool01P3oool3
ooooo`000`3oool00`Soool0oooo0?ooo`020?ooo`;ooooo00?Ooooonoooooooool00oooool30?oo
o`031?ooo`3oool0oooo0080oooo0oooool00okoooooooooooooo`02ooooo`P0oooo0_ooool00ogo
oooWooooooooo`03ooooo`P0oooo0oooool00nooooooooooooooo`02ooooo`P0oooo2?ooool80?oo
o`Sooooo203oool00ooooomoooooooooo`05ooooo`P0oooo2?ooool80?ooo`;ooooo00?noooooooo
ooooool00oooool80?ooo`Sooooo203oool8ooooo`030?oooh3oool0oooo00D0oooo4?ooool80?oo
o`Sooooo203oool7ooooo`03oOooo`3oool0oooo00H0oooo2?ooool80?ooo`Oooooo00=ooooo0?oo
o`3oool01P3oool8ooooo`P0oooo0oooool00001\
\>"],
  ImageRangeCache->{{{0, 290.938}, {179.313, 0}} -> {-2.19357, -4.10002, 
  0.0188492, 0.0292786}}],

Cell[TextData[{
  "Any point ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " satisfying ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] f[z, c]\)]],
  " is a ",
  StyleBox["fixed point",
    FontSlant->"Italic"],
  " of the map.  Fixed points can be classified as\na) ",
  StyleBox["attracting",
    FontSlant->"Italic"],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\(f\^\[Prime]\)[z, 
            c]\[RightBracketingBar]\  < \ 1\)]],
  "\nb) ",
  StyleBox["repelling",
    FontSlant->"Italic"],
  " if  ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\(f\^\[Prime]\)[z, 
            c]\[RightBracketingBar]\  > \ 1\)]],
  "\nc) ",
  StyleBox["neutral",
    FontSlant->"Italic"],
  " or ",
  StyleBox["indifferent",
    FontSlant->"Italic"],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\(f\^\[Prime]\)[z, 
            c]\[RightBracketingBar]\  = \ 1\)]],
  "\nNeutral fixed points can be classified further by expressing the \
derivative of the mapping function as ",
  Cell[BoxData[
      \(TraditionalForm\`f\^\[Prime] = \[ExponentialE]\^\(2  \[Pi]\ \
\[ImaginaryI]\ \[Alpha]\)\)]],
  " where \[Alpha] is real.  Thus, a fixed point is described as either ",
  StyleBox["rationally",
    FontSlant->"Italic"],
  " or ",
  StyleBox["irrationally",
    FontSlant->"Italic"],
  " indifferent according to \[Alpha].  Similarly, any point ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " satisfying ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] \(f\^k\)[z, c]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^j\)[z, c] \[NotEqual] z\)]],
  " for any ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] j < k\)]],
  " is classified as a ",
  StyleBox["periodic point",
    FontSlant->"Italic"],
  " and identified as a member of a ",
  StyleBox["cycle of period k",
    FontSlant->"Italic"],
  " or a ",
  StyleBox["k-cycle",
    FontSlant->"Italic"],
  " for short.  Periodic points are either attracting, repelling, or \
indifferent according to value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\((f\^k)\)\^\[Prime]\
\[RightBracketingBar]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Consider a point ",
  StyleBox["z",
    FontSlant->"Italic"],
  " near a periodic point ",
  Cell[BoxData[
      \(TraditionalForm\`z\_k\)]],
  ".  If the cycle is repelling, application of the function ",
  Cell[BoxData[
      \(TraditionalForm\`f\^k\)]],
  " increases the distance between the test point and the periodic point, \
whereas for attractive cycles that distance decreases.  Conversely, inverse \
iteration ",
  Cell[BoxData[
      \(TraditionalForm\`f\^\(-k\)\)]],
  " produces a set of points that is closer to a repelling ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "-cycle.  Thus, according to the theorem that the Julia set consists of \
repelling periodic points, we expect that any seed point subjected to inverse \
iteration long enough will generate a set of points that approximates the \
Julia set.  This behavior is reminiscent of other dynamical systems, such as \
the ",
  ButtonBox["Henon map",
    ButtonData:>{"Applications/henon.nb", None},
    ButtonStyle->"Hyperlink"],
  ", for which there is a unique ",
  StyleBox["strange attractor",
    FontSlant->"Italic"],
  " such that a point is either captured by the set or escapes to infinity \
upon iteration."
}], "Text"],

Cell[TextData[{
  "In this notebook we apply the IIM to the quadratic map ",
  Cell[BoxData[
      \(TraditionalForm\`f[z, c] = z\^2 + c\)]],
  " and leave other maps to the exercises.   For this map the inverse is \
double-valued, ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\(-1\)\)[z, 
          c] = \(\[PlusMinus]\@\(z - c\)\)\)]],
  ".  Given a seed on ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0 \[Element] J[f, c]\)]],
  ", the first inverse iteration yields 2 points, the next 4 points, and the \
",
  Cell[BoxData[
      \(TraditionalForm\`k\^th\)]],
  " iteration ",
  Cell[BoxData[
      \(TraditionalForm\`2\^k\)]],
  " more points approximating ",
  Cell[BoxData[
      \(TraditionalForm\`J[f, c]\)]],
  ".  Thus, the deterministic version of the IIM algorithm uses ",
  StyleBox["Nest", "InlineInput",
    FontWeight->"Bold"],
  " to produce list of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^k\)]],
  " points representing the ",
  Cell[BoxData[
      \(TraditionalForm\`k\^th\)]],
  " inverse iteration beginning from an arbitrary seed.  Alternatively, one \
can construct a set of points by selecting one of the two roots at random.  \
Some number of initial iterations, depending upon ",
  StyleBox["c",
    FontSlant->"Italic"],
  " and the seed chosen, must be discarded to allow transients to decay, but \
all subsequent pre-images are retained.  For a given number of points in the \
final set, the random IIM reaches much deeper into the iteration tree than \
the deterministic algorithm and, hence, usually converges more rapidly."
}], "Text"],

Cell[CellGroupData[{

Cell["References", "Subsection"],

Cell[TextData[{
  "The Science of Fractal Images",
  StyleBox[", edited by H.-O. Peitgen and D. Saupe, (Springer-Verlag, Berlin, \
1988).",
    FontSlant->"Plain"]
}], "Text",
  CellDingbat->None,
  CellMargins->{{30, Inherited}, {Inherited, Inherited}},
  FontSlant->"Italic"],

Cell[TextData[{
  "H.-O. Peitgen and P.H. Richter, ",
  StyleBox["The Beauty of Fractals",
    FontSlant->"Italic"],
  ", (Springer-Verlag, Berlin, 1986)."
}], "Text",
  CellDingbat->None,
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(\(ClearAll["\<Global`*\>"];\)\), "\n", 
    \(\(Off[General::spell, \ General::spell1];\)\), "\n", 
    \(\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 12};\)\)}], "Input"],

Cell[BoxData[
    \(Needs["\<Graphics`\>"]\)], "Input"],

Cell[BoxData[
    \(\(ComplexToArgand = {Complex[x_, y_] \[Rule] {x, y}, 
          x_Real \[Rule] {x, 0}, x_Integer \[Rule] {x, 0}};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Implementation", "Section"],

Cell[CellGroupData[{

Cell["Deterministic IIM algorithm", "Subsection"],

Cell[TextData[{
  "The deterministic IIM algorithm replaces each point by two pre-images and \
iterates the procedure ",
  StyleBox["n",
    FontSlant->"Italic"],
  " times to produce ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " points approximating the Julia set.  The simplest implementation uses ",
  StyleBox["Nest", "InlineInput",
    FontWeight->"Bold"],
  " to perform the iteration and ",
  StyleBox["Flatten", "InlineInput",
    FontWeight->"Bold"],
  " to produce a simple list of complex numbers.  To ensure that all results \
are numerical instead of symbolic, we convert arguments to numerical form \
before iteration, which saves time and storage.  The final results are then \
converted from complex numbers to Argand coordinates for plotting."
}], "Text"],

Cell[BoxData[{
    \(\(\(JuliaDIIM::usage\  = \ \*"\"\<JuliaDIIM[c,z0,n] performs n inverse \
iterations of the quadratic map for parameter c beginning with seed z0, \
producing \!\(2\^n\) points approximating the Julia set.\>\"";\)\(\n\)
    \)\), "\n", 
    \(JuliaDIIM[c_, z0_, n_] := 
      Module[{cc = N[c], 
          zz = N[z0]}, \((Nest[{\@\(# - cc\), \(-\@\(# - cc\)\)} &, zz, n] // 
              Flatten)\) /. ComplexToArgand]\)}], "Input"],

Cell["\<\
Note that this implementation retains only the final level of the iteration \
tree.  \
\>", "Text"],

Cell[TextData[{
  "Take care not use too many iterations \[LongDash] the result contains ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " points; ",
  StyleBox["n",
    FontSlant->"Italic"],
  "\[LessEqual]17 is usually sufficient."
}], "Caution"]
}, Closed]],

Cell[CellGroupData[{

Cell["Random IIM algorithm", "Subsection"],

Cell[TextData[{
  "The random IIM algorithm chooses one of the two pre-images at random, \
effectively performing a random walk on the inverse iteration tree.  All hits \
on this tree are retained using ",
  StyleBox["NestList", "InlineInput",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(\(JuliaRIIM::usage\  = \ "\<JuliaRIIM[c,z0,n] samples n points of the \
backward orbit of seed z0 for the quadratic map with parameter c, choosing \
the root randomly.\>";\)\(\n\)
    \)\), "\n", 
    \(JuliaRIIM[c_, z0_, n_] := 
      Module[{cc = N[c], zz = N[z0]}, 
        NestList[\((1 - 2  Random[Integer])\) \@\(# - cc\) &, zz, n] /. 
          ComplexToArgand]\)}], "Input"],

Cell["\<\
Note that a number of the initial iterations, depending upon the seed, should \
be discarded before plotting in order to suppress transients before the \
inverse orbit has settled on the attractor.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Histograming frequency distributions", "Subsection"],

Cell[TextData[{
  "The IIM algorithms often visit various portions of a Julia set with vastly \
different frequencies, hitting some regions often and others rarely.  \
Consequently, for some sets it can take a very large number of iterations \
before an adequate representation of the set is achieved.  This behavior can \
be investigated using the following function which produces a two-dimensional \
table of hit frequencies on a uniform grid.  The resulting two-dimensional \
histogram can be displayed using ",
  StyleBox["ListPlot3D", "InlineInput",
    FontWeight->"Bold"],
  ", for example."
}], "Text"],

Cell[BoxData[
    \(histogram[
        data_, {xmin_, xmax_, nx_Integer}, {ymin_, ymax_, ny_Integer}] := 
      Module[{histo, i, j, k, dx, dy}, dx = \((xmax - xmin)\)/nx; 
        dy = \((ymax - ymin)\)/ny; histo = Table[0, {nx}, {ny}]; 
        Do[{i, j} = \ 
            Round[\((data\[LeftDoubleBracket]k\[RightDoubleBracket] - {xmin, 
                      ymin})\)/{dx, dy}]; i = Min[nx, Max[i, 1]]; 
          j = Min[ny, Max[j, 1]]; \ \(++histo\[LeftDoubleBracket]i, 
              j\[RightDoubleBracket]\), {k, 1, Length[data]}]; 
        histo]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Section"],

Cell["\<\
You may find that in the interest of economizing file size, this notebook may \
have been provided without output, but regeneration of the output does not \
take long on modern microcomputers.\
\>", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell["Sampling properties", "Subsection"],

Cell["\<\
We begin with a connected Julia set belonging to the main bud of the \
Mandelbrot set.\
\>", "Text"],

Cell[BoxData[
    \(\(JuliaData = JuliaDIIM[\(-1\), 0.2, 15];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[JuliaData, Axes \[Rule] False, 
        AspectRatio \[Rule] Automatic, 
        Prolog \[Rule] AbsolutePointSize[1]];\)\)], "Input"],

Cell[BoxData[
    \(\(JuliaData = 
        Drop[Evaluate[JuliaRIIM[\(-1\), 5  I, 100000]], 100];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[JuliaData, Axes \[Rule] False, 
        AspectRatio \[Rule] Automatic, 
        Prolog \[Rule] AbsolutePointSize[1]];\)\)], "Input"],

Cell[TextData[{
  "Both algorithms produce very similar images and the choice of seed does \
not seem to matter (although there are special cases which should be avoided, \
such as ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0 = 0\)]],
  ")."
}], "Text"],

Cell["\<\
Upon closer examination one finds that some regions are rather sparsely \
populated.\
\>", "Text"],

Cell[BoxData[
    \(\(ListPlot[JuliaData, Axes \[Rule] False, 
        AspectRatio \[Rule] Automatic, Prolog \[Rule] AbsolutePointSize[1], 
        PlotRange \[Rule] {{\(-0.12\), 0.12}, {0.5, 0.8}}];\)\)], "Input"],

Cell["\<\
This nonuniform sampling is conveniently displayed in the form of a \
two-dimensional histogram of hit frequencies.\
\>", "Text"],

Cell[BoxData[
    \(\(histo = 
        histogram[
          JuliaData, {\(-1.6\), 1.6, 161}, {\(-0.8\), 0.8, 81}];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot3D[histo, Boxed \[Rule] False, 
        Axes \[Rule] False];\)\)], "Input"],

Cell[TextData[{
  "The IIM does not work well for the case below \[LongDash] comparison with \
the results of the escape time algorithm shows that IIM misses practically of \
the interesting structure within the outline shown unless a prohibitively \
large number of points is employed; see ",
  ButtonBox["Julia.nb",
    ButtonData:>{"Applications/Julia.nb", None},
    ButtonStyle->"Hyperlink"],
  " for comparison.  Nevertheless, for dendritic sets IIM is much more \
efficient than the escape time algorithm.  More sophisticated algorithms are \
available which are more successful than either for other sets."
}], "Text"],

Cell[BoxData[{
    \(\(JuliaData = 
        Drop[Evaluate[JuliaRIIM[\(-0.745429\) + 0.113008  I, I, 100000]], 
          100];\)\), "\n", 
    \(\(ListPlot[JuliaData, Axes \[Rule] False, 
        AspectRatio \[Rule] Automatic, 
        Prolog \[Rule] AbsolutePointSize[1]];\)\)}], "Input"],

Cell["\<\
Fancier algorithms keep track of the hit frequencies and stop accumulating \
points in regions visited too often; in that way the proportion of samples in \
less popular regions is enhanced.  However, we will not pursue such \
algorithms here.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Dendrites", "Subsection"],

Cell["\<\
IIM algorithms are usually better for dendritic sets than escape time or \
boundary scanning algorithms, in part because they do not waste a lot of time \
examining large areas not relevant to the desired Julia set.\
\>", "Text"],

Cell[BoxData[{
    \(\(JuliaData = Drop[Evaluate[JuliaRIIM[I, 1, 100000]], 100];\)\), "\n", 
    \(\(ListPlot[JuliaData, Axes \[Rule] False, 
        AspectRatio \[Rule] Automatic, 
        Prolog \[Rule] AbsolutePointSize[1]];\)\)}], "Input"],

Cell["\<\
It is interesting to examine the convergence of the deterministic algorithm \
given a distant seed.  If we begin at a distant point and perform too few \
iterations, the set appears to enclose significant empty space\
\>", "Text"],

Cell[BoxData[{
    \(\(JuliaData = JuliaDIIM[I, 10, 10];\)\), "\n", 
    \(\(ListPlot[JuliaData, Axes \[Rule] False, 
        AspectRatio \[Rule] Automatic, 
        Prolog \[Rule] AbsolutePointSize[1]];\)\)}], "Input"],

Cell["\<\
but upon further iteration the enclosed space collapses and reveals the \
filamentary nature of this set.\
\>", "Text"],

Cell[BoxData[{
    \(\(JuliaData = JuliaDIIM[I, 10, 15];\)\), "\n", 
    \(\(ListPlot[JuliaData, Axes \[Rule] False, 
        AspectRatio \[Rule] Automatic, 
        Prolog \[Rule] AbsolutePointSize[1]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(JuliaData = JuliaDIIM[I, 10, 17];\)\), "\n", 
    \(\(ListPlot[JuliaData, Axes \[Rule] False, 
        AspectRatio \[Rule] Automatic, 
        Prolog \[Rule] AbsolutePointSize[1]];\)\)}], "Input"],

Cell["\<\
Notice that a different starting condition produces more rapid convergence.\
\>", "Text"],

Cell[BoxData[{
    \(\(JuliaData = JuliaDIIM[I, 0, 10];\)\), "\n", 
    \(\(ListPlot[JuliaData, Axes \[Rule] False, 
        AspectRatio \[Rule] Automatic, 
        Prolog \[Rule] AbsolutePointSize[1]];\)\)}], "Input"],

Cell[TextData[{
  "and that the random IIM yields good convergence without misleading \
enclosed space even for a distant seed.  Below we choose the number of points \
to be about ",
  Cell[BoxData[
      \(TraditionalForm\`2\^10\)]],
  ", plus some discarded initial iterations, for comparison with the 10 \
iteration DIIM result at the beginning of this section."
}], "Text"],

Cell[BoxData[{
    \(\(JuliaData = Drop[Evaluate[JuliaRIIM[I, 10, 1200]], 100];\)\), "\n", 
    \(\(ListPlot[JuliaData, Axes \[Rule] False, 
        AspectRatio \[Rule] Automatic, 
        Prolog \[Rule] AbsolutePointSize[1]];\)\)}], "Input"],

Cell["\<\
The RIIM algorithm is more robust because it penetrates deeper into the \
inverse iteration tree for the same total number of points with points \
sprinkled over all levels, whereas the DIIM produces all points at a single \
shallower level.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseMain"],

Cell[CellGroupData[{

Cell["Simple Julia sets", "ExerciseTitle"],

Cell["\<\
The Julia sets for a couple of special parameters are especially simple.\
\>", "ExerciseText"],

Cell[TextData[{
  "a) Construct the Julia set for ",
  Cell[BoxData[
      \(TraditionalForm\`c = 0\)]],
  " and show that it is really as simple as it appears."
}], "ExerciseText"],

Cell[TextData[{
  "b) Construct the Julia set for ",
  Cell[BoxData[
      \(TraditionalForm\`c = \(-2\)\)]],
  " and show that it is really as simple as it appears."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Douady rabbit", "ExerciseTitle"],

Cell[TextData[{
  "Julia sets for ",
  Cell[BoxData[
      \(TraditionalForm\`c \[TildeTilde] \(-0.12\)\  + \ 
          0.74  \[ImaginaryI]\)]],
  " are sometimes described as Douady rabbits.  Display the Julia set for ",
  Cell[BoxData[
      \(TraditionalForm\`c = \(-0.12\) + 0.74  \[ImaginaryI]\)]],
  " and explain its whimsical description.  Find the periodic points and \
display them with their basin of attraction.  Where is ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " located within the Mandelbrot set.  Show that other points in this \
vicinity produce qualitatively similar Julia sets.  What happens as a border \
is crossed?"
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rational maps", "ExerciseTitle"],

Cell["\<\
Rational mapping functions occur in iterative methods for solving algebraic \
equations, such as Newton's method, and often produce interesting Julia sets \
that provide insight into the chaotic behavior such methods sometimes \
exhibit.  Use the random IIM algorithm to display Julia sets for the \
following maps based upon rational functions.\
\>", "ExerciseText"],

Cell[TextData[{
  "a)",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`f[z] = \((\(z - 2\)\/z)\)\^2\)]],
  ".  "
}], "ExerciseText"],

Cell[TextData[{
  "b)",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`f[z] = \(2  z\^3 + 1\)\/\(3  z\^2\)\)]],
  ".  "
}], "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1392, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowCellLabel->False,
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}, {
        Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->0.5,
    CellMargins->{{25, 0}, {6, 6}},
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 1, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 105, 2, 81, "Title"],
Cell[1884, 57, 455, 15, 85, "Author"],

Cell[CellGroupData[{
Cell[2364, 76, 31, 0, 83, "Section"],
Cell[2398, 78, 415, 7, 93, "Text"],
Cell[2816, 87, 1764, 53, 145, "Text"],
Cell[4583, 142, 85311, 1112, 229, 1186, 69, "GraphicsData", "PostScript", \
"Graphics"],
Cell[89897, 1256, 2201, 72, 245, "Text"],
Cell[92101, 1330, 1231, 31, 146, "Text"],
Cell[93335, 1363, 1582, 40, 172, "Text"],

Cell[CellGroupData[{
Cell[94942, 1407, 32, 0, 68, "Subsection"],
Cell[94977, 1409, 277, 8, 41, "Text"],
Cell[95257, 1419, 246, 7, 41, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[95552, 1432, 33, 0, 51, "Section"],
Cell[95588, 1434, 223, 4, 125, "Input"],
Cell[95814, 1440, 55, 1, 73, "Input"],
Cell[95872, 1443, 148, 2, 73, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[96057, 1450, 33, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[96115, 1454, 49, 0, 68, "Subsection"],
Cell[96167, 1456, 784, 18, 94, "Text"],
Cell[96954, 1476, 452, 8, 189, "Input"],
Cell[97409, 1486, 109, 3, 41, "Text"],
Cell[97521, 1491, 256, 8, 71, "Caution"]
}, Closed]],

Cell[CellGroupData[{
Cell[97814, 1504, 42, 0, 68, "Subsection"],
Cell[97859, 1506, 286, 7, 68, "Text"],
Cell[98148, 1515, 405, 8, 185, "Input"],
Cell[98556, 1525, 221, 4, 67, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[98814, 1534, 58, 0, 68, "Subsection"],
Cell[98875, 1536, 611, 11, 94, "Text"],
Cell[99489, 1549, 567, 10, 151, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[100105, 1565, 27, 0, 51, "Section"],
Cell[100135, 1567, 248, 5, 67, "Text"],

Cell[CellGroupData[{
Cell[100408, 1576, 41, 0, 68, "Subsection"],
Cell[100452, 1578, 110, 3, 41, "Text"],
Cell[100565, 1583, 76, 1, 73, "Input"],
Cell[100644, 1586, 163, 3, 73, "Input"],
Cell[100810, 1591, 111, 2, 73, "Input"],
Cell[100924, 1595, 163, 3, 73, "Input"],
Cell[101090, 1600, 257, 7, 41, "Text"],
Cell[101350, 1609, 108, 3, 41, "Text"],
Cell[101461, 1614, 214, 3, 99, "Input"],
Cell[101678, 1619, 139, 3, 41, "Text"],
Cell[101820, 1624, 129, 3, 73, "Input"],
Cell[101952, 1629, 105, 2, 73, "Input"],
Cell[102060, 1633, 626, 11, 94, "Text"],
Cell[102689, 1646, 289, 6, 99, "Input"],
Cell[102981, 1654, 267, 5, 67, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[103285, 1664, 31, 0, 68, "Subsection"],
Cell[103319, 1666, 239, 4, 67, "Text"],
Cell[103561, 1672, 243, 4, 99, "Input"],
Cell[103807, 1678, 240, 4, 67, "Text"],
Cell[104050, 1684, 219, 4, 99, "Input"],
Cell[104272, 1690, 129, 3, 41, "Text"],
Cell[104404, 1695, 219, 4, 99, "Input"],
Cell[104626, 1701, 219, 4, 99, "Input"],
Cell[104848, 1707, 99, 2, 41, "Text"],
Cell[104950, 1711, 218, 4, 99, "Input"],
Cell[105171, 1717, 377, 8, 67, "Text"],
Cell[105551, 1727, 242, 4, 99, "Input"],
Cell[105796, 1733, 265, 5, 67, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[106110, 1744, 33, 0, 54, "ExerciseMain"],

Cell[CellGroupData[{
Cell[106168, 1748, 42, 0, 58, "ExerciseTitle"],
Cell[106213, 1750, 104, 2, 41, "ExerciseText"],
Cell[106320, 1754, 181, 5, 41, "ExerciseText"],
Cell[106504, 1761, 186, 5, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[106727, 1771, 38, 0, 58, "ExerciseTitle"],
Cell[106768, 1773, 670, 15, 93, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[107475, 1793, 38, 0, 58, "ExerciseTitle"],
Cell[107516, 1795, 377, 6, 67, "ExerciseText"],
Cell[107896, 1803, 168, 7, 46, "ExerciseText"],
Cell[108067, 1812, 175, 7, 52, "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

