(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1840456,      70024]*)
(*NotebookOutlinePosition[   1878093,      71340]*)
(*  CellTagsIndexPosition[   1878049,      71336]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Predator-Prey Models", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "\tVolterra (1926) proposed a simple two-component model to explain \
oscillatory populations of certain Adriatic fish.  Similar equations were \
also proposed by Lotka (1920) as a model of chemical oscillations.  Let ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " represent the population of a prey fish and ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  " represent the population of a predator.  The ",
  StyleBox["Lotka-Volterra",
    FontSlant->"Italic"],
  " ",
  "model takes the form"
}], "Text"],

Cell[BoxData[{
    \(\[DifferentialD]X\/\[DifferentialD]\[Tau] \[Equal] \((A - B\ Y)\) 
        X\), "\n", 
    \(\[DifferentialD]Y\/\[DifferentialD]\[Tau] \[Equal] \((C\ X - D)\) 
        Y\)}], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " represents the growth of the prey population in the absence of predators, \
",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " represents the population loss due to predation, ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " represents the death rate of predators in the absence of prey, ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " represents the growth of the predator population, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " is a time variable.  The interaction between these species is taken to be \
proportional to both populations.  The model is obviously too simple \
\[LongDash] finite environmental resources would not permit exponential \
growth of the prey population even if predators were absent and there must be \
some saturation mechanism for the predator population \[LongDash] but it is a \
useful starting point for ",
  StyleBox["predator-prey",
    FontSlant->"Italic"],
  " models."
}], "Text"],

Cell[TextData[{
  "\tThis is an example of an ",
  StyleBox["autonomous",
    FontSlant->"Italic"],
  " dynamical system that is described by a system of first-order ordinary \
differential equations of the form"
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_t r\  = \ v[r]\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`r = {r\_1, \(r\_\(\(2\)\(,\)\)\) \[CenterEllipsis], 
          r\_n}\)]],
  " is point in an ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-dimensional ",
  StyleBox["phase space",
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v = {v\_1, v\_2, \[CenterEllipsis], v\_n}\)]],
  " is an ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-dimensional velocity field that depends only upon the coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and has no explicit dependence upon time.  Thus, if one knows the \
phase-space coordinates at any time the subsequent evolution of the system \
can, at least in principle, be computed for all later times.  The dynamics of \
the system are described by a family of nonintersecting trajectories, or ",
  StyleBox["orbits",
    FontSlant->"Italic"],
  ", in phase space.  The Lotka-Volterra equations are a two-dimensional \
autonomous system describing the phase-space trajectory ",
  Cell[BoxData[
      \(TraditionalForm\`r[\[Tau]] = {X[\[Tau]], Y[\[Tau]]}\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tPoints ",
  Cell[BoxData[
      \(TraditionalForm\`r\_fp\)]],
  " where the velocity vanishes, such that ",
  Cell[BoxData[
      \(TraditionalForm\`v[r\_fp] \[Equal] 0\)]],
  ", are described as ",
  StyleBox["fixed points",
    FontSlant->"Italic"],
  " and are especially important in the analysis of autonomous systems.  Near \
any fixed point, we can linearize the equations of motion by performing a \
series expansion of the velocity field.  The resulting linearized equations \
of motion can then be expressed in the form"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`r[t]\  \[TildeTilde] \ 
      r\_fp\ \ \[DoubleLongRightArrow]\ \ \ \(\[PartialD]\_t r[
            t]\)\  \[TildeTilde] \ 
      S\[CenterDot]\((r[t] - r\_fp)\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell["where", "Text"],

Cell[BoxData[
    \(TraditionalForm\`S\_\(i, j\) = \
\((\[PartialD]v\_i\/\[PartialD]r\_j)\)\_fp\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "is the ",
  StyleBox["stability matrix ",
    FontSlant->"Italic"],
  "and is ",
  "composed of derivatives of velocity with respect to position evaluated at \
the fixed point",
  ".  It is useful to define a displacement vector"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Delta][t]\  = 
      r[t] - r\_fp\ \ \ \[DoubleLongRightArrow]\ \ \ \(\[PartialD]\_t \
\[Delta][t]\)\  \[Equal] \ S\ \[Delta][t]\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "and a unitary matrix ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  " that diagonalizes ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ", such that"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`U\ S\ U\^\(-1\)\  = \ \[Lambda]\ , \ \ \[Eta]\  = \ 
      U\ \[Delta]\ \ \[DoubleLongRightArrow]\ \ \ \ \(\[PartialD]\_t \
\[Eta]\_i[t]\)\  \[Equal] \ \[Lambda]\_i\ \[Eta]\_i[t]\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell["permits explicit solutions in the form", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Eta]\_i[
        t]\  = \ \[Eta]\_i[0]\ Exp[\(\[Lambda]\_i\) t]\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_i\)]],
  " is an eigenvalue of ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_i\)]],
  " is the corresponding eigenvector.  The dynamical behavior of the system \
near its fixed points can now be classified according to the properties of \
the eigenvalues of the stability matrix.  For simplicity, consider a \
two-dimensional system such that the eigenvalues are either both real or are \
a pair of complex conjugates.  Although one can classify all possibilities \
rather completely, for the present purposes it is sufficient to consider the \
case of complex eigenvalues.  If the real part of an eigenvalue is negative, \
the corresponding fixed point is considered ",
  StyleBox["stable ",
    FontSlant->"Italic"],
  "because small initial displacements are damped exponentially, whereas if \
the real part is positive the fixed point is ",
  StyleBox["unstable",
    FontSlant->"Italic"],
  " because small initial displacements grow exponentially.  The imaginary \
parts of these eigenvalues produce rotations in phase space, either clockwise \
or counterclockwise spirals.  When ",
  Cell[BoxData[
      \(TraditionalForm\`Re[\[Lambda]] = 0\)]],
  ", the orbit reduces to a circle at fixed distance that is described as ",
  StyleBox["neutrally stable",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "\tIn this notebook we study some of the behavior of predator-prey models.  \
We begin with the original Lotka-Volterra equations and use dimensional \
analysis to reduce the number of parameters from 4 to 1 by rescaling the \
population and time variables.  We then determine the fixed points, analyze \
their stability, and display families of orbits for representative \
parameters.  Next we consider a more realistic predator-prey model that \
requires three independent parameters and supports more interesting \
phenomena, such as stable limit cycles.  In the process, we also introduce ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "functions for analyzing and plotting inequalities.",
  StyleBox[" ",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell["References:", "Subsection"],

Cell[TextData[{
  "J.D. Murray, ",
  StyleBox["Mathematical Biology",
    FontSlant->"Italic"],
  ", (Springer-Verlag, Berlin, 1989)"
}], "Text",
  CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "S. H. Strogatz, ",
  StyleBox["Nonlinear Dynamics and Chaos",
    FontSlant->"Italic"],
  ", (Perseus Books,  Reading MA, 1994)"
}], "Text",
  CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(\(ClearAll["\<Global`*\>"];\)\), "\n", 
    \(\(Off[General::spell, General::spell1];\)\)}], "Input"],

Cell["\<\
$DefaultFont={\"Times\", 12}; 
$TextStyle={FontFamily\[Rule]\"Times\", \
FontSize\[Rule]12,FontSlant\[Rule]\"Italic\"}; \
\>", "Input"],

Cell[BoxData[{
    \(\(Needs["\<Utilities`Notation`\>"];\)\), "\n", 
    \(\(Needs["\<Utilities`FilterOptions`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`\>"];\)\), "\[IndentingNewLine]", 
    \(Needs["\<Algebra`InequalitySolve`\>"]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Original Lotka-Volterra model", "Section"],

Cell["\tThe original Lotka-Volterra equations", "Text"],

Cell[BoxData[{
    \(\[DifferentialD]X\/\[DifferentialD]\[Tau] \[Equal] \((A - B\ Y)\) 
        X\), "\n", 
    \(\[DifferentialD]Y\/\[DifferentialD]\[Tau] \[Equal] \((C\ X - D)\) 
        Y\)}], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "appear to involve 4 parameters, but by judicious scaling of ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " we may be able to deduce simpler equations with fewer parameters.  Thus, \
let"
}], "Text"],

Cell[BoxData[
    \(X \[Rule] a\ x\ , \ 
    Y \[Rule] b\ y, \ \[Tau] \[Rule] c\ t\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["such that", "Text"],

Cell[BoxData[{
    \(\[DifferentialD]x\/\[DifferentialD]t \[Equal] \((A\  - b\ B\ y)\) 
        c\ x\), "\n", 
    \(\[DifferentialD]y\/\[DifferentialD]t \[Equal] \((C\ a\ x - D)\) 
        c\ y\)}], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["If we now choose", "Text"],

Cell[BoxData[
    \(c\  = \ A\^\(-1\), \ \ b\  = \ A\ B\^\(-1\), \ \ a\  = \ 
      D\ C\^\(-1\)\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["and define", "Text"],

Cell[BoxData[
    \(\[Alpha]\  = \ D\ A\^\(-1\)\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["we obtain a simpler set of equations", "Text"],

Cell[BoxData[{
    \(\[DifferentialD]x\/\[DifferentialD]t\  \[Equal] \ \((1\  - \ y)\) 
        x\), "\[IndentingNewLine]", 
    \(\[DifferentialD]y\/\[DifferentialD]t\  \[Equal] \ \[Alpha] \((x - 
            1)\)\ y\)}], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "in terms of a single parameter, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", that governs the interaction between the two species.  Note that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] > 0\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tAlthough the fixed points are obviously ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 0}\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 1}\)]],
  ", we perform a derivation below to illustrate the steps.  First, we define \
the phase-space coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`r = {x, y}\)]],
  " and the corresponding velocity field ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " using the equations of motion."
}], "Text"],

Cell[BoxData[{
    \(\(r = {x, y};\)\), "\[IndentingNewLine]", 
    \(\(v = {\((1 - y)\) x, \[Alpha]\ \((x - 1)\) y};\)\)}], "Input"],

Cell[TextData[{
  "We then solve ",
  Cell[BoxData[
      \(TraditionalForm\`v[r] \[Equal] 0\)]],
  " for the locations of the fixed points"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fp = Solve[Thread[v \[Equal] 0], r]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 0, y \[Rule] 0}, {x \[Rule] 1, y \[Rule] 1}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "and construct the stability matrix ",
  Cell[BoxData[
      \(TraditionalForm\`S = \((\[PartialD]v/\[PartialD]r)\)\_fp\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S = Outer[D, v, r] /. fp\)], "Input"],

Cell[BoxData[
    \({{{1, 0}, {0, \(-\[Alpha]\)}}, {{0, \(-1\)}, {\[Alpha], 
          0}}}\)], "Output"]
}, Closed]],

Cell["\<\
Finally, we evaluate the eigenvalues of the stability matrix.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues /@ S\)], "Input"],

Cell[BoxData[
    \({{1, \(-\[Alpha]\)}, {\(-\[ImaginaryI]\)\ \@\[Alpha], \[ImaginaryI]\ \@\
\[Alpha]}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Thus, the origin has mixed stability: the prey population increases \
exponentially if there are no predators whereas the predator population \
decreases exponentially if there are no prey.  The fixed point at ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 1}\)]],
  " is neutral \[LongDash] the counterclockwise rotation about the fixed \
point represents stable oscillations in both populations.  Orbits close to \
the neutral fixed points are simply counterclockwise circles.  The same \
qualitative features are found for any positive ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe following functions produce phase-space trajectories and plot them \
together with the velocity field.  Notice that we can supply a list of \
initial conditions, each a ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_0, y\_0}\)]],
  " pair, to ",
  StyleBox["PhaseAndField", "InlineInput",
    FontWeight->"Bold"],
  " in order to plot a family of orbits on the same figure.  Also notice that \
we use ",
  StyleBox["FilterOptions", "InlineInput",
    FontWeight->"Bold"],
  " to distribution the appropriate options to ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParametricPlot", "InlineInput",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["PlotVectorField", "InlineInput",
    FontWeight->"Bold"],
  ".  However, because some of the commonly used options for the two plotting \
functions are the same, some of the options for ",
  StyleBox["PlotVectorField", "InlineInput",
    FontWeight->"Bold"],
  " were set to ",
  StyleBox["Automatic", "InlineInput",
    FontWeight->"Bold"],
  " to avoid conflicts.  Some examples follow."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[trajectory];\)\), "\[IndentingNewLine]", 
    \(trajectory[\[Alpha]_, {x0_, y0_}, tmax_, 
        opts___Rule] := {x[t], 
          y[t]} /. \(NDSolve[{\(x\^\[Prime]\)[t] \[Equal] \((1 - y[t])\) 
                  x[t], \(y\^\[Prime]\)[t] \[Equal] \[Alpha]\ \((x[t] - 1)\) 
                  y[t], x[0] \[Equal] x0, y[0] \[Equal] y0}, {x, y}, {t, 0, 
              tmax}, opts]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)}], \
"Input"],

Cell[BoxData[{
    \(\(Clear[PhaseAndField];\)\), "\[IndentingNewLine]", 
    \(PhaseAndField[\[Alpha]_, ic : {{_, _} .. }, xmax_, ymax_, tmin_, tmax_, 
        opts___Rule] := 
      With[{optParametricPlot\  = \ FilterOptions[ParametricPlot, opts], 
          optPlotField = FilterOptions[PlotVectorField, opts], 
          optND\  = 
            FilterOptions[NDSolve, 
              opts]}, \ \
\[IndentingNewLine]DisplayTogether[\[IndentingNewLine]PlotVectorField[\ {\((1 \
- y)\) x, \[Alpha]\ \((x - 1)\) y}, {x, 0, xmax}, {y, 0, ymax}, 
            PlotPoints \[Rule] Automatic, 
            optPlotField], \[IndentingNewLine]ParametricPlot[
            Evaluate[
              Table[trajectory[\[Alpha], 
                  ic\[LeftDoubleBracket]i\[RightDoubleBracket], tmax, 
                  optND], {i, Length[ic]}]], {t, tmin, tmax}, 
            optParametricPlot], Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<prey\>", "\<predator\>"}, 
          PlotLabel \[Rule] "\<Lotka-Volterra model, \[Alpha]=\>" <> 
              ToString[\[Alpha]]]]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PhaseAndField[2, Table[{x0, 1}, {x0, 0.5, 4, 0.5}], 4, 6, 0, 
        10];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.55167 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.236455 0.0369446 0.236455 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.26026 -0.0125 -5 -15.6875 ]
[.26026 -0.0125 5 0 ]
[.49672 -0.0125 -5 -15.6875 ]
[.49672 -0.0125 5 0 ]
[.73317 -0.0125 -5 -15.6875 ]
[.73317 -0.0125 5 0 ]
[.96963 -0.0125 -5 -15.6875 ]
[.96963 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.25 -31.375 ]
[.5 -0.0125 13.25 -15.6875 ]
[-0.0125 .03694 -10 -7.84375 ]
[-0.0125 .03694 0 7.84375 ]
[-0.0125 .2734 -10 -7.84375 ]
[-0.0125 .2734 0 7.84375 ]
[-0.0125 .50985 -10 -7.84375 ]
[-0.0125 .50985 0 7.84375 ]
[-0.0125 .74631 -10 -7.84375 ]
[-0.0125 .74631 0 7.84375 ]
[-0.0125 .98276 -10 -7.84375 ]
[-0.0125 .98276 0 7.84375 ]
[-0.0125 1.21922 -10 -7.84375 ]
[-0.0125 1.21922 0 7.84375 ]
[-0.0125 1.45567 -10.25 -7.84375 ]
[-0.0125 1.45567 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .77584 -25.9375 -23.625 ]
[-0.01875 .77584 -10.25 23.625 ]
[ 0 1.55167 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.56417 -70.875 0 ]
[.5 1.56417 70.875 15.6875 ]
[ 0 0 0 0 ]
[ 1 1.55167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.26026 0 m
.26026 .00625 L
s
gsave
.26026 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.49672 0 m
.49672 .00625 L
s
gsave
.49672 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.73317 0 m
.73317 .00625 L
s
gsave
.73317 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.96963 0 m
.96963 .00625 L
s
gsave
.96963 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.0711 0 m
.0711 .00375 L
s
.11839 0 m
.11839 .00375 L
s
.16568 0 m
.16568 .00375 L
s
.21297 0 m
.21297 .00375 L
s
.30756 0 m
.30756 .00375 L
s
.35485 0 m
.35485 .00375 L
s
.40214 0 m
.40214 .00375 L
s
.44943 0 m
.44943 .00375 L
s
.54401 0 m
.54401 .00375 L
s
.5913 0 m
.5913 .00375 L
s
.63859 0 m
.63859 .00375 L
s
.68588 0 m
.68588 .00375 L
s
.78046 0 m
.78046 .00375 L
s
.82776 0 m
.82776 .00375 L
s
.87505 0 m
.87505 .00375 L
s
.92234 0 m
.92234 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.25 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(prey) show
85.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03694 m
.00625 .03694 L
s
gsave
-0.0125 .03694 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .2734 m
.00625 .2734 L
s
gsave
-0.0125 .2734 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .50985 m
.00625 .50985 L
s
gsave
-0.0125 .50985 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .74631 m
.00625 .74631 L
s
gsave
-0.0125 .74631 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .98276 m
.00625 .98276 L
s
gsave
-0.0125 .98276 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 1.21922 m
.00625 1.21922 L
s
gsave
-0.0125 1.21922 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 1.45567 m
.00625 1.45567 L
s
gsave
-0.0125 1.45567 -71.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08424 m
.00375 .08424 L
s
0 .13153 m
.00375 .13153 L
s
0 .17882 m
.00375 .17882 L
s
0 .22611 m
.00375 .22611 L
s
0 .32069 m
.00375 .32069 L
s
0 .36798 m
.00375 .36798 L
s
0 .41527 m
.00375 .41527 L
s
0 .46256 m
.00375 .46256 L
s
0 .55715 m
.00375 .55715 L
s
0 .60444 m
.00375 .60444 L
s
0 .65173 m
.00375 .65173 L
s
0 .69902 m
.00375 .69902 L
s
0 .7936 m
.00375 .7936 L
s
0 .84089 m
.00375 .84089 L
s
0 .88818 m
.00375 .88818 L
s
0 .93547 m
.00375 .93547 L
s
0 1.03005 m
.00375 1.03005 L
s
0 1.07735 m
.00375 1.07735 L
s
0 1.12464 m
.00375 1.12464 L
s
0 1.17193 m
.00375 1.17193 L
s
0 1.26651 m
.00375 1.26651 L
s
0 1.3138 m
.00375 1.3138 L
s
0 1.36109 m
.00375 1.36109 L
s
0 1.40838 m
.00375 1.40838 L
s
0 1.50296 m
.00375 1.50296 L
s
0 1.55026 m
.00375 1.55026 L
s
.25 Mabswid
0 0 m
0 1.55167 L
s
gsave
-0.01875 .77584 -102.719 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
84.625 11.8438 translate
90 rotate
-84.625 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(predator) show
106.250 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 1.54542 m
.02381 1.55167 L
s
.26026 1.54542 m
.26026 1.55167 L
s
.49672 1.54542 m
.49672 1.55167 L
s
.73317 1.54542 m
.73317 1.55167 L
s
.96963 1.54542 m
.96963 1.55167 L
s
.125 Mabswid
.0711 1.54792 m
.0711 1.55167 L
s
.11839 1.54792 m
.11839 1.55167 L
s
.16568 1.54792 m
.16568 1.55167 L
s
.21297 1.54792 m
.21297 1.55167 L
s
.30756 1.54792 m
.30756 1.55167 L
s
.35485 1.54792 m
.35485 1.55167 L
s
.40214 1.54792 m
.40214 1.55167 L
s
.44943 1.54792 m
.44943 1.55167 L
s
.54401 1.54792 m
.54401 1.55167 L
s
.5913 1.54792 m
.5913 1.55167 L
s
.63859 1.54792 m
.63859 1.55167 L
s
.68588 1.54792 m
.68588 1.55167 L
s
.78046 1.54792 m
.78046 1.55167 L
s
.82776 1.54792 m
.82776 1.55167 L
s
.87505 1.54792 m
.87505 1.55167 L
s
.92234 1.54792 m
.92234 1.55167 L
s
.25 Mabswid
0 1.55167 m
1 1.55167 L
s
.99375 .03694 m
1 .03694 L
s
.99375 .2734 m
1 .2734 L
s
.99375 .50985 m
1 .50985 L
s
.99375 .74631 m
1 .74631 L
s
.99375 .98276 m
1 .98276 L
s
.99375 1.21922 m
1 1.21922 L
s
.99375 1.45567 m
1 1.45567 L
s
.125 Mabswid
.99625 .08424 m
1 .08424 L
s
.99625 .13153 m
1 .13153 L
s
.99625 .17882 m
1 .17882 L
s
.99625 .22611 m
1 .22611 L
s
.99625 .32069 m
1 .32069 L
s
.99625 .36798 m
1 .36798 L
s
.99625 .41527 m
1 .41527 L
s
.99625 .46256 m
1 .46256 L
s
.99625 .55715 m
1 .55715 L
s
.99625 .60444 m
1 .60444 L
s
.99625 .65173 m
1 .65173 L
s
.99625 .69902 m
1 .69902 L
s
.99625 .7936 m
1 .7936 L
s
.99625 .84089 m
1 .84089 L
s
.99625 .88818 m
1 .88818 L
s
.99625 .93547 m
1 .93547 L
s
.99625 1.03005 m
1 1.03005 L
s
.99625 1.07735 m
1 1.07735 L
s
.99625 1.12464 m
1 1.12464 L
s
.99625 1.17193 m
1 1.17193 L
s
.99625 1.26651 m
1 1.26651 L
s
.99625 1.3138 m
1 1.3138 L
s
.99625 1.36109 m
1 1.36109 L
s
.99625 1.40838 m
1 1.40838 L
s
.99625 1.50296 m
1 1.50296 L
s
.99625 1.55026 m
1 1.55026 L
s
.25 Mabswid
1 0 m
1 1.55167 L
s
gsave
.5 1.56417 -131.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Lotka) show
90.313 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
98.438 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Volterra) show
142.000 15.813 moveto
(model) show
171.500 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
177.500 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
186.250 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
194.750 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
200.750 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.02381 .03694 m
.02381 .03694 L
s
% Start of user PostScript
0. 0. MAarrowzero1
% End of user PostScript
.02381 .13828 m
.02381 .13688 L
s
% Start of user PostScript
0. 0.42857143 0. 0.42262478 MAarrowhead1
% End of user PostScript
.02381 .23962 m
.02381 .23681 L
s
% Start of user PostScript
0. 0.85714286 0. 0.84524956 MAarrowhead1
% End of user PostScript
.02381 .34096 m
.02381 .33674 L
s
% Start of user PostScript
0. 1.2857143 0. 1.2678743 MAarrowhead1
% End of user PostScript
.02381 .4423 m
.02381 .43667 L
s
% Start of user PostScript
0. 1.7142857 0. 1.6904991 MAarrowhead1
% End of user PostScript
.02381 .54363 m
.02381 .5366 L
s
% Start of user PostScript
0. 2.1428571 0. 2.1131239 MAarrowhead1
% End of user PostScript
.02381 .64497 m
.02381 .63653 L
s
% Start of user PostScript
0. 2.5714286 0. 2.5357487 MAarrowhead1
% End of user PostScript
.02381 .74631 m
.02381 .73647 L
s
% Start of user PostScript
0. 3. 0. 2.9583735 MAarrowhead1
% End of user PostScript
.02381 .84765 m
.02381 .8364 L
s
% Start of user PostScript
0. 3.4285714 0. 3.3809982 MAarrowhead1
% End of user PostScript
.02381 .94898 m
.02381 .93633 L
s
% Start of user PostScript
0. 3.8571429 0. 3.803623 MAarrowhead1
% End of user PostScript
.02381 1.05032 m
.02381 1.03626 L
s
% Start of user PostScript
0. 4.2857143 0. 4.2262478 MAarrowhead1
% End of user PostScript
.02381 1.15166 m
.02381 1.13619 L
s
% Start of user PostScript
0. 4.7142857 0. 4.6488726 MAarrowhead1
% End of user PostScript
.02381 1.253 m
.02381 1.23612 L
s
% Start of user PostScript
0. 5.1428571 0. 5.0714974 MAarrowhead1
% End of user PostScript
.02381 1.35434 m
.02381 1.33606 L
s
% Start of user PostScript
0. 5.5714286 0. 5.4941221 MAarrowhead1
% End of user PostScript
.02381 1.45567 m
.02381 1.43599 L
s
% Start of user PostScript
0. 6. 0. 5.9167469 MAarrowhead1
% End of user PostScript
.09137 .03694 m
.09184 .03694 L
s
% Start of user PostScript
0.28571429 0. 0.2876965 0. MAarrowhead1
% End of user PostScript
.09137 .13828 m
.09164 .13728 L
s
% Start of user PostScript
0.28571429 0.42857143 0.28684698 0.42432382 MAarrowhead1
% End of user PostScript
.09137 .23962 m
.09143 .23761 L
s
% Start of user PostScript
0.28571429 0.85714286 0.28599746 0.84864765 MAarrowhead1
% End of user PostScript
.09137 .34096 m
.09123 .33794 L
s
% Start of user PostScript
0.28571429 1.2857143 0.28514794 1.2729715 MAarrowhead1
% End of user PostScript
.09137 .4423 m
.09103 .43828 L
s
% Start of user PostScript
0.28571429 1.7142857 0.28429842 1.6972953 MAarrowhead1
% End of user PostScript
.09137 .54363 m
.09083 .53861 L
s
% Start of user PostScript
0.28571429 2.1428571 0.2834489 2.1216191 MAarrowhead1
% End of user PostScript
.09137 .64497 m
.09063 .63894 L
s
% Start of user PostScript
0.28571429 2.5714286 0.28259937 2.5459429 MAarrowhead1
% End of user PostScript
.09137 .74631 m
.09043 .73928 L
s
% Start of user PostScript
0.28571429 3. 0.28174985 2.9702668 MAarrowhead1
% End of user PostScript
.09137 .84765 m
.09023 .83961 L
s
% Start of user PostScript
0.28571429 3.4285714 0.28090033 3.3945906 MAarrowhead1
% End of user PostScript
.09137 .94898 m
.09003 .93995 L
s
% Start of user PostScript
0.28571429 3.8571429 0.28005081 3.8189144 MAarrowhead1
% End of user PostScript
.09137 1.05032 m
.08983 1.04028 L
s
% Start of user PostScript
0.28571429 4.2857143 0.27920129 4.2432382 MAarrowhead1
% End of user PostScript
.09137 1.15166 m
.08963 1.14061 L
s
% Start of user PostScript
0.28571429 4.7142857 0.27835177 4.6675621 MAarrowhead1
% End of user PostScript
.09137 1.253 m
.08943 1.24095 L
s
% Start of user PostScript
0.28571429 5.1428571 0.27750225 5.0918859 MAarrowhead1
% End of user PostScript
.09137 1.35434 m
.08923 1.34128 L
s
% Start of user PostScript
0.28571429 5.5714286 0.27665273 5.5162097 MAarrowhead1
% End of user PostScript
.09137 1.45567 m
.08902 1.44161 L
s
% Start of user PostScript
0.28571429 6. 0.27580321 5.9405335 MAarrowhead1
% End of user PostScript
.15893 .03694 m
.15986 .03694 L
s
% Start of user PostScript
0.57142857 0. 0.575393 0. MAarrowhead1
% End of user PostScript
.15893 .13828 m
.15946 .13768 L
s
% Start of user PostScript
0.57142857 0.42857143 0.57369396 0.42602287 MAarrowhead1
% End of user PostScript
.15893 .23962 m
.15906 .23841 L
s
% Start of user PostScript
0.57142857 0.85714286 0.57199492 0.85204573 MAarrowhead1
% End of user PostScript
.15893 .34096 m
.15866 .33915 L
s
% Start of user PostScript
0.57142857 1.2857143 0.57029588 1.2780686 MAarrowhead1
% End of user PostScript
.15893 .4423 m
.15826 .43989 L
s
% Start of user PostScript
0.57142857 1.7142857 0.56859683 1.7040915 MAarrowhead1
% End of user PostScript
.15893 .54363 m
.15786 .54062 L
s
% Start of user PostScript
0.57142857 2.1428571 0.56689779 2.1301143 MAarrowhead1
% End of user PostScript
.15893 .64497 m
.15745 .64136 L
s
% Start of user PostScript
0.57142857 2.5714286 0.56519875 2.5561372 MAarrowhead1
% End of user PostScript
.15893 .74631 m
.15705 .74209 L
s
% Start of user PostScript
0.57142857 3. 0.56349971 2.9821601 MAarrowhead1
% End of user PostScript
.15893 .84765 m
.15665 .84283 L
s
% Start of user PostScript
0.57142857 3.4285714 0.56180066 3.4081829 MAarrowhead1
% End of user PostScript
.15893 .94898 m
.15625 .94356 L
s
% Start of user PostScript
0.57142857 3.8571429 0.56010162 3.8342058 MAarrowhead1
% End of user PostScript
.15893 1.05032 m
.15585 1.0443 L
s
% Start of user PostScript
0.57142857 4.2857143 0.55840258 4.2602287 MAarrowhead1
% End of user PostScript
.15893 1.15166 m
.15544 1.14503 L
s
% Start of user PostScript
0.57142857 4.7142857 0.55670354 4.6862515 MAarrowhead1
% End of user PostScript
.15893 1.253 m
.15504 1.24577 L
s
% Start of user PostScript
0.57142857 5.1428571 0.5550045 5.1122744 MAarrowhead1
% End of user PostScript
.15893 1.35434 m
.15464 1.3465 L
s
% Start of user PostScript
0.57142857 5.5714286 0.55330545 5.5382972 MAarrowhead1
% End of user PostScript
.15893 1.45567 m
.15424 1.44724 L
s
% Start of user PostScript
0.57142857 6. 0.55160641 5.9643201 MAarrowhead1
% End of user PostScript
.22649 .03694 m
.22789 .03694 L
s
% Start of user PostScript
0.85714286 0. 0.86308951 0. MAarrowhead1
% End of user PostScript
.22649 .13828 m
.22729 .13808 L
s
% Start of user PostScript
0.85714286 0.42857143 0.86054094 0.42772191 MAarrowhead1
% End of user PostScript
.22649 .23962 m
.22669 .23922 L
s
% Start of user PostScript
0.85714286 0.85714286 0.85799238 0.85544381 MAarrowhead1
% End of user PostScript
.22649 .34096 m
.22608 .34036 L
s
% Start of user PostScript
0.85714286 1.2857143 0.85544381 1.2831657 MAarrowhead1
% End of user PostScript
.22649 .4423 m
.22548 .44149 L
s
% Start of user PostScript
0.85714286 1.7142857 0.85289525 1.7108876 MAarrowhead1
% End of user PostScript
.22649 .54363 m
.22488 .54263 L
s
% Start of user PostScript
0.85714286 2.1428571 0.85034669 2.1386095 MAarrowhead1
% End of user PostScript
.22649 .64497 m
.22428 .64377 L
s
% Start of user PostScript
0.85714286 2.5714286 0.84779812 2.5663314 MAarrowhead1
% End of user PostScript
.22649 .74631 m
.22367 .7449 L
s
% Start of user PostScript
0.85714286 3. 0.84524956 2.9940534 MAarrowhead1
% End of user PostScript
.22649 .84765 m
.22307 .84604 L
s
% Start of user PostScript
0.85714286 3.4285714 0.842701 3.4217753 MAarrowhead1
% End of user PostScript
.22649 .94898 m
.22247 .94718 L
s
% Start of user PostScript
0.85714286 3.8571429 0.84015243 3.8494972 MAarrowhead1
% End of user PostScript
.22649 1.05032 m
.22186 1.04831 L
s
% Start of user PostScript
0.85714286 4.2857143 0.83760387 4.2772191 MAarrowhead1
% End of user PostScript
.22649 1.15166 m
.22126 1.14945 L
s
% Start of user PostScript
0.85714286 4.7142857 0.83505531 4.704941 MAarrowhead1
% End of user PostScript
.22649 1.253 m
.22066 1.25059 L
s
% Start of user PostScript
0.85714286 5.1428571 0.83250674 5.1326629 MAarrowhead1
% End of user PostScript
.22649 1.35434 m
.22006 1.35172 L
s
% Start of user PostScript
0.85714286 5.5714286 0.82995818 5.5603848 MAarrowhead1
% End of user PostScript
.22649 1.45567 m
.21945 1.45286 L
s
% Start of user PostScript
0.85714286 6. 0.82740962 5.9881067 MAarrowhead1
% End of user PostScript
.29404 .03694 m
.29592 .03694 L
s
% Start of user PostScript
1.1428571 0. 1.150786 0. MAarrowhead1
% End of user PostScript
.29404 .13828 m
.29511 .13848 L
s
% Start of user PostScript
1.1428571 0.42857143 1.1473879 0.42942095 MAarrowhead1
% End of user PostScript
.29404 .23962 m
.29431 .24002 L
s
% Start of user PostScript
1.1428571 0.85714286 1.1439898 0.8588419 MAarrowhead1
% End of user PostScript
.29404 .34096 m
.29351 .34156 L
s
% Start of user PostScript
1.1428571 1.2857143 1.1405918 1.2882628 MAarrowhead1
% End of user PostScript
.29404 .4423 m
.2927 .4431 L
s
% Start of user PostScript
1.1428571 1.7142857 1.1371937 1.7176838 MAarrowhead1
% End of user PostScript
.29404 .54363 m
.2919 .54464 L
s
% Start of user PostScript
1.1428571 2.1428571 1.1337956 2.1471047 MAarrowhead1
% End of user PostScript
.29404 .64497 m
.2911 .64618 L
s
% Start of user PostScript
1.1428571 2.5714286 1.1303975 2.5765257 MAarrowhead1
% End of user PostScript
.29404 .74631 m
.29029 .74772 L
s
% Start of user PostScript
1.1428571 3. 1.1269994 3.0059466 MAarrowhead1
% End of user PostScript
.29404 .84765 m
.28949 .84925 L
s
% Start of user PostScript
1.1428571 3.4285714 1.1236013 3.4353676 MAarrowhead1
% End of user PostScript
.29404 .94898 m
.28869 .95079 L
s
% Start of user PostScript
1.1428571 3.8571429 1.1202032 3.8647885 MAarrowhead1
% End of user PostScript
.29404 1.05032 m
.28788 1.05233 L
s
% Start of user PostScript
1.1428571 4.2857143 1.1168052 4.2942095 MAarrowhead1
% End of user PostScript
.29404 1.15166 m
.28708 1.15387 L
s
% Start of user PostScript
1.1428571 4.7142857 1.1134071 4.7236304 MAarrowhead1
% End of user PostScript
.29404 1.253 m
.28628 1.25541 L
s
% Start of user PostScript
1.1428571 5.1428571 1.110009 5.1530514 MAarrowhead1
% End of user PostScript
.29404 1.35434 m
.28547 1.35695 L
s
% Start of user PostScript
1.1428571 5.5714286 1.1066109 5.5824723 MAarrowhead1
% End of user PostScript
.29404 1.45567 m
.28467 1.45849 L
s
% Start of user PostScript
1.1428571 6. 1.1032128 6.0118933 MAarrowhead1
% End of user PostScript
.3616 .03694 m
.36395 .03694 L
s
% Start of user PostScript
1.4285714 0. 1.4384825 0. MAarrowhead1
% End of user PostScript
.3616 .13828 m
.36294 .13889 L
s
% Start of user PostScript
1.4285714 0.42857143 1.4342349 0.43111999 MAarrowhead1
% End of user PostScript
.3616 .23962 m
.36194 .24083 L
s
% Start of user PostScript
1.4285714 0.85714286 1.4299873 0.86223998 MAarrowhead1
% End of user PostScript
.3616 .34096 m
.36093 .34277 L
s
% Start of user PostScript
1.4285714 1.2857143 1.4257397 1.29336 MAarrowhead1
% End of user PostScript
.3616 .4423 m
.35993 .44471 L
s
% Start of user PostScript
1.4285714 1.7142857 1.4214921 1.72448 MAarrowhead1
% End of user PostScript
.3616 .54363 m
.35892 .54665 L
s
% Start of user PostScript
1.4285714 2.1428571 1.4172445 2.1556 MAarrowhead1
% End of user PostScript
.3616 .64497 m
.35792 .64859 L
s
% Start of user PostScript
1.4285714 2.5714286 1.4129969 2.58672 MAarrowhead1
% End of user PostScript
.3616 .74631 m
.35692 .75053 L
s
% Start of user PostScript
1.4285714 3. 1.4087493 3.0178399 MAarrowhead1
% End of user PostScript
.3616 .84765 m
.35591 .85247 L
s
% Start of user PostScript
1.4285714 3.4285714 1.4045017 3.4489599 MAarrowhead1
% End of user PostScript
.3616 .94898 m
.35491 .95441 L
s
% Start of user PostScript
1.4285714 3.8571429 1.4002541 3.8800799 MAarrowhead1
% End of user PostScript
.3616 1.05032 m
.3539 1.05635 L
s
% Start of user PostScript
1.4285714 4.2857143 1.3960065 4.3111999 MAarrowhead1
% End of user PostScript
.3616 1.15166 m
.3529 1.15829 L
s
% Start of user PostScript
1.4285714 4.7142857 1.3917588 4.7423199 MAarrowhead1
% End of user PostScript
.3616 1.253 m
.35189 1.26023 L
s
% Start of user PostScript
1.4285714 5.1428571 1.3875112 5.1734399 MAarrowhead1
% End of user PostScript
.3616 1.35434 m
.35089 1.36217 L
s
% Start of user PostScript
1.4285714 5.5714286 1.3832636 5.6045599 MAarrowhead1
% End of user PostScript
.3616 1.45567 m
.34988 1.46411 L
s
% Start of user PostScript
1.4285714 6. 1.379016 6.0356799 MAarrowhead1
% End of user PostScript
.42916 .03694 m
.43197 .03694 L
s
% Start of user PostScript
1.7142857 0. 1.726179 0. MAarrowhead1
% End of user PostScript
.42916 .13828 m
.43077 .13929 L
s
% Start of user PostScript
1.7142857 0.42857143 1.7210819 0.43281903 MAarrowhead1
% End of user PostScript
.42916 .23962 m
.42956 .24163 L
s
% Start of user PostScript
1.7142857 0.85714286 1.7159848 0.86563807 MAarrowhead1
% End of user PostScript
.42916 .34096 m
.42836 .34397 L
s
% Start of user PostScript
1.7142857 1.2857143 1.7108876 1.2984571 MAarrowhead1
% End of user PostScript
.42916 .4423 m
.42715 .44631 L
s
% Start of user PostScript
1.7142857 1.7142857 1.7057905 1.7312761 MAarrowhead1
% End of user PostScript
.42916 .54363 m
.42595 .54866 L
s
% Start of user PostScript
1.7142857 2.1428571 1.7006934 2.1640952 MAarrowhead1
% End of user PostScript
.42916 .64497 m
.42474 .651 L
s
% Start of user PostScript
1.7142857 2.5714286 1.6955962 2.5969142 MAarrowhead1
% End of user PostScript
.42916 .74631 m
.42354 .75334 L
s
% Start of user PostScript
1.7142857 3. 1.6904991 3.0297332 MAarrowhead1
% End of user PostScript
.42916 .84765 m
.42233 .85568 L
s
% Start of user PostScript
1.7142857 3.4285714 1.685402 3.4625523 MAarrowhead1
% End of user PostScript
.42916 .94898 m
.42113 .95802 L
s
% Start of user PostScript
1.7142857 3.8571429 1.6803049 3.8953713 MAarrowhead1
% End of user PostScript
.42916 1.05032 m
.41992 1.06037 L
s
% Start of user PostScript
1.7142857 4.2857143 1.6752077 4.3281903 MAarrowhead1
% End of user PostScript
.42916 1.15166 m
.41872 1.16271 L
s
% Start of user PostScript
1.7142857 4.7142857 1.6701106 4.7610094 MAarrowhead1
% End of user PostScript
.42916 1.253 m
.41751 1.26505 L
s
% Start of user PostScript
1.7142857 5.1428571 1.6650135 5.1938284 MAarrowhead1
% End of user PostScript
.42916 1.35434 m
.4163 1.36739 L
s
% Start of user PostScript
1.7142857 5.5714286 1.6599164 5.6266474 MAarrowhead1
% End of user PostScript
.42916 1.45567 m
.4151 1.46973 L
s
% Start of user PostScript
1.7142857 6. 1.6548192 6.0594665 MAarrowhead1
% End of user PostScript
.49672 .03694 m
.5 .03694 L
s
% Start of user PostScript
2. 0. 2.0138755 0. MAarrowhead1
% End of user PostScript
.49672 .13828 m
.49859 .13969 L
s
% Start of user PostScript
2. 0.42857143 2.0079289 0.43451808 MAarrowhead1
% End of user PostScript
.49672 .23962 m
.49719 .24243 L
s
% Start of user PostScript
2. 0.85714286 2.0019822 0.86903615 MAarrowhead1
% End of user PostScript
.49672 .34096 m
.49578 .34518 L
s
% Start of user PostScript
2. 1.2857143 1.9960356 1.3035542 MAarrowhead1
% End of user PostScript
.49672 .4423 m
.49438 .44792 L
s
% Start of user PostScript
2. 1.7142857 1.9900889 1.7380723 MAarrowhead1
% End of user PostScript
.49672 .54363 m
.49297 .55066 L
s
% Start of user PostScript
2. 2.1428571 1.9841423 2.1725904 MAarrowhead1
% End of user PostScript
.49672 .64497 m
.49156 .65341 L
s
% Start of user PostScript
2. 2.5714286 1.9781956 2.6071085 MAarrowhead1
% End of user PostScript
.49672 .74631 m
.49016 .75615 L
s
% Start of user PostScript
2. 3. 1.972249 3.0416265 MAarrowhead1
% End of user PostScript
.49672 .84765 m
.48875 .8589 L
s
% Start of user PostScript
2. 3.4285714 1.9663023 3.4761446 MAarrowhead1
% End of user PostScript
.49672 .94898 m
.48734 .96164 L
s
% Start of user PostScript
2. 3.8571429 1.9603557 3.9106627 MAarrowhead1
% End of user PostScript
.49672 1.05032 m
.48594 1.06438 L
s
% Start of user PostScript
2. 4.2857143 1.954409 4.3451808 MAarrowhead1
% End of user PostScript
.49672 1.15166 m
.48453 1.16713 L
s
% Start of user PostScript
2. 4.7142857 1.9484624 4.7796988 MAarrowhead1
% End of user PostScript
.49672 1.253 m
.48313 1.26987 L
s
% Start of user PostScript
2. 5.1428571 1.9425157 5.2142169 MAarrowhead1
% End of user PostScript
.49672 1.35434 m
.48172 1.37261 L
s
% Start of user PostScript
2. 5.5714286 1.9365691 5.648735 MAarrowhead1
% End of user PostScript
.49672 1.45567 m
.48031 1.47536 L
s
% Start of user PostScript
2. 6. 1.9306224 6.0832531 MAarrowhead1
% End of user PostScript
.56428 .03694 m
.56803 .03694 L
s
% Start of user PostScript
2.2857143 0. 2.301572 0. MAarrowhead1
% End of user PostScript
.56428 .13828 m
.56642 .14009 L
s
% Start of user PostScript
2.2857143 0.42857143 2.2947758 0.43621712 MAarrowhead1
% End of user PostScript
.56428 .23962 m
.56481 .24324 L
s
% Start of user PostScript
2.2857143 0.85714286 2.2879797 0.87243424 MAarrowhead1
% End of user PostScript
.56428 .34096 m
.56321 .34638 L
s
% Start of user PostScript
2.2857143 1.2857143 2.2811835 1.3086514 MAarrowhead1
% End of user PostScript
.56428 .4423 m
.5616 .44953 L
s
% Start of user PostScript
2.2857143 1.7142857 2.2743873 1.7448685 MAarrowhead1
% End of user PostScript
.56428 .54363 m
.55999 .55267 L
s
% Start of user PostScript
2.2857143 2.1428571 2.2675912 2.1810856 MAarrowhead1
% End of user PostScript
.56428 .64497 m
.55839 .65582 L
s
% Start of user PostScript
2.2857143 2.5714286 2.260795 2.6173027 MAarrowhead1
% End of user PostScript
.56428 .74631 m
.55678 .75896 L
s
% Start of user PostScript
2.2857143 3. 2.2539988 3.0535198 MAarrowhead1
% End of user PostScript
.56428 .84765 m
.55517 .86211 L
s
% Start of user PostScript
2.2857143 3.4285714 2.2472027 3.489737 MAarrowhead1
% End of user PostScript
.56428 .94898 m
.55356 .96526 L
s
% Start of user PostScript
2.2857143 3.8571429 2.2404065 3.9259541 MAarrowhead1
% End of user PostScript
.56428 1.05032 m
.55196 1.0684 L
s
% Start of user PostScript
2.2857143 4.2857143 2.2336103 4.3621712 MAarrowhead1
% End of user PostScript
.56428 1.15166 m
.55035 1.17155 L
s
% Start of user PostScript
2.2857143 4.7142857 2.2268142 4.7983883 MAarrowhead1
% End of user PostScript
.56428 1.253 m
.54874 1.27469 L
s
% Start of user PostScript
2.2857143 5.1428571 2.220018 5.2346054 MAarrowhead1
% End of user PostScript
.56428 1.35434 m
.54714 1.37784 L
s
% Start of user PostScript
2.2857143 5.5714286 2.2132218 5.6708225 MAarrowhead1
% End of user PostScript
.56428 1.45567 m
.54553 1.48098 L
s
% Start of user PostScript
2.2857143 6. 2.2064256 6.1070397 MAarrowhead1
% End of user PostScript
.63184 .03694 m
.63605 .03694 L
s
% Start of user PostScript
2.5714286 0. 2.5892685 0. MAarrowhead1
% End of user PostScript
.63184 .13828 m
.63425 .14049 L
s
% Start of user PostScript
2.5714286 0.42857143 2.5816228 0.43791616 MAarrowhead1
% End of user PostScript
.63184 .23962 m
.63244 .24404 L
s
% Start of user PostScript
2.5714286 0.85714286 2.5739771 0.87583232 MAarrowhead1
% End of user PostScript
.63184 .34096 m
.63063 .34759 L
s
% Start of user PostScript
2.5714286 1.2857143 2.5663314 1.3137485 MAarrowhead1
% End of user PostScript
.63184 .4423 m
.62882 .45113 L
s
% Start of user PostScript
2.5714286 1.7142857 2.5586858 1.7516646 MAarrowhead1
% End of user PostScript
.63184 .54363 m
.62702 .55468 L
s
% Start of user PostScript
2.5714286 2.1428571 2.5510401 2.1895808 MAarrowhead1
% End of user PostScript
.63184 .64497 m
.62521 .65823 L
s
% Start of user PostScript
2.5714286 2.5714286 2.5433944 2.627497 MAarrowhead1
% End of user PostScript
.63184 .74631 m
.6234 .76178 L
s
% Start of user PostScript
2.5714286 3. 2.5357487 3.0654131 MAarrowhead1
% End of user PostScript
.63184 .84765 m
.62159 .86532 L
s
% Start of user PostScript
2.5714286 3.4285714 2.528103 3.5033293 MAarrowhead1
% End of user PostScript
.63184 .94898 m
.61978 .96887 L
s
% Start of user PostScript
2.5714286 3.8571429 2.5204573 3.9412455 MAarrowhead1
% End of user PostScript
.63184 1.05032 m
.61798 1.07242 L
s
% Start of user PostScript
2.5714286 4.2857143 2.5128116 4.3791616 MAarrowhead1
% End of user PostScript
.63184 1.15166 m
.61617 1.17597 L
s
% Start of user PostScript
2.5714286 4.7142857 2.5051659 4.8170778 MAarrowhead1
% End of user PostScript
.63184 1.253 m
.61436 1.27951 L
s
% Start of user PostScript
2.5714286 5.1428571 2.4975202 5.2549939 MAarrowhead1
% End of user PostScript
.63184 1.35434 m
.61255 1.38306 L
s
% Start of user PostScript
2.5714286 5.5714286 2.4898745 5.6929101 MAarrowhead1
% End of user PostScript
.63184 1.45567 m
.61074 1.48661 L
s
% Start of user PostScript
2.5714286 6. 2.4822288 6.1308263 MAarrowhead1
% End of user PostScript
.69939 .03694 m
.70408 .03694 L
s
% Start of user PostScript
2.8571429 0. 2.876965 0. MAarrowhead1
% End of user PostScript
.69939 .13828 m
.70207 .14089 L
s
% Start of user PostScript
2.8571429 0.42857143 2.8684698 0.4396152 MAarrowhead1
% End of user PostScript
.69939 .23962 m
.70006 .24484 L
s
% Start of user PostScript
2.8571429 0.85714286 2.8599746 0.87923041 MAarrowhead1
% End of user PostScript
.69939 .34096 m
.69806 .34879 L
s
% Start of user PostScript
2.8571429 1.2857143 2.8514794 1.3188456 MAarrowhead1
% End of user PostScript
.69939 .4423 m
.69605 .45274 L
s
% Start of user PostScript
2.8571429 1.7142857 2.8429842 1.7584608 MAarrowhead1
% End of user PostScript
.69939 .54363 m
.69404 .55669 L
s
% Start of user PostScript
2.8571429 2.1428571 2.834489 2.198076 MAarrowhead1
% End of user PostScript
.69939 .64497 m
.69203 .66064 L
s
% Start of user PostScript
2.8571429 2.5714286 2.8259937 2.6376912 MAarrowhead1
% End of user PostScript
.69939 .74631 m
.69002 .76459 L
s
% Start of user PostScript
2.8571429 3. 2.8174985 3.0773064 MAarrowhead1
% End of user PostScript
.69939 .84765 m
.68801 .86854 L
s
% Start of user PostScript
2.8571429 3.4285714 2.8090033 3.5169216 MAarrowhead1
% End of user PostScript
.69939 .94898 m
.686 .97249 L
s
% Start of user PostScript
2.8571429 3.8571429 2.8005081 3.9565368 MAarrowhead1
% End of user PostScript
.69939 1.05032 m
.68399 1.07644 L
s
% Start of user PostScript
2.8571429 4.2857143 2.7920129 4.396152 MAarrowhead1
% End of user PostScript
.69939 1.15166 m
.68199 1.18038 L
s
% Start of user PostScript
2.8571429 4.7142857 2.7835177 4.8357672 MAarrowhead1
% End of user PostScript
.69939 1.253 m
.67998 1.28433 L
s
% Start of user PostScript
2.8571429 5.1428571 2.7750225 5.2753824 MAarrowhead1
% End of user PostScript
.69939 1.35434 m
.67797 1.38828 L
s
% Start of user PostScript
2.8571429 5.5714286 2.7665273 5.7149976 MAarrowhead1
% End of user PostScript
.69939 1.45567 m
.67596 1.49223 L
s
% Start of user PostScript
2.8571429 6. 2.7580321 6.1546129 MAarrowhead1
% End of user PostScript
.76695 .03694 m
.77211 .03694 L
s
% Start of user PostScript
3.1428571 0. 3.1646615 0. MAarrowhead1
% End of user PostScript
.76695 .13828 m
.7699 .1413 L
s
% Start of user PostScript
3.1428571 0.42857143 3.1553168 0.44131425 MAarrowhead1
% End of user PostScript
.76695 .23962 m
.76769 .24565 L
s
% Start of user PostScript
3.1428571 0.85714286 3.1459721 0.88262849 MAarrowhead1
% End of user PostScript
.76695 .34096 m
.76548 .35 L
s
% Start of user PostScript
3.1428571 1.2857143 3.1366273 1.3239427 MAarrowhead1
% End of user PostScript
.76695 .4423 m
.76327 .45435 L
s
% Start of user PostScript
3.1428571 1.7142857 3.1272826 1.765257 MAarrowhead1
% End of user PostScript
.76695 .54363 m
.76106 .5587 L
s
% Start of user PostScript
3.1428571 2.1428571 3.1179379 2.2065712 MAarrowhead1
% End of user PostScript
.76695 .64497 m
.75885 .66305 L
s
% Start of user PostScript
3.1428571 2.5714286 3.1085931 2.6478855 MAarrowhead1
% End of user PostScript
.76695 .74631 m
.75664 .7674 L
s
% Start of user PostScript
3.1428571 3. 3.0992484 3.0891997 MAarrowhead1
% End of user PostScript
.76695 .84765 m
.75443 .87175 L
s
% Start of user PostScript
3.1428571 3.4285714 3.0899037 3.530514 MAarrowhead1
% End of user PostScript
.76695 .94898 m
.75222 .9761 L
s
% Start of user PostScript
3.1428571 3.8571429 3.0805589 3.9718282 MAarrowhead1
% End of user PostScript
.76695 1.05032 m
.75001 1.08045 L
s
% Start of user PostScript
3.1428571 4.2857143 3.0712142 4.4131425 MAarrowhead1
% End of user PostScript
.76695 1.15166 m
.7478 1.1848 L
s
% Start of user PostScript
3.1428571 4.7142857 3.0618695 4.8544567 MAarrowhead1
% End of user PostScript
.76695 1.253 m
.74559 1.28915 L
s
% Start of user PostScript
3.1428571 5.1428571 3.0525247 5.295771 MAarrowhead1
% End of user PostScript
.76695 1.35434 m
.74338 1.39351 L
s
% Start of user PostScript
3.1428571 5.5714286 3.04318 5.7370852 MAarrowhead1
% End of user PostScript
.76695 1.45567 m
.74117 1.49786 L
s
% Start of user PostScript
3.1428571 6. 3.0338353 6.1783994 MAarrowhead1
% End of user PostScript
.83451 .03694 m
.84014 .03694 L
s
% Start of user PostScript
3.4285714 0. 3.452358 0. MAarrowhead1
% End of user PostScript
.83451 .13828 m
.83773 .1417 L
s
% Start of user PostScript
3.4285714 0.42857143 3.4421638 0.44301329 MAarrowhead1
% End of user PostScript
.83451 .23962 m
.83532 .24645 L
s
% Start of user PostScript
3.4285714 0.85714286 3.4319695 0.88602658 MAarrowhead1
% End of user PostScript
.83451 .34096 m
.8329 .3512 L
s
% Start of user PostScript
3.4285714 1.2857143 3.4217753 1.3290399 MAarrowhead1
% End of user PostScript
.83451 .4423 m
.83049 .45596 L
s
% Start of user PostScript
3.4285714 1.7142857 3.411581 1.7720532 MAarrowhead1
% End of user PostScript
.83451 .54363 m
.82808 .56071 L
s
% Start of user PostScript
3.4285714 2.1428571 3.4013868 2.2150664 MAarrowhead1
% End of user PostScript
.83451 .64497 m
.82567 .66546 L
s
% Start of user PostScript
3.4285714 2.5714286 3.3911925 2.6580797 MAarrowhead1
% End of user PostScript
.83451 .74631 m
.82326 .77021 L
s
% Start of user PostScript
3.4285714 3. 3.3809982 3.101093 MAarrowhead1
% End of user PostScript
.83451 .84765 m
.82085 .87497 L
s
% Start of user PostScript
3.4285714 3.4285714 3.370804 3.5441063 MAarrowhead1
% End of user PostScript
.83451 .94898 m
.81844 .97972 L
s
% Start of user PostScript
3.4285714 3.8571429 3.3606097 3.9871196 MAarrowhead1
% End of user PostScript
.83451 1.05032 m
.81603 1.08447 L
s
% Start of user PostScript
3.4285714 4.2857143 3.3504155 4.4301329 MAarrowhead1
% End of user PostScript
.83451 1.15166 m
.81362 1.18922 L
s
% Start of user PostScript
3.4285714 4.7142857 3.3402212 4.8731462 MAarrowhead1
% End of user PostScript
.83451 1.253 m
.81121 1.29398 L
s
% Start of user PostScript
3.4285714 5.1428571 3.330027 5.3161595 MAarrowhead1
% End of user PostScript
.83451 1.35434 m
.8088 1.39873 L
s
% Start of user PostScript
3.4285714 5.5714286 3.3198327 5.7591727 MAarrowhead1
% End of user PostScript
.83451 1.45567 m
.80639 1.50348 L
s
% Start of user PostScript
3.4285714 6. 3.3096385 6.202186 MAarrowhead1
% End of user PostScript
.90207 .03694 m
.90816 .03694 L
s
% Start of user PostScript
3.7142857 0. 3.7400545 0. MAarrowhead1
% End of user PostScript
.90207 .13828 m
.90555 .1421 L
s
% Start of user PostScript
3.7142857 0.42857143 3.7290107 0.44471233 MAarrowhead1
% End of user PostScript
.90207 .23962 m
.90294 .24725 L
s
% Start of user PostScript
3.7142857 0.85714286 3.717967 0.88942466 MAarrowhead1
% End of user PostScript
.90207 .34096 m
.90033 .35241 L
s
% Start of user PostScript
3.7142857 1.2857143 3.7069232 1.334137 MAarrowhead1
% End of user PostScript
.90207 .4423 m
.89772 .45756 L
s
% Start of user PostScript
3.7142857 1.7142857 3.6958794 1.7788493 MAarrowhead1
% End of user PostScript
.90207 .54363 m
.89511 .56272 L
s
% Start of user PostScript
3.7142857 2.1428571 3.6848356 2.2235617 MAarrowhead1
% End of user PostScript
.90207 .64497 m
.8925 .66787 L
s
% Start of user PostScript
3.7142857 2.5714286 3.6737919 2.668274 MAarrowhead1
% End of user PostScript
.90207 .74631 m
.88988 .77303 L
s
% Start of user PostScript
3.7142857 3. 3.6627481 3.1129863 MAarrowhead1
% End of user PostScript
.90207 .84765 m
.88727 .87818 L
s
% Start of user PostScript
3.7142857 3.4285714 3.6517043 3.5576986 MAarrowhead1
% End of user PostScript
.90207 .94898 m
.88466 .98333 L
s
% Start of user PostScript
3.7142857 3.8571429 3.6406605 4.002411 MAarrowhead1
% End of user PostScript
.90207 1.05032 m
.88205 1.08849 L
s
% Start of user PostScript
3.7142857 4.2857143 3.6296168 4.4471233 MAarrowhead1
% End of user PostScript
.90207 1.15166 m
.87944 1.19364 L
s
% Start of user PostScript
3.7142857 4.7142857 3.618573 4.8918356 MAarrowhead1
% End of user PostScript
.90207 1.253 m
.87683 1.2988 L
s
% Start of user PostScript
3.7142857 5.1428571 3.6075292 5.336548 MAarrowhead1
% End of user PostScript
.90207 1.35434 m
.87422 1.40395 L
s
% Start of user PostScript
3.7142857 5.5714286 3.5964854 5.7812603 MAarrowhead1
% End of user PostScript
.90207 1.45567 m
.8716 1.50911 L
s
% Start of user PostScript
3.7142857 6. 3.5854417 6.2259726 MAarrowhead1
% End of user PostScript
.96963 .03694 m
.97619 .03694 L
s
% Start of user PostScript
4. 0. 4.027751 0. MAarrowhead1
% End of user PostScript
.96963 .13828 m
.97338 .1425 L
s
% Start of user PostScript
4. 0.42857143 4.0158577 0.44641137 MAarrowhead1
% End of user PostScript
.96963 .23962 m
.97057 .24806 L
s
% Start of user PostScript
4. 0.85714286 4.0039644 0.89282275 MAarrowhead1
% End of user PostScript
.96963 .34096 m
.96775 .35361 L
s
% Start of user PostScript
4. 1.2857143 3.9920711 1.3392341 MAarrowhead1
% End of user PostScript
.96963 .4423 m
.96494 .45917 L
s
% Start of user PostScript
4. 1.7142857 3.9801778 1.7856455 MAarrowhead1
% End of user PostScript
.96963 .54363 m
.96213 .56473 L
s
% Start of user PostScript
4. 2.1428571 3.9682845 2.2320569 MAarrowhead1
% End of user PostScript
.96963 .64497 m
.95932 .67028 L
s
% Start of user PostScript
4. 2.5714286 3.9563912 2.6784682 MAarrowhead1
% End of user PostScript
.96963 .74631 m
.9565 .77584 L
s
% Start of user PostScript
4. 3. 3.944498 3.1248796 MAarrowhead1
% End of user PostScript
.96963 .84765 m
.95369 .88139 L
s
% Start of user PostScript
4. 3.4285714 3.9326047 3.571291 MAarrowhead1
% End of user PostScript
.96963 .94898 m
.95088 .98695 L
s
% Start of user PostScript
4. 3.8571429 3.9207114 4.0177024 MAarrowhead1
% End of user PostScript
.96963 1.05032 m
.94807 1.09251 L
s
% Start of user PostScript
4. 4.2857143 3.9088181 4.4641137 MAarrowhead1
% End of user PostScript
.96963 1.15166 m
.94526 1.19806 L
s
% Start of user PostScript
4. 4.7142857 3.8969248 4.9105251 MAarrowhead1
% End of user PostScript
.96963 1.253 m
.94244 1.30362 L
s
% Start of user PostScript
4. 5.1428571 3.8850315 5.3569365 MAarrowhead1
% End of user PostScript
.96963 1.35434 m
.93963 1.40917 L
s
% Start of user PostScript
4. 5.5714286 3.8731382 5.8033478 MAarrowhead1
% End of user PostScript
.96963 1.45567 m
.93682 1.51473 L
s
% Start of user PostScript
4. 6. 3.8612449 6.2497592 MAarrowhead1
% End of user PostScript
.5 Mabswid
.14204 .2734 m
.14205 .2705 L
.14207 .26789 L
.14211 .26492 L
.14218 .26214 L
.14232 .2573 L
.14255 .25216 L
.14286 .24666 L
.14327 .24099 L
.14421 .23126 L
.14544 .2218 L
.14682 .21344 L
.15079 .19617 L
.15331 .18807 L
.15598 .18092 L
.16171 .16886 L
.16895 .15774 L
.1781 .14757 L
.18755 .13999 L
.1971 .13433 L
.20279 .13166 L
.20929 .12913 L
.21569 .12709 L
.22195 .12548 L
.22856 .12412 L
.23483 .12312 L
.24206 .12228 L
.24616 .12194 L
.24804 .12182 L
.25013 .1217 L
.252 .12162 L
.25404 .12155 L
.25517 .12152 L
.25621 .12149 L
.25827 .12146 L
.26006 .12145 L
.26204 .12146 L
.26412 .12149 L
.26607 .12153 L
.26719 .12156 L
.26841 .12161 L
.27065 .1217 L
.27488 .12194 L
.27991 .12232 L
.28462 .12278 L
.29287 .1238 L
.30195 .12525 L
.31885 .12888 L
.33955 .13515 L
.35868 .14309 L
Mistroke
.37759 .15363 L
.39433 .16619 L
.41102 .18372 L
.4192 .1955 L
.42568 .20755 L
.4309 .22047 L
.43311 .22749 L
.43517 .2356 L
.43661 .24289 L
.43727 .24703 L
.43781 .25104 L
.43823 .25485 L
.4386 .25908 L
.43885 .263 L
.43901 .26669 L
.43911 .27109 L
.43911 .27592 L
.439 .28058 L
.43881 .28491 L
.43849 .28981 L
.43802 .29526 L
.43665 .30654 L
.43473 .31808 L
.43207 .33077 L
.42565 .35442 L
.41682 .37967 L
.40681 .40317 L
.37845 .45455 L
.34868 .49395 L
.33277 .51037 L
.31509 .52511 L
.30696 .53065 L
.29819 .53574 L
.29056 .53938 L
.28258 .54239 L
.27556 .54433 L
.27163 .54511 L
.26799 .54564 L
.2647 .54595 L
.26171 .54608 L
.25848 .54608 L
.25512 .54589 L
.25149 .54548 L
.24825 .54492 L
.24457 .54406 L
.24116 .54305 L
.23526 .54076 L
.2291 .53762 L
.22261 .53342 L
.21608 .52816 L
Mistroke
.20523 .51693 L
.19606 .50456 L
.18849 .49202 L
.1741 .4607 L
.16371 .42955 L
.15611 .3995 L
.15004 .3678 L
.14753 .35099 L
.14564 .33565 L
.14426 .32179 L
.14368 .31471 L
.14316 .30739 L
.14281 .30134 L
.1425 .29484 L
.14229 .28905 L
.14221 .28653 L
.14215 .28376 L
.14209 .28052 L
.14207 .27875 L
.14205 .27711 L
.14204 .27421 L
.14204 .27111 L
.14205 .26949 L
.14207 .26773 L
.1421 .26591 L
.14213 .26423 L
.1422 .26124 L
.1423 .2581 L
.14255 .25201 L
.14288 .24642 L
.14368 .23641 L
.14471 .2271 L
.14587 .21898 L
.14921 .2022 L
.15118 .19481 L
.15354 .18739 L
.15845 .17525 L
.16537 .1628 L
.17271 .15314 L
.18107 .14493 L
.18973 .13855 L
.20025 .13279 L
.20656 .13013 L
.21266 .128 L
.2188 .12625 L
.22584 .12464 L
.23325 .12335 L
.23748 .12278 L
.24141 .12234 L
.24524 .12201 L
Mistroke
.24892 .12177 L
.25097 .12166 L
.25289 .12159 L
.255 .12152 L
.25608 .1215 L
.25727 .12148 L
.25927 .12146 L
.26112 .12146 L
.26214 .12146 L
.26326 .12148 L
.26532 .12151 L
.26726 .12157 L
.26933 .12164 L
.27311 .12183 L
.27752 .12213 L
.28224 .12253 L
.29088 .12352 L
.30043 .12498 L
.31117 .12707 L
.33097 .13229 L
.34985 .13914 L
.37004 .14904 L
.38854 .16141 L
.40399 .17552 L
.41198 .18496 L
.41874 .19475 L
.42474 .20559 L
.43023 .21857 L
.43238 .22502 L
.43435 .23214 L
.43591 .23913 L
.43708 .24575 L
.43764 .24966 L
.43815 .25401 L
.43857 .2587 L
.43887 .26324 L
.43904 .26759 L
.43912 .27228 L
.4391 .27636 L
.43899 .28094 L
.43887 .28373 L
.43872 .28642 L
.43836 .29152 L
.43783 .29712 L
.43709 .30335 L
.43532 .31483 L
.43319 .32579 L
.42732 .34888 L
.41871 .37472 L
.39745 .42212 L
Mistroke
.37093 .46567 L
.34324 .4999 L
.32797 .51473 L
.31153 .52763 L
.30362 .5327 L
.2962 .53676 L
.28967 .53976 L
.28258 .54239 L
.27888 .5435 L
.27494 .54447 L
.27279 .5449 L
.27083 .54524 L
.26703 .54575 L
.26379 .546 L
.2603 .5461 L
.2567 .546 L
.25342 .54572 L
.25155 .54549 L
.24955 .54517 L
.24598 .54442 L
.24256 .54349 L
.23947 .54246 L
.23266 .53953 L
.22577 .53558 L
.21465 .52687 L
.20537 .51709 L
.19568 .50399 L
.18744 .4901 L
.17498 .46297 L
.16424 .43136 L
.15616 .39976 L
.14968 .36557 L
.14726 .34901 L
.14522 .33175 L
.14379 .3161 L
.14326 .30881 L
.14286 .30233 L
.14255 .29612 L
.1423 .28953 L
.1422 .28598 L
.14213 .28274 L
.14208 .27969 L
.14205 .27649 L
.14204 .27379 L
.14204 .27092 L
.14207 .26825 L
.1421 .26583 L
.14215 .26304 L
.14223 .26003 L
.14243 .25466 L
Mistroke
.14274 .24855 L
.1431 .24317 L
.14417 .23167 L
.14545 .2217 L
.14693 .21287 L
.1504 .19757 L
.15248 .19055 L
.15501 .18336 L
.16013 .17184 L
.16563 .16241 L
Mfstroke
.26026 .2734 m
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
.26026 .2734 L
s
.37849 .2734 m
.37846 .27634 L
.37839 .27904 L
.37825 .28219 L
.37806 .28521 L
.37759 .29065 L
.37687 .29666 L
.37584 .30339 L
.37446 .31064 L
.37125 .32388 L
.36208 .35071 L
.3553 .36579 L
.34804 .3795 L
.33028 .406 L
.31198 .4259 L
.30142 .43458 L
.29579 .43843 L
.28979 .44194 L
.28404 .44473 L
.27886 .44674 L
.27638 .44755 L
.27371 .44829 L
.2712 .44886 L
.26892 .44929 L
.2666 .44962 L
.26441 .44985 L
.26213 .44998 L
.26084 .45001 L
.25966 .45001 L
.25771 .44995 L
.25558 .44979 L
.25338 .44954 L
.25134 .4492 L
.24909 .44874 L
.24675 .44813 L
.24265 .44677 L
.23836 .44491 L
.23382 .44244 L
.22579 .43668 L
.21788 .42906 L
.2054 .41217 L
.19974 .40206 L
.19505 .39217 L
.18625 .36854 L
.18039 .34704 L
.17787 .33517 L
.17597 .32444 L
.17457 .31481 L
.17338 .30452 L
.17287 .29899 L
Mistroke
.17249 .29393 L
.1722 .28918 L
.17208 .28657 L
.17198 .2842 L
.17191 .28201 L
.17185 .27963 L
.1718 .27725 L
.17178 .27477 L
.17178 .27261 L
.1718 .27031 L
.17183 .26816 L
.17187 .26622 L
.17193 .26423 L
.172 .2624 L
.1722 .25833 L
.17243 .25481 L
.17272 .25114 L
.17358 .24317 L
.17459 .2362 L
.17594 .22891 L
.17764 .22167 L
.18111 .21042 L
.18575 .19947 L
.19173 .18916 L
.198 .18111 L
.20623 .17328 L
.21494 .16729 L
.22412 .16276 L
.22906 .16093 L
.23471 .15925 L
.23971 .1581 L
.24254 .15758 L
.24527 .15716 L
.24784 .15684 L
.25068 .15655 L
.25195 .15645 L
.2533 .15636 L
.25457 .15629 L
.25575 .15623 L
.25713 .15619 L
.25864 .15616 L
.26012 .15614 L
.26172 .15615 L
.26322 .15618 L
.26464 .15623 L
.26592 .15628 L
.26732 .15635 L
.27057 .15659 L
.27404 .15694 L
.28037 .15781 L
Mistroke
.28632 .15893 L
.29196 .16025 L
.30495 .16432 L
.31906 .17055 L
.33217 .17844 L
.34337 .18734 L
.35457 .19926 L
.36012 .20688 L
.36484 .21479 L
.36863 .22262 L
.37206 .23156 L
.37359 .23649 L
.37505 .24212 L
.37618 .2475 L
.37702 .25257 L
.37778 .25876 L
.37809 .26226 L
.3782 .26389 L
.3783 .26564 L
.37842 .2688 L
.37848 .27176 L
.37848 .275 L
.37845 .27686 L
.37841 .27862 L
.37828 .28162 L
.37809 .28487 L
.37784 .28796 L
.37757 .2908 L
.37671 .29787 L
.37562 .30466 L
.37267 .31847 L
.3683 .33372 L
.35756 .36105 L
.34468 .38518 L
.328 .40884 L
.31075 .42701 L
.30047 .43528 L
.291 .44128 L
.28578 .44394 L
.28013 .4463 L
.27484 .44799 L
.27 .4491 L
.26752 .4495 L
.26618 .44967 L
.26493 .4498 L
.26274 .44995 L
.26036 .45001 L
.25904 .45 L
.25779 .44995 L
.25548 .44978 L
Mistroke
.2542 .44964 L
.25302 .44948 L
.25038 .44902 L
.24636 .44802 L
.24204 .44653 L
.23767 .44457 L
.23369 .44236 L
.22655 .4373 L
.22042 .43173 L
.2081 .41641 L
.20277 .40771 L
.19763 .39779 L
.18971 .37877 L
.18238 .35509 L
.17754 .33346 L
.17573 .32292 L
.17421 .31198 L
.17321 .30284 L
.17243 .29306 L
.17213 .28768 L
.17202 .28517 L
.17193 .28286 L
.17186 .28023 L
.17183 .27885 L
.17181 .2774 L
.17178 .27498 L
.17178 .27361 L
.17178 .27233 L
.1718 .27007 L
.17184 .26771 L
.17189 .26572 L
.17196 .26356 L
.17217 .25881 L
.17245 .2545 L
.17282 .2501 L
.17322 .24614 L
.17437 .23753 L
.17565 .23034 L
.17727 .22312 L
.18069 .21159 L
.18534 .20029 L
.19116 .19001 L
.19731 .18189 L
.20538 .17398 L
.21399 .16785 L
.22295 .16326 L
.2283 .16119 L
.23336 .15962 L
.23826 .15841 L
.24091 .15787 L
Mistroke
.24375 .15739 L
.24628 .15703 L
.24909 .1567 L
.25169 .15647 L
.25414 .15631 L
.25567 .15624 L
.25644 .15621 L
.25729 .15618 L
.25881 .15615 L
.26024 .15614 L
.26106 .15615 L
.26193 .15616 L
.26349 .15619 L
.26437 .15622 L
.26519 .15625 L
.26705 .15634 L
.27024 .15656 L
.27317 .15684 L
.27984 .15773 L
.28592 .15884 L
.29258 .16041 L
.3048 .16427 L
.31769 .16986 L
.33156 .17802 L
.34525 .1891 L
.35678 .20212 L
.36181 .20953 L
.3667 .21842 L
.37067 .22763 L
.3737 .23686 L
.37584 .24574 L
.37679 .25104 L
.3775 .25618 L
.37779 .25886 L
.37804 .26173 L
.37822 .26422 L
.37836 .26697 L
.37845 .26999 L
.37848 .27169 L
.37849 .27326 L
.37846 .27633 L
.37838 .27927 L
.37825 .2822 L
.37805 .2854 L
.37753 .29125 L
.37663 .29836 L
.37556 .30497 L
.37238 .31964 L
.36827 .33384 L
.35856 .35888 L
Mistroke
.34473 .38511 L
.32692 .41015 L
.30904 .42852 L
.29876 .43647 L
.29332 .43995 L
.28758 .44308 L
.28257 .44535 L
.27712 .44732 L
.27475 .44801 L
.27222 .44864 L
.26986 .44913 L
.2677 .44948 L
.26555 .44974 L
.26324 .44993 L
.26121 .45001 L
.25908 .45 L
Mfstroke
.49672 .2734 m
.49665 .27931 L
.49645 .28481 L
.49607 .29131 L
.49556 .2976 L
.49426 .30912 L
.49228 .32212 L
.48939 .33699 L
.48551 .35335 L
.47639 .38404 L
.45011 .4487 L
.41058 .51903 L
.36376 .57966 L
.33649 .60577 L
.32367 .6157 L
.31195 .62342 L
.30035 .62971 L
.29008 .6341 L
.28471 .63592 L
.279 .6375 L
.27591 .63819 L
.27309 .63872 L
.27043 .63913 L
.26762 .63946 L
.26295 .63978 L
.25866 .63981 L
.25366 .63952 L
.24921 .63895 L
.24467 .63805 L
.23985 .63674 L
.2314 .63349 L
.22384 .62946 L
.2161 .62415 L
.20314 .61222 L
.18946 .59476 L
.17844 .57629 L
.15985 .53322 L
.15235 .51013 L
.14535 .48448 L
.13538 .43799 L
.1289 .39752 L
.1262 .37619 L
.12389 .3541 L
.12225 .33442 L
.12114 .31695 L
.12074 .30895 L
.12043 .30156 L
.1203 .29756 L
.12017 .29326 L
.12008 .28944 L
Mistroke
.12001 .2859 L
.11998 .28386 L
.11995 .28168 L
.11991 .27792 L
.1199 .2758 L
.1199 .27359 L
.1199 .27172 L
.11991 .26969 L
.11994 .26609 L
.11996 .26409 L
.11999 .26229 L
.12006 .25883 L
.12014 .25561 L
.12037 .2488 L
.1207 .24183 L
.12148 .22992 L
.12203 .22364 L
.12261 .21796 L
.12418 .20575 L
.12571 .19645 L
.12763 .187 L
.13227 .17003 L
.13749 .15653 L
.14314 .14569 L
.15083 .13473 L
.15912 .12604 L
.16746 .11944 L
.17748 .11344 L
.18837 .10861 L
.2016 .1044 L
.20878 .10269 L
.21689 .10114 L
.22494 .09996 L
.23262 .09911 L
.24053 .09848 L
.24465 .09825 L
.24706 .09814 L
.2493 .09806 L
.25121 .098 L
.25333 .09795 L
.25547 .09791 L
.25775 .09788 L
.25979 .09788 L
.26198 .09788 L
.26407 .0979 L
.26599 .09792 L
.26844 .09797 L
.27106 .09804 L
.27584 .09822 L
.28107 .09848 L
Mistroke
.28694 .09886 L
.29775 .09978 L
.30821 .10095 L
.33152 .10457 L
.35481 .10966 L
.37643 .11594 L
.40038 .12513 L
.42572 .1384 L
.44756 .15444 L
.45881 .16537 L
.46993 .17913 L
.47915 .19423 L
.48304 .20229 L
.48624 .21013 L
.48899 .2182 L
.49156 .2275 L
.49277 .23286 L
.49376 .23797 L
.49462 .24332 L
.4953 .24849 L
.49582 .25338 L
.49619 .25797 L
.49649 .26319 L
.49668 .26897 L
.49672 .27434 L
.49662 .28035 L
.49635 .28679 L
.49595 .29292 L
.49533 .29994 L
.49444 .30773 L
.49223 .32237 L
.48934 .33722 L
.48601 .35138 L
.47604 .38508 L
.46192 .42241 L
.42976 .48763 L
.38697 .5522 L
.36452 .57884 L
.34292 .60022 L
.3222 .61674 L
.30321 .62829 L
.29265 .63311 L
.28721 .63512 L
.28156 .63684 L
.27687 .63799 L
.27181 .63893 L
.26728 .63949 L
.26314 .63977 L
.26067 .63982 L
.25801 .63979 L
Mistroke
.25327 .63948 L
.24875 .63887 L
.24466 .63805 L
.24034 .63689 L
.23569 .6353 L
.22667 .6311 L
.21916 .6264 L
.21262 .62134 L
.19904 .60756 L
.18781 .59228 L
.17828 .57598 L
.16076 .53577 L
.15284 .51178 L
.14667 .48966 L
.13748 .44904 L
.13033 .40753 L
.12757 .38745 L
.1251 .36625 L
.12331 .34761 L
.12203 .33135 L
.12094 .31309 L
.12051 .30347 L
.12035 .29916 L
.12021 .29465 L
.12011 .29087 L
.12002 .28675 L
.11996 .28306 L
.11993 .27965 L
.1199 .27571 L
.1199 .27214 L
.11991 .2703 L
.11992 .2683 L
.11994 .26622 L
.11996 .26431 L
.12002 .26073 L
.1201 .257 L
.12031 .25047 L
.1206 .24367 L
.12101 .23646 L
.12197 .22424 L
.12312 .21355 L
.12447 .20381 L
.12589 .19546 L
.12974 .17848 L
.13198 .17092 L
.13461 .16345 L
.13996 .15141 L
.14739 .13921 L
.15514 .1299 L
.16408 .12191 L
Mistroke
.17326 .11576 L
.18445 .11018 L
.19116 .10759 L
.1976 .10551 L
.21048 .10233 L
.21808 .10095 L
.2256 .09988 L
.23285 .09909 L
.2398 .09853 L
.24353 .09831 L
.24773 .09812 L
.24987 .09804 L
.2522 .09797 L
.25442 .09793 L
.25647 .0979 L
.25881 .09788 L
.26103 .09788 L
.26305 .09789 L
.26525 .09791 L
.26768 .09795 L
.27027 .09802 L
.27498 .09818 L
.27941 .09839 L
.28361 .09863 L
.29341 .09938 L
.30448 .10051 L
.3149 .10185 L
.33938 .10611 L
.36303 .11186 L
.38557 .11914 L
.41048 .1299 L
.4241 .13741 L
.43629 .14548 L
.45722 .16368 L
.46717 .17535 L
.47656 .1895 L
.4836 .20357 L
.48901 .21825 L
.49154 .22742 L
.49344 .23626 L
.49432 .24135 L
.49513 .24705 L
.49575 .2526 L
.49618 .25786 L
.49651 .26371 L
.49669 .26943 L
.49672 .27468 L
.49661 .28055 L
.49634 .28707 L
.49611 .29078 L
Mistroke
.49585 .2942 L
.49447 .30748 L
.49258 .32034 L
.48986 .33479 L
.48309 .3623 L
.47192 .39686 L
.45656 .43476 L
.42098 .50256 L
.40457 .52801 L
Mfstroke
.61495 .2734 m
.61481 .28232 L
.61444 .29072 L
.61372 .30076 L
.61274 .31059 L
.61023 .3289 L
.60637 .34997 L
.59301 .40221 L
.57482 .45536 L
.52108 .5728 L
.44602 .69362 L
.40632 .7437 L
.36393 .78699 L
.34406 .80337 L
.32577 .81601 L
.30845 .82561 L
.29339 .8319 L
.28439 .83466 L
.27616 .83649 L
.27174 .83717 L
.26773 .83761 L
.26341 .83788 L
.25892 .83793 L
.25165 .83748 L
.24507 .83649 L
.23809 .83479 L
.23429 .83356 L
.23088 .83228 L
.2169 .82501 L
.2095 .81974 L
.20298 .8142 L
.19096 .8015 L
.18089 .78807 L
.16549 .76158 L
.15139 .72951 L
.13139 .66622 L
.12313 .63155 L
.11559 .59376 L
.10417 .52031 L
.09671 .45462 L
.0922 .40092 L
.09044 .37374 L
.08902 .34632 L
.08852 .33444 L
.0881 .32233 L
.0878 .31231 L
.08756 .30177 L
.08747 .29649 L
.08739 .29169 L
.08734 .28718 L
Mistroke
.0873 .28247 L
.08728 .27791 L
.08727 .27371 L
.08728 .26999 L
.08729 .26605 L
.08733 .26177 L
.08735 .25938 L
.08738 .25718 L
.08745 .25243 L
.08754 .2482 L
.08773 .24074 L
.08799 .23305 L
.0886 .22 L
.08945 .20685 L
.09043 .19536 L
.09149 .1855 L
.0928 .17554 L
.0944 .16564 L
.09776 .14973 L
.1 .14156 L
.10258 .13372 L
.10777 .12143 L
.11357 .11134 L
.12062 .10228 L
.12814 .0951 L
.13574 .08958 L
.14542 .08427 L
.15531 .08019 L
.16736 .07651 L
.17459 .07479 L
.18155 .07341 L
.19546 .07127 L
.2037 .07032 L
.21191 .06956 L
.2193 .06902 L
.2275 .06854 L
.23192 .06834 L
.23691 .06816 L
.24156 .06802 L
.24603 .06792 L
.24842 .06788 L
.251 .06784 L
.25347 .06781 L
.25574 .0678 L
.25843 .06779 L
.25997 .06778 L
.26139 .06778 L
.26403 .06779 L
.26686 .06781 L
.26959 .06784 L
Mistroke
.27257 .06788 L
.27803 .06797 L
.28468 .06814 L
.2909 .06834 L
.30215 .0688 L
.31493 .06948 L
.33958 .07127 L
.37002 .07437 L
.39958 .07845 L
.4358 .08521 L
.47148 .09442 L
.50639 .10704 L
.52382 .11529 L
.54248 .12625 L
.55776 .13752 L
.57308 .15194 L
.58616 .16822 L
.59652 .18571 L
.60134 .19632 L
.60594 .20907 L
.60794 .21593 L
.60985 .22367 L
.61127 .23067 L
.61258 .23865 L
.61356 .24643 L
.61424 .25396 L
.61472 .26222 L
.61494 .2714 L
.61486 .2803 L
.61454 .289 L
.61402 .29708 L
.61322 .30609 L
.61193 .3172 L
.61038 .32796 L
.60558 .35376 L
.59913 .38064 L
.5902 .41132 L
.5433 .52876 L
.47399 .65286 L
.43222 .71205 L
.3868 .76499 L
.36463 .78636 L
.34431 .80319 L
.32516 .81638 L
.30825 .8257 L
.2928 .8321 L
.28529 .83442 L
.27728 .83628 L
.26944 .83745 L
.26515 .8378 L
Mistroke
.26131 .83793 L
.25401 .8377 L
.24732 .8369 L
.24101 .83558 L
.23443 .83361 L
.22843 .83124 L
.22311 .82865 L
.2108 .82075 L
.19997 .81133 L
.18085 .78801 L
.17132 .77254 L
.16324 .75701 L
.14026 .69737 L
.13024 .66174 L
.12257 .62899 L
.10948 .5575 L
.10107 .49537 L
.09473 .43304 L
.09225 .40153 L
.09049 .37467 L
.0893 .35226 L
.08834 .32943 L
.08795 .31757 L
.08767 .307 L
.08748 .29726 L
.08741 .29247 L
.08734 .28728 L
.08731 .28287 L
.08728 .27832 L
.08727 .2745 L
.08727 .27038 L
.08729 .26602 L
.08733 .26145 L
.08738 .25722 L
.08744 .25344 L
.08758 .24629 L
.08779 .2388 L
.08829 .22592 L
.08864 .21925 L
.08906 .21236 L
.08995 .20061 L
.09123 .18773 L
.0926 .17693 L
.09423 .16662 L
.09622 .15635 L
.10048 .13998 L
.10559 .12612 L
.11095 .11553 L
.11805 .10526 L
.12568 .09723 L
Mistroke
.13394 .09076 L
.14372 .08509 L
.153 .08105 L
.16423 .07736 L
.17742 .0742 L
.19069 .07192 L
.19859 .07089 L
.20763 .06994 L
.21665 .0692 L
.2254 .06865 L
.2341 .06826 L
.23916 .06809 L
.24391 .06796 L
.24818 .06788 L
.25064 .06784 L
.25295 .06782 L
.25542 .0678 L
.25769 .06779 L
.26034 .06778 L
.26286 .06779 L
.26548 .0678 L
.26839 .06782 L
.26986 .06784 L
.27146 .06786 L
.27437 .0679 L
.2801 .06802 L
.28545 .06816 L
.29888 .06865 L
.31222 .06932 L
.33841 .07117 L
.35242 .07245 L
.36851 .07419 L
.39839 .07826 L
.42809 .08358 L
.4622 .09172 L
.48124 .09752 L
.49907 .10401 L
.53031 .11882 L
.54629 .12883 L
.56257 .14164 L
.58073 .16088 L
Mfstroke
.73317 .2734 m
.73295 .28537 L
.73236 .29677 L
.73119 .31056 L
.72958 .32422 L
.72545 .35007 L
.71905 .38041 L
.69657 .45798 L
.66564 .53937 L
.57495 .72203 L
.45504 .90059 L
.39627 .96614 L
.36545 .99389 L
.33765 1.01436 L
.31339 1.02815 L
.30034 1.03378 L
.28868 1.03764 L
.27829 1.04007 L
.26921 1.04135 L
.25912 1.04178 L
.24999 1.04118 L
.24034 1.03945 L
.23505 1.03799 L
.23024 1.03633 L
.2209 1.03211 L
.21142 1.0264 L
.19559 1.01319 L
.18256 .99832 L
.16895 .97814 L
.15587 .95332 L
.13608 .90267 L
.12235 .85509 L
.11183 .80903 L
.10171 .75405 L
.09427 .70451 L
.08315 .60902 L
.07541 .51695 L
.07097 .44475 L
.06835 .38638 L
.06735 .35642 L
.0667 .33134 L
.06644 .31827 L
.06634 .31162 L
.06624 .30475 L
.06617 .29887 L
.06611 .29256 L
.06607 .28695 L
.06605 .28181 L
.06603 .27658 L
.06603 .27371 L
Mistroke
.06603 .27114 L
.06604 .26621 L
.06606 .26166 L
.06608 .25911 L
.0661 .25645 L
.06615 .25177 L
.06621 .24685 L
.06629 .24159 L
.06646 .23307 L
.06668 .22435 L
.0672 .20962 L
.06788 .19549 L
.06867 .18324 L
.07047 .16291 L
.07159 .15353 L
.07295 .14406 L
.07614 .12736 L
.07962 .11445 L
.08337 .10421 L
.08809 .09468 L
.09374 .08634 L
.09917 .08037 L
.10578 .07487 L
.11367 .06999 L
.12167 .0663 L
.13197 .06277 L
.14284 .06005 L
.15442 .05792 L
.16802 .0561 L
.18084 .05486 L
.19632 .05379 L
.20536 .05333 L
.21438 .05297 L
.22287 .05271 L
.23256 .05249 L
.23774 .0524 L
.24362 .05233 L
.24664 .0523 L
.24993 .05227 L
.25147 .05227 L
.25309 .05226 L
.25603 .05225 L
.25879 .05224 L
.26177 .05224 L
.26462 .05225 L
.26724 .05226 L
.27035 .05227 L
.27378 .05229 L
.28012 .05235 L
.28611 .05243 L
Mistroke
.29269 .05253 L
.30501 .05277 L
.32037 .05318 L
.33512 .05367 L
.36956 .0552 L
.40547 .05744 L
.442 .0605 L
.48398 .06526 L
.52623 .07186 L
.56627 .08054 L
.58904 .08697 L
.61313 .09541 L
.63347 .10433 L
.65519 .11639 L
.67731 .13278 L
.68885 .14387 L
.69865 .15539 L
.70701 .16748 L
.7151 .18233 L
.72163 .19816 L
.72654 .21454 L
.72855 .22345 L
.7303 .23335 L
.73148 .24224 L
.73243 .25245 L
.73303 .26408 L
.73316 .27086 L
.73315 .2772 L
.73275 .29003 L
.73191 .30275 L
.73069 .31523 L
.72891 .32904 L
.72445 .35535 L
.71772 .38593 L
.70789 .42226 L
.67887 .50662 L
.63502 .60761 L
.52927 .79705 L
.4705 .88087 L
.40832 .95399 L
.37409 .98663 L
.34466 1.00964 L
.33106 1.01851 L
.31686 1.02643 L
.30404 1.03232 L
.29251 1.0365 L
.282 1.03932 L
.27117 1.04114 L
.26518 1.04165 L
.25966 1.04178 L
Mistroke
.24965 1.04114 L
.2447 1.04038 L
.23957 1.03927 L
.23069 1.0365 L
.22158 1.03246 L
.21207 1.02683 L
.19768 1.01522 L
.18367 .99975 L
.17175 .98272 L
.16185 .96539 L
.14358 .924 L
.1278 .87543 L
.11576 .82737 L
.10679 .78316 L
.09814 .73141 L
.09066 .67691 L
.08083 .58441 L
.07467 .5062 L
.07029 .43121 L
.06879 .39763 L
.06759 .36456 L
.06681 .336 L
.06656 .32438 L
.06634 .31205 L
.06626 .30646 L
.06619 .30056 L
.06614 .29556 L
.06609 .2902 L
.06606 .2846 L
.06605 .28159 L
.06604 .27883 L
.06603 .27396 L
.06604 .26885 L
.06605 .26416 L
.06608 .25918 L
.06612 .25458 L
.06616 .25042 L
.06627 .24276 L
.06641 .23495 L
.06661 .22674 L
.06687 .21831 L
.06744 .20404 L
.0683 .18858 L
.06925 .17576 L
.07025 .16498 L
.07146 .15448 L
.074 .13786 L
.07578 .12897 L
.07761 .12138 L
.08147 .10903 L
Mistroke
.08588 .09877 L
.0912 .08976 L
.09632 .0833 L
.10259 .07732 L
.11003 .07205 L
.1176 .06805 L
.12735 .06421 L
.1377 .06124 L
.14863 .05891 L
.16152 .0569 L
.17366 .05551 L
.1884 .05429 L
.1965 .05378 L
.20546 .05332 L
.2135 .053 L
.2227 .05271 L
.23317 .05248 L
.23927 .05238 L
.24221 .05234 L
.24496 .05231 L
.24754 .05229 L
.25042 .05227 L
.25335 .05226 L
.25496 .05225 L
.25648 .05225 L
.25931 .05224 L
.26192 .05224 L
.26497 .05225 L
.2679 .05226 L
.27062 .05227 L
.27358 .05229 L
.27904 .05234 L
.28569 .05242 L
.29194 .05251 L
.30528 .05278 L
.32004 .05317 L
.34638 .05411 L
.37774 .05565 L
Mfstroke
.8514 .2734 m
.85108 .28845 L
.85021 .30296 L
.84847 .32071 L
.84608 .33852 L
.83989 .37273 L
.83019 .41368 L
.79572 .52146 L
.74792 .63765 L
.61005 .89888 L
.52126 1.033 L
.44109 1.1328 L
.36585 1.20418 L
.34762 1.21739 L
.3286 1.22915 L
.31129 1.23784 L
.29633 1.24362 L
.28198 1.2475 L
.26911 1.24943 L
.2562 1.24975 L
.24923 1.24917 L
.24301 1.24819 L
.23299 1.2456 L
.22255 1.24145 L
.21226 1.23577 L
.20319 1.22931 L
.19309 1.22031 L
.18286 1.20902 L
.16611 1.185 L
.15188 1.15802 L
.14033 1.13056 L
.11896 1.06223 L
.11028 1.02577 L
.10202 .98481 L
.09125 .91937 L
.0824 .85167 L
.07112 .73738 L
.06331 .62727 L
.05797 .52347 L
.05488 .44085 L
.05319 .37734 L
.0526 .34642 L
.05238 .33125 L
.05219 .31599 L
.05208 .30329 L
.05203 .29633 L
.052 .28998 L
.05198 .28429 L
.05196 .2792 L
.05196 .27346 L
Mistroke
.05196 .26813 L
.05198 .26285 L
.05199 .25993 L
.052 .25728 L
.05203 .25248 L
.05206 .24754 L
.05215 .23922 L
.05226 .23049 L
.05242 .22156 L
.05261 .21247 L
.05305 .1972 L
.05359 .18327 L
.05419 .17124 L
.05555 .15138 L
.05638 .14221 L
.0574 .13299 L
.05975 .11685 L
.06231 .10447 L
.06506 .09473 L
.06851 .08572 L
.07263 .07791 L
.07659 .07234 L
.08141 .06724 L
.08717 .06273 L
.09302 .05934 L
.10055 .05609 L
.10852 .05357 L
.11702 .05158 L
.12702 .04984 L
.13647 .04861 L
.14791 .04748 L
.16129 .04652 L
.17482 .04582 L
.18287 .04549 L
.19214 .04519 L
.20134 .04495 L
.21044 .04476 L
.2192 .04462 L
.22911 .0445 L
.23468 .04445 L
.24071 .04441 L
.246 .04438 L
.24905 .04437 L
.25194 .04436 L
.255 .04436 L
.25674 .04435 L
.25837 .04435 L
.26138 .04435 L
.26291 .04435 L
.26461 .04436 L
Mistroke
.26757 .04436 L
.2708 .04437 L
.27388 .04438 L
.27674 .04439 L
.28368 .04442 L
.29146 .04448 L
.30624 .04461 L
.32191 .04481 L
.33745 .04506 L
.36863 .04571 L
.40554 .04676 L
.44963 .04848 L
.49188 .05072 L
.54236 .05442 L
.56942 .05701 L
.59955 .06054 L
.65643 .06983 L
.6869 .07684 L
.71522 .08526 L
.74595 .09741 L
.76127 .10514 L
.77727 .1149 L
.79063 .12482 L
.80225 .13528 L
.8133 .14745 L
.82271 .16037 L
.83193 .17664 L
.83657 .18703 L
.84033 .19722 L
.84357 .20796 L
.84651 .22049 L
.84786 .2278 L
.84892 .2348 L
.84976 .24164 L
.85048 .24937 L
.85126 .26382 L
.85136 .27846 L
.85083 .2936 L
.84974 .30847 L
.84767 .32722 L
.84502 .34523 L
.83624 .38929 L
.82521 .43183 L
.80953 .48227 L
.77078 .5849 L
.62517 .87367 L
.54627 .99761 L
.46129 1.10973 L
.41949 1.15577 L
.38204 1.19098 L
Mistroke
.34791 1.2172 L
.33372 1.22621 L
.31866 1.23439 L
.30606 1.24005 L
.29303 1.24466 L
.27987 1.24792 L
.2681 1.24952 L
.25502 1.24969 L
.24325 1.24823 L
.23321 1.24567 L
.22281 1.24157 L
.21121 1.2351 L
.20098 1.2275 L
.18353 1.20984 L
.16701 1.18649 L
.15148 1.15716 L
.12868 1.09659 L
.11246 1.03552 L
.09993 .97329 L
.08939 .90638 L
.07583 .78996 L
.07 .72352 L
.06568 .6645 L
.05989 .56479 L
.05625 .48078 L
.05486 .4401 L
.05385 .4051 L
.05315 .37549 L
.05267 .35036 L
.05229 .32459 L
.05215 .3119 L
.0521 .3057 L
.05205 .29913 L
.05201 .29273 L
.05199 .28696 L
.05197 .28157 L
.05196 .27598 L
.05196 .27109 L
.05197 .26661 L
.05198 .26179 L
.052 .25672 L
.05203 .25147 L
.05208 .24589 L
.05218 .23611 L
.05232 .22703 L
.05247 .21899 L
.05284 .20398 L
.05325 .19148 L
.05382 .17824 L
.05445 .16684 L
Mistroke
.05605 .14565 L
.057 .13638 L
.05815 .12717 L
.06046 .11301 L
.06295 .10194 L
.06631 .09112 L
.06995 .08269 L
.07363 .07636 L
.07809 .07059 L
.08296 .06589 L
.08896 .06159 L
.09603 .05791 L
.10346 .05508 L
.11149 .05281 L
.1209 .05084 L
.1298 .04944 L
.14053 .04817 L
.15309 .04707 L
.1657 .04627 L
.17324 .04589 L
.18186 .04553 L
.19883 .04501 L
Mfstroke
.96963 .2734 m
.96919 .29157 L
.96798 .3093 L
.96556 .33124 L
.96221 .35351 L
.95347 .39697 L
.93966 .45001 L
.88998 .5935 L
.82075 .75173 L
.62627 1.10288 L
.50887 1.26953 L
.40982 1.37989 L
.36345 1.41887 L
.32352 1.44382 L
.31364 1.44852 L
.30342 1.45267 L
.28587 1.45801 L
.27564 1.45996 L
.26636 1.46093 L
.25832 1.46109 L
.24991 1.46055 L
.23639 1.45801 L
.22252 1.45301 L
.2159 1.44967 L
.20907 1.44551 L
.19742 1.43659 L
.17711 1.41463 L
.16098 1.39007 L
.14334 1.35382 L
.12949 1.31649 L
.11685 1.27342 L
.10516 1.22357 L
.08976 1.13728 L
.07775 1.04569 L
.06978 .96672 L
.06337 .88745 L
.05539 .75783 L
.05001 .6368 L
.04641 .52544 L
.04523 .47866 L
.04437 .43843 L
.04376 .40495 L
.04328 .37246 L
.04308 .35673 L
.04291 .34027 L
.04278 .32586 L
.04269 .31329 L
.04265 .30644 L
.04262 .29917 L
.0426 .29526 L
Mistroke
.04259 .29169 L
.04258 .28812 L
.04257 .28479 L
.04257 .28173 L
.04256 .27846 L
.04256 .27287 L
.04256 .26974 L
.04257 .2665 L
.04258 .2608 L
.04259 .25556 L
.04262 .25 L
.04264 .24489 L
.04267 .24028 L
.04274 .23182 L
.04283 .22324 L
.04307 .20663 L
.04324 .19786 L
.04342 .19005 L
.04417 .16613 L
.04468 .1544 L
.04521 .14462 L
.04583 .13528 L
.04654 .12624 L
.04801 .11207 L
.04903 .10458 L
.05006 .09822 L
.05222 .08797 L
.05465 .07961 L
.05757 .07233 L
.06037 .06718 L
.06379 .06245 L
.06784 .05834 L
.07196 .05522 L
.07728 .05226 L
.08292 .04996 L
.08888 .04815 L
.09593 .04656 L
.1026 .04543 L
.11071 .04438 L
.12011 .04348 L
.12966 .04279 L
.14127 .04217 L
.15493 .04164 L
.16845 .04126 L
.17648 .04109 L
.18448 .04095 L
.19231 .04083 L
.20125 .04072 L
.20915 .04065 L
.21803 .04058 L
Mistroke
.22322 .04054 L
.22808 .04052 L
.23315 .0405 L
.23797 .04048 L
.2437 .04046 L
.24678 .04046 L
.25012 .04045 L
.25166 .04045 L
.25335 .04045 L
.25643 .04045 L
.25947 .04045 L
.2623 .04045 L
.26532 .04045 L
.26861 .04045 L
.27175 .04045 L
.27464 .04046 L
.28188 .04047 L
.28892 .04049 L
.3035 .04055 L
.32025 .04065 L
.35051 .04089 L
.38744 .0413 L
.43037 .04197 L
.47508 .04292 L
.52276 .04431 L
.55069 .04534 L
.57793 .04655 L
.62922 .04952 L
.65789 .05169 L
.68962 .05466 L
.72471 .05884 L
.75793 .06395 L
.79506 .07154 L
.81411 .07646 L
.83449 .08277 L
.85218 .08936 L
.86806 .09641 L
.89792 .11381 L
.91352 .12612 L
.92922 .14221 L
.94243 .16048 L
.95289 .18061 L
.95754 .19255 L
.96174 .20631 L
.96469 .21909 L
.96719 .23426 L
.96824 .2434 L
.96895 .2521 L
.96946 .26261 L
.96963 .27302 L
Mistroke
.96913 .29273 L
.96837 .30457 L
.96734 .31597 L
.96469 .33756 L
.96122 .3592 L
.94941 .41388 L
.93227 .47468 L
.90714 .54855 L
.75601 .88023 L
.56418 1.19529 L
.46209 1.32566 L
.41044 1.37931 L
.36564 1.41726 L
.32752 1.44174 L
.30768 1.45103 L
.29046 1.45684 L
.2767 1.4598 L
.26237 1.46109 L
.24828 1.46036 L
.23589 1.45787 L
.22205 1.45279 L
.21466 1.44896 L
.20809 1.44484 L
.19689 1.43613 L
.18542 1.4247 L
.16757 1.40097 L
.15113 1.3712 L
.13588 1.33483 L
.12197 1.29206 L
.10216 1.20887 L
.08817 1.12659 L
.07828 1.0503 L
.06938 .96225 L
.06327 .88609 L
.05471 .74435 L
.05153 .67502 L
.04921 .61506 L
.04621 .51814 L
.04425 .43227 L
.04326 .37082 L
.04291 .34016 L
.04279 .3272 L
.0427 .314 L
.04266 .30684 L
.04263 .30051 L
.0426 .29423 L
.04258 .28859 L
.04258 .28543 L
.04257 .28214 L
.04257 .27888 L
Mistroke
.04256 .27536 L
.04256 .27235 L
.04256 .26916 L
.04257 .26353 L
.04259 .25803 L
.0426 .25498 L
.04261 .25219 L
.04263 .24728 L
.04266 .24199 L
.04273 .23314 L
.04282 .22416 L
.04305 .20824 L
.04336 .19262 L
.04372 .17921 L
.0441 .16795 L
.04458 .15654 L
.04516 .14549 L
.04638 .12816 L
.04724 .11899 L
.04812 .11122 L
.04998 .09868 L
.0521 .08846 L
.05466 .07957 L
.05713 .07328 L
.06017 .06751 L
.06376 .06249 L
.06743 .0587 L
.07217 .05509 L
.07722 .05228 L
.08255 .05009 L
.08886 .04816 L
.09482 .04678 L
.1021 .04551 L
.10342 .04531 L
Mfstroke
0 0 m
1 0 L
1 1.55167 L
0 1.55167 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{277.438, 430.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006P0002QB000`400?l00000o`00003oo`3ooonQ
0?ooo`00o`3ooonQ0?ooo`00o`3ooonQ0?ooo`00e03oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0140oooo00@0gia800000000B9`0gooo[`3oool00=H0oooo00<0okmd0000M02oool0
503oool01@3o_g@004RL0=oOW018B9`0gooo0:h0oooo003F0?ooo`030?oo_`1d0000M;oo01L0oooo
00<0omnL04Qd_`3oool0[@3oool00=H0oooo00<0oooO09a80018W=l0603oool00`3o_g@0M;oo0?oo
o`2/0?ooo`00e`3oool00`3OW4P00000000000020000000607Boo`3oool0oooo0?ooo`2oM00007Bo
1P3oool01@3OW4P00000000000000000M;oo00@0oooo00<0okmd0000001d_ol0[03oool00=L0oooo
00L0okmd0000B02Lgol0oooo0?oog`2LB00007Bo0080oooo00<0okmd0000M02oool0103oool00`3o
gi`0B00007Boo`020?ooo`030;md0000M;l0oooo0080oooo00@0gia80000M01dM4P0W=ooZ`3oool0
0=L0oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0omnL04P0001d_ol0103o
ool00`3OW4P004RL0=ooo`030?ooo`090=nLW02oool0oooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo
0:X0oooo003G0?ooo`030?oog`2LB000B9cO00<0oooo00L0omnL04P0B02Lgol0oooO09a80000B9`0
gooo00<0oooo00D0okmd000000000000000004RLg`050?ooo`050;md0000B9`0gooo0?oOW01dW=l0
ZP3oool00=P0oooo00<0gia80000M02oool00P3oool01`3ooml0W4P004RLg`3oool0_g@004QdM01d
W=l00`3oool01`3ookl0M01809cOo`3oool0gia800000018W=l00P3oool00`3ooml0W4P0001d_`02
0?ooo`030=nLW02oool0oooo0:P0oooo003H0?ooo`040?noM000000004RL0=ooo`80oooo00L0gia8
001d_`3oool0okmd0018W02oW4P0M;oo00<0oooo00/0okmd0018W03Oool0oooo0?oo_`1d0000B9cO
0?ooo`3ooml0W4P0001d_`020?ooo`030?oo_`1dM;l0oooo0:P0oooo003H0?ooo`0K0?oo_`1d0000
M9bL04P0M02oool0oooO09a80000M;l0oooo0?oo_`1d04P0W=oo0;md001dM7@004RL0=ooo`3oool0
gia80000M02oool0oooo0=nLB000B9`0gooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0M02oool0
Z03oool00=L0oooo0140omnL04P000000000B9cO0?oo_`1d000000000000M02oool0omnL04P00000
0000M;oo0?ooo`2oM000001d0;ooo`020?ooo`090?oOW018000000000000001d_ol0_g@000000000
04P0W=oo0080oooo00<0gia80018W03Oool0Z03oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0
ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0
ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0
ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool003H0oooo00@0_g@0000000000000M;ooD03o
ool00`3ookl0M000000000020000000304RLg`3oool0oooo04h0oooo00<0gia80000000000000`00
00000`18W=l0oooo0?ooo`1=0?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool0D@3o
ool00`3ooml0W4P004RLg`0>0?ooo`00=@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLge40oooo
00<0okmd0000001d_ol0DP3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo04d0oooo
00<0okmd00000000M;l00P3oool00`2oM4P0W=oo0?ooo`1B0?ooo`030=nLB000B9`0gooo00d0oooo
000d0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0D03oool00`3ooml0W4P0001d
_`1C0?ooo`030?noM000M;l0oooo05H0oooo00<0omnL04Q8W03Oool0DP3oool00`3ogi`0B01809cO
o`0=0?ooo`00=03oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oooe00oooo00<0
gia80018W03Oool0D`3oool00`3o_g@007Bo0?ooo`1E0?ooo`030?oo_`1d0000M;oo04h0oooo00<0
okmd000000000000100000000`00B9`0gooo0?ooo`0:0?ooo`00=03oool00`3ooml0W4P0001d_`03
0?ooo`030=nLB00004P0W=oo0500oooo00<0omnL04P0B02Lgol0E03oool00`3o_g@0B9cO0?ooo`1D
0?ooo`030?oOW0180000M;oo04h0oooo00<0oooO09a8B02Lgol00P3oool00`2oM00007Bo0?ooo`0<
0?ooo`00=@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO0500oooo00<0oono07@0
001d_ol0E@3oool00`3OW4P0B9cO0?ooo`1B0?ooo`040?oOW0180000001809cOodl0oooo00L0oono
07@0M02oool0oooo0?noM000B9`0gooo00`0oooo000e0?ooo`030=nLB00004P0W=oo0080oooo00<0
oooO09a80000M;l0D@3oool00`2oM00007Bo0?ooo`1E0?ooo`030;md001d_ol0oooo04l0oooo00D0
omnL04P000000000000007Boo`1A0?ooo`060?oOW018B9`0gooo0?oOW01804P0W=oo303oool003D0
oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`1@0?ooo`030=nLB000B9`0gooo05D0
oooo00<0omnL04P0M02oool0D@3oool00`3ookl0M000001d_`1B0?ooo`050?noM000M;l0oooO09a8
0018W=l0303oool003D0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`1@0?oo
o`030?oOW01804P0W=oo05D0oooo00<0oooO09a8001d_ol0D`3oool00`3OW4P007Bo0?ooo`1A0?oo
o`040=nLB018W=l0_g@0001d_``0oooo000f0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d
_`3oool0D03oool00`3ookl0M00007Boo`1E0?ooo`030?oo_`1d0000B9cO05<0oooo00<0omnL04P0
B02Lgol0DP3oool0103OW4P0M7Ad0000M02oool;0?ooo`00=`3oool01P3OW4P0001d0;ooo`3ooml0
W4P004RLge80oooo00<0_g@0001d_`3oool0D03oool01`3o_g@004RL0=ooo`3oool0gia80000B02L
gol0D03oool01P2oM000M;oo0?ooo`3OW4P0001809cOoe<0oooo00<0_g@00000B02Lgol02`3oool0
03P0oooo00@0gia800000000000007BoD@3oool01@3ookl0M0000000000007@0_ooo0540oooo00D0
omnL04P000000000000007Boo`1B0?ooo`040;md00000000000004RLge@0oooo00<0oooO09a80018
W=l02`3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0
ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00300
ooooo`00001^000000<0oooo000`0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0@3oool00300oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`010?ooo`00<03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`3o0?ooofX0oooo00<000000?oo
o`3oool00@3oool00300oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`030000003oool0oooo0040
oooo000`0?ooo`030000003oool0oooo0?l0ooooJP3oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`3o0?ooofX0oooo00<000000?ooo`3oool00@3oool00300oooo00<00000
0?ooo`3oool0o`3ooomZ0?ooo`030000003oool0oooo0040oooo000Q0?ooo`040;md000000000000
07Boo`/0oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`030000003oool0oooo0040oooo000P0?oo
o`060=nLB000M;l0oooo0?oOW0180000B9cO2P3oool00`000000oooo0?ooo`3o0?ooofX0oooo00<0
00000?ooo`3oool00@3oool001l0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`09
0?ooo`030000003oool0oooo0?l0ooooJP3oool00`000000oooo0?ooo`010?ooo`007`3oool00`3o
oml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<000000?ooo`3oool05`3oool2
000001L0oooo0P00000F0?ooo`8000005`3oool2000001L0oooo0P00000G0?ooo`8000005`3oool2
000001H0oooo0P00000G0?ooo`8000005`3oool2000001L0oooo0P00000F0?ooo`8000005`3oool2
000001L0oooo0P00000>0?ooo`030000003oool0oooo0040oooo000O0?ooo`030?oog`2LB00007Bo
00<0oooo00<0gia80000B02Lgol0203oool00`000000oooo0?ooo`0G0?ooo`H000004`3oool60000
0180oooo1P00000C0?ooo`H000004`3oool6000001<0oooo1P00000C0?ooo`H000004P3oool60000
01<0oooo1P00000C0?ooo`H000004`3oool600000180oooo1P00000C0?ooo`H000004`3oool60000
00X0oooo00<000000?ooo`3oool00@3oool00200oooo00<0_g@00018W03Oool00P3oool00`3ogi`0
B00004RLg`080?ooo`<000001@3oool00`000000oooo0?ooo`0?0?ooo`P000004@3oool800000100
oooo2@00000@0?ooo`T00000403oool800000140oooo2000000A0?ooo`P00000403oool900000100
oooo2000000A0?ooo`P000004@3oool800000100oooo2@00000@0?ooo`P000004@3oool8000000H0
oooo0`0000030?ooo`00803oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00P0oooo
00<000000?ooo`3oool05`3oool6000001<0oooo1P0000060?ooodL00000403oool6000001<0oooo
1P00000B0?ooo`L000004P3oool6000001<0oooo1P00000C0?ooo`H000004P3oool700000180oooo
1P00000C0?ooo`H000002P3oool00`000000oooo0?ooo`010?ooo`00803oool00`3ogi`0B00004RL
g`030?ooo`030;md0000B9`0gooo00L0oooo00<000000?ooo`3oool05`3oool2000000l0oooo5000
000<0?ooo`<000005P3oool3000001H0oooo0P0000070?oooc0000004@3oool3000001H0oooo0P00
000G0?ooo`8000005`3oool2000001H0oooo0`00000F0?ooo`8000005`3oool2000000h0oooo00<0
00000?ooo`3oool00@3oool00200oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=oo
o`070?ooo`030000003oool0oooo01l0oooo2@00000>0?oooe@00000:@3ooolQ000009D0oooo00<0
00000?ooo`3oool00@3oool00240oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`07
0?ooo`030000003oool0oooo01d0oooo1000000:0?ooo`d00000DP3ooolN000002`0oooo2P00002;
0?ooo`030000003oool0oooo0040oooo000R0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203o
ool00`000000oooo0?ooo`0K0?ooo`8000002@3oool7000007/0oooo4@00000U0?oooa@00000M`3o
ool00`000000oooo0?ooo`010?ooo`008`3oool0103OW4P0000000000000M;l90?ooo`030000003o
ool0oooo01T0oooo0P0000080?ooo`D000005@3ooom4000003P0oooo3P00000[0?ooo`X00000K@3o
ool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0G0?ooo`800000203oool3
00000180oooo2@00000n0?oooaL00000<`3oool8000002d0oooo1P00001W0?ooo`030000003oool0
oooo0040oooo000`0?ooo`030000003oool0oooo01D0oooo0P0000080?ooo`<000003P3oool80000
05`0oooo1`00000d0?ooo`H00000;@3oool600000640oooo00<000000?ooo`3oool00@3oool00300
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`8000003P3oool5000006T0
oooo2`00000_0?ooo`H00000;@3oool6000005/0oooo00<000000?ooo`3oool00@3oool00300oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`8000003@3oool4000007P0oooo
2P00000[0?ooo`L00000;03oool6000005D0oooo00<000000?ooo`3oool00@3oool00300oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo0`00
000S0?oooah00000A03oool5000002d0oooo1`00000[0?ooo`@00000D@3oool00`000000oooo0?oo
o`010?ooo`00<03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02P3oool2000001X0oooo3@00000J0?oooa800000>P3oool5000002l0oooo1P00000Y
0?ooo`@00000C@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00<0oooo0P00000:0?ooo`800000603oool6000003L0oooo1P00000i0?oo
o`D00000<03oool6000002L0oooo1P0000170?ooo`030000003oool0oooo0040oooo000`0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`80
0000503oool700000400oooo2@00000f0?ooo`D00000<@3oool4000002T0oooo1@0000120?ooo`03
0000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo1@00001=0?ooo`P00000
<`3oool500000300oooo0P00000/0?ooo`800000@03oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0@0?ooo`@00000F@3oool600000380oooo1000000^0?ooo`<00000:`3o
ool3000003d0oooo00<000000?ooo`3oool00@3oool00300oooo0P00000A0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`<00000H@3oool6
00000380oooo1000000]0?ooo`800000;03oool3000003T0oooo0P0000030?ooo`00<03oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0>0?ooo`800000I`3oool600000380oooo1000000[0?ooo`<00000;03oool30000
03L0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool2000006h0
oooo1@00000b0?ooo`<00000:`3oool3000002`0oooo0P00000e0?ooo`030000003oool0oooo0040
oooo000`0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`8000003@3oool3000007<0oooo1@00000a0?ooo`<00000:`3oool2000002`0oooo
0P00000c0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool02`3oool3000007P0oooo1@00
000`0?ooo`<00000:P3oool3000002/0oooo0P00000a0?ooo`030000003oool0oooo0040oooo000`
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00/0oooo0P00000W0?oooa@00000@`3oool400000300oooo0P00000[
0?ooo`800000:`3oool2000002l0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?oo
o`3oool03`3oool010000000oooo0?ooo`3oool2000000H0oooo0P00000=0?ooo`030000003oool0
oooo01h0oooo2@00000B0?ooo`T00000?P3oool4000002l0oooo0P00000[0?ooo`800000:`3oool2
000002d0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03`3oool01000
0000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0I
0?ooo`H000008`3oool6000003d0oooo0`00000^0?ooo`800000:`3oool2000002/0oooo0P00000[
0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00h0oooo0P0000030?oo
o`8000001@3oool2000000`0oooo00<000000?ooo`3oool0603oool5000002/0oooo2000000h0?oo
o`@00000;@3oool2000002/0oooo0P00000[0?ooo`800000:@3oool00`000000oooo0?ooo`010?oo
o`00<03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo0`00000f0?ooo`H0
0000=@3oool4000002d0oooo00<000000?ooo`3oool0:P3oool2000002/0oooo0P00000W0?ooo`03
0000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
5P3oool3000003d0oooo1000000d0?ooo`@00000;03oool2000002`0oooo0P00000[0?ooo`800000
9@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`8000005P3o
ool300000480oooo0`00000d0?ooo`@00000;03oool2000002`0oooo0P00000[0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P00000:0?ooo`030000003oool0
oooo01<0oooo0`0000170?ooo`<00000<`3oool4000002`0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00@3oool0
0300oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo0P0000090?ooo`030000003oool0oooo01<0oooo0P00001<0?ooo`<00000<P3oool30000
02`0oooo00<000000?ooo`3oool0:`3oool2000002X0oooo0P00000Q0?ooo`030000003oool0oooo
0040oooo000`0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool0oooo0P0000050?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool2000001L0oooo6000000R0?oo
o`<00000<@3oool3000001h0oooo00<000000?ooo`3oool02P3oool200000280oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool00@3oool00300oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool00000
00D0oooo0P0000090?ooo`030000003oool0oooo0140oooo0P00000C0?ooo`H00000503oool80000
01l0oooo0`0000040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool20000
00<0oooo00<000000?ooo`3oool05P3oool3000000d0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0E0?ooo`<000002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03P3oool01@000000
oooo0?ooo`3oool0000000D0oooo0P0000090?ooo`030000003oool0oooo0100oooo0P00000B0?oo
o`<000007`3oool7000000P0oooo00<000000?ooo`3oool04@3oool3000000040?ooo`0000000000
000001H0oooo0`00000D0?ooo`D000005P3oool4000000h0oooo00<000000?ooo`3oool0103oool3
000001H0oooo0`00000;0?ooo`030000003oool0oooo00L0oooo1000000E0?ooo`<000001P3oool0
0`000000oooo0?ooo`0=0?ooo`<00000303oool00`000000oooo0?ooo`010?ooo`00<03oool20000
00h0oooo0P0000030?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool03`3oool4000001H0oooo0P00000=0?ooo`D000001@3oool40000
01<0oooo1P00000E0?ooo`@00000503oool5000001@0oooo1P00000>0?ooo`8000000`3oool40000
01D0oooo1@00000;0?ooo`030000003oool0oooo00D0oooo1@00000D0?ooo`D000001P3oool00`00
0000oooo0?ooo`0;0?ooo`D000002P3oool2000000<0oooo000`0?ooo`030000003oool0oooo00d0
oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0?0?ooo`8000003`3oool3000001T0oooo1000000?0?ooo`<000000`3oool5000001<0
oooo1`00000B0?ooo`H000004`3oool6000001@0oooo1@00000@0?ooo`040000003oool0oooo0?oo
o`@000005@3oool4000000`0oooo00<000000?ooo`3oool01@3oool5000001@0oooo100000070?oo
o`030000003oool0oooo00/0oooo1000000;0?ooo`030000003oool0oooo0040oooo000`0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0200000100
oooo0P00000>0?ooo`<000006`3oool600000100oooo2P00000C0?ooo`H000004`3oool5000001@0
oooo1@00000E0?ooo`@00000403oool00`000000oooo0?ooo`020?ooo`<000005P3oool3000000`0
oooo00<000000?ooo`3oool01P3oool4000001D0oooo0`0000070?ooo`030000003oool0oooo00`0
oooo0`00000:0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`00000@0?ooo`8000000`3oool00`000000oooo0?ooo`070?oo
o`<00000103oool900000100oooo2000000A0?ooo`P000005@3oool4000001H0oooo0P00000E0?oo
o`@000005P3oool200000140oooo0P0000030?ooo`8000005`3oool2000000d0oooo00<000000?oo
o`3oool01`3oool2000001H0oooo0P0000080?ooo`030000003oool0oooo00`0oooo0P00000:0?oo
o`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000000D0oooo0P0000040?ooo`8000000P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<00000203oool2000000H0oooo1`00000B0?oo
o`@000005`3oool3000001X0oooo0P00000^0?ooo`8000006@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`010?oo
o`00<03oool00`000000oooo0?ooo`050?ooo`8000001P3oool01@000000oooo0?ooo`3oool00000
00D0oooo0P0000040?ooo`8000000P3oool00`000000oooo0?ooo`0=0?ooo`80000000@0oooo0000
000000000000203oool00`000000oooo0?ooo`070?ooo`@00000<@3oool3000001T0oooo0`00000]
0?ooo`800000;03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`040?oo
o`<000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool3
000000030?ooo`000000oooo00l0oooo1P0000070?ooo`030000003oool0oooo00P0oooo0P00000f
0?ooo`8000006@3oool2000002d0oooo0P00000/0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0040oooo000`0?oo
o`030000003oool0oooo00@0oooo0`0000060?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`020?ooo`D000003`3oool6000000L0oooo00<000000?ooo`3oool0@`3oool2
000001P0oooo0P00000]0?ooo`800000:`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`00
0000oooo0?ooo`040?ooo`<000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo00@00000
0?ooo`3oool0oooo1P00000?0?ooo`030000003oool0000000<000001P3oool00`000000oooo0?oo
o`160?ooo`8000005`3oool2000002d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`010?ooo`00<03oool00`000000oooo0?ooo`040?ooo`@000001@3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00@000000?ooo`3oool0oooo1P00000>0?ooo`040000003oool0oooo0?ooo`80
00001P3oool00`000000oooo0?ooo`0J0?ooo`P000009`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`010?ooo`00
<03oool00`000000oooo0?ooo`040?ooo`@000001@3oool01@000000oooo0?ooo`3oool0000000@0
oooo0P0000050?ooo`@000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool05@3oool6000000P0oooo1P00000R0?ooo`8000005`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00@3oool00300oooo
00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo0P00000E0?ooo`@0
00004P3oool4000001l0oooo0P00000G0?ooo`030000003oool0oooo02X0oooo0P00000[0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0140oooo0`00000J0?ooo`<000007P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo0P0000090?ooo`03
0000003oool0oooo0100oooo0`00000O0?ooo`8000007@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`010?ooo`00
<03oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool200000140
oooo0P00000S0?ooo`800000703oool2000001H0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo0P00000V0?ooo`800000
6`3oool2000001H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P00
00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`070?ooo`800000403oool00`000000oooo0?ooo`0X0?ooo`8000006P3oool2000001D0oooo0P00
000[0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00@3oool00300oooo00<00000
0?ooo`3oool03@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo0P00
000]0?ooo`8000006@3oool2000001D0oooo0P00000[0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00@3oool00300oooo0P00000>0?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool01@3oool2000000`0oooo00<000000?ooo`3oool01P3oool2000000h0oooo0P00
000`0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00d0oooo0P0000030?ooo`00<03oool00`000000oooo0?ooo`0=
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00H0oooo0P00000=0?ooo`800000<P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo0P00
00080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01P3oool2000000d0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0F0?ooo`8000005@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`060?ooo`800000303oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0E0?ooo`8000005@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00
00040?ooo`8000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool04`3oool2000002/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`010?ooo`00<03oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000@0oooo0P00
00070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool2000000/0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0040oooo000`
0?ooo`030000003oool0oooo00`0oooo0P0000020?ooo`030000003oool0oooo0080oooo0P000006
0?ooo`8000002`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo0P00000Z
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?oo
o`3oool0303oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool2
000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`800000?P3oool2
000001H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0303oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo01@0oooo0P00000D0?ooo`800000:P3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00`0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo
00`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool2000000L0oooo00<000000?ooo`3oool02@3oool200000440oooo00<00000
0?ooo`3oool0503oool2000001@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00`0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool2
000000L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0303oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool2000004<0oooo00<00000
0?ooo`3oool0503oool2000001@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00`0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0G0?ooo`8000000P3oool00`000000oooo0?ooo`0B0?ooo`<00000503oool0
10000000oooo00000000000X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3o
ool00300oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo0P00
000:0?ooo`030000003oool0oooo02<0oooo0`00000G0?ooo`@000000P3oool00`000000oooo0?oo
o`0@0?ooo`D00000503oool4000001D0oooo1000000?0?ooo`030000003oool0oooo0080oooo1@00
000G0?ooo`800000203oool00`000000oooo0?ooo`0;0?ooo`8000006`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool00300oooo0P00000=
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0280oooo1@00000G0?ooo`<000000P3oool200000140oooo1@00000D0?ooo`@000005@3o
ool4000000l0oooo00<000000?ooo`3oool00P3oool5000001@0oooo1@0000080?ooo`030000003o
ool0oooo00T0oooo1000000D0?ooo`D000000P3oool00`000000oooo0?ooo`0B0?ooo`800000503o
ool010000000oooo0000000000080?ooo`8000000`3oool00300oooo00<000000?ooo`3oool0303o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0S0?ooo`@000005`3oool3000000<0oooo00<000000?ooo`3oool0403oool5000001@0oooo
0`00000F0?ooo`<000003`3oool00`000000oooo0?ooo`030?ooo`@00000503oool5000000T0oooo
00<000000?ooo`3oool0203oool4000001@0oooo1@0000020?ooo`030000003oool0oooo00l0oooo
1@00000D0?ooo`@000002@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?oo
o`0<0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`800000
9P3oool4000001L0oooo0`0000020?ooo`030000003oool0oooo0100oooo0`0000000`3oool00000
0?ooo`0C0?ooo`<000005P3oool3000000l0oooo00<000000?ooo`3oool00`3oool4000001D0oooo
100000090?ooo`030000003oool0oooo00T0oooo0`00000E0?ooo`@000000`3oool00`000000oooo
0?ooo`0>0?ooo`D00000503oool4000000T0oooo00<000000?ooo`3oool00@3oool00300oooo00<0
00000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0V0?ooo`<00000603oool200000080oooo0P00000B0?ooo`800000
00<0oooo0000003oool04`3oool3000001H0oooo0P00000A0?ooo`030000003oool0oooo00<0oooo
0P00000F0?ooo`<000002P3oool00`000000oooo0?ooo`090?ooo`8000005P3oool4000000<0oooo
00<000000?ooo`3oool03`3oool4000001D0oooo0`0000090?ooo`030000003oool0oooo0040oooo
000`0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool01@3oool2000000X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
:03oool2000001L0oooo0P0000030?ooo`030000003oool0oooo0100oooo0P0000000`3oool00000
0000000C0?ooo`<000005P3oool200000140oooo00<000000?ooo`3oool00`3oool2000001L0oooo
0P00000:0?ooo`030000003oool0oooo00T0oooo0P00000G0?ooo`800000103oool00`000000oooo
0?ooo`0?0?ooo`<000005P3oool2000000X0oooo00<000000?ooo`3oool00@3oool00300oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`050?ooo`8000002P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool2000000<0oooo00<000000?ooo`3oool0
4@3oool010000000oooo0?ooo`00000D0?ooo`8000005`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool2000000X0oooo00<000000?ooo`3o
ool02@3oool2000001L0oooo0P0000040?ooo`030000003oool0oooo0100oooo0P00000F0?ooo`80
00002P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`050?ooo`800000
1@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool3000000T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000
oooo0?ooo`0?0?ooo`800000=@3oool2000001D0oooo00<000000?ooo`3oool04P3oool2000001L0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0
oooo0P00000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo0P00000F0?ooo`8000002P3oool00`000000
oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`050?ooo`8000001@3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool3000000T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`0>0?ooo`<0
0000=@3oool2000001D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01@0oooo0P00000:0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000
003oool0oooo00@0oooo0`0000050?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`050?ooo`<000002@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?oo
o`<00000103oool00`000000oooo0?ooo`0=0?ooo`@00000=P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3o
ool0103oool3000000D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00D0oooo0`0000090?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0`000004
0?ooo`030000003oool0oooo00`0oooo1000000g0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0103oool4000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo1@0000080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0100000040?ooo`030000003oool0oooo00/0oooo1@00000g
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?oo
o`3oool0103oool4000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00@0oooo1@0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool010000003
0?ooo`030000003oool0oooo00d0oooo1000000g0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00@3oool001l0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`090?oo
o`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool2000000L0oooo00<000000?ooo`3oool00P3oool2
000000<0oooo00<000000?ooo`3oool03`3oool2000003L0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`010?ooo`008@3oool00`3o_g@0000007Boo`0<0?ooo`030000003oool0oooo
00`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000Q0?oo
o`030?oog`2LB00007Bo00`0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`180?ooo`8000005@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`010?ooo`008P3oool00`3OW4P004RL0=ooo`0;0?ooo`030000003oool0oooo
00`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000R0?oo
o`030?oOW01804P0W=oo00/0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00@3oool00280oooo00<0oono07@0001d_ol02`3oool30000
00`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00H0oooo0`000003
0?ooo`008`3oool00`2oM00007Bo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000S0?ooo`030=nLB000B9`0gooo
00X0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00@3oool002<0oooo00<0omnL04P0B02Lgol02P3oool00`000000oooo0?ooo`0<0?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`010?ooo`008`3oool00`3o
okl0M00007Boo`0:0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0040oooo000T0?ooo`030;md0000M;l0oooo00T0oooo00<000000?oo
o`3oool0303oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo01<0oooo0P00000D0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`010?ooo`008P3oool01@3o
okl0M0000000000007@0_ooo00T0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0303oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000004T0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool09`3oool2000002X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00`0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0X0?ooo`800000:P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0303oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool2000002T0oooo0P00
000:0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00`0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0
oooo00`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo000`
0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0040oooo000`0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3oool2000001@0oooo0P00
000D0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`010?ooo`00<03oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0<0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04D0oooo0P00
000E0?ooo`030000003oool0oooo0180oooo0P00000Z0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00@3oool00300oooo0P00000=0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`800000AP3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:03oool2000002T0oooo0P00
000Y0?ooo`800000:@3oool2000000X0oooo0P0000030?ooo`00<03oool00`000000oooo0?ooo`0<
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool04`3oool2000000030?ooo`000000oooo01<0oooo0`00
000D0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0X0?ooo`800000:@3oool2000000/0oooo00<000000?ooo`3oool00@3oool00300oooo00<00000
0?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo0P00000:0?ooo`030000003o
ool0oooo02/0oooo0P00000D0?ooo`@00000503oool4000001<0oooo0`00000F0?ooo`800000403o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo0P00000Y0?ooo`8000002`3o
ool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0<0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01@3oool2000000X0oooo00<000000?ooo`3oool0:P3oool4000001<0oooo0`00
000E0?ooo`@000004P3oool7000001<0oooo1@00000=0?ooo`030000003oool0oooo00@0oooo1000
000D0?ooo`8000002P3oool00`000000oooo0?ooo`0:0?ooo`800000703oool2000002T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0<
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo02X0oooo0`00000D0?ooo`<000005@3oool3000001<0oooo00<000000?ooo`0000000`00
000D0?ooo`D000003@3oool00`000000oooo0?ooo`040?ooo`@00000503oool5000000L0oooo00<0
00000?ooo`3oool02P3oool4000001@0oooo1@0000000`3oool000000?ooo`0A0?ooo`8000005P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0
oooo00`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo0P00
000Z0?ooo`<00000503oool4000001D0oooo0`00000C0?ooo`030000003oool0000000<00000503o
ool4000000h0oooo00<000000?ooo`3oool0103oool3000001D0oooo100000080?ooo`030000003o
ool0oooo00X0oooo1000000D0?ooo`D0000000<0oooo0000003oool04@3oool4000001@0oooo1@00
00080?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203o
ool2000002X0oooo0P00000E0?ooo`@000005@3oool2000001@0oooo00<000000?ooo`0000000P00
000E0?ooo`@000003@3oool2000000H0oooo0`00000E0?ooo`@00000203oool00`000000oooo0?oo
o`0:0?ooo`<000005@3oool4000000030?ooo`00000000000180oooo1000000D0?ooo`D00000203o
ool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo0P00
000:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`800000403oool00`000000oooo0?ooo`0F0?ooo`8000005P3oool3000001H0oooo0P00
000D0?ooo`040000003oool00000000001L0oooo0P00000>0?ooo`030000003oool0oooo00D0oooo
0P00000G0?ooo`800000203oool2000000`0oooo0`00000E0?ooo`@0000000<0oooo000000000000
4P3oool3000001D0oooo100000090?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003o
ool0oooo00D0oooo0P0000050?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`050?ooo`8000002P3oool2000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00h0oooo0`00000F0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`0000005P3oool00`000000oooo0?ooo`0B0?ooo`80000000<0oooo000000000000
5`3oool2000000h0oooo00<000000?ooo`3oool01@3oool2000001L0oooo0P0000080?ooo`030000
003oool0oooo00/0oooo0P00000G0?ooo`8000000P3oool200000180oooo0`00000D0?ooo`D00000
2@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`050?ooo`8000001@3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool3000000X0oooo
00<000000?ooo`3oool01@3oool200000080oooo0`0000050?ooo`030000003oool0oooo00l0oooo
1000000]0?ooo`8000005P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000001P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`8000005`3oool200000080
oooo0P00000C0?ooo`800000503oool4000000X0oooo00<000000?ooo`3oool00@3oool00300oooo
00<000000?ooo`3oool0103oool3000000D0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00D0oooo0`00000:0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`<0
00001@3oool00`000000oooo0?ooo`0@0?ooo`D00000:`3oool00`000000oooo0?ooo`0D0?ooo`80
0000503oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00`0oooo0P0000070?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`800000503oool01000
0000oooo00000000000:0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo
00@0oooo0`0000050?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`<000002P3oool00`000000oooo0?ooo`050?ooo`8000000P3oool3000000D0oooo00<00000
0?ooo`3oool0403oool6000002T0oooo0P00000F0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0:03oool2000002X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F
0?ooo`050000003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0000000/0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0103oool4
000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo0`00
000:0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`<000001P3oool00`000000oooo0?oo
o`0@0?ooo`@00000:P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0:03oool2000002X0oooo00<000000?ooo`3oool09`3oool2000001@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0000000;0?ooo`030000003oool0oooo0040oooo000`
0?ooo`030000003oool0oooo00@0oooo100000040?ooo`8000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo100000090?ooo`030000003oool0oooo00D0oooo0P000000
0`3oool0000000000003000000D0oooo00<000000?ooo`3oool0403oool3000002X0oooo0P00000F
0?ooo`800000503oool2000002X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0W
0?ooo`800000:P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000`0?oo
o`030000003oool0oooo00`0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool4000000T0oooo00<000000?ooo`3oool01@3oool2000000030?ooo`0000000000
00<000001@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool05@3oool2000001@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?oo
o`800000:@3oool2000002X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?oo
o`00<03oool00`000000oooo0?ooo`0<0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0>`3oool2000001L0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0X0?ooo`800000:P3oool00`000000oooo0?ooo`0X0?ooo`80
0000:@3oool2000000d0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0
303oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000
2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0E0?ooo`800000503oool2000002X0oooo0P00000Z0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0040oooo000`0?ooo`8000003P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool2000000L0oooo00<000000?ooo`3oool0
2P3oool2000003/0oooo0P00000G0?ooo`800000503oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool09`3oool2000002X0oooo00<000000?ooo`3oool0
2`3oool2000000<0oooo000`0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo0P0000070?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0>@3oool2000001L0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
9`3oool2000002X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000@0oooo0P0000070?ooo`030000
003oool0oooo00T0oooo0P0000070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
>03oool2000001L0oooo0P00000D0?ooo`800000:`3oool00`000000oooo0?ooo`0X0?ooo`800000
:@3oool2000002X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000@0oooo0P0000070?ooo`030000
003oool0oooo00T0oooo0P0000080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
=`3oool2000001L0oooo0P00000D0?ooo`030000003oool0oooo02T0oooo0P00000Z0?ooo`030000
003oool0oooo02P0oooo0P00000Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0@3oool00300oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000040?ooo`800000
1`3oool00`000000oooo0?ooo`090?ooo`800000203oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo03H0oooo0P00000H0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool00000103oool2000000L0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
=P3oool2000001L0oooo0P00000D0?ooo`800000:`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03@0oooo0P00000H0?ooo`030000
003oool0oooo01<0oooo0P00000[0?ooo`030000003oool0oooo02P0oooo0P00000Y0?ooo`800000
:P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool05P3oool2000001D0oooo00<000000?ooo`3oool0
:@3oool2000002X0oooo00<000000?ooo`3oool0:03oool2000002T0oooo0P00000?0?ooo`030000
003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo0P0000080?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0<P3oool2000001P0oooo00<000000?ooo`3oool0
4`3oool2000002/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02P0oooo0P00000?0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00X0oooo0P0000080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
<@3oool2000001T0oooo00<000000?ooo`3oool04`3oool2000002/0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0=0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`800000
203oool00`000000oooo0?ooo`0<0?ooo`800000<P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo01<0oooo0P00000/0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:03oool2000002X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0:0?ooo`8000002@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0C0?ooo`800000
:`3oool2000002X0oooo00<000000?ooo`3oool0:03oool2000002T0oooo0P00000@0?ooo`030000
003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02h0oooo0P00000I0?ooo`030000
003oool0oooo01@0oooo0P00000[0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0X0?ooo`800000403oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0/0?ooo`8000006P3oool00`000000oooo0?ooo`0C0?ooo`800000
;03oool00`000000oooo0?ooo`0X0?ooo`800000:P3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03@3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01@0oooo0P00000/0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool2000002X0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0=0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`800000
2@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02X0oooo0P00000J0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02P0oooo0P00000Y0?ooo`8000004@3oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00800000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00/0oooo0P0000090?ooo`030000003oool0oooo00d0oooo0P00
000Z0?ooo`8000006P3oool2000001D0oooo0P00000/0?ooo`030000003oool0oooo02P0oooo0P00
000Z0?ooo`030000003oool0oooo02P0oooo0P00000A0?ooo`030000003oool0oooo0040oooo000`
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02`3oool2000000T0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0W0?ooo`8000006`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0:03oool2000002X0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0040oooo000`0?ooo`8000003P3oool00`00
0000oooo0?ooo`02000000@0oooo0P0000060?ooo`8000003@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool09@3oool2000001/0oooo0P00000E0?oo
o`800000;03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo0P00000Z0?oo
o`030000003oool0oooo00l0oooo0P0000030?ooo`00<03oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00800000103oool2000000L0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`070?ooo`800000403oool2000002H0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0D0?ooo`800000;03oool00`000000oooo0?ooo`0X0?ooo`800000:P3oool00`000000
oooo0?ooo`0X0?ooo`8000004P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00800000103oool2000000L0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`070?ooo`8000004@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01X0oooo0P00000F0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
:@3oool2000002X0oooo00<000000?ooo`3oool0:03oool200000180oooo00<000000?ooo`3oool0
0@3oool00300oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000@0oooo
0P0000070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01@0oooo0P00000/0?ooo`030000003oool0oooo02T0oooo
0P00000Z0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000
103oool2000000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0100oooo0P00000Q0?ooo`030000003oool0oooo0180oooo0P0000070?ooo`800000
303oool2000000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03@3o
ool01@000000oooo0?ooo`3oool0000000@0oooo0P0000070?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool01`3oool200000180oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0B0?ooo`@000001P3oool00`000000oooo0?ooo`0;0?ooo`@000001@3oool2000000d0oooo
0`00000E0?ooo`8000001@3oool00`000000oooo0?ooo`0>0?ooo`8000006@3oool2000002X0oooo
00<000000?ooo`3oool0:03oool2000001<0oooo00<000000?ooo`3oool00@3oool00300oooo00<0
00000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000070?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool2000001<0oooo0P00000L0?ooo`@00000
4`3oool5000000@0oooo00<000000?ooo`3oool02`3oool4000000H0oooo00<000000?ooo`3oool0
303oool4000001@0oooo100000030?ooo`030000003oool0oooo00h0oooo1@00000D0?ooo`@00000
503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo0P00000C0?ooo`030000
003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool01@000000oooo0?ooo`3oool0000000@0oooo0P0000070?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`8000006P3oool500000180oooo
1@0000050?ooo`030000003oool0oooo00/0oooo0`0000060?ooo`8000003P3oool3000001D0oooo
0`0000030?ooo`800000403oool4000001D0oooo1000000D0?ooo`<000004`3oool010000000oooo
00000000000W0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00@3oool00300oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`00
0000103oool2000000H0oooo0P00000>0?ooo`030000003oool0oooo00P0oooo0P00000D0?ooo`80
00005`3oool800000140oooo0`0000060?ooo`030000003oool0oooo00`0oooo0P0000070?ooo`03
0000003oool0oooo00`0oooo1000000E0?ooo`<000000`3oool00`000000oooo0?ooo`0?0?ooo`@0
00005@3oool3000001D0oooo1@00000@0?ooo`030000003oool0oooo00D00000503oool2000000h0
oooo00<000000?ooo`3oool01@3oool2000000/0oooo00<000000?ooo`3oool00@3oool00300oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`00
0000103oool2000000H0oooo0P00000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P00000D0?ooo`<00000503oool800000180oooo0`0000070?ooo`030000003oool0oooo00`0
oooo0P0000060?ooo`8000003P3oool3000001D0oooo0`0000040?ooo`030000003oool0oooo00l0
oooo0`00000F0?ooo`<000005@3oool400000140oooo00<000000?ooo`3oool01000000E0?ooo`@0
00002`3oool2000000L0oooo1@0000080?ooo`030000003oool0oooo0040oooo000`0?ooo`030000
003oool0oooo00D0oooo0P0000060?ooo`050000003oool0oooo0?ooo`000000103oool2000000H0
oooo0`00000=0?ooo`8000001P3oool200000080oooo00<000000?ooo`3oool04P3oool6000000l0
oooo1P00000F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool2000000L0
oooo0P00000>0?ooo`8000005P3oool2000000@0oooo00<000000?ooo`3oool0403oool3000001D0
oooo0`00000F0?ooo`@000004@3oool00`000000oooo0?ooo`04000001D0oooo0`00000<0?ooo`80
00001`3oool4000000T0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0
103oool3000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000001P3oool3000000h0
oooo00<000000?ooo`3oool0103oool200000080oooo0P00000D0?ooo`H000002`3oool500000280
oooo0P00000>0?ooo`030000003oool0oooo00D0oooo0P00000?0?ooo`8000005P3oool2000000@0
oooo00<000000?ooo`3oool0403oool2000001H0oooo0`00000F0?ooo`<000004@3oool200000080
oooo0`00000F0?ooo`<00000303oool00`000000oooo0?ooo`060?ooo`@000002@3oool00`000000
oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`040?ooo`<000001P3oool01@000000oooo
0?ooo`3oool0000000@0oooo0P0000050?ooo`@000003P3oool00`000000oooo0?ooo`040?ooo`<0
00000P3oool00`000000oooo0?ooo`0C0?oooa8000009@3oool00`000000oooo0?ooo`0E0?ooo`80
00003`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`80
00005P3oool2000001L0oooo0P00000B0?ooo`040000003oool0oooo0?ooo`8000005`3oool20000
00`0oooo0P0000080?ooo`<000002P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000
oooo0?ooo`040?ooo`<000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool00`3oool4000000h0oooo00<000000?ooo`3oool01@3oool3000000030?ooo`0000000000
01D0oooo1@00000`0?ooo`8000005P3oool2000002d0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0E0?ooo`8000005`3oool200000180oooo00@000000?ooo`3oool0oooo0P00000G
0?ooo`800000303oool2000000P0oooo0`00000:0?ooo`030000003oool0oooo0040oooo000`0?oo
o`030000003oool0oooo00@0oooo100000050?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`030?ooo`@000003P3oool00`000000oooo0?ooo`050?ooo`<0000000<0oooo
0000000000005@3oool400000300oooo0P00000G0?ooo`800000;@3oool00`000000oooo0?ooo`0Y
0?ooo`8000005`3oool00`000000oooo0?ooo`0@0?ooo`8000000`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool2000000/0oooo00<00000
0?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0103oool4000000D0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo1000000?0?ooo`030000003oool0
oooo00@0oooo100000000`3oool000000?ooo`0E0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool05@3oool2000002d0oooo0P00000[0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo0P00000;
0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00d0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool2000004L0oooo00<000000?ooo`3oool05P3oool2
000002d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo02P0oooo0P0000090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool0
0300oooo0P00000>0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool2000004L0oooo00<00000
0?ooo`3oool05@3oool2000002d0oooo0P00000[0?ooo`800000:P3oool2000002X0oooo00<00000
0?ooo`3oool0503oool2000000<0oooo000`0?ooo`030000003oool0oooo00d0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00H0oooo0P00000>0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`800000:P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo
00d0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0303oool2000000/0oooo0P0000140?ooo`030000003oool0oooo01H0oooo0P00000^
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?oo
o`3oool03@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0:P3oool2
000002/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0040oooo000`0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:
0?ooo`800000@@3oool00`000000oooo0?ooo`0G0?ooo`800000;P3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo02T0oooo0P00000Z0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03@3oool200000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02P3oool200000440oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0/0?oo
o`800000:`3oool2000002/0oooo0P00000Z0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool00@3oool00300oooo00<000000?ooo`3oool03@3oool200000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo0P00000<0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo02X0oooo0P00000[0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0=0?ooo`800000
0P3oool00`000000oooo0?ooo`030?ooo`800000203oool00`000000oooo0?ooo`0=0?ooo`800000
303oool2000003h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool2000002X0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0=0?ooo`8000000P3o
ool2000000@0oooo0P0000080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0Z0?ooo`800000:`3oool2000002X0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool2
000000@0oooo0P0000080?ooo`8000003`3oool00`000000oooo0?ooo`0;0?ooo`800000>`3oool2
000001X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0040oooo000`0?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`8000001@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0h0?ooo`8000006P3oool00`000000oooo0?ooo`0]0?ooo`800000;03oool00`00
0000oooo0?ooo`0Y0?ooo`800000:P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0040oooo000`0?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`8000001@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo0P00000=0?ooo`800000>@3oool00`000000
oooo0?ooo`0H0?ooo`800000;`3oool00`000000oooo0?ooo`0Z0?ooo`800000:`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00@3oool001l0oooo
00<0gia80000000000000`0000000`18W=l0oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
0P0000020?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo
0P00000>0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0]0?ooo`800000;03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`010?ooo`00803oool00`3o_g@007Bo0?oo
o`020?ooo`030;mdM02oool0oooo00P0oooo00<000000?ooo`3oool03@3oool200000080oooo0P00
00050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0<0?ooo`800000=P3oool00`000000oooo0?ooo`0I0?ooo`800000;`3oool00`000000oooo0?oo
o`0Z0?ooo`800000:`3oool2000002X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`010?ooo`008@3oool00`3o_g@007Bo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo0P000002
0?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0;@3oool2000002`0oooo0P00000[0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`010?ooo`008P3oool00`3o_g@007Bo0?ooo`0;0?oo
o`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03P3oool2000000l0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02h0oooo0P00000/0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0040oooo000S0?ooo`030?noM018W=l0oooo00X0oooo00<000000?ooo`3oool03P3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01`3oool2000000l0oooo0P00000@
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool06P3oool200000300oooo00<00000
0?ooo`3oool0:P3oool2000002/0oooo0P00000Z0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool00@3oool002@0oooo00<0gia804RLg`3oool02@3oool3000000h0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo0P00000@0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo02h0oooo0P00000/0?ooo`800000:`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo01P0oooo0`0000030?ooo`009@3oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo
00h0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool06`3oool200000300oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`01
0?ooo`009@3oool00`3ogi`0B01d0;ooo`080?ooo`030000003oool0oooo00h0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool2
00000140oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo02h0oooo0P00000/0?ooo`800000:`3oool2000002X0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`010?ooo`009@3oool00`3ooml0W4P007Boo`080?ooo`030000003oool0oooo
00h0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0_0?ooo`800000;03oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`01
0?ooo`009@3oool00`3ookl0M00004RLg`080?ooo`030000003oool0oooo00h0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0703oool2
00000300oooo0P00000]0?ooo`030000003oool0oooo02T0oooo0P00000Z0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00@3oool00240oooo00L0okmd0018W03Oool0oooo0=nLB000
04P0W=oo00P0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`8000004P3oool2000002D0oooo
0P00000O0?ooo`030000003oool0oooo02l0oooo0P00000/0?ooo`030000003oool0oooo02X0oooo
0P00000Z0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00@3oool00280oooo00D0
omnL04P000000000000007Boo`090?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0A0?ooo`8000008`3oool2000001l0oooo0P00000a0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0X0?ooo`8000007P3oool00`000000
oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
00001@3oool2000000T0oooo0P00000A0?ooo`030000003oool0oooo0180oooo0P00000P0?ooo`<0
00004`3oool00`000000oooo0?ooo`090?ooo`8000002@3oool00`000000oooo0?ooo`0U0?ooo`80
0000;03oool2000002/0oooo0P00000Z0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool00@3oool00300oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000D0
oooo0P00000:0?ooo`030000003oool0oooo00l0oooo0P00000D0?ooo`<00000703oool3000001@0
oooo100000080?ooo`8000002P3oool3000001D0oooo0P00000>0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo
0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0503oool2000001X0oooo1000000D0?ooo`D0
00001`3oool00`000000oooo0?ooo`080?ooo`D00000503oool4000000/0oooo0P0000070?ooo`<0
00005@3oool2000000`0oooo00<000000?ooo`3oool0:@3oool2000002X0oooo0P00000O0?ooo`03
0000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo0`00000F0?ooo`L000004P3oool5000000L0
oooo0P00000:0?ooo`@00000503oool4000000`0oooo00<000000?ooo`3oool01P3oool4000001@0
oooo1@0000080?ooo`030000003oool0oooo00T0oooo0P00000F0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0040
oooo000`0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00l0oooo0`00000H0?ooo`<000004P3oool900000180oooo0`0000080?ooo`80
00002`3oool3000001D0oooo0`00000<0?ooo`800000203oool3000001D0oooo100000090?ooo`03
0000003oool0oooo00T0oooo1000000D0?ooo`<000001@3oool2000000h0oooo0P00000K0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0
1@3oool2000000L0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`<000005P3oool200000080
oooo0`00000<0?ooo`@000000P3oool5000001<0oooo0`0000080?ooo`800000303oool2000001H0
oooo0P00000=0?ooo`030000003oool0oooo00H0oooo1000000E0?ooo`<000002@3oool00`000000
oooo0?ooo`090?ooo`@000005@3oool4000000@0oooo0P00000>0?ooo`@00000503oool300000003
0?ooo`000000000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`010?ooo`00
<03oool00`000000oooo0?ooo`050?ooo`8000001`3oool010000000oooo0?ooo`3oool2000000D0
oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool03`3oool4000001H0
oooo1@0000000`3oool000000000000;000000@0oooo0P00000F0?ooo`<000002@3oool2000000/0
oooo0P00000G0?ooo`800000303oool2000000P0oooo0`00000E0?ooo`<000002P3oool00`000000
oooo0?ooo`090?ooo`<000005P3oool3000000D0oooo00<000000?ooo`3oool03@3oool3000001D0
oooo1@00000D0?ooo`<000002P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo
0?ooo`040?ooo`<000001`3oool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3o
ool00P3oool2000000@0oooo0P00000@0?ooo`@000005`3oool6000002P0oooo00<000000?ooo`3o
ool0203oool2000000`0oooo00<000000?ooo`3oool05@3oool2000000d0oooo00<000000?ooo`3o
ool01`3oool2000001H0oooo0`0000090?ooo`8000002`3oool2000001H0oooo100000040?ooo`80
00003`3oool3000001D0oooo1@00000D0?ooo`@000002@3oool00`000000oooo0?ooo`010?ooo`00
<03oool00`000000oooo0?ooo`040?ooo`<000001`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool0oooo100000040?ooo`030000003oool0oooo00h0
oooo1@00000G0?ooo`@00000<`3oool00`000000oooo0000000T0?ooo`030000003oool0oooo00/0
oooo0P0000090?ooo`8000005P3oool2000000X0oooo00<000000?ooo`3oool02P3oool2000001H0
oooo0`0000050?ooo`030000003oool0oooo00d0oooo0`00000F0?ooo`D00000503oool3000000X0
oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0103oool4000000H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`@0
0000103oool00`000000oooo0?ooo`0?0?ooo`@00000603oool300000380oooo00<000000?ooo`00
0000<`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0203oool2000000/0oooo0P00000G0?ooo`8000001@3oool2000000l0oooo0`00000F0?ooo`@0
00005@3oool3000000X0oooo00<000000?ooo`3oool00@3oool00300oooo0P0000050?ooo`@00000
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
oooo1@0000030?ooo`030000003oool0oooo00l0oooo1@00000H0?ooo`030000003oool0oooo0340
oooo0P00000c0?ooo`800000;@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0
oooo0P0000050?ooo`8000003`3oool2000001L0oooo0P0000000`3oool000000?ooo`0C0?ooo`<0
00002P3oool2000000<0oooo000`0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`D000000`3oool00`000000
oooo0?ooo`0?0?ooo`D00000B`3oool2000003@0oooo00<000000?ooo`3oool0:`3oool2000002D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`8000005`3oool3000001D0
oooo0P00000<0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03`3oool200000080oooo0P0000190?ooo`800000=03oool2000002d0oooo
00<000000?ooo`3oool0:P3oool200000100oooo00<000000?ooo`3oool05P3oool00`000000oooo
0000000E0?ooo`800000303oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000X0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`160?ooo`800000=03oool2000002d0oooo0P00
000/0?ooo`030000003oool0oooo02T0oooo0P00000E0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03P3oool2000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0oooo0P000017
0?ooo`800000=03oool2000002d0oooo00<000000?ooo`3oool0:P3oool2000002/0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0>0?oo
o`8000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`140?ooo`800000=03oool2000002d0oooo0P00000/0?oo
o`030000003oool0oooo02T0oooo0P00000T0?ooo`030000003oool0oooo0040oooo000`0?ooo`03
0000003oool0oooo00h0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0D0?ooo`800000A03oool2000003D0oooo0P00000]0?ooo`80
0000;03oool00`000000oooo0?ooo`0Y0?ooo`800000903oool00`000000oooo0?ooo`010?ooo`00
<03oool00`000000oooo0?ooo`0>0?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`110?ooo`800000
=@3oool2000002d0oooo0P00000/0?ooo`800000:P3oool2000002D0oooo00<000000?ooo`3oool0
0@3oool00300oooo00<000000?ooo`3oool03P3oool2000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo0P0000120?ooo`030000003o
ool0oooo03@0oooo0P00000]0?ooo`800000;03oool00`000000oooo0?ooo`0Y0?ooo`8000009@3o
ool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0>0?ooo`8000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03@0oooo0P00000]0?ooo`800000;03oool2
000002/0oooo0P00000U0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo
00l0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00T0oooo0P00000G
0?ooo`800000?`3oool00`000000oooo0?ooo`0d0?ooo`800000;P3oool2000002`0oooo00<00000
0?ooo`3oool0:@3oool2000002H0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?oo
o`3oool03`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool2
000002d0oooo0P00000/0?ooo`800000:`3oool2000002H0oooo00<000000?ooo`3oool00@3oool0
0300oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`800000?03oool00`000000oooo0?ooo`0e
0?ooo`800000;P3oool2000002`0oooo0P00000Z0?ooo`030000003oool0000002H0oooo00<00000
0?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`3oool2
000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0=P3oool2000002d0oooo00<000000?ooo`000000:`3oool2
000002/0oooo0P00000W0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo
00l0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`8000002`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo03H0oooo0P00000h0?ooo`800000;P3oool2000002`0oooo0P00000Z
0?ooo`030000003oool0000002L0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?oo
o`3oool03`3oool010000000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0H0?ooo`800000=P3oool2000003T0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0000000[0?ooo`800000:`3oool00`000000oooo0000000W0?ooo`030000003oool0
oooo0040oooo000`0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool0oooo0P000006
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool2000003@0oooo0P00000i
0?ooo`800000;P3oool2000002`0oooo0P00000Z0?ooo`030000003oool0000002P0oooo00<00000
0?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0340oooo0P00000i0?ooo`800000;P3oool00`000000oooo0000000[0?oo
o`800000:`3oool00`000000oooo0000000X0?ooo`030000003oool0oooo0040oooo000`0?ooo`80
0000403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0I0?ooo`800000<@3oool2000003X0oooo00<000000?ooo`3o
ool0;@3oool2000002`0oooo0P00000Z0?ooo`030000003oool0000002P0oooo0P0000030?ooo`00
<03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01X0oooo0P00000_0?ooo`030000
003oool0oooo03T0oooo0P00000^0?ooo`030000003oool0000002/0oooo00<000000?ooo`000000
:P3oool00`000000oooo0000000Y0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool06`3oool2000002d0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0]0?ooo`800000;03oool2000002/0oooo0P00000Z0?ooo`030000003o
ool0oooo0040oooo000`0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00000M0?ooo`800000:P3oool2
000003`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0000000[0?ooo`030000003oool0
000002X0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0:0?ooo`8000007P3oool2000002P0oooo0P00000m0?ooo`030000003oool0oooo
02d0oooo0P00000/0?ooo`800000:`3oool2000002/0oooo00<000000?ooo`3oool00@3oool00300
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo0P00000<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0903oool2000003h0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0000000[0?ooo`030000003oool0000002X0
oooo00<000000?ooo`000000:`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool08@3oool2000003l0oooo
0P00000_0?ooo`800000;03oool00`000000oooo0000000Z0?ooo`030000003oool0000002/0oooo
00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool200000200oooo0P00
000O0?ooo`800000@@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0000002/0oooo00<0
00000?ooo`000000:P3oool00`000000oooo0000000/0?ooo`030000003oool0oooo0040oooo000`
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00X0oooo0P00000Q0?ooo`8000007@3oool200000440oooo00<00000
0?ooo`3oool0;P3oool2000002`0oooo00<000000?ooo`000000:P3oool00`000000oooo0000000/
0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo0P00000S0?oo
o`8000006@3oool2000001P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0]0?oo
o`800000;03oool00`000000oooo0000000Z0?ooo`030000003oool0000002d0oooo00<000000?oo
o`3oool00@3oool00300oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool2000002D0oooo0`00000C0?ooo`<0
0000103oool00`000000oooo0?ooo`0B0?ooo`<000005@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool2000002`0oooo00<000000?ooo`00
0000:P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`<00000
3P3oool4000000D0oooo0P00000D0?ooo`@00000503oool3000000l0oooo00<000000?ooo`3oool0
0`3oool3000001D0oooo00<000000?ooo`3oool0403oool2000002`0oooo00<000000?ooo`000000
:P3oool00`000000oooo0000000^0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000002`3oool2000002T0oooo3`0000070?ooo`<000004`3o
ool600000180oooo1@00000>0?ooo`030000003oool0oooo0080oooo1@00000D0?ooo`<00000403o
ool2000000<0oooo0P00000W0?ooo`030000003oool0000002X0oooo00<000000?ooo`000000;P3o
ool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`0000002`3oool2
000000X0oooo00<000000?ooo`3oool0<03oool600000180oooo1@00000C0?ooo`@000003P3oool0
0`000000oooo0?ooo`030?ooo`@00000503oool5000000h0oooo0P0000040?ooo`@00000503oool2
000000h0oooo00<000000?ooo`000000:`3oool00`000000oooo0000000^0?ooo`030000003oool0
oooo0040oooo000`0?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`030000003oool0oooo
0080oooo0P0000060?ooo`@000002P3oool2000000X0oooo0P00000F0?ooo`800000603oool70000
0140oooo1000000D0?ooo`@000003P3oool2000000D0oooo0`00000E0?ooo`@000003`3oool20000
00<0oooo1000000E0?ooo`@00000303oool00`000000oooo000000050?ooo`<000005P3oool00`00
0000oooo000000090?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00@0
oooo0`0000080?ooo`800000103oool00`000000oooo0?ooo`050?ooo`<000002`3oool00`000000
oooo0?ooo`080?ooo`<000005P3oool5000001<0oooo1000000D0?ooo`<000005P3oool3000000l0
oooo00<000000?ooo`3oool0103oool2000001H0oooo0`00000?0?ooo`800000103oool3000001H0
oooo0`00000<0?ooo`030000003oool0000000H0oooo1@00000D0?ooo`<000002@3oool00`000000
oooo000000090?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`040?ooo`<00000203oool2000000@0oooo
00<000000?ooo`3oool01@3oool4000000X0oooo0P0000090?ooo`<000005`3oool7000002P0oooo
00<000000?ooo`3oool05@3oool200000100oooo0P0000050?ooo`8000005`3oool200000100oooo
0P0000040?ooo`8000005`3oool3000000`0oooo00<000000?ooo`0000001P3oool4000001@0oooo
1@0000070?ooo`030000003oool0000000X0oooo0`00000E0?ooo`<000002`3oool00`000000oooo
0?ooo`010?ooo`00<03oool2000000D0oooo0`0000080?ooo`800000103oool00`000000oooo0?oo
o`050?ooo`@000002P3oool2000000X0oooo0`00000G0?ooo`D00000@@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool200000100oooo0P00
00050?ooo`8000005P3oool3000000`0oooo00<000000?ooo`0000001`3oool3000001D0oooo1000
00080?ooo`030000003oool0000000X0oooo1000000D0?ooo`@000002@3oool2000000<0oooo000`
0?ooo`030000003oool0oooo00@0oooo100000070?ooo`800000103oool00`000000oooo0?ooo`05
0?ooo`D000002@3oool2000000X0oooo1000000H0?ooo`<00000DP3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool2000001L0oooo0P00000=
0?ooo`030000003oool0000000H0oooo0`00000F0?ooo`<00000203oool00`000000oooo0000000;
0?ooo`<000005@3oool3000000/0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?oo
o`3oool0103oool4000000L0oooo0P0000040?ooo`030000003oool0oooo00D0oooo1@00000:0?oo
o`030000003oool0oooo00P0oooo1@00000H0?ooo`030000003oool0oooo0500oooo0P00000`0?oo
o`8000001@3oool00`000000oooo0?ooo`0F0?ooo`800000303oool00`000000oooo000000070?oo
o`<000005P3oool2000000T0oooo00<000000?ooo`0000002P3oool4000001D0oooo0`00000;0?oo
o`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00l0oooo0P0000040?ooo`03
0000003oool0oooo00D0oooo0`00000<0?ooo`8000002@3oool3000006d0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`00
00001`3oool2000001H0oooo0`0000080?ooo`030000003oool0000000/0oooo0`00000E0?ooo`<0
0000303oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0?0?ooo`800000
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo0P00001h0?ooo`030000
003oool0oooo02l0oooo0P00000/0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0
5@3oool2000000T0oooo00<000000?ooo`0000002`3oool2000001H0oooo0`00000<0?ooo`030000
003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00l0oooo0P0000040?ooo`030000003o
ool0oooo00D0oooo0P00000>0?ooo`030000003oool0oooo07D0oooo0P00000a0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000/0oooo0P00000F0?ooo`8000003@3oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0;`3o
ool2000002`0oooo00<000000?ooo`000000:`3oool00`000000oooo0000000<0?ooo`030000003o
ool0oooo01D0oooo0P00000=0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00`0oooo0P00001e0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0000000[0?ooo`030000003oool0000002@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0780oooo0P00000a0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`000000:`3oool00`00
0000oooo0000000d0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`000000:`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0040
oooo000`0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00d0oooo0P00001b0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0000000[0?ooo`030000003oool0000003D0oooo
00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool200000740oooo0P00
000b0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`000000:`3oool00`000000oooo0000
000e0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0:`3oool00`000000oooo0000000[
0?ooo`040000003oool0oooo000003D0oooo00<000000?ooo`3oool00@3oool001L0oooo00<0_ibL
0=ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo0P000007
0?ooo`8000003`3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0000000[0?ooo`030000003oool0000003H0oooo00<00000
0?ooo`3oool00@3oool001D0oooo00@0oono07@00000B9`0gooo5`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0080oooo0P0000070?ooo`8000003`3oool2000006h0oooo0P00000b
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`000000:`3oool010000000oooo0?ooo`00
000f0?ooo`030000003oool0oooo0040oooo000A0?ooo`030?oo_`1d0000000000<0000000<004RL
0=ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo0P000008
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0`
0?ooo`800000;@3oool2000002`0oooo00<000000?ooo`000000=`3oool00`000000oooo0?ooo`01
0?ooo`002`3oool0103ookl0W9cO0?oo_`1d000400000006001d_`3oool0oooo0?ooo`2oW9`0gooo
5`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0000002/0oooo00@000000?ooo`3oool0
0000=`3oool00`000000oooo0?ooo`010?ooo`002`3oool01@3ogi`0B00000000000000007Bo00<0
oooo00<0_gAd0;ooo`3oool06P3oool200000140oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo0P00001[0?ooo`030000003oool0oooo0340
oooo0P00000]0?ooo`800000;03oool00`000000oooo0000000g0?ooo`8000000`3oool000`0oooo
00<0oono07A8W03Oool0103oool00`3OW9`0_ooo0?ooo`0J0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`000000;03oool00`000000oooo0000000h0?ooo`030000003oool0oooo0040oooo
000;0?ooo`030?oog`2LB7@0_ooo00@0oooo00<0oono07Ad_`3oool06`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0<@3oool2000002d0oooo0P00
000/0?ooo`030000003oool0000003T0oooo00<000000?ooo`3oool00@3oool000/0oooo00<0omnL
07BLg`3oool00`3oool00`3ookl0M01d0;ooo`0L0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`800000403oool2000006P0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0000002`0oooo00<00000
0?ooo`000000>@3oool00`000000oooo0?ooo`010?ooo`002`3oool0203o_g@007Bo0?ooo`3oool0
oooO09a8000007@0_ooo7@3oool00`000000oooo0?ooo`0@0?ooo`800000103oool00`000000oooo
0?ooo`060?ooo`8000004@3oool00`000000oooo0?ooo`1U0?ooo`800000<`3oool2000002d0oooo
0P00000/0?ooo`040000003oool0oooo000003T0oooo00<000000?ooo`3oool00@3oool000`0oooo
00D0_g@0000000000000001809cOo`0O0?ooo`030000003oool0oooo0100oooo0P0000040?ooo`03
0000003oool0oooo00H0oooo0P00000A0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0000002`0oooo00<000000?ooo`00
0000>P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0@0?ooo`800000
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo0P00001U0?ooo`030000
003oool0oooo0380oooo0P00000]0?ooo`800000;03oool010000000oooo0?ooo`00000j0?ooo`03
0000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo0100oooo0P0000040?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1R0?ooo`030000
003oool0oooo0380oooo0P00000]0?ooo`030000003oool0000002`0oooo00<000000?ooo`000000
>`3oool00`000000oooo0?ooo`010?ooo`004@3oool0103ookl0M0000000M02ooolK0?ooo`030000
003oool0oooo0100oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool0<`3oool2000002d0oooo0P00000/0?ooo`040000
003oool0oooo000003/0oooo00<000000?ooo`3oool00@3oool000/0oooo00@0oono09bLg`3ookl0
M000100000000`1d_ol0oooo0?ooo`0J0?ooo`030000003oool0oooo0100oooo0P0000040?ooo`80
0000203oool200000140oooo0P00001Q0?ooo`800000=03oool2000002d0oooo00<000000?ooo`00
0000;03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0040oooo000;0?ooo`060?oO
W018000000000000000004P0W=oo7`3oool00`000000oooo0?ooo`0@0?ooo`800000103oool20000
00P0oooo0P00000B0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0<`3oool20000
02d0oooo0P00000/0?ooo`040000003oool0oooo000003`0oooo00<000000?ooo`3oool00@3oool0
00`0oooo00<0oono07@0001d_ol08@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0080oooo0P0000080?ooo`8000004P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
03<0oooo0P00000]0?ooo`030000003oool0000002`0oooo00@000000?ooo`3oool00000?03oool0
0`000000oooo0?ooo`010?ooo`00303oool00`2oM7@0_ooo0?ooo`0@0?ooo`030?oo_`1d00000000
0080000000<0M;oo0?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0080oooo0P0000090?ooo`030000003oool0oooo0100oooo0P00001N0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0;03oool2000002d0oooo00<000000?ooo`000000?@3oool00`00
0000oooo0?ooo`010?ooo`002`3oool0103o_g@000000018W03Oool@0?ooo`030?noM000000007Bo
0080oooo00<0_gA809cOo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0080oooo0P0000090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;@3oool20000
02d0oooo00<000000?ooo`000000;03oool010000000oooo0?ooo`00000m0?ooo`030000003oool0
oooo0040oooo000T0?ooo`030?oOW018B9`0gooo00T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P0000090?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0B0?ooo`<000003@3oool20000
00H0oooo0`00000E0?ooo`030000003oool0oooo01@0oooo0P00000^0?ooo`800000;@3oool00`00
0000oooo0000000n0?ooo`030000003oool0oooo0040oooo000>0?ooo`060=nLB000000000000000
000004P0W=oo403oool00`3ookl0M00007Boo`090?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`8000001P3oool010000000oooo0?ooo`00
000D0?ooo`030000003oool0oooo0380oooo0`00000D0?ooo`@00000303oool00`000000oooo0?oo
o`040?ooo`D00000503oool3000001@0oooo0`00000/0?ooo`030000003oool0000002`0oooo00@0
00000?ooo`3oool00000?P3oool00`000000oooo0?ooo`010?ooo`00303oool02@3ookl0M00004RL
g`3ogi`0W;oo0?ooo`3OW4P004RL0=ooo`0?0?ooo`030?oOW0180000M;oo00T0oooo00<000000?oo
o`3oool01@3oool2000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo008000004`3oool00`000000oooo0?ooo`0`0?ooo`H000004P3oool40000
00`0oooo00<000000?ooo`3oool01@3oool4000001@0oooo1@00000B0?ooo`H00000503oool20000
01@0oooo0P00000]0?ooo`030000003oool0000003l0oooo00<000000?ooo`3oool00@3oool000`0
oooo00T0_gAd0;ooo`3oool0oknL09cOo`3oool0oono07@0M02oool03P3oool0103ogi`0B0000000
B02Lgol90?ooo`<000001@3oool2000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`80000000<0oooo0000000000004`3oool2000001H0oooo1000000E0?ooo`P00000
4@3oool3000000d0oooo00<000000?ooo`3oool01@3oool4000001D0oooo1000000C0?ooo`D00000
5@3oool400000140oooo0P0000000`3oool000000000000H0?ooo`030000003oool0oooo00l0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01P3oool3000000<0oooo000;0?ooo`090?oOW02L_ol0oooo0?oog`2L
M9`0gooo0?ooo`3ogi`0B7Bo00d0oooo00D0omnL04P000000000000007Boo`0:0?ooo`030000003o
ool0oooo00@0oooo0`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool200000080oooo00<000000?ooo`3oool04@3oool3000001H0oooo2000000?0?ooo`D00000503o
ool3000000d0oooo00<000000?ooo`3oool01P3oool3000001D0oooo1000000C0?ooo`030000003o
ool00000008000005@3oool400000180oooo0P0000000`3oool0000000000002000001@0oooo0P00
000B0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool000/0oooo00T0oknL
09cOo`3oool0_g@007Boo`3oool0gia80000M02oool03`3oool00`3ookl0M000001d_`0:0?ooo`03
0000003oool0oooo00@0oooo0`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool4000000030?ooo`000000oooo0180oooo0`00000H0?ooo`D00000:@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo0P00000G0?ooo`<00000503oool010000000
oooo00000000000F0?ooo`<000004P3oool2000000030?ooo`0000000000008000005@3oool40000
00l0oooo00D000000?ooo`3oool000000?ooo`03000001L0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo000;0?ooo`040?oo_`1d00000000
07BooaH0oooo00<0gia8001d_`3oool0203oool00`000000oooo0?ooo`040?ooo`@000002@3oool0
0`000000oooo0?ooo`030?ooo`800000103oool4000000030?ooo`000000oooo01<0oooo0`00000H
0?ooo`@00000=`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo0P00000E
0?ooo`030000003oool0oooo008000005P3oool2000001<0oooo0P000000103oool0000000000000
000E0?ooo`@00000403oool00`000000oooo000000020?ooo`@00000503oool3000001P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`009@3oool00`3ogi`0B01809cOo`08
0?ooo`030000003oool0oooo00@0oooo100000090?ooo`030000003oool0oooo00<0oooo0P000004
0?ooo`H00000503oool4000001T0oooo00<000000?ooo`3oool0=@3oool200000240oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`02000001L0oooo0P00000B0?ooo`8000000P3oool2
000001H0oooo0`00000@0?ooo`040000003oool0oooo00000080oooo0`00000E0?ooo`@00000503o
ool3000000`0oooo00<000000?ooo`3oool00@3oool000l0oooo00D0gia8000000000000000007Bo
o`0>0?ooo`060;md001d_ol0oooo0=nLB00004P0W=oo203oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00<0oooo0P0000040?ooo`L000004`3oool5000004l0oooo0P00000h0?ooo`04
0000003oool0oooo000001L0oooo0P00000C0?ooo`8000000P3oool2000001H0oooo0P00000A0?oo
o`030000003oool0000000<0oooo0`00000E0?ooo`<000005@3oool5000000X0oooo00<000000?oo
o`3oool00@3oool000d0oooo00<0omnL04P00018W=l00P3oool00`3ogi`0B01d0;ooo`0>0?ooo`04
0;md00000000000004RLg`T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?oo
o`8000002P3oool00`000000oooo0?ooo`0A0?ooo`<00000D03oool2000003P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool2000001L0oooo0P00000A0?oo
o`030000003oool000000080oooo0`00000F0?ooo`<000005@3oool4000000/0oooo00<000000?oo
o`3oool00@3oool000`0oooo00<0omnL04Q8W03Oool00`3oool00`3ookl0M4RL0=ooo`0K0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool2000000X0oooo00<000000?ooo`3o
ool04`3oool2000004h0oooo0P00000h0?ooo`800000;`3oool200000080oooo00<000000?ooo`3o
ool05@3oool200000140oooo00<000000?ooo`0000000`3oool2000001H0oooo0`00000F0?ooo`<0
0000303oool00`000000oooo0?ooo`010?ooo`002`3oool00`3ooml0W7BL0=ooo`040?ooo`030;md
001d_ol0oooo01/0oooo00<000000?ooo`3oool04@3oool2000000@0oooo0P00000:0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0B`3oool2000003P0oooo0P00000_0?ooo`800000
6`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0000000<0oooo0P00000F0?ooo`800000
5P3oool3000000d0oooo00<000000?ooo`3oool00@3oool000/0oooo00<0omno0;oOo`3oool00P3o
ool00`3ooml0W4P007Boo`0M0?ooo`030000003oool0oooo0140oooo0P0000040?ooo`8000002P3o
ool00`000000oooo0?ooo`0D0?ooo`800000B`3oool2000003T0oooo0P00000_0?ooo`800000;@3o
ool00`000000oooo000000040?ooo`030000003oool0oooo01D0oooo0P00000F0?ooo`<000003@3o
ool00`000000oooo0?ooo`010?ooo`002`3oool02P3o_g@0M;oo0?ooo`3oool0omnL04P0B02Lgkl0
M0000018W03OoolK0?ooo`030000003oool0oooo0140oooo0P0000040?ooo`8000002P3oool00`00
0000oooo0?ooo`0E0?ooo`800000B@3oool2000003T0oooo0P00000_0?ooo`800000;P3oool00`00
0000oooo0000000L0?ooo`030000003oool0oooo01D0oooo0P00000>0?ooo`030000003oool0oooo
0040oooo000;0?ooo`030?oog`2LB000000000D0000000<004RL0=ooo`3oool06P3oool00`000000
oooo0?ooo`0A0?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0AP3oool2000003T0oooo00<000000?ooo`000000;`3oool2000002d0
oooo00<000000?ooo`000000=@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0040
oooo00070?ooo`040;nLW03Oool0oono07@000@0000000D0M;oo0?ooo`3oool0_gAd0;ooo`0L0?oo
o`030000003oool0oooo0140oooo0P0000050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`140?ooo`800000>P3oool2000002l0oooo0P00000^0?oo
o`800000AP3oool00`000000oooo0?ooo`010?ooo`001P3oool00`3ooml0W4P00000000200000003
07Boo`3oool0oooo0280oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`80
00002P3oool00`000000oooo0?ooo`0F0?ooo`800000A03oool2000003X0oooo0P00000`0?ooo`80
0000;@3oool00`000000oooo000000160?ooo`030000003oool0oooo0040oooo00060?ooo`030?oo
_`2LW=l0oooo02L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`800000
2P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0440oooo0P00000j0?ooo`030000
003oool0000002l0oooo0P00000^0?ooo`800000A`3oool00`000000oooo0?ooo`010?ooo`003`3o
ool01@2oM0000000000000000000B9cO01`0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`030?ooo`8000002P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03l0oooo
0P00000k0?ooo`800000<03oool2000002d0oooo00<000000?ooo`000000A`3oool00`000000oooo
0?ooo`010?ooo`003@3oool00`3OW4P0000007Boo`020?ooo`030?oOW01807@0_ooo01/0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`8000002P3oool2000001X0oooo00<0
00000?ooo`3oool0?@3oool2000003/0oooo00<000000?ooo`000000;`3oool2000002h0oooo0P00
00180?ooo`030000003oool0oooo0040oooo000<0?ooo`030=nLB018W=l0oooo00<0oooo00<0omnL
04Qd_`3oool06`3oool2000001<0oooo00<000000?ooo`3oool00`3oool2000000/0oooo00<00000
0?ooo`3oool0603oool2000003d0oooo0P00000k0?ooo`030000003oool000000300oooo0P00000^
0?ooo`800000A`3oool2000000<0oooo000;0?ooo`030?oOW01dW=l0oooo00<0oooo00<0oknL04Qd
W03Oool0703oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo0P00000;0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0>@3oool2000003d0oooo00<000000?oo
o`000000;`3oool2000002h0oooo0P0000190?ooo`030000003oool0oooo0040oooo000;0?ooo`03
0?noM000M;l0oooo0080oooo00D0omnL04QdM01d000004RL0=ooo`0K0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool00`3oool2000000/0oooo00<000000?ooo`3oool06@3oool20000
03T0oooo0P00000m0?ooo`030000003oool000000300oooo00<000000?ooo`3oool0;@3oool20000
04T0oooo00<000000?ooo`3oool00@3oool000`0oooo00<0okmd000000000000100000000`00B9`0
gooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool2000000/0
oooo00<000000?ooo`3oool06P3oool2000003L0oooo0P00000m0?ooo`030000003oool000000300
oooo0P00000^0?ooo`800000BP3oool00`000000oooo0?ooo`010?ooo`002`3oool01@3ogi`0B000
000000000000B9cO0080oooo00<0_gA809cOo`3oool06`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool2000001`0oooo0P00000e0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`000000<03oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo0P00000M0?ooo`030000
003oool0oooo0340oooo0P00000o0?ooo`030000003oool000000300oooo0P00000^0?ooo`800000
B`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0000000a0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`010?ooo`002`3oool0
1@3ogkl0_moo0?ooo`3oool0_g@000<0000000<0001d0;ooo`3oool06P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00@0oooo0P00000;0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0o0?ooo`800000<@3oool2000002h0oooo0P00
001<0?ooo`030000003oool0oooo0040oooo000;0?ooo`030;md0000000000000080000000D0001d
0;ooo`3oool0_ibL0=ooo`0K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103o
ool2000000/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Z0?ooo`800000@@3o
ool00`000000oooo0000000a0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`010?ooo`002@3oool01@2oM000000000000000B9`0gooo00<0oooo00<0
oooO09a8001d_ol0703oool00`000000oooo0?ooo`0B0?ooo`8000001@3oool2000000/0oooo0P00
000P0?ooo`800000:@3oool00`000000oooo0?ooo`100?ooo`030000003oool000000340oooo0P00
000^0?ooo`800000C@3oool00`000000oooo0?ooo`010?ooo`002`3oool00`3o_i`0W=oo0?ooo`0R
0?ooo`030000003oool0oooo0180oooo0P0000050?ooo`8000002`3oool200000240oooo0P00000V
0?ooo`800000@`3oool200000380oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo0180oooo0P0000050?oo
o`800000303oool00`000000oooo0?ooo`0P0?ooo`8000008`3oool2000004@0oooo00<000000?oo
o`000000<@3oool2000002l0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`010?oo
o`003P3oool01P3ogi`0B000000000000000001809cOoa`0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08P3oool2
000001h0oooo0`0000150?ooo`030000003oool000000380oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0040oooo000=0?ooo`030;md00000000M;oo
0080oooo00<0oooO09adW03Oool06`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0S0?ooo`8000006P3oool30000
04P0oooo0P00000b0?ooo`800000;P3oool2000004l0oooo00<000000?ooo`3oool00@3oool000`0
oooo00<0gia804RLg`3oool0103oool00`3OW9`0_ooo0?ooo`0J0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0
oooo0P00000F0?ooo`<00000B@3oool00`000000oooo0000000b0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`010?ooo`002`3oool00`3ogi`0M9cO
0?ooo`040?ooo`030?oog`2LM9`0gooo01/0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00000X0?ooo`@000003P3oool4000004/0oooo
00<000000?ooo`000000<P3oool2000002h0oooo0P00001@0?ooo`030000003oool0oooo0040oooo
000;0?ooo`030?noW02Lgol0oooo00<0oooo00<0oooO09a8001d_ol0703oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo02T0oooo1`0000030?ooo`H000007`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01D0oooo0P00000c0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`010?ooo`002`3oool00`3ogi`0B7Bo0?ooo`02
0?ooo`030=nLB0000000B9cO01d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00@0oooo0P0000020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0;`3oool5000000d0oooo00<000000?ooo`3oool04`3oool3000001D0oooo0P00000E
0?ooo`800000<`3oool2000002h0oooo0P00001A0?ooo`030000003oool0oooo0040oooo000<0?oo
o`060?noM0000000000000000000B9`0gooo7P3oool2000000H0oooo0P00000<0?ooo`030000003o
ool0oooo00@0oooo0P0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0a0?ooo`@000004`3oool4000001@0oooo1000000C0?ooo`@000005@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0C`3o
ool2000000<0oooo000`0?ooo`030000003oool0oooo00D0oooo0P00000<0?ooo`030000003oool0
oooo00@0oooo0P0000020?ooo`800000203oool00`000000oooo0?ooo`0;0?ooo`800000<@3oool5
00000180oooo1P00000C0?ooo`D000004P3oool5000001@0oooo0`00000E0?ooo`040000003oool0
oooo0?ooo`800000;P3oool200000580oooo00<000000?ooo`3oool00@3oool00300oooo00<00000
0?ooo`3oool0103oool3000000`0oooo00<000000?ooo`3oool0103oool200000080oooo0P000008
0?ooo`800000303oool3000001D0oooo1000000E0?ooo`P000004@3oool4000001@0oooo1@00000B
0?ooo`D00000503oool5000001@0oooo0`0000000`3oool000000?ooo`0B0?ooo`030000003oool0
000001P0oooo0P00000G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000A0?ooo`040?oo_`1d0000001d
0;oooa/0oooo00<000000?ooo`3oool0103oool3000000`0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo00000003000000P0oooo00<000000?ooo`3oool02P3oool3000001H0oooo1`00000@
0?ooo`D00000503oool3000001H0oooo0`00000C0?ooo`030000003oool00000008000005@3oool4
000001@0oooo1@00000D0?ooo`<000005`3oool3000001H0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool0
00/0oooo00@0oono09bLg`3ookl0M000100000000`1d_ol0oooo0?ooo`0J0?ooo`030000003oool0
oooo00@0oooo1000000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000`000008
0?ooo`030000003oool0oooo00X0oooo1000000G0?ooo`D00000:03oool2000001L0oooo0`00000D
0?ooo`@000005P3oool3000001D0oooo1@00000C0?ooo`D00000503oool3000000030?ooo`000000
oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00@3oool000/0oooo00H0omnL04P00000000000000000B02L
golO0?ooo`030000003oool0oooo00@0oooo1000000;0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`000000100000070?ooo`030000003oool0oooo00/0oooo1000000G0?ooo`<00000@P3o
ool00`000000oooo0?ooo`0C0?ooo`@000005`3oool2000001H0oooo1000000D0?ooo`@000005@3o
ool4000001@0oooo0`00000H0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`010?ooo`00303oool00`3ookl0M00007Boo`0Q0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo00000004000000L0oooo0P00000<
0?ooo`D00000603oool00`000000oooo0?ooo`1E0?ooo`040000003oool00000000001L0oooo0P00
000G0?ooo`80000000<0oooo0000003oool04`3oool3000001D0oooo1@00000D0?ooo`@00000503o
ool3000001P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00303oool0
0`2oM7@0_ooo0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo00000002000000X0oooo00<000000?ooo`3oool02P3oool400000700oooo00<00000
0?ooo`0000006@3oool00`000000oooo0?ooo`0E0?ooo`@000005@3oool2000001H0oooo1000000E
0?ooo`<000005@3oool5000001<0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`01
0?ooo`002`3oool0103o_g@000000018W03OoolQ0?ooo`030000003oool0oooo01<0oooo0P000006
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool200000780oooo0P00000b
0?ooo`80000000<0oooo0000003oool04`3oool3000001H0oooo0P0000000`3oool000000?ooo`0D
0?ooo`<000005@3oool4000001@0oooo0`00000=0?ooo`030000003oool0oooo0040oooo000`0?oo
o`030000003oool0oooo01<0oooo0P0000060?ooo`8000003@3oool00`000000oooo0?ooo`1m0?oo
o`800000<`3oool00`000000oooo0000000E0?ooo`8000005`3oool3000001D0oooo0`00000F0?oo
o`<000005@3oool5000000/0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`8000003@3oool2000007d0oooo00<000000?ooo`00
0000=@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo0P0000000`3oool0
00000?ooo`0D0?ooo`8000005P3oool3000001H0oooo1000000<0?ooo`030000003oool0oooo0040
oooo000`0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo07/0oooo0P00000e0?ooo`030000003oool0oooo02`0oooo
0`00000F0?ooo`8000005P3oool3000001D0oooo1000000=0?ooo`030000003oool0oooo0040oooo
000`0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo07X0oooo0P00000f0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`0000005P3oool00`000000oooo0?ooo`0E0?ooo`8000005P3oool3000000h0oooo00<0
00000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0000000e
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`000000;`3oool00`000000oooo0?ooo`0E
0?ooo`8000003`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1h0?oo
o`800000=P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0000004L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1g0?ooo`80
0000=P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0000005T0oooo00<000000?ooo`3o
ool00@3oool00300oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0MP3oool2000003L0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0000001I0?ooo`030000003oool0oooo0040oooo000`0?ooo`8000005@3o
ool00`000000oooo0?ooo`050?ooo`8000003`3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0000001I0?ooo`8000000`3o
ool00300oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`8000003`3oool0
0`000000oooo0?ooo`1d0?ooo`800000=P3oool2000002h0oooo00<000000?ooo`000000FP3oool0
0`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1c0?ooo`800000=`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0000005/0oooo00<000000?ooo`3oool00@3oool00300
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0
oooo0P00001d0?ooo`030000003oool0oooo03D0oooo0P00000^0?ooo`800000G03oool00`000000
oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo03D0oooo
0P00000^0?ooo`030000003oool0000005`0oooo00<000000?ooo`3oool00@3oool00300oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`000000G@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool200000700oooo00<00000
0?ooo`3oool0=P3oool2000002h0oooo00<000000?ooo`000000G@3oool00`000000oooo0?ooo`01
0?ooo`00<03oool00`000000oooo0?ooo`0D0?ooo`8000001`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo06d0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0000005h0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`050?ooo`800000403oool00`000000oooo0?ooo`1/0?ooo`80
0000>03oool00`000000oooo0?ooo`0]0?ooo`800000G`3oool00`000000oooo0?ooo`010?ooo`00
<03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo0P00000A0?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool0=P3oool2000002h0oooo00<000000?ooo`000000
G`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0;@3oool200000600oooo00<000000?ooo`3oool00@3o
ool00300oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00l0oooo0P00001Z0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0;@3oool2
00000640oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`0g0?ooo`800000;`3oool200000640oooo00<000000?ooo`3oool00@3oool00300
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02d0
oooo0P00001R0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`800000IP3oool2000003T0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0000001R0?ooo`030000003oool0oooo0040oooo
000`0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01P3oool200000180oooo00<0
00000?ooo`3oool0H`3oool2000003X0oooo00<000000?ooo`3oool0;@3oool2000006<0oooo00<0
00000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0100oooo0P00001S0?ooo`800000>P3oool00`000000oooo0?ooo`0]
0?ooo`800000I03oool00`000000oooo0?ooo`010?ooo`00<03oool2000000H0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`0h0?ooo`800000;`3oool2000006<0oooo0P0000030?oo
o`00<03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02d0oooo0P00001U0?ooo`03
0000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`060?ooo`800000503oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0180oooo0`00000A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0^0?ooo`800000I@3oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`050?ooo`8000003P3oool00`000000oooo0?ooo`060?ooo`800000503o
ool00`000000oooo0000000c0?ooo`<00000503oool4000000l0oooo00<000000?ooo`3oool00P3o
ool3000001D0oooo00<000000?ooo`3oool0703oool2000002l0oooo0P00001V0?ooo`030000003o
ool0oooo0040oooo000`0?ooo`030000003oool0oooo00@0oooo0`00000>0?ooo`8000001`3oool3
000001@0oooo0`00000F0?ooo`@000005`3oool500000180oooo1P00000=0?ooo`800000103oool4
000001@0oooo0`00000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo
00@0oooo0`00000?0?ooo`030000003oool0oooo00D0oooo0`00000D0?ooo`@000005P3oool70000
0140oooo1`00000A0?ooo`D000003P3oool2000000@0oooo1000000D0?ooo`D00000503oool30000
00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0000000G0?ooo`030000003oool0oooo
0080oooo0P00000B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool00300
oooo00<000000?ooo`3oool0103oool3000000l0oooo00<000000?ooo`3oool0103oool4000001D0
oooo0`00000G0?ooo`H00000403oool4000001D0oooo0`00000?0?ooo`800000103oool3000001H0
oooo1000000D0?ooo`D000000P3oool00`000000oooo0?ooo`0?0?ooo`<000005@3oool00`000000
oooo000000040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`040?ooo`@000003P3oool00`000000oooo
0?ooo`040?ooo`@000005@3oool4000001L0oooo1000000Y0?ooo`800000403oool2000000D0oooo
0P00000F0?ooo`@000005@3oool400000080oooo00<000000?ooo`3oool03`3oool5000001@0oooo
0`0000030?ooo`8000004P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo
000`0?ooo`030000003oool0oooo00@0oooo1000000>0?ooo`030000003oool0oooo00@0oooo1000
000E0?ooo`D00000603oool2000003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0F0?ooo`<000005@3oool400000080oooo00<000000?ooo`3oool0403oool4000001@0oooo1@00
00000`3oool000000000000A0?ooo`800000603oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00<03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo1000000F0?ooo`D00000603oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01`0oooo0P00000G0?ooo`<000000`3oool0
0`000000oooo0?ooo`0?0?ooo`@000005@3oool400000080oooo00<000000?ooo`3oool0403oool4
000001<0oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`070?ooo`8000005@3oool3000005@0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0E0?ooo`800000103oool00`000000oooo0?ooo`0@0?ooo`<000005P3oool3
00000080oooo0P00000A0?ooo`@00000503oool3000001H0oooo0P00000H0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool20000
01P0oooo0P0000030?ooo`030000003oool0oooo0100oooo0`00000E0?ooo`D00000503oool30000
01L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`008P3oool00`3ooml0
W4P004RLg`0;0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo0`0000020?ooo`8000004P3oool2000001H0
oooo1000000D0?ooo`D00000503oool2000000h0oooo00<000000?ooo`3oool00@3oool002<0oooo
00<0gia80018W03Oool02P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0:P3oool2000000<0oooo00<000000?ooo`3oool04@3oool2000001D0oooo
1000000E0?ooo`@000005@3oool4000000`0oooo00<000000?ooo`3oool00@3oool002<0oooo00<0
omnL04P0B02Lgol02P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03`0oooo0P00
000/0?ooo`050000003oool0oooo0?ooo`0000004`3oool2000001H0oooo0`00000F0?ooo`<00000
5@3oool4000000d0oooo00<000000?ooo`3oool00@3oool001l0oooo00<0okmd0000000000001000
00000`00B9`0gooo0?ooo`070?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3o
ool2000001L0oooo0P00000F0?ooo`<000003P3oool00`000000oooo0?ooo`010?ooo`007`3oool0
0`3ooml0W4Q809cOo`020?ooo`030;md0000M;l0oooo00T0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`070?ooo`8000005`3oool00`000000oooo0?ooo`1:0?ooo`800000?`3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool05@3oool2
000001L0oooo0P00000?0?ooo`030000003oool0oooo0040oooo000P0?ooo`070?oo_`1d07@0_ooo
0?ooo`3o_g@004RL0=ooo`090?ooo`<000005`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0B03oool2000003l0oooo0P00000`0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool05P3oool2000000d0oooo0`0000030?ooo`008@3oool0
1P3ogi`0B4RL0=ooo`3ogi`0B01809cOo`T0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01H0oooo0P0000180?ooo`800000@03oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo05/0oooo0P00000@0?ooo`030000003oool0oooo0040oooo
000R0?ooo`050?noM000M;l0oooO09a80018W=l02@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool2000004H0oooo0P0000100?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0040oooo000S0?ooo`040=nLB018W=l0_g@0001d_`T0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
@`3oool200000400oooo0P00000a0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0
0@3oool002@0oooo00@0gia807AdM00007@0_ooo203oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo0040oooo000U0?ooo`030;md000004P0W=oo00P0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01P0oooo0P0000110?ooo`030000003o
ool0oooo0400oooo0P00000`0?ooo`800000L@3oool00`000000oooo0?ooo`010?ooo`009@3oool0
0`3ooml0W4P004RLg`080?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0I0?ooo`800000?P3oool200000480oooo0P00000a0?ooo`030000003oool0
oooo0700oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01X0oooo0P00000l0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0;`3oool200000780oooo00<000000?ooo`3oool00@3oool00300
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01/0
oooo0P00000j0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo01L0oooo
0P00000;0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0=P3oool2000004D0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0040oooo
000`0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo03@0oooo0P0000150?ooo`030000003oool0oooo02l0oooo0P00
001d0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0340oooo0P000016
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`01
0?ooo`00<03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0^0?ooo`<00000AP3oool200000340oooo0P00001e0?oo
o`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool02@3oool200000200oooo00<000000?ooo`3oool0;03oool3000004L0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`800000
:P3oool3000004P0oooo00<000000?ooo`3oool0<03oool2000007H0oooo00<000000?ooo`3oool0
0@3oool00300oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool09@3oool3000004T0oooo0P00000a0?ooo`800000M`3o
ool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`<00000BP3oool2
00000380oooo0P00001g0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool02P3oool2000002@0oooo0P00000P0?ooo`<00000C03oool00`00
0000oooo0?ooo`0`0?ooo`800000N03oool00`000000oooo0?ooo`010?ooo`00<03oool2000001T0
oooo00<000000?ooo`3oool02P3oool2000002H0oooo00<000000?ooo`3oool06`3oool3000004d0
oooo0P00000b0?ooo`030000003oool0oooo07H0oooo0P0000030?ooo`00<03oool00`000000oooo
0?ooo`0H0?ooo`800000303oool00`000000oooo0?ooo`0U0?ooo`8000006@3oool3000004h0oooo
0P00000b0?ooo`800000N@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0W0?ooo`<000004P3oool400000500oooo0P00000b0?ooo`800000NP3oool00`000000oooo0?oo
o`010?ooo`00<03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000:`3oool4000000X0oooo1@00000L
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<@3oool2000007X0oooo00<00000
0?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool01@3oool200000180oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000;P3oool<000000X0oooo00<000000?oo
o`3oool04P3oool3000001D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0a0?oo
o`800000N`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`050?ooo`80
00004P3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0340oooo0`00000D0?ooo`<000005@3oool3000001D0oooo00<000000?ooo`3o
ool00`3oool200000380oooo00<000000?ooo`000000N`3oool00`000000oooo0?ooo`010?ooo`00
<03oool00`000000oooo0?ooo`040?ooo`<000004P3oool00`000000oooo0?ooo`020?ooo`800000
1`3oool00`000000oooo0?ooo`0<0?ooo`8000005P3oool4000001L0oooo1@00000B0?ooo`D00000
4`3oool5000001@0oooo0`0000020?ooo`800000403oool00`000000oooo0?ooo`0P0?ooo`800000
O03oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`040?ooo`<000004P3o
ool010000000oooo0?ooo`3oool3000000L0oooo0P00000=0?ooo`<000005P3oool700000140oooo
1`00000A0?ooo`D00000503oool4000001@0oooo1@0000000`3oool000000?ooo`0@0?ooo`<00000
603oool00`000000oooo0?ooo`040?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003o
ool0oooo00@0oooo1000000A0?ooo`040000003oool0oooo0?ooo`<000001`3oool2000000d0oooo
0`00000G0?ooo`D000004@3oool4000001D0oooo0`00000E0?ooo`@000005@3oool4000000030?oo
o`000000oooo0100oooo1@00000D0?ooo`030000003oool0000000L0oooo0P00000>0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`040?ooo`@000004@3oool010000000oooo0?ooo`3oool4000000L0oooo
00<000000?ooo`3oool0303oool3000001L0oooo1000000Y0?ooo`8000005`3oool3000001D0oooo
100000000`3oool000000?ooo`0A0?ooo`@000005@3oool3000000H0oooo0P00000=0?ooo`030000
003oool0000001P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`0I0?ooo`8000000P3oool4000000L0oooo00<000000?ooo`3oool0303o
ool4000001L0oooo0P0000120?ooo`8000005`3oool3000000030?ooo`000000oooo0180oooo0`00
000E0?ooo`D00000103oool00`000000oooo0000000=0?ooo`<000005`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool00P0000090?ooo`8000003@3oool3000001T0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0E0?ooo`8000000`3oool00`000000oooo0?ooo`0A0?ooo`8000005P3oool4
000000D0oooo0P00000=0?ooo`D00000503oool3000001P0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool0
0300oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0;0?ooo`8000003@3oool00`00
0000oooo0?ooo`1d0?ooo`050000003oool0oooo0?ooo`0000004`3oool2000001L0oooo0`000005
0?ooo`030000003oool0000000d0oooo1000000E0?ooo`@00000503oool00`000000oooo0000000G
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`01
0?ooo`00<03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0Q@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo0P0000060?oo
o`8000003P3oool3000001D0oooo1000000E0?ooo`<000005`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0:`3oool2000000H0oooo00<000000?ooo`0000003P3oool2000001H0oooo0`00000E0?ooo`D0
0000503oool2000001P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`010?ooo`00
<03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo0P0000240?ooo`800000
;@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000h0oooo0P00000G0?ooo`800000
5P3oool4000001D0oooo1000000D0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool0
0@3oool00300oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0840oooo0P00000e0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool05P3o
ool2000001H0oooo0`00000E0?ooo`@000005@3oool3000000h0oooo00<000000?ooo`3oool00@3o
ool00300oooo0P00000K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0000002L0oooo0P00000G0?ooo`8000005P3oool3
000001D0oooo1@00000<0?ooo`8000000`3oool00300oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0=03oool20000
02P0oooo00<000000?ooo`3oool05@3oool2000001L0oooo0P00000F0?ooo`@000003P3oool00`00
0000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0OP3oool2000003D0oooo00<000000?ooo`000000@03oool00`000000
oooo0?ooo`0F0?ooo`8000005P3oool3000000l0oooo00<000000?ooo`3oool00@3oool00300oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07d0oooo
0P00000e0?ooo`030000003oool0000005T0oooo0P00000G0?ooo`800000403oool00`000000oooo
0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0O03oool2000003H0oooo00<000000?ooo`000000F@3oool00`000000oooo0?oo
o`0E0?ooo`8000004@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00d0oooo0P00001l0?ooo`800000=P3oool00`000000oooo0000001b
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07X0oooo0P00000f0?oo
o`030000003oool0000008D0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07T0oooo0P00000f0?ooo`03
0000003oool0000008H0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0
6`3oool2000000l0oooo00<000000?ooo`3oool0N03oool2000003H0oooo00@000000?ooo`3oool0
0000QP3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0K0?ooo`800000
403oool00`000000oooo0?ooo`1f0?ooo`800000=`3oool00`000000oooo000000270?ooo`030000
003oool0oooo0040oooo000`0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`1e0?ooo`030000003oool0000003H0oooo00<000000?ooo`000000R03o
ool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0M03oool00`000000oooo0000000f0?ooo`040000003oool0
oooo000008P0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07<0oooo0P00000g0?ooo`030000003oool0
000008T0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0780oooo0P00000g0?ooo`030000003oool00000
08X0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0?0?ooo`800000LP3oool2000003P0oooo0P00002;0?ooo`030000003oool0oooo0040
oooo000`0?ooo`030000003oool0oooo01`0oooo0P00000A0?ooo`030000003oool0oooo06l0oooo
0P00000h0?ooo`030000003oool0000008/0oooo00<000000?ooo`3oool00@3oool00300oooo00<0
00000?ooo`3oool0703oool200000140oooo00<000000?ooo`3oool0KP3oool2000003P0oooo00<0
00000?ooo`000000S03oool00`000000oooo0?ooo`010?ooo`00<03oool2000001d0oooo0P00000A
0?ooo`800000KP3oool2000003T0oooo0P00002<0?ooo`8000000`3oool00300oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0000002=0?ooo`030000003oool0oooo0040oooo000`0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo03P0oooo0P00002>0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0403oool2000006/0oooo00<000000?ooo`3oool0
>03oool2000008l0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0J03o
ool2000003T0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`010?ooo`00<03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo0P00000B0?ooo`030000003oool0
oooo06L0oooo0P00000j0?ooo`800000T03oool00`000000oooo0?ooo`010?ooo`00<03oool00`00
0000oooo0?ooo`050?ooo`8000005P3oool2000001<0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`0E0?ooo`800000>P3oool200000940oooo00<000000?ooo`3oool00@3oool00300
oooo00<000000?ooo`3oool01@3oool2000001H0oooo0P00000C0?ooo`040000003oool0oooo0000
03H0oooo00<000000?ooo`3oool04P3oool3000001D0oooo0P00000k0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0103oool3000001H0
oooo0P00000C0?ooo`80000000<0oooo000000000000<`3oool3000001<0oooo1000000D0?ooo`<0
0000>P3oool200000980oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0
103oool3000001H0oooo0P00000D0?ooo`030000003oool00000008000005@3oool4000001L0oooo
1P00000A0?ooo`H000004P3oool5000001@0oooo00<000000?ooo`3oool08@3oool2000009<0oooo
00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0103oool4000001D0oooo0`00
000C0?ooo`030000003oool0oooo008000005P3oool800000100oooo2000000A0?ooo`@000004`3o
ool700000180oooo1000000E0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`040?ooo`@000005@3oool3
000001@0oooo00<000000?ooo`0000000P00000G0?ooo`D00000403oool5000001@0oooo0`00000D
0?ooo`L000004`3oool5000001@0oooo0`0000080?ooo`8000003@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`01
0?ooo`00<03oool00`000000oooo0?ooo`0M0?ooo`@000004`3oool00`000000oooo000000030000
01L0oooo1000000X0?ooo`8000005@3oool6000001@0oooo1@00000D0?ooo`D000001`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0000001L0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo01d0
oooo1000000C0?ooo`L00000603oool00`000000oooo0?ooo`0m0?ooo`80000000<0oooo00000000
00005P3oool3000001H0oooo100000070?ooo`030000003oool0oooo00/0oooo0`00000D0?ooo`03
0000003oool0000001P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00
<03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`000000
0P00001H0?ooo`80000000<0oooo0000003oool05P3oool3000001H0oooo100000070?ooo`030000
003oool0oooo00/0oooo1@00000C0?ooo`<00000603oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0040oooo000`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04`3o
ool3000005T0oooo0P00000J0?ooo`030000003oool0oooo01H0oooo0`0000080?ooo`030000003o
ool0oooo00/0oooo1000000C0?ooo`D00000503oool3000001P0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00@3o
ool00300oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo05H0oooo0`00000c0?ooo`8000002@3oool00`000000oooo0?ooo`0;0?ooo`@00000503oool4
000001D0oooo1000000D0?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000`0?ooo`800000803oool20000
01D0oooo0P00001F0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0<0?ooo`<000005@3oool3000001D0oooo1000000E0?ooo`<000005`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo0P0000030?ooo`00<03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01@0oooo0P00001D0?ooo`<00000?`3oool00`000000
oooo0?ooo`0;0?ooo`8000005`3oool2000001H0oooo0`00000E0?ooo`D00000503oool00`000000
oooo0000000H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00@3oool00300oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0D0?ooo`800000D`3oool200000400oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0E0?ooo`8000005`3oool2000001H0oooo
1000000E0?ooo`<000005@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo0040oooo
000`0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05@3oool200000540oooo0P00
00100?ooo`8000009P3oool00`000000oooo0?ooo`0F0?ooo`8000005P3oool3000001D0oooo1@00
000D0?ooo`<000003`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01D0oooo0P00001@0?ooo`800000@@3oool00`000000oooo0?ooo`0m
0?ooo`8000005`3oool2000001H0oooo1000000D0?ooo`D000003P3oool00`000000oooo0?ooo`01
0?ooo`00<03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01H0oooo0P00001>0?oo
o`800000@@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01D0oooo0P00000G0?oo
o`<000005@3oool4000000l0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3o
ool0803oool2000001P0oooo0P00001<0?ooo`800000@@3oool2000005P0oooo00<000000?ooo`3o
ool05P3oool2000001H0oooo0`00000@0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool05P3oool2000004/0oooo0P0000110?ooo`800000
L@3oool2000001L0oooo0P00000A0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool05`3oool2000004T0oooo0P0000120?ooo`800000L@3o
ool00`000000oooo0?ooo`0E0?ooo`<000004@3oool00`000000oooo0?ooo`010?ooo`00<03oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01P0oooo0P0000170?ooo`800000@P3oool2
000008X0oooo0P00000B0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0603oool2000004H0oooo00<000000?ooo`3oool0@@3oool20000
08/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo0P0000140?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`010?ooo`007`3oool01P3ogi`0B000
00000000000004RL0=ooo`/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0I0?oo
o`800000@@3oool2000004@0oooo0P00002P0?ooo`030000003oool0oooo0040oooo000O0?ooo`06
0?noM0000000M;oo0?ooo`3ogi`0B7Bo2`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo01T0oooo0P0000100?ooo`800000A03oool200000:40oooo00<000000?ooo`3oool00@3oool0
02@0oooo00<0okmd04RLg`3oool02@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01X0oooo0P00000n0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0X03oool00`00
0000oooo0?ooo`010?ooo`00903oool00`3ookl0M01d0;ooo`090?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool06`3oool2000003/0oooo0P0000160?ooo`030000003oool0oooo0:40
oooo00<000000?ooo`3oool00@3oool002@0oooo00<0oooO09a8001d_ol02@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo01`0oooo0P00000i0?ooo`800000AP3oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo0040oooo000T0?ooo`030?oo_`1d0000B9cO00T0oooo0`00
000S0?ooo`030000003oool0oooo01`0oooo0P00000g0?ooo`030000003oool0oooo04D0oooo0P00
002R0?ooo`<000000`3oool002@0oooo00<0okmd0000001d_ol02@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo01d0oooo0P00000d0?ooo`800000B03oool00`000000oooo0?ooo`2S
0?ooo`030000003oool0oooo0040oooo000Q0?ooo`060?oOg`3Oool0okmd0000000007@0_ooo2@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo0P00000a0?ooo`800000B@3o
ool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo0040oooo000Q0?ooo`050?oo_`1d0000
00000000B02Lgol02P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01l0oooo0P00
000^0?ooo`800000BP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo0040oooo000R
0?ooo`030=nLW02oool0oooo00/0oooo00<000000?ooo`3oool08`3oool200000280oooo00<00000
0?ooo`3oool0:P3oool2000004/0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`01
0?ooo`008P3oool00`3ogi`0M9cO0?ooo`0;0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool08@3oool2000002P0oooo0P00001<0?ooo`030000003oool0oooo0:H0oooo00<000000?oo
o`3oool00@3oool002<0oooo00D0_g@0000000000000000004RLg`080?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`800000C@3oool00`00
0000oooo0?ooo`2W0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`800000803oool3000004h0
oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool2000002H0oooo
0`00000L0?ooo`<00000C`3oool200000:X0oooo00<000000?ooo`3oool00@3oool00300oooo00<0
00000?ooo`3oool01@3oool2000001H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0V0?ooo`<000005`3oool300000580oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?oo
o`010?ooo`00<03oool00`000000oooo0?ooo`050?ooo`8000005P3oool2000000H0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooo`@000004@3oool400000080oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo00<00000
0?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0103oool3000001H0oooo0P0000060?oo
o`030000003oool0oooo00d0oooo0P00000M0?oooa8000000`3oool3000001D0oooo0`00000E0?oo
o`030000003oool0oooo01l0oooo0P00002/0?ooo`030000003oool0oooo0040oooo000`0?ooo`03
0000003oool0oooo00@0oooo0`00000F0?ooo`<000001@3oool00`000000oooo0?ooo`0>0?ooo`80
00005@3oool4000001L0oooo1@00000C0?ooo`D000004`3oool3000001D0oooo00<000000?ooo`3o
ool01`3oool200000:d0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0
103oool4000001D0oooo0`0000050?ooo`8000003`3oool2000001H0oooo2000000@0?ooo`L00000
4P3oool4000001D0oooo1000000D0?ooo`<000001P3oool2000000l0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`040?ooo`@000005@3o
ool4000000D0oooo00<000000?ooo`3oool03@3oool3000001L0oooo1@00000@0?ooo`@000005@3o
ool3000001H0oooo1000000D0?ooo`D000001@3oool2000000`0oooo00<000000?ooo`000000603o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0M0?ooo`@000001@3oool0
0`000000oooo0?ooo`0=0?ooo`@000005`3oool4000002P0oooo0P00000G0?ooo`<000005P3oool4
000000D0oooo0P00000=0?ooo`<000005@3oool00`000000oooo0000000H0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`00
0000oooo0?ooo`0M0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`@00000603oool00`00
0000oooo0?ooo`100?ooo`8000005P3oool4000000D0oooo0P00000=0?ooo`D00000503oool30000
01L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0040oooo000`0?ooo`030000003oool0oooo02H0oooo0P00000?0?ooo`800000G03oool00`000000
oooo0?ooo`0F0?ooo`<000001@3oool2000000h0oooo1000000D0?ooo`D00000503oool2000001T0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00<03oool2000002P0oooo
00<000000?ooo`3oool0P`3oool2000000L0oooo0P00000>0?ooo`<000005@3oool4000001D0oooo
0`00000G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00X0oooo0P0000030?ooo`00<03oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool01@3oool2000000l0oooo0P00
000E0?ooo`@000005@3oool5000001<0oooo00<000000?ooo`000000603oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`010?ooo`00<03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo08X0oooo0P00000?
0?ooo`8000005P3oool3000001H0oooo1000000D0?ooo`<000005@3oool010000000oooo0?ooo`00
000G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`010?ooo`00<03oool00`000000oooo0?ooo`0W0?ooo`800000RP3oool200000100oooo00<00000
0?ooo`3oool0503oool2000001L0oooo1000000D0?ooo`H000004`3oool3000001L0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0040oooo000`0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0Q`3oool2000002P0oooo00<000000?oo
o`3oool05P3oool3000001D0oooo1@00000C0?ooo`D00000503oool00`000000oooo0000000H0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo03l0oooo0P00000G0?ooo`@0
0000503oool4000001D0oooo0`00000G0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00@3oool00300oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool05P3oool3000001D0oooo0`00000E0?ooo`D00000
503oool00`000000oooo0000000@0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0Q03oool2000005X0oooo0P00000G0?ooo`8000005P3o
ool4000001D0oooo0`00000@0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0P`3oool2000005/0oooo00<000000?ooo`3oool05@3oool3
000001H0oooo0`00000E0?ooo`D000003`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0880oooo0P00001d0?ooo`8000005`3oool20000
01H0oooo1000000@0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01D0
oooo0P00000G0?ooo`<000004@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`0F0?ooo`8000004P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0Y@3oool2000001<0oooo00<0
00000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`01
0?ooo`00<03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo07`0oooo0P00002m0?oo
o`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0N`3oool200000;h0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`1j0?ooo`800000_`3oool00`000000oooo0?ooo`010?ooo`00<03o
ool2000002d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`2m0?ooo`8000000`3o
ool00300oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0;l0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`1g0?ooo`800000`@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo07D0oooo0P0000320?ooo`030000003oool0oooo0040
oooo000`0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0M03oool200000<<0oooo
00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0;@3oool2000007@0oooo0P00
00340?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0L@3oool200000<D0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`1`0?ooo`800000aP3oool00`000000oooo0?ooo`010?oo
o`00<03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0oooo0P00001`0?ooo`80
0000a`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0K@3oool200000<P0oooo00<000000?ooo`3oool0
0@3oool00300oooo00<000000?ooo`3oool01@3oool2000001H0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool00@3o
ool00300oooo00<000000?ooo`3oool01@3oool2000001H0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool00@3oool0
0300oooo00<000000?ooo`3oool0103oool3000001H0oooo0P00000A0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000
oooo0?ooo`040?ooo`<000005P3oool200000180oooo00@000000?ooo`3oool0oooo0P00000b0?oo
o`<00000503oool3000001D0oooo00D000000?ooo`3oool0oooo0000003<0?ooo`030000003oool0
oooo0040oooo000`0?ooo`030000003oool0oooo00@0oooo1000000E0?ooo`<000004@3oool00`00
0000oooo0?ooo`020?ooo`8000005@3oool4000001L0oooo1@00000B0?ooo`@00000503oool50000
01<0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000
oooo0?ooo`040?ooo`@000005@3oool300000140oooo00<000000?ooo`3oool00P3oool3000001D0
oooo1`00000A0?ooo`L000004P3oool5000001<0oooo1@00000C0?ooo`80000000<0oooo0000003o
ool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000`0?ooo`030000
003oool0oooo01d0oooo1000000A0?ooo`040000003oool0oooo0?ooo`@000005P3oool500000100
oooo1000000E0?ooo`@00000503oool5000001<0oooo1000000E0?ooo`030000003oool0000001P0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00@3oool00300oooo0P00000N0?ooo`@000004@3oool010000000oooo
0?ooo`3oool5000001H0oooo0`00000Y0?ooo`8000005P3oool5000001@0oooo1@00000D0?ooo`<0
0000603oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0203oool2000000<0oooo000`0?ooo`030000003oool0oooo03<0oooo00@000000?ooo`3oool0
oooo0`00000I0?ooo`030000003oool0oooo03l0oooo1000000D0?ooo`D00000503oool5000001<0
oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0<`3oool01@000000
oooo0?ooo`3oool0000005`0oooo00@000000?ooo`00000000005@3oool3000001H0oooo1000000D
0?ooo`<00000603oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo01<0oooo0`00000F0?ooo`@00000503oool5000001@0oooo00<000000?oo
o`000000603oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0040oooo000`0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01H0oooo0`00000E0?ooo`@000005@3oool3000001L0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0d0?ooo`800000
GP3oool00`000000oooo0?ooo`0]0?ooo`8000005`3oool3000001D0oooo1@00000D0?ooo`800000
6@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0F0?ooo`8000005P3o
ool4000001D0oooo0`00000G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0
oooo03D0oooo0P00001K0?ooo`030000003oool0oooo04L0oooo0P00000G0?ooo`<000005@3oool5
000001<0oooo0`00000H0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0F0?ooo`8000005P3oool40000
01@0oooo1000000D0?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`0f0?ooo`800000E`3oool2000006<0
oooo0P00000F0?ooo`@00000503oool4000001D0oooo0`00000H0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool05@3oool3000001D0oooo
0`00000E0?ooo`D00000503oool00`000000oooo0000000A0?ooo`030000003oool0oooo0040oooo
000`0?ooo`030000003oool0oooo03L0oooo0P00001D0?ooo`030000003oool0oooo07/0oooo0P00
000G0?ooo`8000005P3oool4000001D0oooo0`00000A0?ooo`030000003oool0oooo0040oooo000`
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo01H0oooo0P00000F0?ooo`<000005@3oool500000100oooo00<00000
0?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0>03oool200000540oooo00<000000?oo
o`3oool0U@3oool2000001L0oooo0P00000F0?ooo`@000004@3oool00`000000oooo0?ooo`010?oo
o`00<03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo04d0oooo0P00002H0?ooo`03
0000003oool0oooo01D0oooo0`00000F0?ooo`<000004P3oool00`000000oooo0?ooo`010?ooo`00
<03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
/03oool2000001L0oooo0P00000C0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003o
ool0oooo03X0oooo0P00001;0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool05@3o
ool3000001<0oooo00<000000?ooo`3oool00@3oool00300oooo0P00000l0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0bP3oool2000001<0oooo0P0000030?ooo`00<03oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo04D0oooo0P00003=0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0?03oool2000004D0
oooo0P00003T0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo03d0oooo
0P0000130?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool00@3oool00300oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0o0?ooo`800000i`3oool00`000000oooo0?oo
o`010?ooo`00<03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03d0oooo0P00003X
0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0>P3oool200000>X0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0h0?ooo`800000j`3oool00`000000oooo0?ooo`010?ooo`00
<03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03D0oooo0P00003]0?ooo`030000
003oool0oooo0040oooo000`0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0<P3o
ool300000>h0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0300oooo0P00003`0?ooo`030000003oool0
oooo0040oooo000`0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0]0?ooo`800000lP3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool09P3oool2000002`0
oooo0P00003c0?ooo`030000003oool0oooo0040oooo000P0?ooo`050?oog`2LB000000000000000
M;l02`3oool00`000000oooo0?ooo`050?ooo`8000005P3oool00`000000oooo0?ooo`0W0?ooo`80
0000:@3oool200000?D0oooo00<000000?ooo`3oool00@3oool00200oooo00L0gia8001d_`3oool0
oono07@00000B9`0gooo00T0oooo00<000000?ooo`3oool0103oool3000001H0oooo0P00000F0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0903oool300000?H0oooo00<000000?oo
o`3oool00@3oool001l0oooo00<0oooO09a8001d_ol00P3oool00`3ogi`0B00004RLg`090?ooo`03
0000003oool0oooo00@0oooo0`00000F0?ooo`8000005P3oool2000001<0oooo0`00000M0?ooo`80
00000P3oool300000100oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`010?ooo`00
7`3oool00`3ookl0M00007Boo`030?ooo`030;md000007@0_ooo00P0oooo00<000000?ooo`3oool0
103oool3000001H0oooo0`00000E0?ooo`<000005@3oool4000001L0oooo1P00000B0?ooo`<00000
5@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0040oooo000O0?ooo`030?oog`2L
B00007Bo00<0oooo00<0gia80000B02Lgol0203oool3000000@0oooo1000000E0?ooo`<000005P3o
ool2000001H0oooo1`00000A0?ooo`L000004P3oool4000001@0oooo0`00000H0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool01P3oool3000000<0oooo000P0?ooo`030;md000007@0
_ooo0080oooo00<0gia80000B02Lgol0203oool00`000000oooo0?ooo`040?ooo`@000005@3oool4
000001D0oooo0`00000F0?ooo`L000003P3oool900000140oooo1P00000C0?ooo`<000005@3oool0
0`000000oooo0000000G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool0
0200oooo00P0okmd00000018W=l0oooo0?oog`2LB00004RL0=ooo`P0oooo00<000000?ooo`3oool0
7@3oool4000001D0oooo1000000F0?ooo`@0000000<0oooo0000000000003P00000I0?ooo`@00000
503oool5000001@0oooo0`00000G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0@3oool00200oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`080?ooo`030000003o
ool0oooo01d0oooo0P00000G0?ooo`D000005`3oool2000002T0oooo0`00000F0?ooo`@00000503o
ool5000001<0oooo00<000000?ooo`000000603oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`008@3oool0
0`3ookl0M000001d_`0<0?ooo`030000003oool0oooo03L0oooo0`00000I0?ooo`030000003oool0
oooo02H0oooo0P00000G0?ooo`<000005P3oool4000001@0oooo0`00000G0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0040oooo000R0?ooo`030?oOW0180000B9cO00/0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`1K0?ooo`8000005P3oool4000001@0oooo1@00000D0?ooo`030000003oool00000
01L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0040oooo000S0?ooo`040?oog`2LB000001d0;ooo`T0oooo00<000000?ooo`3oool0U03oool00`00
0000oooo0?ooo`0F0?ooo`<000005@3oool4000001D0oooo0`00000G0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`010?ooo`009@3oool0103ookl0
M00000000018W=l70?ooo`030000003oool0oooo0:`0oooo0P00000F0?ooo`@000005@3oool50000
01<0oooo00<000000?ooo`000000603oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0040oooo000`0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool05@3oool3000001H0
oooo1000000D0?ooo`<000005`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0040
oooo000`0?ooo`030000003oool0oooo0<<0oooo0P00000G0?ooo`@00000503oool5000001@0oooo
00<000000?ooo`0000005`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?oo
o`330?ooo`030000003oool0oooo01H0oooo0`00000E0?ooo`@000005@3oool3000001L0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0f`3oool2000001L0oooo0`00000E
0?ooo`D000004`3oool00`000000oooo0000000H0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`3K0?oo
o`030000003oool0oooo01H0oooo0P00000F0?ooo`@00000503oool3000001L0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0040oooo000`0?ooo`03
0000003oool0oooo0?<0oooo0P00000G0?ooo`<00000503oool6000001<0oooo00<000000?ooo`00
0000603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000
003oool0oooo0?<0oooo00<000000?ooo`3oool05P3oool2000001D0oooo1@00000D0?ooo`<00000
5`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003o
ool0oooo0?l0oooo303oool2000001H0oooo1000000D0?ooo`D00000503oool00`000000oooo0000
000B0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo0?l0oooo303oool0
0`000000oooo0?ooo`0E0?ooo`<000005@3oool4000001D0oooo0`00000B0?ooo`030000003oool0
oooo0040oooo000`0?ooo`030000003oool0oooo0?l0oooo8`3oool2000001L0oooo0`00000E0?oo
o`D000004@3oool00`000000oooo0?ooo`010?ooo`00<03oool200000?l0oooo903oool00`000000
oooo0?ooo`0F0?ooo`8000005P3oool400000140oooo0P0000030?ooo`00<03oool00`000000oooo
0?ooo`3o0?oooc/0oooo0P00000G0?ooo`<000004`3oool00`000000oooo0?ooo`010?ooo`00<03o
ool00`000000oooo0?ooo`3o0?oooc/0oooo00<000000?ooo`3oool05P3oool2000001@0oooo00<0
00000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0o`3ooomC0?ooo`8000005@3oool0
0`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`3o0?oooe<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`3o0?ooofX0
oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`030000
003oool0oooo0040oooo000`0?ooo`030000003oool0oooo0?l0ooooJP3oool00`000000oooo0?oo
o`010?ooo`00<03oool00`000000oooo0?ooo`3o0?ooofX0oooo00<000000?ooo`3oool00@3oool0
0300oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`030000003oool0oooo0040oooo000`0?ooo`03
0000003oool0oooo0?l0ooooJP3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo
0?ooo`3o0?ooofX0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0o`3o
oomZ0?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo0?l0ooooJP3oool0
0`000000oooo0?ooo`010?ooo`00<03oool00`000000oooo0?ooo`3o0?ooofX0oooo00<000000?oo
o`3oool00@3oool00300oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`010?ooo`00<03ooooo000006h000000`3oool00?l0ooooX@3oool0
0?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool0
0?l0ooooX@3oool00?l0ooooX@3oool00?l0ooooX@3oool00?l0oooo8@3oool00`3ookl0M01d0;oo
o`1m0?ooo`00o`3ooolR0?ooo`030?oOW01807@0_ooo07`0oooo001n0?ooo`030=nLB00000000000
00H0000000@0B9cO0?ooo`3oool0okmd0P0000000`0004P0W=oo0?ooo`020?ooo`070?noM0000000
001809cOo`3oool0_g@0001d_`020?ooo`060?noM0000000001d0;ooo`3ogi`0B0000P0000001@1d
_ol0gia800000000B9`0gooo00h0oooo00<0gia80018W03Oool01`3oool01@3o_g@0000000000000
04P0W=oo00<0oooo00T0okmd0000000007@0_ooo0?ooo`3o_g@000000000B02Lgol00P3oool01@3O
W4P00000000000000000M;oo0080oooo00<0_g@0001d_`3oool0103oool00`2oM00007Bo0?ooo`04
0?ooo`090?oOW018000000000000001d_ol0gia800000000B9`0gooo00@0oooo00`0gia80018W03O
ool0oooo0?noM00007@0_ooo0?ooo`3ooml0W4P00000001d_ol20?ooo`050?noM000000000000000
B02Lgol00`3oool0203ookl0M0000000000007@0_ooo0=nLB0000000B9cO0P3oool01@3OW4P00000
000000000000M;oo0080oooo00@0okmd0000000007@0_ooo0P3oool00`2oM000M;oo0?ooo`060?oo
o`080=nLB000000000000000M02ookl0M00000000000M;lA0?ooo`030=nLB0000000000000<00000
00<0B9cO0?ooo`3oool0D`3oool007l0oooo00@0oooO09a80000B9`0gooo0`3oool02P3OW4P004RL
0=ooo`3ogi`0B01809cOo`3oool0omnL04P00000M;l20?ooo`0F0?noM00004P0W=oO09adW03Oool0
okmd0000M02oool0oooo0;md0000M;l0oono07Ad_`2oM00004RL0=ooo`3oool0_g@007AdM00007@0
_mnL09boo`h0oooo00<0okmd00000018W=l01P3oool01`3ogi`0B01809cOo`3oool0omnL04P00000
M;l00P3oool03@3ogi`0B01d0;oo_`2LW=l0oooo0?noM00004P0W=oO09adW03Oool0omnL04P0001d
_ol00P3oool01P2oM00007Bo0?ooo`3o_g@0001d0;ooo`@0oooo00<0okmd0000M02oool0103oool0
2@2oM00004RL0=ooo`3oool0_g@007AdM00007@0_mnL09boo`040?ooo`070?noM00004P0W=oo0?oo
o`3ookl0M00007Boo`020?ooo`0;0;md0000M;l0_gAd0;ooo`3ogi`0B01809cOo`3oool0omnL04P0
0000M;l00P3oool0303OW4P004RL0=ooo`3ookl0M01d0;noM00007@0W9ad09cOo`3ogi`0B00007Bo
o`80oooo00/0_g@0001d_`3oool0omnL04P0M02ookl0W9cO0?ooo`3ogi`0B00007Boo`060?ooo`0:
0?noM0000000M;oo0?ooo`3ookl0M0000000B02Lgol0okmd07Booa40oooo00<0okmd001d_`3oool0
0P3oool00`2oM7@0_ooo0?ooo`1C0?ooo`00P03oool00`3o_g@0001809cOo`040?ooo`050=nLM02L
gol0gia80018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0oono07@0001d_ol00P3oool01P3o
gi`0B01809cOo`3ooml0W4P004RLg`80oooo00<0_g@0001d_`3oool00P3oool00`2oM000000007Bo
o`0?0?ooo`040?oOW0180000B4Q807Boo`D0oooo00<0gia80018W03Oool00P3oool0303ogi`0B000
04RLg`3oool0oono07@0001d_ol0gibL0;ooo`3ookl0M00007Boo`80oooo00<0gia80018W03Oool0
0`3oool01@3OW9`0_ooo0?oOW0180000M;oo00@0oooo00<0omnL04P0001d_ol0103oool00`2oM000
07Bo0?ooo`020?ooo`030;md00000000M;oo00D0oooo00L0oono07@00018W=l0oooo0?oog`2LB000
07Bo0080oooo00L0gia80018W03Oool0oooo0=nLB000B9`0gooo0080oooo00H0omnL04P00018W=l0
oooo0;md0000M;l20?ooo`080?oo_`1dB4P0B01809cOo`3oool0gia80018W03Oool30?ooo`070=nL
W02oool0oono07@0001d_ol0gibL0;ooo`090?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@0
001d_ol01@3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo0080oooo00<0okmd001d
_`3oool0E`3oool00800oooo00<0omnL04P0001d_ol01P3oool00`3o_g@0001d0;ooo`030?ooo`06
0=nLB00007@0_ooo0?ooo`2oM00007Bo0P3oool01P3ooml0W4P00018M02o_i`0B01809cOo`80oooo
00<0okmd0000M02oool00P3oool00`3ookl0M00004RLg`0?0?ooo`050?oo_`1d0000B9cO0;mdB02L
gol0103oool00`3o_g@0001d0;ooo`030?ooo`060=nLB00007@0_ooo0?ooo`2oM000B9cO0`3oool0
1@2oM00007Bo0?ooo`3oool0okmd00<0000000P0B9cO0?ooo`3oool0oooo0?oog`2LB00004RL0=oo
o`<0oooo00@0oooO09a80000B9`0gooo0`3oool00`3o_g@0001d0;ooo`020?ooo`030?oo_`1d0000
B9cO00D0oooo0100oooO09a80000B9`0gooo0?ooo`3OW4P0000007Boo`3oool0omnL04P0B02Lgol0
oooo0?noM00007@0_ooo0`3oool01P3OW4P0001d0;ooo`3o_g@004RL0=ooo`80oooo00D0okmd0000
0018W=l0oooo0?noM0030000000304RLg`3oool0oooo0080oooo00<0_g@004RLg`3oool02P3oool0
0`3OW4P0001d0;ooo`030?ooo`030;md000007@0_ooo01@0oooo00<0okmd001d_`3oool0EP3oool0
0800oooo00<0oooO09a80000M;l01P3oool00`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004RL0=ooo`020?ooo`050=nLB000B7@0M4P00000M02oool00P3oool00`3ookl0M000
07Boo`030?ooo`040;md0000B9`0gooO09a800P0000000<0B9cO0?ooo`3oool00P3oool01P3ooml0
W4P004RLg`3ookl0M4RL0=ooo`<0oooo00<0oono07@0001d_ol00`3oool01`3ogi`0B01809cOo`3o
ool0gia80018W03Oool00P3oool02`3OW4P004RL0=ooo`3oool0oono07@0B02Lgol0oooo0=nLB000
0000B9cO0080oooo00<0_g@004QdM01dW=l0103oool00`2oM000B7Ad07BLg`030?ooo`030?oo_`1d
0000M;oo00<0oooo00<0_g@00018W03Oool01@3oool03`3OW4P004Q807BLg`3oool0okmd0000M01d
M7@0_ooo0?oog`2LB000B9cO0?ooo`3ookl0M00007Boo`030?ooo`060?oOW01804P0W=oo0?oo_`1d
0000M;oo0P3oool02`3ooml0W4P0001d_`3oool0oono07@0B02Lgol0oooo0=nLB0000000B9cO0080
oooo00<0gia80018W03Oool02P3oool00`3ogi`0B00007Boo`030?ooo`040=nLB000B4P0B4RL0=oo
oa@0oooo00<0okmd04RLg`3oool0E@3oool00840oooo00<0_g@00018W03Oool01P3oool00`3OW4P0
001d0;ooo`020?ooo`070?oo_`1d0000M;oo0?ooo`3ogi`0B01809cOo`020?ooo`050?noM00007@0
_ooo0;md001d_ol00`3oool00`3o_g@0001d0;ooo`020?ooo`030=nLB00007@0_ooo00h0oooo00H0
oooO09a80000M;l0oooo0?noM000M;l40?ooo`030=nLB00007@0_ooo0080oooo00L0oono07@0001d
_ol0oooo0?oOW01807@0_ooo0080oooo00<0omnL04P0B02Lgol00P3oool0303o_g@004RL0=ooo`3o
ool0oono07@00018W=l0oooo0?noM000B9`0_ia807Boo`<0oooo00@0okmd0018W02oW4P0M;oo0`3o
ool00`3o_g@0001d0;ooo`020?ooo`030=nLB00007@0_ooo00D0oooo0100okmd0000M02LW7@0W=oo
0?oo_`1d0000M;no07Ad_`3oool0_g@00018W03Oool0oooo0=nLB00007@0_ooo0P3oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool00P3oool03`3OW4P0001d0;ooo`3oool0okmd0018W03Oool0
oooo0?oo_`1d0000B9cO0?ooo`3ogi`0B01d0;ooo`0;0?ooo`030;md0000B9`0gooo0080oooo00@0
gia80018W03O_g@007Bo5@3oool00`3OW4P0B9cO0?ooo`1D0?ooo`00P@3oool00`3o_g@0001809cO
o`070?ooo`0;0;md000007@0_ooo0?ooo`3o_g@0001d0;ooo`3oool0oooO09a80018W=l00P3oool0
1P3ookl0M00007Boo`3oool0_gA809cOo`<0oooo00L0gia80000M02oool0oooo0;md000004P0W=oo
00l0oooo00H0_g@00018W03Oool0oooo0;md001d_ol40?ooo`0;0;md000007@0_ooo0?ooo`3o_g@0
001d0;ooo`3oool0oono07@0001d_ol00P3oool00`3ooml0W4P004RLg`030?ooo`0M0=nLB00007@0
_ooo0?ooo`3OW4P004RL0=ooo`3ookl0M01809cOo`2oM000M7Ad0018W03Oool0oono07@0B02Lgol0
_g@007AdM000B9`0gooo0?ooo`3OW4P0001d0;ooo`3oool0_g@00000B02Lgol01@3oool0303ookl0
M01809cOg`2LB4P0W=oO09a80018W=l0okmd001d_`3o_g@0001d0;ooo`80oooo00L0_g@00000M02o
ool0oooo0?noM00007@0_ooo0080oooo00L0gia80000M02oool0oooo0;md000004P0W=oo0080oooo
00X0gia80000M02oool0oooo0=nLB000B9`0gooo0?oo_`1d0000M;oo2`3oool00`3ooml0W4P0001d
_`020?ooo`050;md0000B9`0gooo0;md0000M;l00P3oool00`3ooml0W4P0000000070000000304RL
g`3oool0oooo00H0oooo00<0_g@007Boo`3oool0D`3oool00840oooo00<0oono07@0001d_ol0203o
ool0203o_g@00000000000000000M;oo0?ooo`3ookl0M0000`0000001P1d_ol0oooo0;md0000M;l0
oono07@00080000000T007Bo0?ooo`3oool0omnL04P000000000B9bL07@00018W=l03`3oool01`3O
W4P0001d0;ooo`3oool0oooO09a8B02Lgol0103oool01@3o_g@00000000000000000M;oo00<0oooo
00D0_g@004RLg`3oool0oono07@000030000000507Boo`3oool0oooo0?oOW01800000P000000401d
_ol0omnL04P000000000M;oo0?ooo`2oM000001d0;oOW0180000000007Boo`3oool0_g@00000M02o
ool20?ooo`060?oOW0180000000004RLW01d0000B9cO103oool03@3ookl0M00000000018W=l0oooO
09a800000000B9cO0?ooo`3o_g@000000018W03Oool00`3oool01@3o_g@00000000000000000M;oo
00@0oooo00H0omnL04P000000000B9bo09a80018W=l30?ooo`050?oOW018000000000000001d_ol0
0P3oool00`2oM000B9cO0?ooo`0<0?ooo`050=nLB000000000000000B02Lgol0603oool00`3ogi`0
B01d0;ooo`1C0?ooo`00P@3oool00`3ooml0W4P0001d_`0@0?ooo`030?noM00007@0_ooo0080oooo
00<0okmd0018W03Oool06`3oool00`3o_g@0001809cOo`020?ooo`030?oOW01807@0_ooo00/0oooo
00<0gia80018W03Oool00P3oool00`3o_g@0001d0;ooo`100?ooo`030;md0000M;l0oooo00T0oooo
00<0gia80018W03Oool0:@3oool00`3ooml0W4P007Boo`1C0?ooo`00PP3oool00`3OW4P004RL0=oo
o`0@0?ooo`070=nLM02Lgol0oooo0?ooo`3ogi`0B01809cOo`0K0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd001d_`3oool02P3oool00`3ogi`0B01d0;ooo`030?ooo`030=nLM02Lgol0oooo03l0
oooo00<0okmd0000M02oool02@3oool00`3ogi`0B01d0;ooo`0Y0?ooo`030?oo_`1d0000B9cO05<0
oooo00220?ooo`030?noM0000000M;oo01@0oooo00<0oooO09a80018W=l06`3oool00`3ogi`0B000
04RLg`040?ooo`030;md0000M;l0oooo00T0oooo00<0oooO09a8001d_ol0A@3oool00`3ogi`0B018
09cOo`090?ooo`030?oog`2LB000M;oo02D0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo
05<0oooo00210?ooo`060;md0000000000000000000004P0W=oo4`3oool00`2oM00007Bo0?ooo`0I
0?ooo`080;md0000000000000000000007@0_ooo0?ooo`3OW4P2000000030000M02oool0oooo00P0
oooo00<0gia804RLg`3oool0A03oool00`3ooml0W4P004RLg`0:0?ooo`030=nLB018W=l0oooo02D0
oooo00D0omnL04P000000000000007Boo`1D0?ooo`00V03oool01@3ooml0W4P00000000007@0_ooo
02`0oooo00@0oooO09a80000000007BoA03oool0103ookl0M00000000000M;l80?ooo`040?oog`2L
B0000000001d_gl0oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40oooo003o0?oooj40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 415.125}, {644.625, 0}} -> {-0.661726, -0.755825, \
0.0174242, 0.0174242}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[trajectory[2, {0.5, 0.5}, 200]], {t, 0, 10}, 
        PlotRange \[Rule] {Automatic, {0, 3}}, 
        PlotStyle \[Rule] {{}, Dashing[{0.02, 0.02}]}, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<population density\>"}, 
        PlotLegend \[Rule] {"\<prey\>", "\<predator\>"}, 
        LegendPosition \[Rule] {\(-0.75\), 0.4}, 
        LegendSize \[Rule] {0.7, 0.2}, 
        LegendShadow \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 0.206011 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -5 -15.6875 ]
[.21429 -0.0125 5 0 ]
[.40476 -0.0125 -5 -15.6875 ]
[.40476 -0.0125 5 0 ]
[.59524 -0.0125 -5.125 -15.6875 ]
[.59524 -0.0125 5.125 0 ]
[.78571 -0.0125 -5 -15.6875 ]
[.78571 -0.0125 5 0 ]
[.97619 -0.0125 -8 -15.6875 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -3.78125 -31.375 ]
[.5 -0.0125 3.78125 -15.6875 ]
[-0.0125 .10301 -19 -7.84375 ]
[-0.0125 .10301 0 7.84375 ]
[-0.0125 .20601 -10 -7.84375 ]
[-0.0125 .20601 0 7.84375 ]
[-0.0125 .30902 -19 -7.84375 ]
[-0.0125 .30902 0 7.84375 ]
[-0.0125 .41202 -10 -7.84375 ]
[-0.0125 .41202 0 7.84375 ]
[-0.0125 .51503 -19 -7.84375 ]
[-0.0125 .51503 0 7.84375 ]
[-0.0125 .61803 -10 -7.84375 ]
[-0.0125 .61803 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -47.0313 ]
[-0.01875 .30902 -19 47.0313 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -66.125 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -64.7813 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
66.563 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
gsave
-0.0125 .10301 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .20601 m
.00625 .20601 L
s
gsave
-0.0125 .20601 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .41202 m
.00625 .41202 L
s
gsave
-0.0125 .41202 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .51503 m
.00625 .51503 L
s
gsave
-0.0125 .51503 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -134.875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
108.031 11.8438 translate
90 rotate
-108.031 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(population) show
119.250 15.813 moveto
(density) show
153.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10301 m
.04262 .11471 L
.06244 .13049 L
.10458 .17726 L
.14264 .23706 L
.18314 .31746 L
.20184 .35582 L
.21169 .3741 L
.22214 .39028 L
.22741 .39661 L
.23021 .39934 L
.23322 .40173 L
.23463 .40263 L
.23597 .40336 L
.23728 .40394 L
.2385 .40436 L
.23964 .40465 L
.24086 .40484 L
.24156 .40489 L
.24222 .4049 L
.24344 .40482 L
.24461 .40462 L
.24589 .40426 L
.24654 .40402 L
.24723 .40372 L
.24848 .40307 L
.25091 .40137 L
.25312 .39931 L
.25849 .39226 L
.26358 .38287 L
.27324 .35824 L
.28349 .32411 L
.30191 .25408 L
.32161 .18736 L
.33966 .14365 L
.34909 .12731 L
.35901 .11405 L
.36897 .1041 L
.37458 .09973 L
.37987 .0963 L
.3848 .09365 L
.39014 .0913 L
.39459 .08973 L
.39948 .08838 L
.40477 .0873 L
.40767 .08687 L
.41038 .08657 L
.41168 .08646 L
.41291 .08637 L
.41403 .08631 L
Mistroke
.41522 .08625 L
.41651 .08622 L
.41771 .0862 L
.41845 .08619 L
.41914 .0862 L
.42043 .08622 L
.42159 .08625 L
.42284 .0863 L
.42402 .08636 L
.4251 .08643 L
.42773 .08665 L
.43022 .08692 L
.43517 .08764 L
.44055 .08869 L
.45015 .0912 L
.45903 .09423 L
.47773 .10281 L
.49835 .11573 L
.51773 .13138 L
.5386 .15237 L
.5798 .20798 L
.61947 .28026 L
.65763 .35873 L
.66775 .3771 L
.67728 .3914 L
.68256 .3975 L
.68534 .40006 L
.68827 .40223 L
.69075 .40359 L
.69215 .40415 L
.69347 .40454 L
.69467 .40478 L
.69577 .40489 L
.69704 .40488 L
.69825 .40475 L
.69938 .40451 L
.70061 .40411 L
.70176 .40361 L
.70283 .40304 L
.70529 .40129 L
.70788 .39881 L
.71278 .39228 L
.71813 .38234 L
.72767 .35784 L
.73654 .32858 L
.75526 .25768 L
.77556 .18836 L
.78665 .15927 L
.79688 .13816 L
.80666 .12252 L
Mistroke
.81702 .10998 L
.82644 .10152 L
.83164 .09786 L
.83657 .09494 L
.84114 .09268 L
.84613 .09066 L
.85034 .08929 L
.85488 .08812 L
.85765 .08755 L
.8602 .08712 L
.86259 .0868 L
.86521 .08652 L
.86634 .08643 L
.86756 .08635 L
.86871 .08629 L
.86976 .08625 L
.87094 .08621 L
.87223 .0862 L
.87344 .0862 L
.87457 .08621 L
.87577 .08624 L
.87706 .08629 L
.87828 .08636 L
.8794 .08643 L
.882 .08665 L
.88474 .08695 L
.8899 .08772 L
.89554 .08884 L
.90583 .09162 L
.91517 .09494 L
.93612 .10508 L
.95532 .11768 L
.97613 .13515 L
.97619 .13521 L
Mfstroke
[ .02 .02 ] 0 setdash
.02381 .10301 m
.04262 .08546 L
.06244 .07216 L
.07286 .06694 L
.08255 .06304 L
.0932 .05974 L
.09916 .05832 L
.10458 .05729 L
.10941 .05657 L
.11206 .05626 L
.11454 .05603 L
.11664 .05587 L
.11891 .05574 L
.1202 .05569 L
.12142 .05565 L
.12253 .05563 L
.12373 .05562 L
.1244 .05561 L
.12514 .05562 L
.12583 .05563 L
.12646 .05564 L
.12767 .05567 L
.12894 .05571 L
.13031 .05578 L
.13159 .05586 L
.1345 .0561 L
.13703 .05637 L
.13933 .05668 L
.14451 .05758 L
.14932 .05869 L
.15442 .06017 L
.16359 .06376 L
.17346 .06918 L
.18435 .07753 L
.19445 .08812 L
.2037 .10097 L
.21386 .11952 L
.22456 .14543 L
.2341 .17535 L
.2443 .21546 L
.26267 .30838 L
.28258 .42044 L
.28803 .44731 L
.29381 .47172 L
.29874 .48852 L
.30152 .49617 L
.30416 .50217 L
.30665 .50665 L
.30797 .50857 L
.30937 .51026 L
Mistroke
.31066 .51151 L
.31183 .51239 L
.31301 .51302 L
.31412 .51339 L
.31543 .51356 L
.31608 .51354 L
.3168 .51343 L
.31808 .51302 L
.31927 .51241 L
.32067 .5114 L
.32195 .51021 L
.32482 .50668 L
.32958 .49839 L
.33475 .48638 L
.34415 .45845 L
.38498 .30771 L
.40527 .24198 L
.4243 .1919 L
.4425 .15401 L
.4621 .12264 L
.48218 .09874 L
.4924 .08919 L
.50329 .08065 L
.51366 .07392 L
.52308 .06885 L
.53201 .06487 L
.54145 .06149 L
.54622 .06008 L
.55146 .05876 L
.55628 .05775 L
.56068 .057 L
.56587 .05632 L
.56873 .05604 L
.57004 .05593 L
.57144 .05584 L
.57262 .05577 L
.57394 .05571 L
.57513 .05567 L
.57625 .05564 L
.57756 .05562 L
.57877 .05561 L
.5794 .05562 L
.58009 .05563 L
.58082 .05564 L
.58149 .05565 L
.58276 .05569 L
.58411 .05576 L
.58653 .05591 L
.58913 .05613 L
.59199 .05646 L
Mistroke
.59712 .05725 L
.60192 .05826 L
.61087 .06091 L
.6159 .06288 L
.6205 .06503 L
.63036 .07093 L
.6395 .07831 L
.64954 .0891 L
.66023 .10461 L
.67053 .12464 L
.68166 .1535 L
.69217 .18916 L
.70183 .23003 L
.72227 .33863 L
.73225 .39553 L
.74134 .44268 L
.74585 .46277 L
.75076 .48127 L
.75539 .4951 L
.75968 .50451 L
.76202 .50823 L
.76421 .51083 L
.76547 .51192 L
.76662 .51268 L
.76788 .51324 L
.76852 .51342 L
.76921 .51353 L
.7699 .51356 L
.77054 .51352 L
.77175 .51325 L
.77305 .5127 L
.77378 .51227 L
.77446 .5118 L
.77682 .50959 L
.77933 .50637 L
.78427 .49758 L
.78878 .48707 L
.79892 .45686 L
.81724 .38987 L
.83789 .31264 L
.85702 .24955 L
.87674 .19629 L
.89528 .15682 L
.91586 .12339 L
.93449 .10079 L
.95462 .08282 L
.97311 .07103 L
.97619 .06943 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.142857 0.499493 0.47619 0.594731 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0113379 0.113379 [
[ 0 0 0 0 ]
[ 1 .28571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .28571 L
0 .28571 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0204082 0.35119 0.133787 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ .13333 .13333 ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .0771 -61 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(predator) show
106.250 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.151927 0.35119 0.265306 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20862 -61 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(prey) show
85.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{376.438, 232.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008d0001GB000`400?l00000o`00003oo`3ooooo
0?ooocH0oooo003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo
003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0
oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0oooo=P3oool0
0?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0oooo=P3oool00?l0ooooo`3o
oolf0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooocD0oooo00@0okmd0000000004P0W=ooo03oool0
0?l0oooo=@3oool01@3o_g@0001809cOg`2LM9`0gooo0?/0oooo003o0?ooocD0oooo00<0oono07@0
001d_ol0o@3oool00?l0oooo=P3oool00`2oM00007Bo0?ooo`3l0?ooo`00o`3ooolf0?ooo`030=nL
B000B9`0gooo0?`0oooo003o0?ooocH0oooo00<0omnL04P0B02Lgol0o03oool00?l0oooo=P3oool0
0`3ooml0W4P004RLg`3l0?ooo`00o`3ooole0?ooo`030?oo_`1d000000000080000000<0M;oo0?oo
o`3oool0n03oool00?l0oooo=`3oool00`3o_g@0001d0;ooo`3k0?ooo`00o`3ooolh0?ooo`030=nL
M02Lgol0oooo0?X0oooo003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?oo
ocH0oooo003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo003o
0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0oooo
=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0oooo=P3oool006H0
oooo00@0_g@0000000000000M;ooC03oool00`3OW4P00000000000030000000304RLg`3oool0oooo
04d0oooo00<0oooO09a80018W=l0C@3oool01@3ooml0W4P000000000000007Bo04h0oooo00H0oono
07@00000000000000018W03Ooom60?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0
0`3oool0102oM00000000000001d_olZ0?ooo`00I@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RL
gd`0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`1>0?ooo`030=nLB000B9`0gooo
04`0oooo00L0gia8001d_`3oool0oono07@00000B9`0gooo04/0oooo00<0oono07@00018W=l00P3o
ool00`3OW4P0001d0;ooo`170?ooo`030?noM0000000M;oo00D0oooo00H0gia8001d_`3oool0omnL
04P00018W=lY0?ooo`00I03oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo04`0oooo
00<0okmd001d_`3oool0DP3oool00`3ogi`0B01809cOo`1;0?ooo`030?oog`2LB000M;oo0080oooo
00<0omnL04P00018W=l0B`3oool00`3o_g@004RL0=ooo`030?ooo`030;md0018W=l0oooo04H0oooo
00<0oooO09a80000M;l0103oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo02P0oooo
001T0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0goooC03oool00`3o_g@007Bo
0?ooo`1=0?ooo`030?noM0000000000000@0000000<004RL0=ooo`3oool0B03oool00`3ookl0M000
07Boo`030?ooo`030;md000007@0_ooo04X0oooo00<0okmd0018W03Oool00`3oool00`2oM00007Bo
0?ooo`170?ooo`030=nLB000B9`0gooo00<0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P0
0018W03OoolW0?ooo`00I03oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo04d0oooo
00<0okmd04RLg`3oool0C03oool00`3ooml0W4Q809cOo`020?ooo`030;md0000M;l0oooo04X0oooo
00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`1:0?ooo`030?oog`2LB000M;oo0080oooo
00<0oono07@00018W=l0B03oool00`3ogi`0B01809cOo`030?ooo`030?oog`2LB00007Bo00<0oooo
00<0gia80000B02Lgol09`3oool006D0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RL
g`1>0?ooo`030=nLB018W=l0oooo04`0oooo00L0oono07@0M02oool0oooo0?noM000B9`0gooo04/0
oooo00<0_g@00000M02oool00P3oool00`3OW4P0001809cOo`1<0?ooo`060;md000004P0W=oO09a8
000007@0_oooB03oool00`3ookl0M00007Boo`040?ooo`030;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l09`3oool006D0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`1?0?oo
o`030;md001d_ol0oooo04`0oooo00H0omnL04Q8W03Oool0omnL04P0B02Lgom;0?ooo`080?noM000
0000B9cO0?ooo`3ooml0W4P00018W03Ooom=0?ooo`050?oog`2LB00000000018W03Oool0B@3oool0
0`2oM00007Bo0?ooo`030?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l09`3oool0
06D0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`1>0?ooo`030?oOW01807@0_ooo
04d0oooo00D0okmd001d_`3ooml0W4P004RLg`1;0?ooo`030?oog`2LB00000000080000000<0001d
0;ooo`3oool0C@3oool01P2oM000001809cOo`3ogi`0B4RL0=ooodP0oooo00<0gia80018W03Oool0
0`3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo02H0oooo001U0?ooo`040?oog`2L
B00004RL0=ooo`80oooo00<0gia80018W03Oool0CP3oool00`3ooml0W4P007Boo`1>0?ooo`040=nL
B018W=l0_g@0001d_d`0oooo00<0oono07@00000M;l0D03oool00`3ogi`0B00007Boo`020?ooo`03
0?noM018W=l0oooo04L0oooo00<0omnL04P0B02Lgol00`3oool0103ooml0W4P00018W03Oool20?oo
o`030=nLB000B9`0gooo02H0oooo001V0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3o
ool0CP3oool00`3ookl0M00004RLg`1?0?ooo`040=nLB01dM7@0001d0;oood`0oooo00<0omnL04P0
0018W=l0C`3oool00`3ogi`0B01809cOo`020?ooo`030?noM000B9`0gooo04L0oooo00<0oono07@0
001d_ol0103oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo02H0oooo001W0?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cOB`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol0
D03oool00`2oM000001809cOo`1=0?ooo`040?oog`2LB000001d0;ooodd0oooo00<0oooO09a80018
W=l00P3oool00`2oM00007Bo0?ooo`180?ooo`030;md0000M;l0oooo00@0oooo00H0gia80000M02o
ool0oooO09a80018W=lW0?ooo`00J03oool0103OW4P0000000000000M;m=0?ooo`050?oOW0180000
00000000001d_ol0D@3oool00`3ooml0W4P004RLg`1?0?ooo`040?oo_`1d0000000004RLgd`0oooo
00D0oooO09a8000000000000001d_`180?ooo`050?oo_`1d000000000000M02oool01@3oool0103O
W4P0000000000000M;lX0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0oooo=P3oool00?l0oooo
o`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?oo
o`00o`3ooooo0?ooocH0oooo003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo
0?ooocH0oooo001N0?ooool00000/`00000T0?ooo`00GP3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
8P3oool005h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0R0?ooo`00GP3oool0
0`000000oooo0?ooo`3o0?ooojl0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?oo
o`3oool0o`3ooon_0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo0?l0
oooo[`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooojl0oooo
00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0o`3ooon_0?ooo`030000003o
ool0oooo0280oooo001N0?ooo`<00000o`3ooon]0?ooo`<00000903oool005h0oooo00<000000?oo
o`3oool0o`3ooon_0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo0?l0
oooo[`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooojl0oooo
00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0o`3ooon_0?ooo`030000003o
ool0oooo0280oooo001N0?ooo`030000003oool0oooo0?l0oooo[`3oool00`000000oooo0?ooo`0R
0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooojl0oooo00<000000?ooo`3oool08P3oool005h0
oooo00<000000?ooo`3oool0o`3ooon_0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000
003oool0oooo0?l0oooo[`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool300000?l0oooo[@3o
ool3000002@0oooo001N0?ooo`030000003oool0oooo0?l0oooo[`3oool00`000000oooo0?ooo`0R
0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooojl0oooo00<000000?ooo`3oool08P3oool005h0
oooo00<000000?ooo`3oool0o`3ooon_0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000
003oool0oooo0?l0oooo[`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?oo
o`3o0?ooojl0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0m03oool2
00000;P0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0:03oool80000
00P0oooo1@00002a0?ooo`H000002@3oool200000:l0oooo00<000000?ooo`3oool08P3oool005h0
oooo00<000000?ooo`3oool09P3oool2000001D0oooo1000002[0?ooo`800000`03oool00`000000
oooo0?ooo`0R0?ooo`00GP3oool300000?l0oooo203oool200000:<0oooo0`00000T0?ooo`00GP3o
ool00`000000oooo0?ooo`3S0?ooo`800000903oool200000:<0oooo00<000000?ooo`3oool08P3o
ool005h0oooo00<000000?ooo`3oool0703oool300000<80oooo0P00000X0?ooo`030000003oool0
oooo0:00oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool06P3oool20000
02`0oooo00<000000?ooo`3oool0U03oool2000002/0oooo0P00002P0?ooo`030000003oool0oooo
0280oooo001N0?ooo`030000003oool0oooo01P0oooo0P00000_0?ooo`030000003oool0oooo0940
oooo0P00000_0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool08P3oool005h0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0`0?ooo`800000T03oool00`000000oooo
0?ooo`3?0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?oooe00oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo0?l0ooooCP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0280oooo001N0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`8000004@3oool00`00
0000oooo0?ooo`0R0?ooo`00GP3oool300000?l0ooooV`3oool00`000000oooo0?ooo`0?0?ooo`<0
0000903oool005h0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0R0?ooo`00GP3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo09P0oooo4@00000H0?ooo`800000@03o
ool00`000000oooo0?ooo`1G0?oooa400000603oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0280oooo001N0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0U`3oool2
00000140oooo0`00000D0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0DP3oool4
00000140oooo0`00000D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool08P3oool0
0440oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`060?oOW0180000
000000000000B9`0gooo2`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo09H0oooo
0P00000F0?ooo`@000003`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04l0oooo
0P00000H0?ooo`@000009`3oool00`000000oooo0?ooo`0R0?ooo`00@03oool01P3OW4P007Bo0?oo
o`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3oool0omnL
04Qd_`/0oooo00<000000?ooo`3oool02`3oool2000009L0oooo0P00000L0?ooo`<000002`3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo04`0oooo0P00000N0?ooo`<00000903oool0
0`000000oooo0?ooo`0R0?ooo`00?`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
00/0oooo00<0okmd04RLg`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0BP3oool300000240oooo0P0000080?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0Q0?ooo`8000008P3oool00`00
0000oooo0?ooo`0R0?ooo`00?`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oo
o`X0oooo00<0oono07@0M02oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0B03oool2000002H0oooo0P00001@0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0903oool200000200oooo00<000000?ooo`3oool08P3oool003l0
oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`0:0?ooo`030?oog`2LB000M;oo00T0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo02P0
oooo0P00001?0?ooo`030000003oool0oooo04H0oooo0P00000Y0?ooo`80000000<0oooo0000003o
ool06`3oool00`000000oooo0?ooo`0R0?ooo`00@03oool00`2oM00004RL0=ooo`020?ooo`030?oO
W0180000B9cO00X0oooo00<0oono07@00018W=l02@3oool4000000L0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02/0oooo0P00002E0?ooo`030000
003oool0oooo02/0oooo0P00000I0?ooo`@00000903oool00400oooo00<0gia80000B02Lgol00P3o
ool00`3ooml0W4P0001d_`0:0?ooo`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool02@3o
ool2000004/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0^0?ooo`800000TP3o
ool00`000000oooo0?ooo`0[0?ooo`040000003oool0oooo000001/0oooo00<000000?ooo`3oool0
8P3oool00400oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`060?oOg`3O
ool0okmd0000000007@0_ooo2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0a0?ooo`800000S`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo0P00000I0?ooo`030000003oool0oooo0280
oooo00100?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool01@3ookl0
M0000000000004P0W=oo00X0oooo00<000000?ooo`3oool0303oool2000004T0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0c0?ooo`800000S03oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R0?oo
o`00@@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00L0oooo00<0gibL0;ooo`3o
ool02`3oool00`000000oooo0?ooo`0>0?ooo`800000B03oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool01`3oool2000008T0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`060?ooo`8000005P3oool00`000000oooo0?ooo`0R0?ooo`00
@P3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00<0omnL07BLg`3oool02`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`090?ooo`800000503oool00`000000oooo0?ooo`0R0?ooo`00@`3oool0103OW4P0
000000000000M;l:0?ooo`050;md00000000000000000018W=l0203oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0280oooo001N0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0R0?ooo`00
GP3oool3000001@0oooo0P00001o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
4@3oool2000004@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo00`0oooo0`00000T0?ooo`00GP3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`120?ooo`8000003P3o
ool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280
oooo001N0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool08P3oool005h0oooo0`00000N0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0KP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02H0oooo0`00000T0?ooo`00
GP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
8P3oool005h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo06/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0280oooo001N0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool08P3oool0
03L0oooo00<0_ibL0=ooo`3oool0903oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
06X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0R0?ooo`00=@3oool0103ookl0
M0000018W03OoolU0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0J03oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool08P3oool00340
oooo00<0oono07@0000000000`0000000`00B9`0gooo0?ooo`0T0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool08P3oool002/0oooo00@0oono09bLg`3ookl0M000100000001P00M;l0
oooo0?ooo`3oool0_ibL0=ooobD0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0R
0?ooo`00:`3oool01@3ogi`0B00000000000000007Bo00<0oooo00<0_gAd0;ooo`3oool0:03oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0R0?ooo`00;03oool00`3ookl0M4RL0=ooo`040?ooo`030=nLW02oool0oooo
02P0oooo0`00000V0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0F@3oool30000
02@0oooo000[0?ooo`030?oog`2LB7@0_ooo00@0oooo00<0oono07Ad_`3oool0:@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo0280oooo000[0?ooo`030?oOW01dW=l0oooo00<0oooo
00<0oono07@0M02oool0:P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool08P3oool002/0oooo00P0okmd001d_`3oool0oooo0?oog`2LB000001d0;oo
ob/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0280oooo000/0?ooo`050;md0000000000000000B02Lgol0;@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool08P3oool002h0oooo00H0omnL04P0000000000000
0000B02LgolZ0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0R0?ooo`00;@3oool00`2oM000000007Boo`020?ooo`030?oog`2LM9`0gooo02T0oooo
0`00000]0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo0`00000T0?ooo`00;03oool00`3OW4P0B9cO0?oo
o`040?ooo`030=nLW02oool0oooo02P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo0280oooo000[0?ooo`030?oOW01dW=l0oooo00@0oooo00<0oooO
09adW03Oool0:@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0280oooo000[0?oo
o`030?noW02Lgol0oooo00<0oooo00<0oooO09a8001d_ol0:P3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0R0?oo
o`00:`3oool00`3ogi`0B7Bo0?ooo`020?ooo`030=nLB0000000B9cO01X0oooo00<0oono07@00000
00000P0000000`18W=l0oooo0?ooo`090?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool08P3oool002`0oooo00H0okmd00000000000000000018W03Oool50?ooo`030;nLW03Oool0oooo
01D0oooo00<0okmd0000001d_ol0303oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
0280oooo000e0?ooo`040?oo_`1d000004RL0=oooaH0oooo00<0oooO09a80000M;l0303oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo0280oooo000a0?ooo`030?oo_`1d0000000000<0
000000<004RL0=ooo`3oool05P3oool00`3OW4P004RL0=ooo`0;0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0280
oooo000[0?ooo`040?oo_`2LW=l0oono07@000@0000000H007Bo0?ooo`3oool0oooo0;nLW03OoolG
0?ooo`030?oOW01804P0W=oo00/0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool08P3oool002/0oooo00D0omnL04P0
000000000000001d_`030?ooo`030;mdM02oool0oooo01X0oooo00<0oono07@0001d_ol02`3oool4
00000340oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0340oooo1000000T0?ooo`00;03oool00`3ookl0M4RL0=ooo`040?ooo`030=nLW02oool0oooo
01/0oooo00<0_g@0001d_`3oool02P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool08P3oool002/0oooo00<0oooO09a8M02oool0103oool00`3ookl0
M7Bo0?ooo`0L0?ooo`030=nLB000B9`0gooo00X0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo0280oooo000[0?ooo`030?oOW01dW=l0oooo00<0oooo
00<0oono07@0M02oool07@3oool00`3ogi`0B01809cOo`0:0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0R0?ooo`00:`3oool0203o_g@007Bo0?oo
o`3oool0oooO09a8000007@0_ooo7P3oool00`3ookl0M00007Boo`0:0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0R0?ooo`00;03oool01@2oM000
00000000000004P0W=oo0240oooo00<0_g@0001d_`3oool02@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool08P3oool00500oooo00D0oono07@00000
0000001d0;ooo`090?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool08P3oool002`0oooo00D0_g@00018W03Oool0oono07@0000200000003
0000M02oool0oooo02P0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0280oooo000[0?ooo`030?oOW0180000000000<0000000@0B9cO0?ooo`2oW9`0
gooo:@3oool3000003P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0640oooo0`00000T0?ooo`00:`3oool0103ooml0W4P00000M02oool30?ooo`03
0?noM018W=l0oooo02T0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0R0?ooo`00
<@3oool00`3o_g@007Bo0?ooo`0Z0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0280oooo000_0?ooo`030?oog`2o
_kl0W9bo02`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0R0?ooo`00;`3oool0
1P3ogkl0W7A8000000000000001d0;ooobT0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`0R0?ooo`00:`3oool00`3ogi`0B00000000002000000050000B02Lgol0oooo0;nLW03Oool0
:@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`0R0?ooo`00:`3oool00`3o_g@0001d0;ooo`040?ooo`030;md001d
_ol0oooo02T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool08P3oool00380oooo00<0gmoO0?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0280oooo000_0?ooo`060?noM00000000000
0000000007@0_ooo:@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0280oooo000W
0?ooo`060;nLW03Oool0oooo0?ooo`3ogi`0B0000`0000001000B9`0gooo0?oo_`1dM;lZ0?ooo`<0
0000?@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0O@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0i0?ooo`<00000903oool002H0oooo00<0oooO09a800000000
0`0000000`00M;l0oooo0?ooo`020?ooo`030?noM00007@0_ooo02X0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0280oooo000V0?ooo`030?oo_`1d
0000B9cO03D0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo0280oooo001N0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0280oooo000_0?ooo`050;md000000000000
00000018W=l0:P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool08P3oool002d0oooo00<0gia80000001d_ol00P3oool00`3ogi`0B01d0;ooo`0Y0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0R0?oo
o`00;03oool00`3OW4P0B9cO0?ooo`030?ooo`030?oOW018M;l0oooo02T0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0280oooo000[0?ooo`030?oO
W01dW=l0oooo00<0oooo00<0oknL04QdW03Oool0:P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo0280oooo000[0?ooo`030?noM000M;l0oooo0080oooo00D0omnL04QdM01d000004RL
0=ooo`0Y0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool08P3oool002`0oooo00<0
okmd000000000000100000000`00B9`0gooo0?ooo`0X0?ooo`<00000@P3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0IP3oool3000002@0oooo000[
0?ooo`050?oOW0180000000000000018W=l00P3oool00`2oM4P0W=oo0?ooo`0Y0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1X0?ooo`030000003o
ool0oooo0280oooo001N0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool08P3oool0
05h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0R0?ooo`00:`3oool01@3ogkl0
_moo0?ooo`3oool0_g@000<0000000<0001d0;ooo`3oool0:03oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0R0?oo
o`00:`3oool00`2oM000000000000002000000050000M02oool0oooo0;nLW03Oool0:@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`0R0?ooo`00:@3oool01@2oM000000000000000B9`0gooo00<0oooo00<0oooO09a8
001d_ol0:P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0R@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0280oooo000[0?ooo`03
0?noW02Lgol0oooo0300oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0R0?ooo`00
GP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
8P3oool002/0oooo00<0oono09bLg`3oool00`3oool0103o_g@000000000M02ooolY0?ooo`<00000
AP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0n0?ooo`<00000903oool002/0oooo00@0oono09bLg`3ookl0M000
100000000`00B9`0gooo0?ooo`0X0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0R0?ooo`00:`3oool02@3ogi`0B0000000000004P0W=oo0?ooo`3o
oml0W4Qd0;ooo`0Z0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0280oooo000W0?ooo`040?oog`2LB000001d0;oo
oc<0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0280oooo000o0?ooo`030?oo_`1d000000000080000000L0B9cO0?ooo`3oool0oooo0?oOW0180000
M;oo0080oooo00H0omnL04P00000000000000018W03Oool;0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0R0?ooo`00;P3oool01P3ogi`0B0000000
00000000001809cOo`d0oooo00<0okmd0000001d_ol0103oool00`3ogi`0B00007Boo`020?ooo`06
0?noM0000000M;oo0?ooo`3ogi`0B7Bo2`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool08P3oool002d0oooo00<0_g@00000001d_ol00P3oool00`3o
oml0W7BL0=ooo`0<0?ooo`030?oog`2LB00007Bo00h0oooo00<0okmd04RLg`3oool02@3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo0280oooo000/0?ooo`030=nLB018W=l0oooo00@0
oooo00<0gibL0;ooo`3oool0303oool00`3OW4P004RL0=ooo`0=0?ooo`030?oo_`1d07@0_ooo00T0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0R0?ooo`00:`3oool00`3ogi`0M9cO
0?ooo`040?ooo`030?oog`2LM9`0gooo00d0oooo00<0omnL04P0B02Lgol03@3oool00`3ooml0W4P0
07Boo`090?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool08P3oool002/0oooo00<0
oknL09cOo`3oool00`3oool00`3ooml0W4P007Boo`0>0?ooo`030?oo_`1d0000M;oo00d0oooo00<0
oono07@00018W=l02@3oool4000004X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`1Z0?ooo`@00000903oool002/0oooo00<0omnL04Qd_`3oool00P3oool00`3OW4P0000004RLg`0@
0?ooo`030;md0000M;l0oooo00`0oooo00<0okmd0000001d_ol02@3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo0280oooo000/0?ooo`060?noM0000000000000000000B9`0gooo4@3o
ool00`3OW4P004RL0=ooo`090?ooo`060?oOg`3Oool0okmd0000000007@0_ooo2@3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`0R0?ooo`00@`3oool00`3ogi`0B01809cOo`090?ooo`050?oo_`1d000000000000B02L
gol02P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0KP3oool00`000000oooo0?ooo`0R0?ooo`00<@3oool0103ookl0M0000000M02oool>0?ooo`03
0?oo_`1d0000M;oo00X0oooo00<0gibL0;ooo`3oool02`3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo0280oooo000[0?ooo`040?oo_`2LW=l0oono07@000<0000000<0001809cOo`3o
ool03`3oool00`2oM00007Bo0?ooo`090?ooo`030?oOW01dW=l0oooo00/0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0R0?ooo`00:`3oool00`3ogi`0B0000000000200000003001d
_`3oool0oooo00l0oooo00D0oono07@000000000001d0;ooo`0:0?ooo`050;md0000000000000000
0018W=l0203oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0280oooo000]0?ooo`03
0?oOW01807@0_ooo02h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo0280oooo000/0?ooo`030?oo_`1dB9`0gooo02l0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
V@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0280oooo000[0?ooo`030?oog`2L
B7@0_ooo00<0oooo00@0okmd0000000007@0_ooo:@3oool3000004l0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
@`3oool3000002@0oooo000[0?ooo`040?noM000B9`0gono07@000@0000000<004RL0=ooo`3oool0
:03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0R0?ooo`00:`3oool02@3ogi`0B000000000000000B9cO0?ooo`3o
oml0W4Qd0;ooo`0Z0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool07@3oool010000000oooo0?ooo`00000Z0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0280oooo
001N0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool010000000oooo0?oo
o`00000Z0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool0703oool010000000oooo0?ooo`00000Y0?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0280oooo
001N0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo0280oooo000_0?ooo`050=nLB000000000000000001d_ol0:P3o
ool3000005@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0703oool00`000000oooo0000001b0?ooo`<00000903o
ool002d0oooo00<0omnL04P00018W=l00P3oool00`3ogi`0B01d0;ooo`0Y0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0R0?ooo`00;03oool00`3o
gi`0B4RL0=ooo`030?ooo`030?oo_`1dB9`0gooo02T0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool06`3oool20000
07D0oooo00<000000?ooo`3oool08P3oool002/0oooo00<0oooO09adW03Oool0103oool00`2oM000
M;oo0?ooo`0Y0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`2T0?ooo`030000003oool0oooo01X0oooo0P00000Y0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool08P3oool002/0oooo00<0omno0;oOo`3oool00P3oool00`3ooml0W4P0
07Boo`0[0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`2T0?ooo`030000003oool0oooo01X0oooo0P00000Y0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool08P3oool002/0oooo00X0okmd07Boo`3oool0oooo0?oOW01804P0W=no07@0
0000B9`0gooo:@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`0I0?ooo`800000:03oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo0280oooo000[0?ooo`030?oog`2LB000000000D0000000<004RL0=oo
o`3oool0:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01P0oooo0P00002W0?oo
o`030000003oool0oooo01T0oooo0P00000X0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool08P3oool002L0oooo00@0_ibL0=ooo`3ookl0M000100000001@1d_ol0oooo0?ooo`2oM7@0
_ooo02X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0H0?ooo`800000Z03oool0
0`000000oooo0?ooo`0H0?ooo`800000:03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo0280oooo000V0?ooo`030?oog`2LB00000000080000000<0M;oo0?ooo`3oool0<03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`000000:03oool00`00
0000oooo0?ooo`1m0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`000000:03oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo0280oooo000V0?ooo`030?oo_`2LW=l0oooo03D0
oooo0`00001H0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000009`3oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`0000009`3oool00`00
0000oooo0?ooo`190?ooo`<00000903oool002h0oooo00H0gia800000000000000000000B02LgolZ
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3o
ool0000002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0R0?ooo`00;03oool0
2@3ookl0M00004RLg`3ogi`0W;oo0?ooo`3OW4P004RL0=ooo`0Y0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`0R0?ooo`00;03oool02@2oM7@0_ooo0?ooo`3o_i`0W=oo
0?ooo`3ookl0M01d0;ooo`0Y0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool04`3o
ool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool08P3oool002/0oooo00T0
omnL09boo`3oool0oooO09adW03Oool0oooo0?oOW018M;l0:P3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo0280oooo000[0?ooo`090?noW02Lgol0oooo0;md001d_ol0oooo0=nLB000
07@0_ooo02X0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0R0?ooo`00:`3oool0
103ookl0M0000000001d_ol_0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool08P3o
ool005h0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool08P3oool00340oooo00@0oono07@0000007@0_ooo:@3oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0280oooo000[0?ooo`040?oo_`2LW=l0oono
07@000<0000000<0001809cOo`3oool0:@3oool3000005h0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1_0?ooo`<00000903oool002/0oooo00<0omnL04P0000000000P0000000`00
M;l0oooo0?ooo`0[0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo0280oooo000]0?ooo`030?oOW01807@0_ooo02h0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0R0?ooo`00;03oool00`3ookl0M4RL
0=ooo`0N0?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool0203oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0]`3oool2000000P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool08P3oool002/0oooo00<0oooO09a8M02oool00`3oool0103o_g@000000000
M02ooolI0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool0203oool00`000000oooo
0?ooo`1R0?ooo`8000001P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool08P3oool002/0oooo00@0okmd0018W03Ookl0M000100000000`00B9`0gooo
0?ooo`0I0?ooo`030?noM000M;l0oooo00`0oooo00<000000?ooo`3oool0H`3oool7000000`0oooo
00<000000?ooo`3oool0[`3oool6000000d0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0280oooo000[0?ooo`090?oOW0180000000000000018W=l0
oooo0?oog`2LB7@0_ooo01`0oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo0<80oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo0280oooo001A0?ooo`030?noM018W=l0oooo00X0oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0280oooo000`0?ooo`050?oo
g`2LB00000000018W03Oool07@3oool00`3OW4P0B9cO0?ooo`090?ooo`@00000M@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`1<0?ooo`@00000903oool002`0oooo00@0_g@00000000007@0_ooo0P3oool00`3ookl0
M7Bo0?ooo`0N0?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0R0?ooo`00:`3oool01P3ogi`0W;oo0?oog`2LB000001d0;ooo`80oooo00<0gibL0;oo
o`3oool07@3oool00`3ogi`0B01d0;ooo`080?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool08P3oool002/0oooo00X0oknL09cOo`3oool0oooO09a8000004P0W=oo0?oo_`1dB9`0gooo
7P3oool00`3ooml0W4P007Boo`080?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<000000?ooo`3oool08P3oool002/0oooo00<0
oono07Ad_`3oool00P3oool0102oM00000000000M02ooolO0?ooo`030?oo_`1d0000B9cO00P0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo
5@3oool00`000000oooo0?ooo`0R0?ooo`00:`3oool0103ogi`0B0000000001d_olP0?ooo`070?no
M000B9`0gooo0?ooo`3OW4P0001809cOo`080?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3oool08P3oool00500
oooo00D0omnL04P000000000000007Boo`090?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3oool08P3oool005h0
oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3o
ool08P3oool002/0oooo00<0oono09bLg`3oool00`3oool0103o_g@000000000M02ooolY0?ooo`03
0000003oool0oooo0?l0oooo?P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0280
oooo000[0?ooo`040?oo_`2LW=l0oono07@000@0000000<004RL0=ooo`3oool0:03oool300000?l0
oooo?P3oool00`000000oooo0?ooo`1/0?ooo`<00000903oool002/0oooo00T0omnL04P000000000
001809cOo`3oool0oooO09a8M02oool0:P3oool00`000000oooo0?ooo`3o0?oooch0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0280oooo000W0?oo
o`040?oog`2LB000001d0;oooc<0oooo00<000000?ooo`3oool0o`3oooln0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`00
0000oooo0?ooo`3o0?ooocl0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo0280oooo000[0?ooo`050?oO_`2ogol0oooo0?ooo`2oM0000`0000000`00
07@0_ooo0?ooo`0X0?ooo`030000003oool0oooo0?l0oooo?`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool08P3oool002/0oooo00<0_g@000000000
00000P0000001@0007@0_ooo0?ooo`2oW9`0gooo02T0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`310?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0R0?ooo`00:@3oool01@2oM000000000000000B9`0gooo00<0oooo00<0oooO09a8
001d_ol00P3oool00`2oM00004RL0=ooo`0U0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool08P3oool002/0oooo00<0oknL09cOo`3oool0203oool00`3ogi`0B7Bo0?ooo`0U0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0R0?ooo`00
:`3oool00`3ookl0M7Bo0?ooo`070?ooo`030?noM000B9`0gooo02H0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0280oooo000[0?ooo`040?oOW018
0000001d0;ooo`D0oooo00<0gia8001d_`3oool09`3oool3000007X0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0580oooo0`00000T0?ooo`00;03o
ool00`3ogi`0B000000000050000000304RLg`3oool0oooo02L0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0R0?ooo`00<@3oool00`3o_g@0001809cOo`0Z0?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?oooaX0oooo00<00000
0?ooo`3oool08P3oool00300oooo00<0_g@0001d_`3oool0:`3oool00`000000oooo0?ooo`1k0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo
0280oooo000[0?ooo`060?oOW0180000M;oo0?noM0000000M;oo;@3oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0
oooo0280oooo000[0?ooo`040?oOW01800000000001d_bl0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0R
0?ooo`00GP3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0?l0oooo6`3oool00`00
0000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oood40oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oood40oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool300000?l0oooo@P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05D0oooo0`00000T0?ooo`00GP3oool0
0`000000oooo0?ooo`3o0?oood80oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo0?l0oooo@`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool08P3oool005h0
oooo00<000000?ooo`3oool0o`3ooom30?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo0<40oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0280oooo001N0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0280
oooo001N0?ooo`<00000O`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo
7@3oool3000002@0oooo001N0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`3o0?ooob00oooo00<000000?ooo`3oool08P3oool005h0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo803oool0
0`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`030000003oool0oooo0280oooo000o0?ooo`03
0=nLB0000000000000<0000000H0B9cO0?ooo`3oool0omnL04P0001d_ol20?ooo`060?oOW0180000
000000000000B9`0gooo2`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0?l0oooo
8@3oool00`000000oooo0?ooo`0R0?ooo`00@03oool00`3o_g@007Bo0?ooo`020?ooo`060;mdM02o
ool0oooo0?oOW0180000M;oo0P3oool01P3o_g@0000007Boo`3oool0omnL04Qd_`/0oooo00<00000
0?ooo`3oool0o`3ooom70?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool08P3oool0
0440oooo00<0okmd001d_`3oool03P3oool00`3o_g@0B9cO0?ooo`090?ooo`030000003oool0oooo
0?l0ooooB03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool08P3oool00480oooo00<0okmd001d_`3oool03@3oool00`3ookl0M01d0;ooo`090?ooo`03
0000003oool0oooo08<0oooo0P0000330?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0R0?ooo`00@`3oool00`3o_g@0B9cO0?ooo`0<0?ooo`030?oo
g`2LB000M;oo00T0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`310?ooo`D00000
H@3oool00`000000oooo0?ooo`0R0?ooo`00A03oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?oo_`1d
0000B9cO00T0oooo1000003o0?oooj/0oooo1000000T0?ooo`00A@3oool00`2oM000M;oo0?ooo`0:
0?ooo`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool0o`3ooon_0?ooo`030000003oool0
oooo0280oooo00150?ooo`030?oOW01807@0_ooo00L0oooo00H0omoO0=ooo`3o_g@000000000M02o
ool90?ooo`030000003oool0oooo0?l0oooo[`3oool00`000000oooo0?ooo`0R0?ooo`00A@3oool0
0`3ooml0W4P007Boo`070?ooo`050?oo_`1d000000000000B02Lgol02P3oool00`000000oooo0?oo
o`0j0?ooo`030?oog`2LB00000000080000000<0M;oo0?ooo`3oool0o`3ooom]0?ooo`030000003o
ool0oooo0280oooo00150?ooo`030?oo_`1d0000B9cO00P0oooo00<0gibL0;ooo`3oool02`3oool0
0`000000oooo0?ooo`0l0?ooo`030?noM00007@0_ooo0?l0ooooL03oool00`000000oooo0?ooo`0R
0?ooo`00@@3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol0203oool00`3ogi`0M9cO0?oo
o`0;0?ooo`030000003oool0oooo03`0oooo00<0oono07@0001d_ol0o`3ooom`0?ooo`030000003o
ool0oooo0280oooo00120?ooo`050?oOW018000000000000001d_ol02P3oool01@2oM00000000000
00000000B9cO00P0oooo00<000000?ooo`3oool0?03oool00`3ooml0W4P004RLg`3o0?ooog00oooo
00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0?@3oool00`3OW4P000000000
00020000000607Boo`3oool0oooo0?ooo`2oM00007Bo1P3oool01@3OW4P00000000000000000M;oo
0080oooo00/0oono07@000000000001d0;ooo`3OW4P0000004RLg`3oool0omnL04P0000200000009
07Boo`3OW4P000000018W03Oool0okmd0000000004P0W=oo0080oooo00D0okmd0000000000000018
09cOo`030?ooo`030;md0000M;l0oooo0?l0oooo=`3oool00`000000oooo0?ooo`0R0?ooo`00GP3o
ool00`000000oooo0?ooo`0m0?ooo`070?noM00004P0W=oo0?ooo`3ooml0W4P0001d_`020?ooo`03
0?noM00007@0_ooo00@0oooo00<0omnL04P0001d_ol00P3oool08@2oM00007Bo0?ooo`3OW4P004RL
0=ooo`3ookl0M01d0;noM00007@0W9ad09cOo`2oM00004RL0=ooo`3oool0_g@007AdM00007@0_mnL
09boo`3o_g@0001809cOg`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`020?ooo`03
0?noM00007@0_ooo0?l0oooo=`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool3000003d0oooo
00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0omnL04P0001d_ol0103oool00`3O
W4P004RL0=ooo`030?ooo`040=nLW02oool0_g@0001d_`80oooo00L0oono07A8B01804P0W=oo0?oo
o`2oM00007Bo00<0oooo00L0_g@00000001d_ol0oooo0?oo_`1d0000M;oo0080oooo00<0gia80018
W03Oool00P3oool01`3ogi`0B00004RLg`3oool0omnL04P0001d_ol0o`3ooole0?ooo`<00000903o
ool005h0oooo00<000000?ooo`3oool0?@3oool00`3ooml0W4P004RLg`030?ooo`070?oOW01804P0
W=oo0?oog`2LB00004RL0=ooo`030?ooo`050?noM0000000000000000018W=l00`3oool00`3o_g@0
04RL0=ooo`020?ooo`070?noM0000000B9cO0?ooo`3o_g@0001d0;ooo`020?ooo`030?oo_`1d0000
B9cO0080oooo00L0_g@0001d_`3oool0oooo0?noM00007@0_ooo00<0oooo00L0gia80000M02oool0
oooO09a80000B9`0gooo0?l0oooo=P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000
oooo0?ooo`0n0?ooo`030=nLB00007@0_ooo0080oooo00L0oooO09a80018W=l0oooo0;md0018M7@0
M9cO00<0oooo00/0oono07@0B02Lgol0oooo0=nLB0000000B9cO0?ooo`3ookl0M00007Boo`020?oo
o`070?oog`2LB00007Bo0?ooo`3ookl0M00007Boo`030?ooo`0;0;md0000B9`0gooo0?ooo`3OW4P0
04RL0=ooo`3oool0oono07@0001d_ol00`3oool01`3ogi`0B01809cOo`3oool0_g@004QdM01dW=l0
o`3ooolf0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo00D0oooo1@00
00040?ooo`H000000`3oool6000000<0oooo1P00000H0?ooo`040?noM000000004RL0=ooo`80oooo
00L0gia8001d_`3oool0okmd0018W02oW4P0M;oo00<0oooo00/0okmd0018W03Oool0oooo0?oo_`1d
0000B9cO0?ooo`3o_g@0001d0;ooo`020?ooo`070=nLB00007@0_ooo0?ooo`3o_g@0001d0;ooo`02
0?ooo`070=nLB00007@0_ooo0?ooo`3ogi`0B01809cOo`020?ooo`030=nLB00007@0_ooo0080oooo
00P0oono07@0001d_ol0oooo0?noM000B9`0_ia807Boool0oooo=@3oool00`000000oooo0?ooo`0R
0?ooo`00GP3oool00`000000oooo0?ooo`0n0?ooo`0P0?oo_`1d0000M9bL04P0M02oool0oooO09a8
0000M;l0oooo0?oo_`1d04P0W=oo0;md001dM7@004RL0=ooo`3oool0gia80000M02oool0oooo0=nL
B000B9`0gooo0?ooo`3OW4P0001d0;ooo`3oool0_g@00000B02Lgol20?ooo`0;0=nLB00007@0_ooo
0?ooo`2oM000001809cOo`3oool0oooO09a80018W=l00`3oool03`2oM000001d0;ooo`3oool0okmd
0000M02oool0oooo0?oo_`1d04P0W=oo0;md001dM7@004RL0=ooo`3o0?oooc80oooo00<000000?oo
o`3oool08P3oool005h0oooo00<000000?ooo`3oool0?@3oool04@3ogi`0B00000000018W=l0oono
07@000000000001d0;ooo`3ogi`0B0000000001d_ol0oooo0;md000007@0_ooo0080oooo00D0omnL
04P000000000000007Boo`030?ooo`060?oOW0180000000004RL_`2LB000B9cO0`3oool0203ogi`0
B00000000018W9`0M00004RLg`3ookl0M0000`000000101d_ol0oooo0?ooo`3o_g@30000000:07Bo
o`3oool0omnL04P000000000M;oo0?ooo`2oM000001d0;ooool0oooo<P3oool00`000000oooo0?oo
o`0R0?ooo`00GP3oool00`000000oooo0?ooo`1L0?ooo`030;md0000M;l0oooo00X0oooo00<0okmd
0000M02oool0o`3ooom30?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo
05`0oooo00<0okmd0000M02oool02`3oool00`3OW7@0W=oo0?ooo`3o0?oood80oooo00<000000?oo
o`3oool08P3oool005h0oooo00<000000?ooo`3oool0G03oool00`3ogi`0B01809cOo`3o0?oooe00
oooo00<000000?ooo`3oool08P3oool005h0oooo0`00001L0?ooo`030?oog`2LB000B9cO0?l0oooo
CP3oool3000002@0oooo001N0?ooo`030000003oool0oooo05/0oooo00@0oono07@00000000007Bo
o`3ooom@0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo0?l0oooo[`3o
ool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooojl0oooo00<00000
0?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0o`3ooon_0?ooo`030000003oool0oooo
0280oooo001N0?ooo`030000003oool0oooo0?l0oooo[`3oool00`000000oooo0?ooo`0R0?ooo`00
GP3oool00`000000oooo0?ooo`3o0?ooojl0oooo00<000000?ooo`3oool08P3oool005h0oooo00<0
00000?ooo`3oool0o`3ooon_0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0
oooo0?l0oooo[`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool300000?l0oooo[@3oool30000
02@0oooo001N0?ooo`030000003oool0oooo03X0oooo00<0oooO09a8000000000P0000000`1d_ol0
oooo0?ooo`0A0?ooo`040=nLB000000004RL0=ooool0ooooF03oool00`000000oooo0?ooo`0R0?oo
o`00GP3oool00`000000oooo0?ooo`0l0?ooo`030?noM00007@0_ooo01@0oooo00D0okmd0018W03O
gi`0B4RL0=ooo`3o0?oooeL0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3o
ool0?03oool00`3ookl0M00007Boo`0G0?ooo`030?oOW018M;l0oooo0?l0ooooEP3oool00`000000
oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0l0?ooo`030?oog`2LB000B9cO01P0oooo
00<0okmd07Boo`3oool0o`3ooomE0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003o
ool0oooo03d0oooo00<0gia80000000000000P0000001P1d_ol0oooo0?ooo`3oool0_g@0001d_`H0
oooo00D0gia8000000000000000007Boo`040?ooo`030?noM0000000M;oo0?l0ooooE@3oool00`00
0000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0m0?ooo`070?noM00004P0W=oo0?oo
o`3ooml0W4P0001d_`020?ooo`030?noM00007@0_ooo00@0oooo00<0omnL04P0001d_ol00P3oool0
0`2oM00007Bo0?ooo`020?ooo`040=nLB00007@0M7A809cOool0ooooE03oool00`000000oooo0?oo
o`0R0?ooo`00GP3oool00`000000oooo0?ooo`0m0?ooo`030?oo_`1d0000M;oo0080oooo00L0oooO
09a80018W=l0oooo0?oOW0180000M;oo00@0oooo00<0gia80018W03Oool00`3oool02@3OW9`0_ooo
0?ooo`3oool0gia80018W03Ooml0W7BL0=ooo`3o0?oooe<0oooo00<000000?ooo`3oool08P3oool0
05h0oooo00<000000?ooo`3oool0?@3oool00`3ooml0W4P004RLg`030?ooo`070?oOW01804P0W=oo
0?oog`2LB00004RL0=ooo`030?ooo`050?noM0000000000000000018W=l01@3oool01@2oM00004RL
0=ooo`3ogi`0M9cO0?l0ooooD`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool3000003h0oooo
00<0gia80000M02oool00P3oool01`3ooml0W4P004RLg`3oool0_g@004QdM01dW=l00`3oool01`3o
okl0M01809cOo`3oool0gia800000018W=l00P3oool00`3ooml0W4P0001d_`020?ooo`030=nLW02o
ool0oooo0?l0ooooC`3oool3000002@0oooo001N0?ooo`030000003oool0oooo00D0oooo8@00000H
0?ooo`040?noM000000004RL0=ooo`80oooo00L0gia8001d_`3oool0okmd0018W02oW4P0M;oo00<0
oooo00/0okmd0018W03Oool0oooo0?oo_`1d0000B9cO0?ooo`3ooml0W4P0001d_`020?ooo`030?oo
_`1dM;l0oooo0?l0ooooD@3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?oo
o`0n0?ooo`0K0?oo_`1d0000M9bL04P0M02oool0oooO09a80000M;l0oooo0?oo_`1d04P0W=oo0;md
001dM7@004RL0=ooo`3oool0gia80000M02oool0oooo0=nLB000B9`0gooo0?oo_`1d0000B9cO0080
oooo00<0omnL04P0M02oool0o`3ooomA0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000
003oool0oooo03d0oooo0140omnL04P000000000B9cO0?oo_`1d000000000000M02oool0omnL04P0
00000000M;oo0?ooo`2oM000001d0;ooo`020?ooo`090?oOW018000000000000001d_ol0_g@00000
000004P0W=oo0080oooo00<0gia80018W03Oool0o`3ooomA0?ooo`030000003oool0oooo0280oooo
001=0?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool02@3oool00`000000oooo0?oo
o`3o0?ooojl0oooo00<000000?ooo`3oool08P3oool004d0oooo00<0okmd00000000M;l00P3oool0
0`2oM4P0W=oo0?ooo`090?ooo`030000003oool0oooo0?l0oooo[`3oool00`000000oooo0?ooo`0R
0?ooo`00DP3oool00`3ogi`0B4RL0=ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0500oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool08P3oool00580oooo00<0oono07@0001d_ol02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0280oooo001B0?ooo`030?oOW0180000M;oo00T0ooooo`00002c000002@0oooo
001A0?ooo`040?oOW0180000001809cOool0ooooh03oool004l0oooo00D0omnL04P0000000000000
07Boo`3o0?ooon40oooo001A0?ooo`030?oo_`1d000007Bo0?l0ooooh@3oool005<0oooo00<0gia8
001d_`3oool0o`3ooooO0?ooo`00D`3oool00`3ogi`0B01809cOo`3o0?oooml0oooo001@0?ooo`06
0;md001d_ol0oooo0=nLB00004P0W=ooo`3ooooO0?ooo`00D@3oool0102oM000000000000018W=oo
0?ooon00oooo003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo
003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0
oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0oooo=P3oool0
0?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0oooo=P3oool00001\
\>"],
  ImageRangeCache->{{{0, 563.625}, {348, 0}} -> {-1.05103, -0.648943, \
0.0055943, 0.0055943}, {{13.625, 549.938}, {339.688, 8.25}} -> {-2.55292, \
-0.682409, 0.0364292, 0.0168411}, {{80.6875, 268.375}, {66.6875, 13.0625}} -> \
{-1.54451, -13.3198, 0.0268534, 0.07049}, {{90.6875, 146.563}, {62.8125, \
41.5625}} -> {-3.1226, -29.2333, 0.0458074, 0.148236}, {{90.6875, 146.563}, \
{38.125, 16.875}} -> {-3.1226, -31.673, 0.0458074, 0.148236}}]
}, Closed]],

Cell[TextData[{
  "\tWe observe that the orbits are closed, corresponding to periodic \
oscillations for both populations.  These oscillations are approximately \
sinusoidal very close to the fixed point but become increasingly distorted as \
their amplitude increases.  Nevertheless, the orbits appear to remain closed \
for arbitrarily large amplitudes.  This is a new feature that is not \
predicted by our linear stability analysis, which applies in the immediate \
vicinity of the fixed point.  Why are the orbits closed?  It turns out that \
we can integrate these equation of motion for ",
  Cell[BoxData[
      \(TraditionalForm\`y[x]\)]],
  " explicitly and thereby deduce a conserved quantity that is determined by \
the initial conditions and remains constant thereafter.  First, we eliminate \
the time dependence to obtain"
}], "Text"],

Cell[BoxData[
    \(\[DifferentialD]y\/\[DifferentialD]x\  \[Equal] \ \[Alpha]\ \(\(x - 
              1\)\/\(1 - 
              y\)\) \(y\/x\)\ \ \[DoubleLongRightArrow]\ \ \ \(\(1 - 
                y\)\/y\) \[DifferentialD]y\  \[Equal] \ \(-\[Alpha]\) \(\(1 - 
              x\)\/x\) \(\(\[DifferentialD]\)\(x\)\(\ \ \)\)\)], \
"DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["Next we integrate both sides, such that", "Text"],

Cell[BoxData[
    \(Log[y]\  - \ y\  \[Equal] \ \(-\[Alpha]\)\ \((Log[x]\ \  - \ x)\)\  - \ 
        T\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is a constant.  Therefore, for specific choices of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " we have a unique parametric dependence of ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " upon ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "; in other words, a closed orbit.  The constant of integration is \
determined by the initial conditions, such that"
}], "Text"],

Cell[BoxData[
    \(T\  = \ \(\(\[Alpha]\ x\_0\)\(\ \)\(-\)\(\ \)\(y\_0\)\(\ \)\(-\)\(\ \
\)\(Log[\(x\_0\^\[Alpha]\) y\_0]\)\(\ \)\)\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "is a constant of the motion.  Notice that ",
  Cell[BoxData[
      \(TraditionalForm\`T \[GreaterEqual] 1 + \[Alpha]\)]],
  " and that the minimum value of ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " corresponds to the fixed point ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0 = \(y\_0 = 1\)\)]],
  ".  Furthermore, the greater the oscillation amplitude the larger the value \
of ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ".  The population parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " defines a family of closed orbits while the conserved quantity ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", as determined by the initial conditions, selects the appropriate member \
of that family."
}], "Text"],

Cell["\<\
\tAnother feature of this system also merits discussion.  Notice that for \
large amplitudes the orbits tend to \"bunch up\" near the coordinate axes and \
in the lower left corner of phase space.  Thus, small fluctuations in \
environmental conditions could shift the system from one orbit to another \
nearby orbit whose amplitude is quite different in the region of phase space \
(here toward the upper right) where the orbits spread out again.  Therefore, \
small perturbations that occur at a vulnerable time can produce large effects \
upon the subsequent behavior of the system.  This is a common feature of \
conservative systems that is often not very realistic. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["More realistic predator-prey model", "Section"],

Cell["\<\
\tMore realistic predator-prey models should include saturation mechanisms \
for both species.  For example, we can describe the finite carrying capacity \
of the environment by assuming that the prey population would obey a logistic \
equation in the absence of predators.  Furthermore, we assume that there is \
maximum prey consumption rate per predator.  A simple equation with those \
features is\
\>", "Text"],

Cell[BoxData[
    \(\[DifferentialD]X\/\[DifferentialD]\[Tau] \[Equal] \(R\_X\) 
          X\ \((1 - 
              X\/K\_X)\)\  - \ \(A\ X\ Y\)\/\(X + B\)\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`R\_X\)]],
  " is a reproduction rate, ",
  Cell[BoxData[
      \(TraditionalForm\`K\_X\)]],
  " describes the environmental carrying capacity, ",
  Cell[BoxData[
      \(TraditionalForm\`A/B\)]],
  " describes the predation rate for small prey populations, and ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " is a saturation parameter.  Similarly, we assume that the predator \
population is also described by a logistic equation but that the carrying \
capacity for predators is proportional to the prey density, such that"
}], "Text"],

Cell[BoxData[
    \(\[DifferentialD]Y\/\[DifferentialD]\[Tau] \[Equal] \(R\_Y\) 
        Y\ \((1 - Y\/\(\(K\_Y\) X\))\)\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["\<\
As before, we would like to use dimensional analysis to reduce the number of \
free parameters.  Let\
\>", "Text"],

Cell[BoxData[{
    \(X \[Rule] \[Alpha]\ x\ , \ 
    Y \[Rule] \[Beta]\ y, \ \[Tau] \[Rule] \[Gamma]\ t\), \
"\[IndentingNewLine]", 
    \(\[DifferentialD]X\/\[DifferentialD]\[Tau] \[Equal] \(R\_X\) 
          X\ \((1 - 
              X\/K\_X)\)\  - \ \(\(A\ X\ Y\)\/\(X + 
                  B\)\)\ \ \[DoubleLongRightArrow]\ \ \(1\/\(\[Gamma]\ x\)\) \
\[DifferentialD]x\/\[DifferentialD]t \[Equal] \ 
      R\_X\ \((1\  - \[Alpha]\/K\_X\ x)\)\  - \ \(A\ \[Beta]\ y\)\/\(\[Alpha]\
\ x\  + \ B\)\), "\n", 
    \(\[DifferentialD]Y\/\[DifferentialD]\[Tau] \[Equal] \(R\_Y\) 
        Y\ \((1 - 
              Y\/\(\(K\_Y\) X\))\)\ \ \[DoubleLongRightArrow]\ \ \(1\/\(\
\[Gamma]\ y\)\) \[DifferentialD]y\/\[DifferentialD]t \[Equal] \ \(\(R\_Y\)\(\ \
\)\((1 - \(\[Beta]\/\(\[Alpha]\ K\_Y\)\) y\/x)\)\(\ \)\)\)}], "DisplayFormula",\

  FontFamily->"Times New Roman"],

Cell["The predator equation takes its simplest form when we choose", "Text"],

Cell[BoxData[
    \(\[Beta]\/\(\[Alpha]\ K\_Y\) = 1\ , \ \ \[Gamma]\ R\_Y = 
      c\ \ \ \[DoubleLongRightArrow]\ \ \
\(\[DifferentialD]y\/\[DifferentialD]t\)\  \[Equal] \ 
        c\ y\ \((1 - y\/x)\)\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["Then the prey equation can be simplified by choosing", "Text"],

Cell[BoxData[
    \(\[Gamma]\  = R\_X\^\(-1\), \ \ \[Alpha] = 
      K\_X, \ \(A\ \[Beta]\)\/K\_X = a, \ 
    B\/K\_X = 
      b\ \ \ \[DoubleLongRightArrow]\ \ \
\(\[DifferentialD]x\/\[DifferentialD]t\)\  \[Equal] \ 
        x\ \((1 - x)\)\  - \ \(a\ x\ y\)\/\(x + b\)\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["Therefore, we obtain dimensionless equations of the form", "Text"],

Cell[BoxData[{
    \(\[DifferentialD]x\/\[DifferentialD]t\  \[Equal] \ 
      x\ \((1 - x)\)\  - \ \(a\ x\ y\)\/\(x + b\)\), "\[IndentingNewLine]", 
    \(\[DifferentialD]y\/\[DifferentialD]t\  \[Equal] \ 
      c\ y\ \((1 - y\/x)\)\)}], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["where", "Text"],

Cell[BoxData[
    \(a\  = \ A\ K\_Y\ , \ \ b\  = \ B\ K\_X\ , \ \ c\  = \ 
      R\_Y\/R\_X\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["\<\
are three independent parameters that describe the dynamics of this system.  \
These parameters must be positive.\
\>", "Text"],

Cell["\<\
\tNext we evaluate the fixed points and the stability matrix for this system.\
\
\>", "Text"],

Cell[BoxData[{
    \(\(r = {x, y};\)\), "\[IndentingNewLine]", 
    \(\(v = {x\ \((1 - x)\)\  - \ \(a\ x\ y\)\/\(x + b\), 
          c\ y\ \((1 - y\/x)\)};\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fp = Solve[Thread[v \[Equal] 0], r]\)], "Input"],

Cell[BoxData[
    \({{y \[Rule] 0, 
        x \[Rule] 1}, {y \[Rule] 
          1\/2\ \((1 - a - b - \@\(4\ b + \((\(-1\) + a + b)\)\^2\))\), 
        x \[Rule] 
          1\/2\ \((1 - a - 
                b - \@\(4\ b + \((\(-1\) + a + b)\)\^2\))\)}, {y \[Rule] 
          1\/2\ \((1 - a - b + \@\(4\ b + \((\(-1\) + a + b)\)\^2\))\), 
        x \[Rule] 
          1\/2\ \((1 - a - 
                b + \@\(4\ b + \((\(-1\) + a + b)\)\^2\))\)}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(S = Outer[D, v, r]\)], "Input"],

Cell[BoxData[
    \({{1 - 
          2\ x + \(a\ x\ y\)\/\((b + x)\)\^2 - \(a\ y\)\/\(b + x\), \(-\(\(a\ \
x\)\/\(b + x\)\)\)}, {\(c\ y\^2\)\/x\^2, \(-\(\(c\ y\)\/x\)\) + 
          c\ \((1 - y\/x)\)}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "The second solution is not a viable fixed point with positive nonnegative \
populations.  The fixed point at ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 0}\)]],
  " is unstable whenever predators are present."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[
      S /. fp\[LeftDoubleBracket]1\[RightDoubleBracket]]\)], "Input"],

Cell[BoxData[
    \({\(-1\), c}\)], "Output"]
}, Closed]],

Cell["\<\
The nature of the nontrivial fixed point depends upon the parameter values in \
an interesting manner.  To analyze this behavior we observe that the secular \
equation for two-dimensional systems takes the form\
\>", "Text"],

Cell[BoxData[
    \(Det[S - \[Lambda]\ \[DoubleStruckOne]] \[Equal] 
      0\ \ \[DoubleLongRightArrow]\ \ \[Lambda]\^2\  - \ 
        Tr[S] \[Lambda]\  + \ Det[S]\  \[Equal] \ 0\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell["such that the eigenvalues", "Text"],

Cell[BoxData[
    \(\[Lambda]\  = \ \(1\/2\) \((\ 
          Tr[S]\  \[PlusMinus] \ \@\(Tr[S]\^2 - 4  Det[S]\)\ )\)\)], \
"DisplayFormula",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "are expressed in terms of two simple properties of the stability matrix.  \
We assume that ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is strictly real at the fixed point.  Therefore, the necessary and \
sufficient conditions for a stable fixed point require both ",
  Cell[BoxData[
      \(TraditionalForm\`Tr[S] < 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Det[S] > 0\)]],
  ".  For this system these quantities become"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(trS = 
      FullSimplify[
        Tr[S /. fp\[LeftDoubleBracket]3\[RightDoubleBracket]], {a > 0, b > 0, 
          c > 0}]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\(-2\)\ a\^2 + \((1 + b)\)\ \((\(-1\) - 
                  b + \@\(\((\(-1\) + a)\)\^2 + 2\ \((1 + a)\)\ b + b\^2\))\) \
+ a\ \((1 - 3\ b + 2\ \@\(\((\(-1\) + a)\)\^2 + 2\ \((1 + a)\)\ b + b\^2\) + 
                  2\ c)\)\)\/\(2\ a\)\)\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(detS = 
      FullSimplify[
        Det[S /. fp\[LeftDoubleBracket]3\[RightDoubleBracket]], {a > 0, 
          b > 0, c > 0}]\)], "Input"],

Cell[BoxData[
    \(\(\((\(-a\^2\) + a\ \((2 - 2\ b + \@\(\((\(-1\) + a)\)\^2 + 2\ \((1 + \
a)\)\ b + b\^2\))\) + \((1 + b)\)\ \((\(-1\) - b + \@\(\((\(-1\) + a)\)\^2 + \
2\ \((1 + a)\)\ b + b\^2\))\))\)\ c\)\/\(2\ a\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has some difficulty analyzing this inequality for ",
  Cell[BoxData[
      \(TraditionalForm\`Det[S]\)]],
  ","
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InequalitySolve[detS < 0, c] // 
      Simplify[#, {a > 0, b > 0}] &\)], "Input"],

Cell[BoxData[
    \(InequalitySolve::"nineq" \(\(:\)\(\ \)\) 
      "\!\(\(\(\((\(\(-a\^2\)\) + \(\(a\\ \(\(\[LeftSkeleton] 1 \
\[RightSkeleton]\)\)\)\) + \(\(\(\((1 + b)\)\)\\ \(\((\(\(-1\)\) - b + \@\(\(\
\[LeftSkeleton] 1 \[RightSkeleton]\)\^2 + \(\(\[LeftSkeleton] 1 \
\[RightSkeleton]\)\) + b\^2\))\)\)\)\))\)\)\\ c\)\/\(2\\ a\) < 0\) is not a \
formula constructed with univariate polynomial equations and inequalities in \
\!\(c\)."\)], "Message"],

Cell[BoxData[
    \(c < 0\)], "Output"]
}, Closed]],

Cell[TextData[{
  "one quickly sees that it cannot be satisfied unless ",
  Cell[BoxData[
      \(TraditionalForm\`c < 0\)]],
  ", which is not a valid parameter range; therefore, the condition on ",
  Cell[BoxData[
      \(TraditionalForm\`Det[S]\)]],
  " never leads to instability.  The condition on ",
  Cell[BoxData[
      \(TraditionalForm\`Tr[S]\)]],
  ", on the other hand, does yield an unstable region of parameter space.  \
This fixed point is stable for any ",
  Cell[BoxData[
      \(TraditionalForm\`a < 1\/2\)]],
  ", but for larger ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and small ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " it is unstable when ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is below the surface plotted below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(UnstableRegion = \((Simplify[#, {a > 0, b > 0}] &)\) /@ 
        InequalitySolve[trS > 0, c]\)], "Input"],

Cell[BoxData[
    \(c < \(2\ a\^2 + a\ \((\(-1\) + 3\ b - 2\ \@\(a\^2 + 2\ a\ \((\(-1\) + \
b)\) + \((1 + b)\)\^2\))\) - \((1 + b)\)\ \((\(-1\) - b + \@\(a\^2 + 2\ a\ \
\((\(-1\) + b)\) + \((1 + b)\)\^2\))\)\)\/\(2\ a\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(InequalityPlot3D[UnstableRegion, {a, 0, 2}, {b, 0, 5}, {c, 0, 2}, 
        AxesLabel \[Rule] {"\<a\>", "\<b\>", "\<c\>"}, 
        ViewPoint \[Rule] {3.0, \ 2.0, \ 1.0}, 
        PlotLabel \[Rule] "\<unstable region: c below surface\>"];\)\)], \
"Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05478 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
-0.0402395 1.16747 1.35851e-016 1.16747 [
[.5 1.06728 -80.375 0 ]
[.5 1.06728 80.375 15.6875 ]
[.96885 .33143 -9.75472 -15.6875 ]
[.96885 .33143 9.24528 0 ]
[.79362 .23426 -5.07932 -15.6875 ]
[.79362 .23426 4.92068 0 ]
[.59373 .12341 -9.53048 -15.6875 ]
[.59373 .12341 9.46952 0 ]
[.36356 -0.00424 -4.94206 -15.6875 ]
[.36356 -0.00424 5.05794 0 ]
[.69636 .10775 -5.04887 -15.6875 ]
[.69636 .10775 4.95113 0 ]
[.0337 .06944 -4.83662 -15.6875 ]
[.0337 .06944 5.16338 0 ]
[.09671 .05243 -9.22766 -15.6875 ]
[.09671 .05243 9.77234 0 ]
[.16097 .03507 -9.26657 -15.6875 ]
[.16097 .03507 9.73343 0 ]
[.22651 .01738 -9.30634 -15.6875 ]
[.22651 .01738 9.69366 0 ]
[.29337 -0.00068 -9.34701 -15.6875 ]
[.29337 -0.00068 9.65299 0 ]
[.18353 -0.04351 -4.8838 -15.6875 ]
[.18353 -0.04351 5.1162 0 ]
[.0113 .10755 -10 -5.74917 ]
[.0113 .10755 0 9.93833 ]
[.00615 .26019 -19 -5.93397 ]
[.00615 .26019 0 9.75353 ]
[.00091 .41585 -19 -6.12272 ]
[.00091 .41585 0 9.56478 ]
[-0.00444 .5746 -19.25 -6.31555 ]
[-0.00444 .5746 0 9.37195 ]
[-0.00988 .73655 -19 -6.5126 ]
[-0.00988 .73655 0 9.1749 ]
[-0.07237 .48657 -9.25 -6.19031 ]
[-0.07237 .48657 0 9.49719 ]
[ 0 0 0 0 ]
[ 1 1.05478 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.06728 -141.375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(unstable) show
106.563 15.813 moveto
(region) show
137.813 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
144.750 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
153.000 15.813 moveto
(below) show
184.563 15.813 moveto
(surface) show
219.750 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.98153 .35283 m
.3447 0 L
s
.96924 .34602 m
.96944 .35331 L
s
gsave
.96885 .33143 -70.7547 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.79386 .24885 m
.79397 .25615 L
s
gsave
.79362 .23426 -66.0793 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.59378 .138 m
.5938 .1453 L
s
gsave
.59373 .12341 -70.5305 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.36339 .01036 m
.36331 .01765 L
s
gsave
.36356 -0.00424 -65.9421 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.93592 .32756 m
.93603 .33193 L
s
.90175 .30863 m
.90185 .313 L
s
.86671 .28921 m
.8668 .29359 L
s
.83075 .26929 m
.83083 .27367 L
s
.75597 .22786 m
.75603 .23224 L
s
.71707 .20631 m
.71712 .21068 L
s
.6771 .18416 m
.67713 .18854 L
s
.63602 .1614 m
.63604 .16578 L
s
.55033 .11393 m
.55033 .11831 L
s
.50563 .08916 m
.50562 .09354 L
s
.45961 .06367 m
.45959 .06804 L
s
.41222 .03741 m
.41218 .04179 L
s
gsave
.69636 .10775 -66.0489 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.02599 .08598 m
.3447 0 L
s
.03322 .08403 m
.03299 .09132 L
s
gsave
.0337 .06944 -65.8366 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0963 .06701 m
.09609 .07431 L
s
gsave
.09671 .05243 -70.2277 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.16061 .04966 m
.16043 .05696 L
s
gsave
.16097 .03507 -70.2666 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.22621 .03197 m
.22606 .03926 L
s
gsave
.22651 .01738 -70.3063 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
.29313 .01391 m
.29302 .02121 L
s
gsave
.29337 -0.00068 -70.347 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.04574 .08065 m
.0456 .08503 L
s
.05831 .07726 m
.05817 .08164 L
s
.07092 .07386 m
.07079 .07824 L
s
.08358 .07044 m
.08345 .07482 L
s
.10906 .06357 m
.10894 .06795 L
s
.12187 .06011 m
.12175 .06449 L
s
.13473 .05664 m
.13462 .06102 L
s
.14765 .05316 m
.14754 .05754 L
s
.17363 .04615 m
.17352 .05053 L
s
.1867 .04263 m
.1866 .047 L
s
.19982 .03909 m
.19972 .04346 L
s
.21299 .03553 m
.21289 .03991 L
s
.23949 .02838 m
.2394 .03276 L
s
.25282 .02479 m
.25274 .02916 L
s
.2662 .02118 m
.26613 .02555 L
s
.27964 .01755 m
.27957 .02193 L
s
.30668 .01026 m
.30661 .01463 L
s
.32028 .00659 m
.32022 .01097 L
s
.33394 .0029 m
.33388 .00728 L
s
gsave
.18353 -0.04351 -65.8838 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.02599 .08598 m
0 .87024 L
s
.0254 .10378 m
.03245 .1019 L
s
gsave
.0113 .10755 -71 -9.74917 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02033 .25674 m
.02742 .25501 L
s
gsave
.00615 .26019 -80 -9.93397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.01516 .41272 m
.02229 .41115 L
s
gsave
.00091 .41585 -80 -10.1227 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.00989 .57181 m
.01705 .57041 L
s
gsave
-0.00444 .5746 -80.25 -10.3156 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.00451 .73411 m
.0117 .73289 L
s
gsave
-0.00988 .73655 -80 -10.5126 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.02414 .14174 m
.02837 .14064 L
s
.02287 .17989 m
.02712 .17881 L
s
.0216 .21822 m
.02585 .21716 L
s
.01905 .29545 m
.0233 .29444 L
s
.01776 .33435 m
.02202 .33336 L
s
.01646 .37344 m
.02073 .37247 L
s
.01385 .4522 m
.01813 .45128 L
s
.01254 .49187 m
.01682 .49098 L
s
.01122 .53174 m
.01551 .53088 L
s
.00855 .61208 m
.01286 .61127 L
s
.00721 .65255 m
.01152 .65177 L
s
.00587 .69323 m
.01018 .69247 L
s
.00315 .77519 m
.00747 .77449 L
s
.00178 .81649 m
.00611 .81581 L
s
.00041 .85799 m
.00474 .85734 L
s
gsave
-0.07237 .48657 -70.25 -10.1903 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
68.250 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.69767 .40927 m
.70392 1.05478 L
s
.70392 1.05478 m
1 1.02281 L
s
1 1.02281 m
.98153 .35283 L
s
.98153 .35283 m
.69767 .40927 L
s
.02599 .08598 m
.3447 0 L
s
.3447 0 m
.3342 .82058 L
s
.3342 .82058 m
0 .87024 L
s
0 .87024 m
.02599 .08598 L
s
.69767 .40927 m
.70392 1.05478 L
s
.70392 1.05478 m
0 .87024 L
s
0 .87024 m
.02599 .08598 L
s
.02599 .08598 m
.69767 .40927 L
s
.98153 .35283 m
.3447 0 L
s
.3447 0 m
.3342 .82058 L
s
.3342 .82058 m
1 1.02281 L
s
1 1.02281 m
.98153 .35283 L
s
0 0 m
1 0 L
1 1.05478 L
0 1.05478 L
closepath
clip
newpath
.5 Mabswid
.568 .808 .989 r
.69126 .41653 m .6861 .37178 L .67829 .37338 L closepath p F P
0 g
s
.568 .808 .989 r
.69126 .41653 m .67829 .37338 L .6705 .37497 L closepath p F P
0 g
s
.568 .808 .989 r
.69126 .41653 m .6705 .37497 L .66273 .37656 L closepath p F P
0 g
s
.568 .808 .989 r
.69126 .41653 m .66273 .37656 L .65498 .37814 L closepath p F P
0 g
s
.568 .808 .989 r
.69126 .41653 m .65498 .37814 L .64724 .37973 L closepath p F P
0 g
s
.568 .808 .989 r
.69126 .41653 m .64724 .37973 L .63952 .38131 L closepath p F P
0 g
s
.568 .808 .989 r
.69126 .41653 m .63952 .38131 L .63181 .38288 L closepath p F P
0 g
s
.568 .808 .989 r
.69126 .41653 m .63181 .38288 L .62412 .38445 L closepath p F P
0 g
s
.935 .932 .573 r
.69126 .41653 m .67846 .3926 L .6861 .37178 L closepath p F P
0 g
s
.938 .922 .551 r
.69126 .41653 m .67082 .41524 L .67846 .3926 L closepath p F P
0 g
s
.944 .912 .534 r
.69126 .41653 m .66321 .44009 L .67082 .41524 L closepath p F P
0 g
s
.955 .904 .526 r
.69126 .41653 m .6556 .46769 L .66321 .44009 L closepath p F P
0 g
s
.968 .896 .527 r
.69126 .41653 m .64801 .49881 L .6556 .46769 L closepath p F P
0 g
s
.983 .886 .536 r
.69126 .41653 m .64044 .53464 L .64801 .49881 L closepath p F P
0 g
s
.994 .872 .553 r
.69126 .41653 m .63289 .57714 L .64044 .53464 L closepath p F P
0 g
s
.996 .849 .574 r
.69126 .41653 m .62537 .63011 L .63289 .57714 L closepath p F P
0 g
s
.568 .808 .989 r
.56764 .34797 m .55386 .35088 L .62412 .38445 L p F P
0 g
s
.568 .808 .989 r
.62412 .38445 m .63181 .38288 L .56764 .34797 L p F P
0 g
s
.568 .808 .989 r
.58147 .34504 m .56764 .34797 L .63181 .38288 L p F P
0 g
s
.568 .808 .989 r
.63181 .38288 m .63952 .38131 L .58147 .34504 L p F P
0 g
s
.568 .808 .989 r
.59536 .34211 m .58147 .34504 L .63952 .38131 L p F P
0 g
s
.568 .808 .989 r
.63952 .38131 m .64724 .37973 L .59536 .34211 L p F P
0 g
s
.568 .808 .989 r
.60931 .33916 m .59536 .34211 L .64724 .37973 L p F P
0 g
s
.568 .808 .989 r
.64724 .37973 m .65498 .37814 L .60931 .33916 L p F P
0 g
s
.568 .808 .989 r
.62331 .3362 m .60931 .33916 L .65498 .37814 L p F P
0 g
s
.568 .808 .989 r
.65498 .37814 m .66273 .37656 L .62331 .3362 L p F P
0 g
s
.568 .808 .989 r
.63736 .33323 m .62331 .3362 L .66273 .37656 L p F P
0 g
s
.568 .808 .989 r
.66273 .37656 m .6705 .37497 L .63736 .33323 L p F P
0 g
s
.568 .808 .989 r
.65148 .33025 m .63736 .33323 L .6705 .37497 L p F P
0 g
s
.568 .808 .989 r
.6705 .37497 m .67829 .37338 L .65148 .33025 L p F P
0 g
s
.568 .808 .989 r
.66565 .32726 m .65148 .33025 L .67829 .37338 L p F P
0 g
s
.568 .808 .989 r
.67829 .37338 m .6861 .37178 L .66565 .32726 L p F P
0 g
s
.951 .936 .741 r
.66565 .32726 m .6861 .37178 L .67846 .3926 L p F P
0 g
s
.951 .936 .741 r
.67846 .3926 m .65166 .35725 L .66565 .32726 L p F P
0 g
s
.959 .924 .723 r
.65166 .35725 m .67846 .3926 L .67082 .41524 L p F P
0 g
s
.959 .924 .723 r
.67082 .41524 m .6377 .39065 L .65166 .35725 L p F P
0 g
s
.967 .91 .705 r
.6377 .39065 m .67082 .41524 L .66321 .44009 L p F P
0 g
s
.967 .91 .705 r
.66321 .44009 m .62377 .42846 L .6377 .39065 L p F P
0 g
s
.973 .894 .686 r
.62377 .42846 m .66321 .44009 L .6556 .46769 L p F P
0 g
s
.973 .894 .686 r
.6556 .46769 m .60986 .47221 L .62377 .42846 L p F P
0 g
s
.977 .874 .667 r
.60986 .47221 m .6556 .46769 L .64801 .49881 L p F P
0 g
s
.977 .874 .667 r
.64801 .49881 m .59596 .52447 L .60986 .47221 L p F P
0 g
s
.978 .852 .647 r
.59596 .52447 m .64801 .49881 L .64044 .53464 L p F P
0 g
s
.978 .852 .647 r
.64044 .53464 m .58206 .59019 L .59596 .52447 L p F P
0 g
s
.976 .824 .627 r
.58206 .59019 m .64044 .53464 L .63289 .57714 L p F P
0 g
s
.976 .824 .627 r
.63289 .57714 m .56814 .68153 L .58206 .59019 L p F P
0 g
s
.966 .783 .606 r
.56814 .68153 m .63289 .57714 L .62537 .63011 L p F P
0 g
s
.966 .783 .606 r
.62537 .63011 m .55419 .86084 L .56814 .68153 L p F P
0 g
s
.568 .808 .989 r
.49908 .31158 m .48023 .3157 L .55386 .35088 L p F P
0 g
s
.568 .808 .989 r
.55386 .35088 m .56764 .34797 L .49908 .31158 L p F P
0 g
s
.568 .808 .989 r
.51803 .30744 m .49908 .31158 L .56764 .34797 L p F P
0 g
s
.568 .808 .989 r
.56764 .34797 m .58147 .34504 L .51803 .30744 L p F P
0 g
s
.568 .808 .989 r
.53708 .30327 m .51803 .30744 L .58147 .34504 L p F P
0 g
s
.568 .808 .989 r
.58147 .34504 m .59536 .34211 L .53708 .30327 L p F P
0 g
s
.568 .808 .989 r
.55624 .29908 m .53708 .30327 L .59536 .34211 L p F P
0 g
s
.568 .808 .989 r
.59536 .34211 m .60931 .33916 L .55624 .29908 L p F P
0 g
s
.568 .808 .989 r
.5755 .29487 m .55624 .29908 L .60931 .33916 L p F P
0 g
s
.568 .808 .989 r
.60931 .33916 m .62331 .3362 L .5755 .29487 L p F P
0 g
s
.568 .808 .989 r
.59487 .29063 m .5755 .29487 L .62331 .3362 L p F P
0 g
s
.568 .808 .989 r
.62331 .3362 m .63736 .33323 L .59487 .29063 L p F P
0 g
s
.568 .808 .989 r
.61435 .28637 m .59487 .29063 L .63736 .33323 L p F P
0 g
s
.568 .808 .989 r
.63736 .33323 m .65148 .33025 L .61435 .28637 L p F P
0 g
s
.568 .808 .989 r
.63393 .28209 m .61435 .28637 L .65148 .33025 L p F P
0 g
s
.568 .808 .989 r
.65148 .33025 m .66565 .32726 L .63393 .28209 L p F P
0 g
s
.925 .895 .78 r
.61448 .31652 m .65166 .35725 L .6377 .39065 L p F P
0 g
s
.925 .895 .78 r
.6377 .39065 m .59508 .35494 L .61448 .31652 L p F P
0 g
s
.932 .879 .761 r
.59508 .35494 m .6377 .39065 L .62377 .42846 L p F P
0 g
s
.917 .909 .797 r
.63393 .28209 m .66565 .32726 L .65166 .35725 L p F P
0 g
s
.917 .909 .797 r
.65166 .35725 m .61448 .31652 L .63393 .28209 L p F P
0 g
s
.932 .879 .761 r
.62377 .42846 m .57571 .39856 L .59508 .35494 L p F P
0 g
s
.936 .86 .74 r
.57571 .39856 m .62377 .42846 L .60986 .47221 L p F P
0 g
s
.936 .86 .74 r
.60986 .47221 m .55636 .44928 L .57571 .39856 L p F P
0 g
s
.939 .839 .718 r
.55636 .44928 m .60986 .47221 L .59596 .52447 L p F P
0 g
s
.939 .839 .718 r
.59596 .52447 m .53699 .51034 L .55636 .44928 L p F P
0 g
s
.939 .815 .695 r
.53699 .51034 m .59596 .52447 L .58206 .59019 L p F P
0 g
s
.939 .815 .695 r
.58206 .59019 m .51757 .58819 L .53699 .51034 L p F P
0 g
s
.937 .786 .668 r
.51757 .58819 m .58206 .59019 L .56814 .68153 L p F P
0 g
s
.937 .786 .668 r
.56814 .68153 m .49799 .69961 L .51757 .58819 L p F P
0 g
s
.936 .751 .628 r
.49799 .69961 m .56814 .68153 L .55419 .86084 L p F P
0 g
s
.568 .808 .989 r
.4262 .27355 m .403 .2788 L .48023 .3157 L p F P
0 g
s
.568 .808 .989 r
.48023 .3157 m .49908 .31158 L .4262 .27355 L p F P
0 g
s
.568 .808 .989 r
.44955 .26826 m .4262 .27355 L .49908 .31158 L p F P
0 g
s
.568 .808 .989 r
.49908 .31158 m .51803 .30744 L .44955 .26826 L p F P
0 g
s
.568 .808 .989 r
.47306 .26293 m .44955 .26826 L .51803 .30744 L p F P
0 g
s
.568 .808 .989 r
.51803 .30744 m .53708 .30327 L .47306 .26293 L p F P
0 g
s
.936 .751 .628 r
.55419 .86084 m .4776 .97553 L .49799 .69961 L p F P
0 g
s
.568 .808 .989 r
.49674 .25757 m .47306 .26293 L .53708 .30327 L p F P
0 g
s
.568 .808 .989 r
.53708 .30327 m .55624 .29908 L .49674 .25757 L p F P
0 g
s
.568 .808 .989 r
.52058 .25216 m .49674 .25757 L .55624 .29908 L p F P
0 g
s
.568 .808 .989 r
.55624 .29908 m .5755 .29487 L .52058 .25216 L p F P
0 g
s
.568 .808 .989 r
.54458 .24673 m .52058 .25216 L .5755 .29487 L p F P
0 g
s
.568 .808 .989 r
.5755 .29487 m .59487 .29063 L .54458 .24673 L p F P
0 g
s
.568 .808 .989 r
.56875 .24125 m .54458 .24673 L .59487 .29063 L p F P
0 g
s
.568 .808 .989 r
.59487 .29063 m .61435 .28637 L .56875 .24125 L p F P
0 g
s
.568 .808 .989 r
.59309 .23574 m .56875 .24125 L .61435 .28637 L p F P
0 g
s
.568 .808 .989 r
.61435 .28637 m .63393 .28209 L .59309 .23574 L p F P
0 g
s
.901 .861 .791 r
.54458 .31331 m .59508 .35494 L .57571 .39856 L p F P
0 g
s
.901 .861 .791 r
.57571 .39856 m .52042 .35928 L .54458 .31331 L p F P
0 g
s
.906 .842 .771 r
.52042 .35928 m .57571 .39856 L .55636 .44928 L p F P
0 g
s
.906 .842 .771 r
.55636 .44928 m .49628 .41223 L .52042 .35928 L p F P
0 g
s
.908 .82 .748 r
.49628 .41223 m .55636 .44928 L .53699 .51034 L p F P
0 g
s
.895 .877 .81 r
.5688 .27252 m .61448 .31652 L .59508 .35494 L p F P
0 g
s
.895 .877 .81 r
.59508 .35494 m .54458 .31331 L .5688 .27252 L p F P
0 g
s
.887 .891 .828 r
.59309 .23574 m .63393 .28209 L .61448 .31652 L p F P
0 g
s
.887 .891 .828 r
.61448 .31652 m .5688 .27252 L .59309 .23574 L p F P
0 g
s
.908 .82 .748 r
.53699 .51034 m .47212 .47514 L .49628 .41223 L p F P
0 g
s
.908 .796 .724 r
.47212 .47514 m .53699 .51034 L .51757 .58819 L p F P
0 g
s
.908 .796 .724 r
.51757 .58819 m .44785 .55362 L .47212 .47514 L p F P
0 g
s
.904 .766 .698 r
.44785 .55362 m .51757 .58819 L .49799 .69961 L p F P
0 g
s
.568 .808 .989 r
.34892 .2337 m .3219 .24005 L .403 .2788 L p F P
0 g
s
.568 .808 .989 r
.403 .2788 m .4262 .27355 L .34892 .2337 L p F P
0 g
s
.904 .766 .698 r
.49799 .69961 m .42333 .66069 L .44785 .55362 L p F P
0 g
s
.877 .711 .672 r
.42333 .66069 m .49799 .69961 L .4776 .97553 L p F P
0 g
s
.568 .808 .989 r
.37615 .2273 m .34892 .2337 L .4262 .27355 L p F P
0 g
s
.568 .808 .989 r
.4262 .27355 m .44955 .26826 L .37615 .2273 L p F P
0 g
s
.568 .808 .989 r
.40361 .22085 m .37615 .2273 L .44955 .26826 L p F P
0 g
s
.568 .808 .989 r
.44955 .26826 m .47306 .26293 L .40361 .22085 L p F P
0 g
s
.568 .808 .989 r
.43129 .21434 m .40361 .22085 L .47306 .26293 L p F P
0 g
s
.568 .808 .989 r
.47306 .26293 m .49674 .25757 L .43129 .21434 L p F P
0 g
s
.568 .808 .989 r
.45919 .20778 m .43129 .21434 L .49674 .25757 L p F P
0 g
s
.568 .808 .989 r
.49674 .25757 m .52058 .25216 L .45919 .20778 L p F P
0 g
s
.877 .711 .672 r
.4776 .97553 m .39794 .84897 L .42333 .66069 L p F P
0 g
s
.568 .808 .989 r
.48733 .20117 m .45919 .20778 L .52058 .25216 L p F P
0 g
s
.568 .808 .989 r
.52058 .25216 m .54458 .24673 L .48733 .20117 L p F P
0 g
s
.568 .808 .989 r
.51569 .1945 m .48733 .20117 L .54458 .24673 L p F P
0 g
s
.568 .808 .989 r
.54458 .24673 m .56875 .24125 L .51569 .1945 L p F P
0 g
s
.882 .834 .794 r
.45862 .31469 m .52042 .35928 L .49628 .41223 L p F P
0 g
s
.882 .834 .794 r
.49628 .41223 m .43019 .36784 L .45862 .31469 L p F P
0 g
s
.886 .813 .772 r
.43019 .36784 m .49628 .41223 L .47212 .47514 L p F P
0 g
s
.886 .813 .772 r
.47212 .47514 m .40175 .42981 L .43019 .36784 L p F P
0 g
s
.887 .79 .748 r
.40175 .42981 m .47212 .47514 L .44785 .55362 L p F P
0 g
s
.877 .851 .814 r
.48709 .26791 m .54458 .31331 L .52042 .35928 L p F P
0 g
s
.877 .851 .814 r
.52042 .35928 m .45862 .31469 L .48709 .26791 L p F P
0 g
s
.568 .808 .989 r
.54429 .18778 m .51569 .1945 L .56875 .24125 L p F P
0 g
s
.568 .808 .989 r
.56875 .24125 m .59309 .23574 L .54429 .18778 L p F P
0 g
s
.887 .79 .748 r
.44785 .55362 m .37321 .50487 L .40175 .42981 L p F P
0 g
s
.884 .761 .722 r
.37321 .50487 m .44785 .55362 L .42333 .66069 L p F P
0 g
s
.87 .866 .832 r
.51563 .22596 m .5688 .27252 L .54458 .31331 L p F P
0 g
s
.87 .866 .832 r
.54458 .31331 m .48709 .26791 L .51563 .22596 L p F P
0 g
s
.568 .808 .989 r
.26706 .19188 m .23663 .19931 L .3219 .24005 L p F P
0 g
s
.568 .808 .989 r
.3219 .24005 m .34892 .2337 L .26706 .19188 L p F P
0 g
s
.862 .878 .848 r
.54429 .18778 m .59309 .23574 L .5688 .27252 L p F P
0 g
s
.862 .878 .848 r
.5688 .27252 m .51563 .22596 L .54429 .18778 L p F P
0 g
s
.884 .761 .722 r
.42333 .66069 m .34438 .60179 L .37321 .50487 L p F P
0 g
s
.87 .721 .695 r
.34438 .60179 m .42333 .66069 L .39794 .84897 L p F P
0 g
s
.568 .808 .989 r
.29778 .18437 m .26706 .19188 L .34892 .2337 L p F P
0 g
s
.568 .808 .989 r
.34892 .2337 m .37615 .2273 L .29778 .18437 L p F P
0 g
s
.568 .808 .989 r
.32879 .1768 m .29778 .18437 L .37615 .2273 L p F P
0 g
s
.568 .808 .989 r
.37615 .2273 m .40361 .22085 L .32879 .1768 L p F P
0 g
s
.87 .721 .695 r
.39794 .84897 m .31481 .74507 L .34438 .60179 L p F P
0 g
s
.568 .808 .989 r
.36008 .16916 m .32879 .1768 L .40361 .22085 L p F P
0 g
s
.568 .808 .989 r
.40361 .22085 m .43129 .21434 L .36008 .16916 L p F P
0 g
s
.568 .808 .989 r
.39166 .16145 m .36008 .16916 L .43129 .21434 L p F P
0 g
s
.568 .808 .989 r
.43129 .21434 m .45919 .20778 L .39166 .16145 L p F P
0 g
s
.568 .808 .989 r
.42354 .15367 m .39166 .16145 L .45919 .20778 L p F P
0 g
s
.568 .808 .989 r
.45919 .20778 m .48733 .20117 L .42354 .15367 L p F P
0 g
s
.568 .808 .989 r
.45571 .14581 m .42354 .15367 L .48733 .20117 L p F P
0 g
s
.568 .808 .989 r
.48733 .20117 m .51569 .1945 L .45571 .14581 L p F P
0 g
s
.868 .812 .792 r
.35832 .31916 m .43019 .36784 L .40175 .42981 L p F P
0 g
s
.868 .812 .792 r
.40175 .42981 m .32602 .37934 L .35832 .31916 L p F P
0 g
s
.87 .791 .77 r
.32602 .37934 m .40175 .42981 L .37321 .50487 L p F P
0 g
s
.568 .808 .989 r
.18039 .14789 m .14684 .15641 L .23663 .19931 L p F P
0 g
s
.568 .808 .989 r
.23663 .19931 m .26706 .19188 L .18039 .14789 L p F P
0 g
s
.87 .791 .77 r
.37321 .50487 m .29363 .45029 L .32602 .37934 L p F P
0 g
s
.869 .765 .745 r
.29363 .45029 m .37321 .50487 L .34438 .60179 L p F P
0 g
s
.863 .831 .813 r
.39064 .26656 m .45862 .31469 L .43019 .36784 L p F P
0 g
s
.863 .831 .813 r
.43019 .36784 m .35832 .31916 L .39064 .26656 L p F P
0 g
s
.857 .846 .832 r
.42303 .2196 m .48709 .26791 L .45862 .31469 L p F P
0 g
s
.857 .846 .832 r
.45862 .31469 m .39064 .26656 L .42303 .2196 L p F P
0 g
s
.869 .765 .745 r
.34438 .60179 m .26098 .53783 L .29363 .45029 L p F P
0 g
s
.863 .733 .718 r
.26098 .53783 m .34438 .60179 L .31481 .74507 L p F P
0 g
s
.568 .808 .989 r
.4882 .13788 m .45571 .14581 L .51569 .1945 L p F P
0 g
s
.568 .808 .989 r
.51569 .1945 m .54429 .18778 L .4882 .13788 L p F P
0 g
s
.85 .859 .849 r
.45554 .177 m .51563 .22596 L .48709 .26791 L p F P
0 g
s
.85 .859 .849 r
.48709 .26791 m .42303 .2196 L .45554 .177 L p F P
0 g
s
.568 .808 .989 r
.21427 .13928 m .18039 .14789 L .26706 .19188 L p F P
0 g
s
.568 .808 .989 r
.26706 .19188 m .29778 .18437 L .21427 .13928 L p F P
0 g
s
.842 .87 .864 r
.4882 .13788 m .54429 .18778 L .51563 .22596 L p F P
0 g
s
.842 .87 .864 r
.51563 .22596 m .45554 .177 L .4882 .13788 L p F P
0 g
s
.863 .733 .718 r
.31481 .74507 m .22774 .65501 L .26098 .53783 L p F P
0 g
s
.568 .808 .989 r
.24851 .13058 m .21427 .13928 L .29778 .18437 L p F P
0 g
s
.568 .808 .989 r
.29778 .18437 m .32879 .1768 L .24851 .13058 L p F P
0 g
s
.568 .808 .989 r
.2831 .12179 m .24851 .13058 L .32879 .1768 L p F P
0 g
s
.568 .808 .989 r
.32879 .1768 m .36008 .16916 L .2831 .12179 L p F P
0 g
s
.568 .808 .989 r
.31806 .11291 m .2831 .12179 L .36008 .16916 L p F P
0 g
s
.568 .808 .989 r
.36008 .16916 m .39166 .16145 L .31806 .11291 L p F P
0 g
s
.568 .808 .989 r
.35338 .10394 m .31806 .11291 L .39166 .16145 L p F P
0 g
s
.568 .808 .989 r
.39166 .16145 m .42354 .15367 L .35338 .10394 L p F P
0 g
s
.857 .795 .79 r
.24483 .32582 m .32602 .37934 L .29363 .45029 L p F P
0 g
s
.857 .795 .79 r
.29363 .45029 m .20894 .39302 L .24483 .32582 L p F P
0 g
s
.858 .772 .766 r
.20894 .39302 m .29363 .45029 L .26098 .53783 L p F P
0 g
s
.568 .808 .989 r
.08858 .10155 m .05219 .11119 L .14684 .15641 L p F P
0 g
s
.568 .808 .989 r
.14684 .15641 m .18039 .14789 L .08858 .10155 L p F P
0 g
s
.858 .772 .766 r
.26098 .53783 m .17286 .47306 L .20894 .39302 L p F P
0 g
s
.855 .745 .741 r
.17286 .47306 m .26098 .53783 L .22774 .65501 L p F P
0 g
s
.853 .814 .811 r
.28068 .26746 m .35832 .31916 L .32602 .37934 L p F P
0 g
s
.853 .814 .811 r
.32602 .37934 m .24483 .32582 L .28068 .26746 L p F P
0 g
s
.568 .808 .989 r
.38907 .09487 m .35338 .10394 L .42354 .15367 L p F P
0 g
s
.568 .808 .989 r
.42354 .15367 m .45571 .14581 L .38907 .09487 L p F P
0 g
s
.847 .83 .83 r
.31658 .21558 m .39064 .26656 L .35832 .31916 L p F P
0 g
s
.847 .83 .83 r
.35832 .31916 m .28068 .26746 L .31658 .21558 L p F P
0 g
s
.855 .745 .741 r
.22774 .65501 m .1363 .57366 L .17286 .47306 L p F P
0 g
s
.84 .844 .847 r
.35259 .16864 m .42303 .2196 L .39064 .26656 L p F P
0 g
s
.84 .844 .847 r
.39064 .26656 m .31658 .21558 L .35259 .16864 L p F P
0 g
s
.568 .808 .989 r
.12538 .09181 m .08858 .10155 L .18039 .14789 L p F P
0 g
s
.568 .808 .989 r
.18039 .14789 m .21427 .13928 L .12538 .09181 L p F P
0 g
s
.832 .855 .863 r
.38877 .1256 m .45554 .177 L .42303 .2196 L p F P
0 g
s
.832 .855 .863 r
.42303 .2196 m .35259 .16864 L .38877 .1256 L p F P
0 g
s
.568 .808 .989 r
.42514 .0857 m .38907 .09487 L .45571 .14581 L p F P
0 g
s
.568 .808 .989 r
.45571 .14581 m .4882 .13788 L .42514 .0857 L p F P
0 g
s
.824 .865 .877 r
.42514 .0857 m .4882 .13788 L .45554 .177 L p F P
0 g
s
.824 .865 .877 r
.45554 .177 m .38877 .1256 L .42514 .0857 L p F P
0 g
s
.568 .808 .989 r
.1626 .08195 m .12538 .09181 L .21427 .13928 L p F P
0 g
s
.568 .808 .989 r
.21427 .13928 m .24851 .13058 L .1626 .08195 L p F P
0 g
s
.568 .808 .989 r
.20025 .07199 m .1626 .08195 L .24851 .13058 L p F P
0 g
s
.568 .808 .989 r
.24851 .13058 m .2831 .12179 L .20025 .07199 L p F P
0 g
s
.568 .808 .989 r
.23833 .0619 m .20025 .07199 L .2831 .12179 L p F P
0 g
s
.568 .808 .989 r
.2831 .12179 m .31806 .11291 L .23833 .0619 L p F P
0 g
s
.847 .781 .786 r
.1189 .3341 m .20894 .39302 L .17286 .47306 L p F P
0 g
s
.847 .781 .786 r
.17286 .47306 m .07965 .40838 L .1189 .3341 L p F P
0 g
s
.848 .757 .762 r
.07965 .40838 m .17286 .47306 L .1363 .57366 L p F P
0 g
s
.568 .808 .989 r
.27685 .0517 m .23833 .0619 L .31806 .11291 L p F P
0 g
s
.568 .808 .989 r
.31806 .11291 m .35338 .10394 L .27685 .0517 L p F P
0 g
s
.848 .757 .762 r
.1363 .57366 m .04005 .49774 L .07965 .40838 L p F P
0 g
s
.844 .8 .808 r
.15801 .26999 m .24483 .32582 L .20894 .39302 L p F P
0 g
s
.844 .8 .808 r
.20894 .39302 m .1189 .3341 L .15801 .26999 L p F P
0 g
s
.839 .817 .828 r
.19714 .21321 m .28068 .26746 L .24483 .32582 L p F P
0 g
s
.839 .817 .828 r
.24483 .32582 m .15801 .26999 L .19714 .21321 L p F P
0 g
s
.833 .831 .845 r
.23637 .16197 m .31658 .21558 L .28068 .26746 L p F P
0 g
s
.833 .831 .845 r
.28068 .26746 m .19714 .21321 L .23637 .16197 L p F P
0 g
s
.568 .808 .989 r
.31581 .04138 m .27685 .0517 L .35338 .10394 L p F P
0 g
s
.568 .808 .989 r
.35338 .10394 m .38907 .09487 L .31581 .04138 L p F P
0 g
s
.825 .843 .861 r
.27576 .11505 m .35259 .16864 L .31658 .21558 L p F P
0 g
s
.825 .843 .861 r
.31658 .21558 m .23637 .16197 L .27576 .11505 L p F P
0 g
s
.817 .852 .875 r
.31537 .07159 m .38877 .1256 L .35259 .16864 L p F P
0 g
s
.817 .852 .875 r
.35259 .16864 m .27576 .11505 L .31537 .07159 L p F P
0 g
s
.568 .808 .989 r
.35524 .03095 m .31581 .04138 L .38907 .09487 L p F P
0 g
s
.568 .808 .989 r
.38907 .09487 m .42514 .0857 L .35524 .03095 L p F P
0 g
s
.809 .861 .887 r
.35524 .03095 m .42514 .0857 L .38877 .1256 L p F P
0 g
s
.809 .861 .887 r
.38877 .1256 m .31537 .07159 L .35524 .03095 L p F P
0 g
s
.25 Mabswid
.02599 .08598 m
.3447 0 L
s
.3447 0 m
.3342 .82058 L
s
.3342 .82058 m
0 .87024 L
s
0 .87024 m
.02599 .08598 L
s
.98153 .35283 m
.3447 0 L
s
.3447 0 m
.3342 .82058 L
s
.3342 .82058 m
1 1.02281 L
s
1 1.02281 m
.98153 .35283 L
s
.98153 .35283 m
.3447 0 L
s
.96924 .34602 m
.96944 .35331 L
s
gsave
.96885 .33143 -70.7547 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.79386 .24885 m
.79397 .25615 L
s
gsave
.79362 .23426 -66.0793 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.59378 .138 m
.5938 .1453 L
s
gsave
.59373 .12341 -70.5305 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.36339 .01036 m
.36331 .01765 L
s
gsave
.36356 -0.00424 -65.9421 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.93592 .32756 m
.93603 .33193 L
s
.90175 .30863 m
.90185 .313 L
s
.86671 .28921 m
.8668 .29359 L
s
.83075 .26929 m
.83083 .27367 L
s
.75597 .22786 m
.75603 .23224 L
s
.71707 .20631 m
.71712 .21068 L
s
.6771 .18416 m
.67713 .18854 L
s
.63602 .1614 m
.63604 .16578 L
s
.55033 .11393 m
.55033 .11831 L
s
.50563 .08916 m
.50562 .09354 L
s
.45961 .06367 m
.45959 .06804 L
s
.41222 .03741 m
.41218 .04179 L
s
gsave
.69636 .10775 -66.0489 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.02599 .08598 m
0 .87024 L
s
.0254 .10378 m
.03245 .1019 L
s
gsave
.0113 .10755 -71 -9.74917 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02033 .25674 m
.02742 .25501 L
s
gsave
.00615 .26019 -80 -9.93397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.01516 .41272 m
.02229 .41115 L
s
gsave
.00091 .41585 -80 -10.1227 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.00989 .57181 m
.01705 .57041 L
s
gsave
-0.00444 .5746 -80.25 -10.3156 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.00451 .73411 m
.0117 .73289 L
s
gsave
-0.00988 .73655 -80 -10.5126 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.02414 .14174 m
.02837 .14064 L
s
.02287 .17989 m
.02712 .17881 L
s
.0216 .21822 m
.02585 .21716 L
s
.01905 .29545 m
.0233 .29444 L
s
.01776 .33435 m
.02202 .33336 L
s
.01646 .37344 m
.02073 .37247 L
s
.01385 .4522 m
.01813 .45128 L
s
.01254 .49187 m
.01682 .49098 L
s
.01122 .53174 m
.01551 .53088 L
s
.00855 .61208 m
.01286 .61127 L
s
.00721 .65255 m
.01152 .65177 L
s
.00587 .69323 m
.01018 .69247 L
s
.00315 .77519 m
.00747 .77449 L
s
.00178 .81649 m
.00611 .81581 L
s
.00041 .85799 m
.00474 .85734 L
s
gsave
-0.07237 .48657 -70.25 -10.1903 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
68.250 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 303.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001ab000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00L`3oool01@3OW4P000000000000004P0W=oo0?l0oooo>@3oool00780
oooo00L0omnL04P0M02oool0oooo0?oo_`1d0000B9cO0?l0oooo>03oool00780oooo00<0oono07@0
001d_ol00P3oool00`3ookl0M00007Boo`3o0?ooocL0oooo001c0?ooo`030;md0018W=l0oooo0080
oooo00<0gia80018W03Oool0o`3ooolf0?ooo`00L`3oool00`3OW4P004RL0=ooo`020?ooo`030?oO
W01804P0W=oo0?l0oooo=P3oool007<0oooo00<0omnL04P0B01d_ml00P3oool00`3ookl0M00007Bo
o`3o0?ooocH0oooo001c0?ooo`080?oo_`1d0000B4Q804RLg`3oool0okmd0000B02Lgooo0?ooocH0
oooo001d0?ooo`030;md0000M;l0gia80080000000<0B9cO0?ooo`3oool0o`3ooole0?ooo`00M03o
ool00`3OW4P004RL0=ooo`3o0?ooocX0oooo001d0?ooo`030?oOW01804P0W=oo0?l0oooo>P3oool0
07@0oooo00<0oono07@00018W=l0o`3ooolj0?ooo`00M@3oool00`3OW4P007Bo0?ooo`3o0?ooocT0
oooo001c0?ooo`050?oog`2LB00000000000M02oool0o`3oooli0?ooo`00o`3ooona0?ooo`00]03o
ool00`3OW4P00000000000030000000304RLg`3oool0oooo0?<0oooo002E0?ooo`040;md00000000
000007Boo`<0oooo00<0omnL04P0001d_ol01@3oool00`3ooml0W4P004RLg`0>0?ooo`030?noM000
M;l0oooo0080oooo00<0_gAd0;ooo`3oool0l`3oool009@0oooo00H0gia8001d_`3oool0omnL04P0
0018W=l20?ooo`030?oOW0180000M;oo00H0oooo00<0gia80018W03Oool03P3oool00`3o_g@007Bo
0?ooo`3g0?ooo`00T`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00X0oooo00<0
omnL04P0B02Lgol03`3oool00`3o_g@007Bo0?ooo`3f0?ooo`00T`3oool00`3ooml0W4P004RLg`02
0?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0okmd000000000000100000000`00B9`0gooo0?oo
o`0=0?ooo`030?noM018W=l0oooo0?D0oooo002C0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia8
0000B02Lgol01@3oool00`3ooml0W4Q809cOo`020?ooo`030;md0000M;l0oooo0100oooo00<0gia8
04RLg`3oool0m03oool009@0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`060?oo
o`070?oo_`1d07@0_ooo0?ooo`3o_g@004RL0=ooo`0A0?ooo`030;md001d_ol0oooo0?<0oooo002D
0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool01P3ogi`0B4RL0=ooo`3o
gi`0B01809cOoa40oooo00<0omnL04P0M02oool0l`3oool007d0oooo00@0_g@0000000000000M;oo
0`3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool0
0`3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00L0oooo00D0okmd001d_`3ooml0
W4P004RLg`0A0?ooo`030?oog`2LB000M;oo0?<0oooo001l0?ooo`060=nLB000M;l0oooo0?oOW018
0000B9cO0P3oool00`3ogi`0B00007Boo`020?ooo`030?noM000000007Bo0080oooo00<0_gA809cO
o`3oool00`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00@0gia8
04RLg`2oM00007Bo4@3oool00`3ookl0M00004RLg`3c0?ooo`00N`3oool00`3ooml0W4P004RLg`02
0?ooo`030?noM00004P0W=oo00/0oooo00<0omnL04Q8W03Oool0103oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo00T0oooo00@0gia807AdM00007@0_ooo303oool01`3o_g@004RL0=oo
o`3oool0gia80000B02Lgol0l`3oool007/0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P0
0018W03Oool:0?ooo`030?oo_`1d0000M;oo00D0oooo00H0gia80000M02oool0oooO09a80018W=l;
0?ooo`030;md000004P0W=oo00d0oooo00D0omnL04P000000000000007Boo`3d0?ooo`00N`3oool0
0`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00X0oooo00<0omnL04P0001d_ol01P3oool0
103OW4P0000000000000M;l<0?ooo`030?oog`2LB000B9cO0?l0oooo1`3oool007`0oooo00<0_g@0
0018W03Oool00P3oool00`3ogi`0B00004RLg`090?ooo`040?oOW0180000001809cOool0oooo803o
ool007`0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`050?oOW0180000
00000000001d_ol0o`3ooolQ0?ooo`00I@3oool0102oM00000000000001d_ol30?ooo`030?oOW018
0000M;oo0080oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`020?ooo`030?oOW018
0000B9cO00<0oooo00<0_g@00018W03Oool0203oool00`3ookl0M000001d_`3o0?ooob40oooo001T
0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`030?no
M000M;l0oooo0080oooo00<0_gAd0;ooo`3oool00P3oool0103ooml0W4P00018W03Oool20?ooo`03
0=nLB000B9`0gooo00X0oooo00<0gia8001d_`3oool0o`3ooolO0?ooo`00H`3oool00`3ooml0W4P0
04RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0okmd001d_`3oool01`3oool00`3ogi`0B000
07Boo`020?ooo`030=nLB000M;l0oooo00X0oooo00<0omnL04P0B02Lgol0o`3ooolO0?ooo`00H`3o
ool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0okmd001d_`3oool0
1`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0_g@007Boo`3oool0gia80000B02L
golN0?ooo`800000oP3oool006<0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`09
0?ooo`030?noM018W=l0oooo00L0oooo00@0gia800000000000007Bo2P3oool0102oM00000000000
0018W=lK0?ooo`@0000000@0oooo0000000000000000o03oool006@0oooo00<0_g@00018W03Oool0
0P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0oooo02l0oooo100000000`3oool00000
0?ooo`020?ooo`030000003oool0oooo00800000nP3oool004d0oooo00@0_g@0000000000000M;oo
0`3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0
0`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00/0oooo00<0_g@007Boo`3oool0
:`3oool4000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`800000n03oool004`0oooo
00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00@0oooo00<0okmd0000
001d_ol01P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00X0oooo00<0omnL04P0
M02oool09`3oool4000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`800000mP3oool004/0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`03
0?oog`2LB00007Bo00H0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:0?oo
o`030?oog`2LB000M;oo02<0oooo100000020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0103oool00`000000oooo0000003e0?ooo`00B`3oool00`3ooml0W4P004RLg`020?ooo`04
0?oog`2LB00004RL0=ooo`P0oooo00<0gia80018W03Oool01P3oool00`3ogi`0B00007Boo`020?oo
o`030=nLB000M;l0oooo00X0oooo00<0oono07@00018W=l0803oool3000000030?ooo`000000oooo
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00800000l`3oool004/0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`080?ooo`03
0?oOW01804P0W=oo00L0oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`070?noM000B9`0
gooo0?ooo`3OW4P0001809cOo`0L0?ooo`@00000103oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool200000?40oooo001<0?ooo`030;md0000
B9`0gooo0080oooo00<0omnL04P00018W=l0203oool00`3ookl0M00007Boo`080?ooo`040=nLB000
00000000001d_`T0oooo00D0omnL04P000000000000007Boo`0I0?ooo`@000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool200000>l0
oooo000m0?ooo`040;md00000000000007Boo`/0oooo00<0gia80000B02Lgol00P3oool00`3ooml0
W4P0001d_`090?ooo`030;md0000M;l0oooo02l0oooo0`0000020?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool03@3oool200000>d0oooo000l0?ooo`060=nLB000M;l0oooo0?oOW018
0000B9cO2P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00P0oooo00<0gia80018
W03Oool0:`3oool5000000@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0>X0oooo000k0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02L
gol02@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00<0omnL04P0
B02Lgol09`3oool4000000@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0@0?oo
o`800000jP3oool003/0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool90?oo
o`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0203oool00`3ookl0M00007Boo`0T0?oo
o`<000000`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00800000403oool20000
0>P0oooo000k0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol02P3oool01P3OW4P0
001d0;ooo`3ooml0W4P004RLg`X0oooo00<0_g@0001d_`3oool07`3oool400000080oooo00<00000
0?ooo`3oool09`3oool5000000030<oLh`000000oooo0100oooo0P00003V0?ooo`00?03oool00`2o
M00004RL0=ooo`020?ooo`030?oOW0180000B9cO00/0oooo00@0gia800000000000007Bo2@3oool0
1@3ookl0M0000000000007@0_ooo01/0oooo100000000`3oool000000?ooo`020?ooo`030000003o
ool0oooo02@0oooo10000000102Ac_d00000097>o@0000030<oLh`8000004@3oool200000>@0oooo
000l0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0=@3oool4000000@0oooo00D0
00000?ooo`3oool0oooo0000000R0?ooo`@000001@2Ac_d2000000H0cmcS00<000000?ooo`3oool0
3P3oool00`000000oooo0000003S0?ooo`00?03oool00`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo0300oooo100000030?ooo`030000003oool0oooo02D0oooo10000009097>o@030000003?
g><0cmcS00H0cmcS00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0200000>40oooo000l
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0;@3oool300000080oooo00<0
00000?ooo`3oool09P3oool4000000<0TLkm0P000007097>o@8000002@3?g><200000180oooo0P00
003O0?ooo`00?@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo02T0oooo1@000004
0?ooo`030000003oool0oooo0240oooo1@000009097>o@030000002Ac_d0TLkm00<0TLkm00<00000
0<oLh`0000002`3?g><00`000000oooo0?ooo`0A0?ooo`800000g@3oool003h0oooo00H0gia80000
M02oool0oooO09a80018W=lV0?ooo`@00000103oool00`000000oooo0?ooo`0R0?ooo`@000003`2A
c_d01@000000TLkm097>o@2Ac_d000000080cmcS00<000000<oLh`3?g><02P3?g><00`000000oooo
0?ooo`0B0?ooo`800000f`3oool003l0oooo00@0gia800000000000007Bo903oool3000000<0oooo
00<000000?ooo`3oool08`3oool400000080TLkm0P00000@097>o@<000000`3?g><00`000000cmcS
0<oLh`0;0<oLh`800000503oool00`000000oooo0?ooo`3H0?ooo`00H`3oool400000080oooo00D0
00000?ooo`3oool0oooo0000000R0?ooo`<00000202Ac_d00`000000TLkm097>o@0>097>o@030000
003?g><0cmcS0080cmcS00<000000<oLh`3?g><03@3?g><00`000000oooo0?ooo`0B0?ooo`800000
f03oool005l0oooo100000000`3oool000000?ooo`0V0?ooo`@00000302Ac_d00`000000TLkm097>
o@0<097>o@030000003?g><0cmcS00<0cmcS00<000000<oLh`3?g><03P3?g><00`000000oooo0?oo
o`0C0?ooo`800000eP3oool005`0oooo100000040?ooo`030000003oool0oooo0280oooo0`00000A
097>o@8000002`2Ac_d00`000000cmcS0<oLh`040<oLh`030000003?g><0cmcS00l0cmcS00<00000
0?ooo`3oool0503oool200000540oooo00T0olAO01@000000000000003F?o`34Ga@00000000DG`34
ool0NP3oool005P0oooo100000030?ooo`030000003oool0oooo02<0oooo10000002097>o@800000
4P2Ac_d00`000000TLkm097>o@07097>o@030000003?g><0cmcS00D0cmcS00<000000<oLh`3?g><0
403?g><2000001D0oooo0`00001?0?ooo`0908le000055l0a?oo0?ooo`2?=@00=CDe0000=@2?a5l0
Ghoo07X0oooo001D0?ooo`@000000`3oool00`000000oooo0?ooo`0T0?ooo`<00000202Ac_d00`00
0000TLkm097>o@0@097>o@8000001P2Ac_d00`000000cmcS0<oLh`060<oLh`030000003?g><0cmcS
0180cmcS00<000000?ooo`3oool04P3oool010000000oooo0?ooo`00001>0?ooo`0308le0000=Hl0
oooo0080oooo00<0ScD00000000eSol0N`3oool00540oooo0`0000020?ooo`030000003oool0oooo
02D0oooo1000000<097>o@8000004P2Ac_d00`000000TLkm097>o@02097>o@030000003?g><0cmcS
00L0cmcS00<000000<oLh`3?g><04`3?g><00`000000oooo0?ooo`0E0?ooo`800000C03oool00`3o
ScD0000e08ooo`020?ooo`030?ooS`0e000055o407/0oooo001=0?ooo`D00000103oool00`000000
oooo0?ooo`0Q0?ooo`@000004P2Ac_d00`000000TLkm097>o@0@097>o@040000002Ac_d0TLkm0000
00X0cmcS00<000000<oLh`3?g><0503?g><2000001L0oooo0P00001:0?ooo`030?ooS`0e0000=Hoo
00<0oooo00<0ScD0000DG`34ool0NP3oool004T0oooo1@0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool07@3oool4000000<0TLkm0P00000B097>o@8000004@2Ac_d200000003
0=7Jg`000000000000P0cmcS00<000000<oLh`3?g><05P3?g><00`000000oooo0?ooo`0F0?ooo`80
0000B@3oool00`3oScD0000e08ooo`020?ooo`030<AO500003D0Sooo07X0oooo00160?ooo`<00000
103oool00`000000oooo0?ooo`0Q0?ooo`D000002@2Ac_d200000180TLkm00<00000097>o@2Ac_d0
3P2Ac_d00`000000dM[O0=7Jg`020=7Jg`030000003?g><0cmcS00D0cmcS00<000000<oLh`3?g><0
5`3?g><00`000000oooo0?ooo`0G0?ooo`8000006P3oool00`3oohl0=@00000000020000000701AO
a03oool0oooo0?ooo`3oa5l0500003F?o`020?ooo`060?o4G`0D000000000000000055l0a?oo6P3o
ool01`34Ga@0000e08ooo`3oool0ScD00000501Oa?l0NP3oool00480oooo100000020?ooo`030000
003oool0oooo0280oooo1000000@097>o@030000002Ac_d0TLkm0100TLkm0P00000=097>o@030000
003Af]l0dM[O00@0dM[O00<000000<oLh`3?g><0103?g><00`000000cmcS0<oLh`0H0<oLh`800000
6@3oool00`000000oooo0?ooo`0I0?ooo`030?n?=@000000=Hoo00@0oooo00<0olAO01@0000eSol0
0P3oool01P3oScD0000003F?o`3oool0olAO01@eSa/0oooo00H0olAO01@00000000055mO03D0000D
GlAj0?ooo`00?P3oool4000000030?ooo`000000oooo02D0oooo0`000002097>o@8000004@2Ac_d2
00000180TLkm00<00000097>o@2Ac_d02@2Ac_d00`000000dM[O0=7Jg`060=7Jg`800000103?g><0
0`000000cmcS0<oLh`0J0<oLh`030000003oool0oooo01L0oooo0P00000I0?ooo`030?ooa01O5000
03F?00h0oooo00<0ohle01AOa03oool0V@3oool003`0oooo0P0000000`3oool000000?ooo`020?oo
o`030000003oool0oooo0200oooo10000007097>o@8000004@2Ac_d200000140TLkm0P000009097>
o@030000003Af]l0dM[O00P0dM[O00D000000<oLh`3?g><0cmcS0000000M0<oLh`030000003oool0
oooo01P0oooo0P00000H0?ooo`030<AO500055l0a?oo00d0oooo00<0oon?03D0=@2?ool0V@3oool0
03`0oooo00@000000?ooo`00000000008`3oool3000000d0TLkm0P00000A097>o@030000002Ac_d0
TLkm0100TLkm0P000006097>o@030000003Af]l0dM[O00X0dM[O0P0000000`3?g><000000<oLh`0K
0<oLh`030000003BgN00000001/0oooo0P00000F0?ooo`030?o4G`0D01@0GlCo00d0oooo00<0ooo4
05lD000eSol0V@3oool003`0oooo00<000000?ooo`3oool00`00000N0?ooo`<000004P2Ac_d00`00
0000TLkm097>o@0?097>o@8000004P2Ac_d00`000000TLkm097>o@02097>o@030000003Af]l0dM[O
00d0dM[O0P00000K0<oLh`040000003BgN00d]gP0=;Mh08000006@3oool010000000oooo00000000
000D0?ooo`030?ooS`0e0000=Hoo00d0oooo00<0oon?03D0000DGl@0V@3oool003`0oooo00<00000
0?ooo`3oool00`3oool2000001P0oooo10000002097>o@8000004P2Ac_d200000140TLkm0P00000A
097>o@80000000<0TLkm0000003Af]l0403Af]l2000001T0cmcS00<000000=;Mh03BgN00103BgN00
0`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`000000503oool00`2?=@0003F?0?oo
o`0<0?ooo`030?n?=@000000=Hoo09T0oooo000l0?ooo`030000003oool0oooo00D0oooo0P00000C
0?ooo`<00000202Ac_d200000180TLkm0P00000A097>o@030000002Ac_d0TLkm0100TLkm00<00000
0=7Jg`3Af]l0403Af]l00`000000dM[O0000000G0<oLh`030000003BgN00d]gP00H0d]gP00<00000
0?ooo`3oool06P3oool200000180oooo00<0a5lD000DG`34ool02@3oool01P3oa<@0a?oo0?n?=@00
0000000e08oooiT0oooo000l0?ooo`030000003oool0oooo00L0oooo0P00000=0?ooo`@000003@2A
c_d200000180TLkm0P00000@097>o@8000003`2Ac_d00`000000dM[O0=7Jg`0A0=7Jg`040000003A
f]l0dM[O000001D0cmcS00<000000=;Mh03BgN00203BgN000`000000oooo0?ooo`0K0?ooo`800000
403oool00`3oa5l0500D05o4o`090?ooo`050?ooS`0e000000000000501Oa?l0VP3oool002d0oooo
00@0_g@0000000000000M;oo2`3oool3000000T0oooo0P0000070?ooo`@000004`2Ac_d200000180
TLkm0P00000@097>o@800000302Ac_d00`000000dM[O0=7Jg`0A0=7Jg`030000003Af]l0dM[O0080
dM[O0P00000B0<oLh`030000003BgN00d]gP00X0d]gP00<000000?ooo`3oool0703oool2000000h0
oooo00<0oon?03D0000eSol02P3oool00`34Gel0Sooo0?ooo`2K0?ooo`00;03oool01P3OW4P007Bo
0?ooo`3ogi`0B00004RLg`X0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`0000000000
008000000`2Ac_d2000001@0TLkm0P00000B097>o@030000002Ac_d0TLkm00l0TLkm00<00000097>
o@2Ac_d0202Ac_d00`000000dM[O0=7Jg`0B0=7Jg`030000003Af]l0dM[O00@0dM[O00<000000<oL
h`3?g><03P3?g><00`000000d]gP0=;Mh00<0=;Mh08000007P3oool2000000d0oooo00<0ScD0000e
S`3oool02@3oool00`3oa5l0=Eo40?ooo`2K0?ooo`00:`3oool00`3ooml0W4P004RLg`020?ooo`03
0?noM00004P0W=oo00T0oooo00<000000?ooo`3oool02P3oool4000000T0TLkm0P00000D097>o@80
00004@2Ac_d200000100TLkm0P000008097>o@030000003Af]l0dM[O0180dM[O00<000000=7Jg`3A
f]l01@3Af]l2000000d0cmcS00<000000=;Mh03BgN003`3BgN000`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00P0oooo00D0oon?03D000000000000e08ooo`0:0?ooo`0508le000000000000
0000000DGl@0V03oool002/0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W034ool8
0?ooo`030000003oool0oooo00L0oooo0`00000?097>o@800000502Ac_d200000140TLkm0P00000@
097>o@8000001@2Ac_d00`000000dM[O0=7Jg`0C0=7Jg`030000003Af]l0dM[O00L0dM[O00<00000
0<oLh`3?g><02@3?g><00`000000d]gP0=;Mh00A0=;Mh0030000003oool0oooo01d0oooo0P00002d
0?ooo`00:`3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0GlCo00P0oooo00<000000?oo
o`3oool0203oool200000140TLkm0P00000D097>o@030000002Ac_d0TLkm0100TLkm0P00000@097>
o@050000002Ac_d0TLkm097>o@0000005P3Af]l00`000000dM[O0=7Jg`080=7Jg`800000203?g><0
0`000000d]gP0=;Mh00C0=;Mh0030000003oool0oooo01h0oooo0P00002b0?ooo`00;03oool00`2o
M00004RL0=ooo`020?ooo`030?oOW018000055o400P0oooo00<000000?ooo`3oool02P3oool20000
0140TLkm0P00000C097>o@8000004P2Ac_d00`000000TLkm097>o@0>097>o@<000005`3Af]l00`00
0000dM[O0=7Jg`0:0=7Jg`030000003?g><0cmcS00@0cmcS00<000000=;Mh03BgN005@3BgN000`00
0000oooo0?ooo`0M0?ooo`040000003oool0000000000;00oooo000/0?ooo`030=nLB00004P0W=oo
0080oooo00<0oooO09a80000=Hl0203oool00`000000oooo0?ooo`0<0?ooo`8000004@2Ac_d20000
01<0TLkm0P00000A097>o@8000003`2Ac_d010000000dmOL00000000000E0=7Jg`030000003Af]l0
dM[O00/0dM[O00<000000<oLh`3?g><00P3?g><00`000000d]gP0=;Mh00G0=;Mh08000007@3oool0
10000000oooo0?ooo`3oool200000:h0oooo000/0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@0
000DG`34ool01`3oool00`000000oooo0?ooo`0>0?ooo`8000004@2Ac_d2000001<0TLkm0P00000A
097>o@800000302Ac_d00`000000dmOL0=?Gg0020=?Gg0030000003Af]l0dM[O0180dM[O00<00000
0=7Jg`3Af]l0303Af]l2000000030<oLh`000000d]gP01/0d]gP00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`2[0?ooo`00;03oool0103ooml0W4P00018W03Oool20?ooo`030=nLB00055l0
a?oo00L0oooo00<000000?ooo`3oool0403oool200000140TLkm0P00000C097>o@8000004@2Ac_d2
000000T0TLkm00<000000=?Gg03Cem`0103Cem`200000180dM[O00<000000=7Jg`3Af]l03P3Af]l0
0`000000d]gP0=;Mh00L0=;Mh0030000003oool0oooo0200oooo0P00002[0?ooo`00;@3oool00`3o
gi`0B00007Boo`020?ooo`030=nLB000=Hl0oooo00L0oooo00<000000?ooo`3oool04P3oool20000
0140TLkm0P00000C097>o@8000004@2Ac_d2000000<0TLkm100000090=?Gg0030000003Af]l0dM[O
00l0dM[O00<000000=7Jg`3Af]l03@3Af]l00`000000e=[L0000000N0=;Mh0030000003oool0oooo
0240oooo0P00002Y0?ooo`00;P3oool01P3OW4P0001d0;ooo`3ooml0W4P001AOa0L0oooo00<00000
0?ooo`3oool05@3oool200000140TLkm0P00000C097>o@8000003`2Ac_d5000000<0TLkm00<00000
0=?Gg03Cem`0203Cem`2000000l0dM[O00<000000=7Jg`3Af]l0303Af]l010000000e=[L0=CJg03D
f]`2000001d0d]gP00<000000?ooo`3oool08P3oool200000:L0oooo000_0?ooo`040=nLB0000000
0000001d_`P0oooo00<000000?ooo`3oool05`3oool200000140TLkm0P00000C097>o@8000002@2A
c_d4000000<0TLkm0P000002097>o@030000003Cem`0dmOL00/0dmOL00<000000=7Jg`3Af]l0303A
f]l00`000000dM[O0=7Jg`0<0=7Jg`030000003Df]`0e=[L00<0e=[L00<000000=;Mh03BgN006`3B
gN02000002@0oooo0P00002U0?ooo`00>`3oool00`000000oooo0?ooo`0I0?ooo`8000004@2Ac_d2
000001<0TLkm0P000003097>o@@000002@2Ac_d2000000l0dmOL0P00000<0=7Jg`030000003Af]l0
dM[O00/0dM[O00<000000=CJg03Df]`01@3Df]`00`000000d]gP0=;Mh00L0=;Mh0030000003oool0
oooo02<0oooo00<000000?ooo`3oool0XP3oool003/0oooo00<000000?ooo`3oool06`3oool20000
0140TLkm0P00000B097>o@@000003@2Ac_d00`000000dmOL0=?Gg00@0=?Gg0030000003Af]l0dM[O
00T0dM[O00<000000=7Jg`3Af]l02P3Af]l00`000000e=[L0=CJg0070=CJg08000007@3BgN000`00
0000oooo0?ooo`0S0?ooo`800000XP3oool003/0oooo0`00000M0?ooo`8000004@2Ac_d2000000d0
TLkm0`000002097>o@800000302Ac_d00`000000dmOL0=?Gg00B0=?Gg0030000003Af]l0dM[O00P0
dM[O00<000000=7Jg`3Af]l02@3Af]l00`000000e=[L0=CJg00:0=CJg0030000003BgN00d]gP01T0
d]gP00<000000=ONg@000000903oool010000000oooo00000000002P0?ooo`00>`3oool00`000000
oooo0?ooo`0O0?ooo`8000004@2Ac_d2000000P0TLkm0`000007097>o@8000002@2Ac_d00`000000
dmOL0=?Gg00D0=?Gg0800000203Af]l00`000000dM[O0=7Jg`080=7Jg`030000003Df]`0e=[L00`0
e=[L00<000000=;Mh03BgN005`3BgN001@000000emkM0=ONg@3Gg]d0000002<0oooo00@000000?oo
o`3oool0oooo0P00002N0?ooo`00>`3oool00`000000oooo0?ooo`0Q0?ooo`8000004@2Ac_d20000
00<0TLkm0`00000<097>o@8000001P2Ac_d00`000000dmOL0=?Gg00G0=?Gg0030000003Af]l0dM[O
00D0dM[O00<000000=7Jg`3Af]l01`3Af]l00`000000e=[L0=CJg00>0=CJg08000005P3BgN000`00
0000emkM0=ONg@030=ONg@030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool20000
09`0oooo000k0?ooo`030000003oool0oooo02<0oooo0P00000@097>o@@000004@2Ac_d2000000<0
TLkm00<000000=?Gg03Cem`06@3Cem`2000000D0dM[O00<000000=7Jg`3Af]l01`3Af]l00`000000
e=[L0=CJg00@0=CJg0030000003BgN00d]gP01<0d]gP00<000000=ONg@3Gg]d0103Gg]d00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo09T0oooo000k0?ooo`030000003oool0oooo02D0oooo
0P00000:097>o@@000000`2Ac_d200000180TLkm0P0000000`2Ac_d000000=?Gg00L0=?Gg0030000
003Af]l0dM[O0080dM[O00<000000=7Jg`3Af]l01P3Af]l00`000000e=[L0=CJg00B0=CJg0030000
003BgN00d]gP0140d]gP00<000000=ONg@3Gg]d01P3Gg]d2000002P0oooo0P00002I0?ooo`00>`3o
ool00`000000oooo0?ooo`0W0?ooo`800000102Ac_d4000000T0TLkm0P00000B097>o@030000003C
em`0dmOL01d0dmOL0P0000020=7Jg`030000003Af]l0dM[O00D0dM[O00<000000=CJg03Df]`0503D
f]`200000100d]gP00<000000=ONg@3Gg]d02@3Gg]d00`000000oooo0?ooo`0W0?ooo`800000U`3o
ool003/0oooo00<000000?ooo`3oool0:@3oool4000000l0TLkm0P00000?097>o@030000003Cem`0
dmOL0200dmOL00<000000=7Jg`0000001P3Af]l00`000000e=[L0=CJg00G0=CJg0030000003BgN00
d]gP00`0d]gP00<000000=ONg@3Gg]d02`3Gg]d00`000000oooo0?ooo`0X0?ooo`800000U@3oool0
03/0oooo00<000000?ooo`3oool0;03oool200000100TLkm0P00000<097>o@030000003Cem`0dmOL
0280dmOL0P0000050=7Jg`030000003Df]`0e=[L01T0e=[L00<000000=;Mh03BgN002P3BgN000`00
0000emkM0=ONg@0=0=ONg@030000003oool0oooo02T0oooo0P00002C0?ooo`00>`3oool00`000000
oooo0?ooo`0^0?ooo`800000402Ac_d2000000T0TLkm00<000000=?Gg03Cem`0903Cem`2000000@0
dM[O00<000000=CJg03Df]`06P3Df]`2000000T0d]gP00<000000=ONg@3Gg]d03`3Gg]d00`000000
oooo0?ooo`0Y0?ooo`800000TP3oool003/0oooo00<000000?ooo`3oool0<03oool200000100TLkm
0P000006097>o@040000003Ee=P00000000002@0dmOL00H000000=?Gg000000000000=7Jg`00000O
0=CJg0030000003BgN00d]gP00D0d]gP00<000000=ONg@3Gg]d04@3Gg]d00`000000oooo0?ooo`0X
0?ooo`040000003oool0000000000900oooo000k0?ooo`030000003oool0oooo0380oooo0P00000@
097>o@800000102Ac_d01@000000eMCH0=GDf03Ee=P0000002<0dmOL00D000000=?Gg03Cem`0dmOL
0000000Q0=CJg0030000003BgN00d]gP00@0d]gP00<000000=ONg@3Gg]d04P3Gg]d00`000000oooo
0?ooo`0[0?ooo`800000SP3oool003/0oooo00<000000?ooo`3oool0=03oool3000000l0TLkm0P00
00000`2Ac_d000000=GDf0040=GDf08000008@3Cem`01@000000dmOL0=?Gg0000000emSH00800000
803Df]`2000000<0d]gP00<000000=ONg@3Gg]d0503Gg]d00`000000oooo0?ooo`0/0?ooo`800000
S03oool003/0oooo00<000000?ooo`3oool0=`3oool2000000l0TLkm00<000000=GDf03Ee=P01P3E
e=P2000001l0dmOL00<000000=?Gg0000000103Gf=P00`000000e=[L0=CJg00O0=CJg0030000003B
gN00000001P0emkM00<000000?ooo`3oool0;@3oool2000008X0oooo000k0?ooo`030000003oool0
oooo03T0oooo0P00000<097>o@030000003Ee=P0eMCH00T0eMCH00<000000=?Gg03Cem`0703Cem`0
0`000000dmOL000000050=OHf0030000003Df]`0e=[L01l0e=[L00<000000=ONg@3Gg]d0603Gg]d2
000002l0oooo00<000000?ooo`3oool0Q`3oool003/0oooo0P00000l0?ooo`8000002P2Ac_d00`00
0000eMCH0=GDf00:0=GDf0800000703Cem`2000000L0emSH0P00000N0=CJg0030000003IfmT00000
01/0emkM00<000000?ooo`3oool0;@3oool2000008L0oooo000k0?ooo`030000003oool0oooo03d0
oooo0P000007097>o@030000003Ee=P0eMCH00d0eMCH00<000000=?Gg03Cem`06@3Cem`00`000000
emSH0=OHf0080=OHf0030000003Df]`0e=[L01X0e=[L00@000000=WKf@3IfmT0fM_I0P00000J0=ON
g@030000003oool0oooo02h0oooo0P0000250?ooo`00>`3oool00`000000oooo0?ooo`0o0?ooo`<0
00000`2Ac_d00`000000eMCH0=GDf00?0=GDf0800000603Cem`2000000/0emSH00<000000=CJg03D
f]`06@3Df]`00`000000fM_I0=WKf@030=WKf@030000003Gg]d0emkM01P0emkM00<000000?ooo`3o
ool0;`3oool2000008<0oooo000k0?ooo`030000003oool0oooo0480oooo0`00000D0=GDf0030000
003Cem`0dmOL01D0dmOL0P00000<0=OHf0800000603Df]`00`000000fM_I0=WKf@050=WKf@030000
003Gg]d0emkM01P0emkM00<000000?ooo`3oool0;P3oool010000000oooo0000000000210?ooo`00
>`3oool00`000000oooo0?ooo`140?ooo`030000003Ee=P0eMCH01<0eMCH0P00000D0=?Gg0030000
003Gf=P0000000h0emSH00<000000=CJg03Df]`0503Df]`00`000000fM_I0=WKf@070=WKf@030000
003Gg]d0emkM01H0emkM00<000000=cPf@000000;`3oool01@000000oooo0?ooo`3oool000000240
oooo00<0oon?03D0000000000P0000000`0DGl@0oooo0?ooo`1G0?ooo`00>`3oool00`000000oooo
0?ooo`130?ooo`030000003Ee=P0eMCH01H0eMCH0P00000A0=?Gg0040000003Gf=P0emSH000000l0
emSH00<000000=CJg03Df]`04P3Df]`00`000000fM_I0=WKf@090=WKf@030000003Gg]d0emkM01D0
emkM00@000000=cPf@3Lh=T00000<`3oool200000240oooo00<0ohle0000000eSol0FP3oool003/0
oooo00<000000?ooo`3oool0@P3oool00`000000eMCH0=GDf00I0=GDf0030000003Cem`0dmOL00d0
dmOL00D000000=OHf03Gf=P0emSH0000000@0=OHf08000004P3Df]`00`000000fM_I0=WKf@0:0=WK
f@800000503Gg]d00`000000g>3I0=cPf@020=cPf@030000003oool0oooo0380oooo0P00000O0?oo
o`030?ooa01O500003F?05X0oooo000k0?ooo`030000003oool0oooo0440oooo00<000000=GDf03E
e=P06`3Ee=P2000000d0dmOL00D000000=OHf03Gf=P0emSH0000000B0=OHf0030000003Df]`0e=[L
00h0e=[L00<000000=WKf@3IfmT03@3IfmT00`000000emkM0=ONg@0@0=ONg@030000003Lh=T0g>3I
00@0g>3I00<000000?ooo`3oool0<`3oool2000001h0oooo00<0a5lD000DG`34ool0F@3oool003/0
oooo00<000000?ooo`3oool0@@3oool00`000000eMCH0=GDf00M0=GDf0030000003Cem`0dmOL00T0
dmOL00<000000=OHf03Gf=P00P3Gf=P00`000000emSH0=OHf00A0=OHf08000003@3Df]`00`000000
fM_I0=WKf@0?0=WKf@030000003Gg]d0emkM00h0emkM00<000000=cPf@3Lh=T01P3Lh=T00`000000
oooo0?ooo`0d0?ooo`800000703oool00`3oa5l0500D05o4o`1I0?ooo`00>`3oool00`000000oooo
0?ooo`100?ooo`030000003Ee=P0eMCH01l0eMCH0P0000080=?Gg0030000003Gf=P0emSH00<0emSH
00<000000=OHf03Gf=P04`3Gf=P00`000000e=[L0=CJg0090=CJg0030000003IfmT0fM_I0140fM_I
00<000000=ONg@3Gg]d03@3Gg]d00`000000g>3I0=cPf@070=cPf@030000003oool0oooo03D0oooo
00<000000?ooo`3oool06@3oool00`3oohl0=@0003F?o`1I0?ooo`00>`3oool00`000000oooo0?oo
o`0o0?ooo`030000003Ee=P0eMCH0280eMCH0P0000050=?Gg0030000003Gf=P0emSH00@0emSH00<0
00000=OHf03Gf=P0503Gf=P00`000000e=[L0=CJg0080=CJg0030000003IfmT0fM_I0180fM_I0P00
000<0=ONg@030000003Lh=T0g>3I00T0g>3I00<000000?ooo`3oool0=@3oool2000001X0oooo00<0
ScD0000eS`3oool0F03oool003/0oooo00<000000?ooo`3oool0?P3oool00`000000eMCH0=GDf00U
0=GDf0030000003Cem`0dmOL0080dmOL00<000000=OHf03Gf=P0103Gf=P00`000000emSH0=OHf00E
0=OHf08000001`3Df]`00`000000fM_I0=WKf@0E0=WKf@030000003Gg]d0emkM00P0emkM00<00000
0=cPf@3Lh=T02`3Lh=T00`000000oooo0?ooo`0e0?ooo`<00000603oool00`34Ga@001AO0<Coo`1H
0?ooo`00>`3oool00`000000oooo0?ooo`0n0?ooo`030000003Ee=P0eMCH02H0eMCH0P0000000`3C
em`000000=OHf0060=OHf0030000003Gf=P0emSH01L0emSH00<000000=CJg03Df]`00`3Df]`00`00
0000fM_I0=WKf@0G0=WKf@030000003Gg]d0emkM00L0emkM00<000000=cPf@3Lh=T0303Lh=T00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo008000005P3oool00`3oa5l0500D05o4o`1H0?oo
o`00>`3oool00`000000oooo0?ooo`0m0?ooo`030000003Ee=P0eMCH02T0eMCH00<000000=OHf03G
f=P01P3Gf=P00`000000emSH0=OHf00H0=OHf0050000003Df]`0e=[L0=CJg00000006`3IfmT00`00
0000emkM0=ONg@050=ONg@030000003Lh=T0g>3I00h0g>3I00<000000?ooo`3oool0>03oool20000
01@0oooo00<0oon?03D0000eSol0F03oool003X0oooo0`00000m0?ooo`040000003FdM<000000000
02P0eMCH00@000000=SDe000000000001P3Gf=P00`000000emSH0=OHf00I0=OHf080000000<0e=[L
0000003IfmT06`3IfmT00`000000emkM0=ONg@030=ONg@030000003Lh=T0g>3I0100g>3I00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0B0?ooo`0308le0000=Hl0oooo05L0oooo000j0?oo
o`030000003oool0oooo03d0oooo00D000000=KAd`3FdM<0e]7C0000000W0=GDf0050000003He=@0
f=CD0=SDe00000001@3Gf=P00`000000emSH0=OHf00K0=OHf0030000003IfmT0fM_I01`0fM_I0P00
00020=ONg@030000003Lh=T0g>3I0180g>3I00<000000?ooo`3oool0>@3oool200000100oooo00D0
oon?03D000000000000e08ooo`1G0?ooo`00>P3oool00`000000oooo0?ooo`0l0?ooo`030000003F
dM<0e]7C00<0e]7C0P00000T0=GDf0030000003He=@0f=CD00<0f=CD00<000000=OHf03Gf=P00P3G
f=P00`000000emSH0=OHf00J0=OHf0030000003Kf=@0000001l0fM_I00<000000=ONg@0000005@3L
h=T00`000000oooo0?ooo`0j0?ooo`800000JP3oool003X0oooo00<000000?ooo`3oool0>`3oool0
0`000000e]7C0=KAd`060=KAd`030000003Ee=P0eMCH0200eMCH00<000000=SDe03He=@01@3He=@2
00000080emSH00<000000=OHf03Gf=P06P3Gf=P00`000000fmSD0=_He002000001h0fM_I00<00000
0=cPf@3Lh=T05@3Lh=T00`000000oooo0?ooo`0k0?ooo`800000J03oool003X0oooo00<000000?oo
o`3oool0>P3oool00`000000e]7C0=KAd`080=KAd`800000803Ee=P00`000000f=CD0=SDe0070=SD
e0030000003Gf=P0000001/0emSH00<000000=_He03Kf=@00`3Kf=@00`000000fM_I0=WKf@0J0=WK
f@030000003NgM@0000001L0g>3I00<000000?ooo`3oool0?03oool2000006H0oooo000j0?ooo`03
0000003oool0oooo03X0oooo00<000000=KAd`3FdM<02P3FdM<2000001d0eMCH00<000000=SDe03H
e=@02@3He=@2000001X0emSH00<000000=_He03Kf=@01@3Kf=@00`000000fM_I0=WKf@0I0=WKf@04
0000003NgM@0g]gD000001L0g>3I00<000000?ooo`3oool0>`3oool00`000000oooo0000001U0?oo
o`00>P3oool00`000000oooo0?ooo`0i0?ooo`030000003FdM<0e]7C00d0e]7C00<000000=GDf03E
e=P06@3Ee=P00`000000f=CD0=SDe00;0=SDe0800000603Gf=P00`000000fmSD0=_He0070=_He080
0000603IfmT00`000000g]gD0=kMe0020=kMe0030000003Lh=T0g>3I01D0g>3I00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`02000006<0oooo000j0?ooo`030000003oool0oooo03P0oooo
00<000000=KAd`3FdM<03`3FdM<2000001T0eMCH00<000000=SDe03He=@02`3He=@010000000f=CD
00000000000F0=OHf0030000003Kf=@0fmSD00T0fmSD00<000000=WKf@3IfmT0503IfmT00`000000
g]gD0=kMe0040=kMe08000005P3Lh=T00`000000oooo0?ooo`0n0?ooo`800000H@3oool003X0oooo
00<000000?ooo`3oool0>03oool00`000000e]7C0=KAd`0A0=KAd`030000003Ee=P0eMCH01D0eMCH
00<000000=SDe03He=@0303He=@01@000000f=CD0=SDe03He=@0000001@0emSH00<000000=_He03K
f=@02`3Kf=@00`000000fM_I0=WKf@0C0=WKf@030000003NgM@0g]gD00H0g]gD00<000000=cPf@3L
h=T04P3Lh=T00`000000hnCC000000110?ooo`800000G`3oool003X0oooo00<000000?ooo`3oool0
=`3oool00`000000e]7C0=KAd`0C0=KAd`800000503Ee=P00`000000f=CD0=SDe00=0=SDe0030000
003He=@0f=CD0080f=CD00<000000=OHf03Gf=P0403Gf=P00`000000fmSD0=_He00=0=_He0030000
003IfmT0fM_I0140fM_I00<000000=kMe03NgM@0203NgM@00`000000g>3I0=cPf@0A0=cPf@040000
003Si=<0hnCC00000480oooo0P00001M0?ooo`00>P3oool00`000000oooo0?ooo`0f0?ooo`030000
003FdM<0e]7C01H0e]7C00<000000=GDf03Ee=P04@3Ee=P00`000000f=CD0=SDe00=0=SDe0030000
003He=@0f=CD00<0f=CD0P00000@0=OHf0030000003Kf=@0fmSD00h0fmSD0P00000@0=WKf@030000
003NgM@0g]gD00X0g]gD00<000000=cPf@3Lh=T03`3Lh=T00`000000hnCC0>?Td`020>?Td`030000
003oool0oooo0440oooo00<000000?ooo`3oool0FP3oool003X0oooo00<000000?ooo`3oool0=P3o
ool00`000000e]7C0=KAd`0G0=KAd`800000403Ee=P00`000000f=CD0=SDe00>0=SDe0030000003H
e=@0f=CD00D0f=CD00<000000=OHf03Gf=P0303Gf=P00`000000fmSD0=_He00A0=_He0030000003I
fmT0fM_I00`0fM_I00<000000=kMe03NgM@0303NgM@00`000000g>3I0=cPf@0=0=cPf@030000003S
i=<0hnCC00@0hnCC00<000000?ooo`3oool0@@3oool2000005X0oooo000j0?ooo`030000003oool0
oooo03D0oooo00<000000=KAd`3FdM<06P3FdM<00`000000eMCH0=GDf00=0=GDf0030000003He=@0
f=CD00h0f=CD00<000000=SDe03He=@01P3He=@2000000/0emSH00<000000=_He03Kf=@04`3Kf=@0
0`000000fM_I0=WKf@0;0=WKf@030000003NgM@0g]gD00d0g]gD00<000000=cPf@3Lh=T0303Lh=T0
0`000000hnCC0>?Td`040>?Td`030000003oool0oooo04<0oooo0P00001H0?ooo`00>P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003FdM<0e]7C01`0e]7C0P00000<0=GDf0030000003He=@0f=CD
00l0f=CD00<000000=SDe03He=@0203He=@00`000000emSH0=OHf0080=OHf0030000003Kf=@0fmSD
01@0fmSD00<000000=WKf@3IfmT02@3IfmT00`000000g]gD0=kMe00?0=kMe0030000003Lh=T0g>3I
00X0g>3I00<000000>?Td`3Si=<01P3Si=<00`000000oooo0?ooo`120?ooo`040000003oool00000
000005H0oooo000M0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool0
0`3OW4P00000000000030000000304RLg`3oool0oooo00P0oooo00@000000?ooo`0000000000<P3o
ool00`000000e]7C0=KAd`0O0=KAd`8000002@3Ee=P00`000000f=CD0=SDe00@0=SDe0030000003H
e=@0f=CD00T0f=CD0P0000070=OHf0030000003Kf=@0fmSD01H0fmSD0P0000080=WKf@030000003N
gM@0g]gD0140g]gD00<000000=cPf@3Lh=T0203Lh=T00`000000hnCC0>?Td`080>?Td`030000003o
ool0oooo0440oooo00@000000?ooo`3oool0oooo0P00001D0?ooo`00703oool01P3OW4P007Bo0?oo
o`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`03
0;mdM02oool0oooo00P0oooo0P00000d0?ooo`030000003FdM<0e]7C0240e]7C00<000000=GDf03E
e=P01P3Ee=P00`000000f=CD0=SDe00@0=SDe0030000003He=@0f=CD00/0f=CD00<000000=OHf03G
f=P00`3Gf=P00`000000fmSD0=_He00I0=_He0030000003IfmT0fM_I00D0fM_I00<000000=kMe03N
gM@04P3NgM@00`000000g>3I0=cPf@060=cPf@030000003Si=<0hnCC00X0hnCC00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`1A0?ooo`006`3oool00`3ooml0W4P004RLg`020?ooo`030?no
M00004P0W=oo00P0oooo00<0okmd001d_`3oool0303oool00`000000oooo0?ooo`0b0?ooo`030000
003FdM<0e]7C02<0e]7C0P0000050=GDf0030000003He=@0f=CD0140f=CD00<000000=SDe03He=@0
303He=@01@000000emSH0=OHf03Gf=P0000001d0fmSD00<000000=WKf@3IfmT00`3IfmT00`000000
g]gD0=kMe00D0=kMe08000001P3Lh=T00`000000hnCC0>?Td`0;0>?Td`030000003oool0oooo04H0
oooo0P00001A0?ooo`006`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0
oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`0a0?ooo`030000003FdM<0e]7C02H0
e]7C00D000000=GDf03Ee=P0eMCH0000000D0=SDe0030000003He=@0f=CD00d0f=CD0P0000000`3G
f=P000000=_He00M0=_He08000000P3IfmT00`000000g]gD0=kMe00G0=kMe0030000003Lh=T0g>3I
0080g>3I00<000000>?Td`3Si=<03@3Si=<00`000000oooo0?ooo`170?ooo`800000C`3oool001/0
oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo00X0
oooo00<000000?ooo`3oool0<@3oool00`000000e]7C0=KAd`0W0=KAd`80000000<0eMCH0000003H
e=@04`3He=@00`000000f=CD0=SDe00?0=SDe0030000003Kf=@0fmSD01l0fmSD00<000000=WKf@00
00006P3NgM@010000000g>3I0=cPf@00000A0>?Td`030000003oool0oooo04P0oooo0P00001=0?oo
o`00703oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0gia804RLg`3o
ool02@3oool00`000000oooo0?ooo`0`0?ooo`030000003FdM<0e]7C02X0e]7C00<000000=SDe03H
e=@04`3He=@00`000000f=CD0=SDe00>0=SDe0040000003Le=00000000000200fmSD00<000000=kM
e03NgM@06P3NgM@00`000000g>3I0000000B0>?Td`030000003oool0oooo04T0oooo0P00001;0?oo
o`00703oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00/0oooo00<0_g@007Boo`3o
ool0203oool00`000000oooo0?ooo`0_0?ooo`040000003Hc<h00000000002T0e]7C00@000000=[@
c`00000000004`3He=@00`000000f=CD0=SDe00>0=SDe0050000003Le=00g=C@0=cDd00000007P3K
f=@00`000000h=W@0000000L0=kMe0030000003Si=<0hnCC0140hnCC00<000000?ooo`3oool0B@3o
ool00`000000oooo0000001:0?ooo`00703oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0
gooo00X0oooo00<0omnL04P0M02oool0203oool00`000000oooo0?ooo`0_0?ooo`050000003Hc<h0
f<c>0=S<cP000000:03FdM<01@000000f]3?0=[@c`3Jd<l000000180f=CD00<000000=SDe03He=@0
3@3He=@00`000000g=C@0=cDd0030=cDd0030000003Kf=@0fmSD01/0fmSD00<000000>3Id03PfM00
0P00000I0=kMe0030000003Uh<l0000001<0hnCC00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`02000004P0oooo000L0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0
2P3oool00`3ooml0W4P007Boo`080?ooo`030000003oool0oooo02h0oooo00<000000=S<cP3Hc<h0
0`3Hc<h2000002D0e]7C00<000000=[@c`3Jd<l00`3Jd<l200000100f=CD00<000000=SDe03He=@0
303He=@00`000000g=C@0=cDd0050=cDd08000006P3Kf=@00`000000h=W@0>3Id0030>3Id0030000
003NgM@0g]gD01H0g]gD00@000000>GPc`3Uh<l000004`3Si=<00`000000oooo0?ooo`1<0?ooo`80
0000AP3oool001d0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo
_`1d0000B9cO00P0oooo00<000000?ooo`3oool0;@3oool00`000000f<c>0=S<cP060=S<cP030000
003FdM<0e]7C0240e]7C00<000000=[@c`3Jd<l01P3Jd<l00`000000f=CD0=SDe00=0=SDe0030000
003He=@0f=CD00`0f=CD00<000000=cDd03Le=001`3Le=000`000000fmSD0=_He00G0=_He0030000
003PfM00h=W@00@0h=W@00<000000=kMe03NgM@0503NgM@00`000000iN3?0>GPc`020>GPc`030000
003Si=<0hnCC0140hnCC00<000000?ooo`3oool0C@3oool2000004@0oooo000N0?ooo`060=nLB000
07@0_ooo0?oog`2LB000B9cO1`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol0203oool0
0`000000oooo0?ooo`0]0?ooo`030000003Hc<h0f<c>00L0f<c>0P00000Q0=KAd`030000003Jd<l0
f]3?00L0f]3?0P00000=0=SDe0030000003He=@0f=CD00/0f=CD00<000000=cDd03Le=002@3Le=02
000001H0fmSD00<000000>3Id03PfM001P3PfM02000001@0g]gD00<000000>GPc`3Uh<l00`3Uh<l0
0`000000hnCC0>?Td`0A0>?Td`030000003oool0oooo04h0oooo0P0000120?ooo`007`3oool0103O
W4P0000000000000M;l90?ooo`050?oOW018000000000000001d_ol02@3oool00`000000oooo0?oo
o`0/0?ooo`030000003Hc<h0f<c>00X0f<c>00<000000=KAd`3FdM<07@3FdM<00`000000f]3?0=[@
c`0:0=[@c`8000002`3He=@00`000000f=CD0=SDe00;0=SDe0030000003Le=00g=C@00/0g=C@00<0
00000=_He03Kf=@04P3Kf=@00`000000h=W@0>3Id0090>3Id0030000003NgM@0g]gD0100g]gD00<0
00000>GPc`3Uh<l01@3Uh<l00`000000hnCC0>?Td`0?0>?Td`030000003Zj<`000000540oooo00<0
00000?ooo`3oool06`3oool0102?=@0000000000000eSol30?ooo`030?o4G`0D0000=Hoo0080oooo
00H0olAO01@0000000000000000DG`34oolB0?ooo`00>P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003Hc<h0f<c>00/0f<c>0P00000L0=KAd`030000003Jd<l0f]3?00d0f]3?00<000000=SDe03H
e=@0203He=@00`000000f=CD0=SDe00:0=SDe0030000003Le=00g=C@00d0g=C@00<000000=_He03K
f=@04@3Kf=@00`000000h=W@0>3Id00:0>3Id0030000003NgM@0g]gD00h0g]gD00<000000>GPc`3U
h<l01`3Uh<l00`000000hnCC0>?Td`0>0>?Td`030000003Zj<`000000580oooo0`00000I0?ooo`06
0<AO5000=Hl0oooo0?o4G`0D000055o40P3oool00`3oa5l0500003F?o`020?ooo`060?n?=@000000
=Hoo0?ooo`3oa5l053F?4P3oool003X0oooo00<000000?ooo`3oool0:`3oool00`000000f<c>0=S<
cP0>0=S<cP030000003FdM<0e]7C01T0e]7C00<000000=[@c`3Jd<l03P3Jd<l2000000P0f=CD00<0
00000=SDe03He=@02@3He=@00`000000g=C@0=cDd00?0=cDd0800000403Kf=@00`000000h=W@0>3I
d00<0>3Id08000003P3NgM@00`000000iN3?0>GPc`080>GPc`030000003Si=<0hnCC00`0hnCC00D0
00000>[Xc03Zj<`0j^S<0000001C0?ooo`8000005`3oool00`3ool@0Ga@001AOa0020?ooo`030?n?
=@0001@0GlCo00/0oooo00<0ohle01AOa03oool0403oool003X0oooo0P00000[0?ooo`030000003H
c<h0f<c>0100f<c>0P00000H0=KAd`030000003Jd<l0f]3?0140f]3?00<000000=SDe03He=@01@3H
e=@00`000000f=CD0=SDe0090=SDe0030000003Le=00g=C@0140g=C@00<000000=_He03Kf=@03@3K
f=@00`000000h=W@0>3Id00>0>3Id0030000003NgM@0g]gD00X0g]gD00<000000>GPc`3Uh<l02P3U
h<l00`000000hnCC0>?Td`0;0>?Td`030000003Zj<`0j^S<0080j^S<00<000000?ooo`3oool0D03o
ool010000000oooo00000000000E0?ooo`030?ooa01O500055o40080oooo00@0ooo405lD000055l0
a?oo2P3oool00`3oohl0=@0e08ooo`0@0?ooo`00>P3oool00`000000oooo0?ooo`0Z0?ooo`030000
003Hc<h0f<c>0180f<c>00<000000=KAd`3FdM<0503FdM<00`000000f]3?0=[@c`0C0=[@c`800000
1@3He=@00`000000f=CD0=SDe0080=SDe0030000003Le=00g=C@01<0g=C@00<000000=_He03Kf=@0
2`3Kf=@00`000000h=W@0>3Id00@0>3Id0030000003NgM@0g]gD00T0g]gD00<000000>GPc`3Uh<l0
2`3Uh<l00`000000hnCC0>?Td`090>?Td`030000003Zj<`0j^S<00@0j^S<00<000000?ooo`3oool0
D`3oool2000001<0oooo00<0ooo405lD0000=Hl00`3oool00`34Ga@0000D05o4o`0:0?ooo`030?oo
a01O5000=Hoo0100oooo000j0?ooo`030000003oool0oooo02T0oooo00<000000=S<cP3Hc<h0503H
c<h00`000000e]7C0=KAd`0C0=KAd`030000003Jd<l0f]3?01D0f]3?00<000000=SDe03He=@00P3H
e=@00`000000f=CD0=SDe0070=SDe0030000003Le=00g=C@01D0g=C@0P00000;0=_He0030000003P
fM00h=W@0140h=W@0P0000080=kMe0030000003Uh<l0iN3?00d0iN3?00<000000>?Td`3Si=<0203S
i=<00`000000j^S<0>[Xc0040>[Xc0030000003oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool00`2?=@0001AO0<Coo`020?ooo`030?o4G`0D000055o400X0oooo00<0oon?03D0000DGl@0403o
ool003X0oooo00<000000?ooo`3oool0:03oool00`000000f<c>0=S<cP0F0=S<cP8000004P3FdM<0
0`000000f]3?0=[@c`0G0=[@c`8000000P3He=@00`000000f=CD0=SDe0070=SDe0030000003Le=00
g=C@01L0g=C@00<000000=_He03Kf=@01`3Kf=@00`000000h=W@0>3Id00D0>3Id0030000003NgM@0
g]gD00@0g]gD00<000000>GPc`3Uh<l03`3Uh<l00`000000hnCC0>?Td`060>?Td`030000003Zj<`0
j^S<00H0j^S<00<000000?ooo`3oool0E@3oool200000140oooo00<0a5lD0000501Oa?l00P3oool0
0`3ool@0Ga@0000eS`0:0?ooo`030?n?=@000000=Hoo0100oooo000i0?ooo`030000003oool0oooo
02T0oooo00<000000=S<cP3Hc<h0603Hc<h00`000000e]7C0=KAd`0>0=KAd`030000003Jd<l0f]3?
01X0f]3?00<000000=SDe0000000203He=@00`000000g=C@0=cDd00I0=cDd08000001P3Kf=@00`00
0000h=W@0>3Id00F0>3Id0030000003NgM@0g]gD00<0g]gD00<000000>GPc`3Uh<l0403Uh<l00`00
0000hnCC0>?Td`050>?Td`030000003Zj<`0j^S<00L0j^S<00<000000?ooo`3oool0EP3oool20000
00l0oooo00<0olAO01@0000DGl@00`3oool00`2?=@0001AO0<Coo`060?ooo`060?o4a034ool0ohle
0000000003D0Sooo403oool003T0oooo00<000000?ooo`3oool0:03oool00`000000f<c>0=S<cP0J
0=S<cP8000003P3FdM<00`000000f]3?0=[@c`0K0=[@c`800000203He=@00`000000g=C@0=cDd00K
0=cDd0030000003Kf=@0fmSD00<0fmSD00<000000>3Id03PfM005`3PfM0200000080g]gD00<00000
0>GPc`3Uh<l04P3Uh<l00`000000hnCC0>?Td`030>?Td`030000003Zj<`0j^S<00T0j^S<00<00000
0?ooo`3oool0E`3oool2000000d0oooo00@0ooo405lD000055l0a?oo0P3oool00`34Ga@001AO0<Co
o`060?ooo`050?ooS`0e000000000000501Oa?l04@3oool003T0oooo00<000000?ooo`3oool0:03o
ool00`000000f<c>0=S<cP0L0=S<cP030000003FdM<0e]7C00X0e]7C00<000000=[@c`3Jd<l0703J
d<l010000000f]3?0000000000050=SDe0030000003Le=00g=C@01d0g=C@00D000000=_He03Kf=@0
fmSD0000000L0>3Id0030000003NgM@0000001D0iN3?00<000000>?Td`3Si=<00P3Si=<00`000000
j^S<0>[Xc0090>[Xc0030000003oool0oooo05P0oooo0`00000<0?ooo`030?o4G`0D0000=Hoo0080
oooo00<0a5lD000eS`3oool01`3oool00`34Gel0Sooo0?ooo`0B0?ooo`00>@3oool00`000000oooo
0?ooo`0W0?ooo`030000003Hc<h0f<c>01h0f<c>0P0000090=KAd`030000003Jd<l0f]3?01d0f]3?
00D000000=[@c`3Jd<l0f]3?000000030=SDe0030000003Le=00g=C@01l0g=C@0P0000000`3Kf=@0
00000>3Id00L0>3Id0030000003Uh<l0iN3?01D0iN3?00@000000>?Td`3Si=<000003@3Zj<`00`00
0000oooo0?ooo`1G0?ooo`040000003oool0oooo000000`0oooo00H0a5lD0000=@2?ool0ooo405lD
000DGl@80?ooo`030?o4G`0eGl@0oooo0180oooo000i0?ooo`030000003oool0oooo02H0oooo00<0
00000=S<cP3Hc<h08@3Hc<h00`000000e]7C0=KAd`060=KAd`030000003Jd<l0f]3?01d0f]3?00<0
00000=[@c`3Jd<l00P3Jd<l2000000030=SDe0000000g=C@0280g=C@00<000000>3Id03PfM006`3P
fM000`000000i]c:0000000G0>GPc`030000003Si=<0000000h0j^S<00<000000?ooo`3oool0FP3o
ool2000000/0oooo00@0a5lD00000000000003F?2P3oool01@2?=@00000000000000000055o400l0
oooo000i0?ooo`030000003oool0oooo02H0oooo00<000000=S<cP3Hc<h08P3Hc<h2000000D0e]7C
00<000000=[@c`3Jd<l07P3Jd<l00`000000f]3?0=[@c`040=[@c`030000003Le=00g=C@0240g=C@
00@000000>7Eb`00000000006`3PfM0010000000i]c:0>KLbP00000G0>GPc`030000003Zj<`0j^S<
00h0j^S<00<000000?ooo`3oool0F`3oool2000002/0oooo000i0?ooo`030000003oool0oooo02D0
oooo00<000000=S<cP3Hc<h09@3Hc<h01@000000e]7C0=KAd`3FdM<000000240f]3?00<000000=[@
c`3Jd<l00`3Jd<l010000000g/o:00000000000Q0=cDd0050000003QeL/0hMG;0>7Eb`0000006@3P
fM000`000000i]c:0>KLbP020>KLbP800000503Uh<l00`000000k>G70000000?0>[Xc0030000003o
ool0oooo05d0oooo0P00000Y0?ooo`00>@3oool00`000000oooo0?ooo`0T0?ooo`030000003Hc<h0
f<c>02L0f<c>0P0000000`3FdM<000000=[@c`0P0=[@c`030000003Jd<l0f]3?00<0f]3?00D00000
0=k?bP3NclX0g/o:0000000O0=cDd0030000003QeL/0hMG;00<0hMG;00<000000>3Id03PfM005P3P
fM000`000000i]c:0>KLbP040>KLbP030000003Uh<l0iN3?0140iN3?00@000000>cUa`3/iLL00000
3`3Zj<`00`000000oooo0?ooo`1N0?ooo`8000009`3oool003T0oooo00<000000?ooo`3oool0903o
ool00`000000f<c>0=S<cP0Y0=S<cP030000003Jd<l0f]3?0200f]3?00<000000=[@c`3Jd<l00P3J
d<l00`000000g/o:0=k?bP030=k?bP8000007@3Le=000`000000hMG;0>7Eb`040>7Eb`8000005@3P
fM000`000000i]c:0>KLbP060>KLbP030000003Uh<l0iN3?00l0iN3?00<000000>cUa`3/iLL00P3/
iLL00`000000j^S<0>[Xc00=0>[Xc0030000003oool0oooo05l0oooo00<000000?ooo`3oool0903o
ool003T0oooo00<000000?ooo`3oool08`3oool00`000000f<c>0=S<cP0Y0=S<cP040000003KblX0
000000000200f]3?00<000000=[@c`3Jd<l00P3Jd<l00`000000g/o:0=k?bP050=k?bP030000003L
e=00g=C@01T0g=C@00<000000>7Eb`3QeL/01`3QeL/00`000000h=W@0>3Id00B0>3Id0030000003V
g<X0i]c:00L0i]c:00<000000>GPc`3Uh<l03P3Uh<l00`000000k>G70>cUa`030>cUa`030000003Z
j<`0j^S<00`0j^S<00<000000?ooo`3oool0H03oool2000002@0oooo000i0?ooo`030000003oool0
oooo02<0oooo00<000000=S<cP3Hc<h0:@3Hc<h01@000000fl_:0=_;bP3KblX0000001l0f]3?00D0
00000=[@c`3Jd<l0f]3?000000090=k?bP030000003Le=00g=C@01P0g=C@00<000000>7Eb`3QeL/0
203QeL/00`000000h=W@0>3Id00@0>3Id0030000003Vg<X0i]c:00T0i]c:00<000000>GPc`3Uh<l0
303Uh<l00`000000k>G70>cUa`050>cUa`030000003Zj<`0j^S<00X0j^S<00<000000??__@000000
H@3oool010000000oooo00000000000R0?ooo`00>@3oool300000280oooo00<000000=S<cP3Hc<h0
:@3Hc<h00`000000fl_:0=_;bP030=_;bP8000007@3Jd<l01@000000f]3?0=[@c`3Jd<l0000000X0
g/o:0P00000G0=cDd0030000003QeL/0hMG;00X0hMG;0P00000@0>3Id0030000003Vg<X0i]c:00X0
i]c:0P00000<0>GPc`030000003/iLL0k>G700H0k>G700<000000>[Xc03Zj<`02@3Zj<`00`000000
lnnm0000001U0?ooo`800000803oool003T0oooo00<000000?ooo`3oool08@3oool010000000f<O9
00000000000Y0=S<cP030000003KblX0fl_:00D0fl_:00<000000=[@c`3Jd<l06P3Jd<l010000000
f]3?0=[@c`00000=0=k?bP030000003Le=00g=C@01<0g=C@00<000000>7Eb`3QeL/03@3QeL/00`00
0000h=W@0>3Id00<0>3Id0030000003Vg<X0i]c:00d0i]c:00<000000>GPc`3Uh<l0203Uh<l00`00
0000k>G70>cUa`080>cUa`030000003Zj<`0j^S<00L0j^S<00D000000??__@3ckkd0lnnm0000001V
0?ooo`8000007P3oool003T0oooo00<000000?ooo`3oool08@3oool01@000000f<O90=S7b@3HalT0
000002L0f<c>00<000000=_;bP3KblX01`3KblX2000001X0f]3?00@000000=[@c`3Jd<l000003P3N
clX2000001<0g=C@00<000000>7Eb`3QeL/03P3QeL/2000000`0h=W@00<000000>KLbP3Vg<X03P3V
g<X00`000000iN3?0>GPc`070>GPc`030000003/iLL0k>G700T0k>G700<000000>[Xc03Zj<`01P3Z
j<`01@000000lnnm0??__@3ckkd0000006P0oooo00<000000?ooo`3oool06`3oool003T0oooo00<0
00000?ooo`3oool0803oool00`000000f<O90=S7b@030=S7b@8000009@3Hc<h00`000000fl_:0=_;
bP090=_;bP030000003Jd<l0f]3?01L0f]3?00<000000=[@c`0000004@3NclX00`000000g=C@0=cD
d00?0=cDd0030000003QeL/0hMG;0140hMG;00<000000>3Id03PfM00203PfM000`000000i]c:0>KL
bP0@0>KLbP030000003Uh<l0iN3?00D0iN3?00<000000>cUa`3/iLL02`3/iLL00`000000j^S<0>[X
c0040>[Xc0030000003ckkd0lnnm0080lnnm00<000000?ooo`3oool0I`3oool2000001/0oooo000i
0?ooo`030000003oool0oooo0200oooo00<000000=S7b@3HalT01@3HalT00`000000f<c>0=S<cP0Q
0=S<cP030000003KblX0fl_:00/0fl_:0P00000G0=[@c`030000003Jd<l000000180g/o:0P00000?
0=cDd0030000003QeL/0hMG;0180hMG;00<000000>3Id03PfM001`3PfM000`000000i]c:0>KLbP0A
0>KLbP030000003Uh<l0iN3?00@0iN3?00<000000>cUa`3/iLL0303/iLL00`000000j^S<0>[Xc003
0>[Xc0030000003ckkd0lnnm00<0lnnm00<000000?ooo`3oool0J03oool2000001T0oooo000i0?oo
o`030000003oool0oooo01l0oooo00<000000=S7b@3HalT01`3HalT200000240f<c>00<000000=_;
bP3KblX03@3KblX00`000000f]3?0=[@c`0D0=[@c`8000005@3NclX00`000000g=C@0=cDd00;0=cD
d0030000003QeL/0hMG;01@0hMG;0P0000060>3Id0030000003Vg<X0i]c:01<0i]c:0P0000030>GP
c`030000003/iLL0k>G700h0k>G700D000000>[Xc03Zj<`0j^S<000000060??__@030000003oool0
oooo06T0oooo0`00000G0?ooo`00>@3oool00`000000oooo0?ooo`0O0?ooo`030000003HalT0f<O9
00T0f<O900<000000=S<cP3Hc<h07@3Hc<h00`000000fl_:0=_;bP0?0=_;bP800000503Jd<l20000
01H0g/o:0P00000:0=cDd0030000003QeL/0hMG;01L0hMG;00<000000>3Id03PfM000`3PfM000`00
0000i]c:0>KLbP0E0>KLbP040000003Uh<l0iN3?00000140k>G700@000000>[Xc03Zj<`000001`3c
kkd00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo008000005@3oool003T0oooo00<00000
0?ooo`3oool07P3oool00`000000f<O90=S7b@0;0=S7b@8000007@3Hc<h00`000000fl_:0=_;bP0A
0=_;bP030000003Jd<l0f]3?0140f]3?00<000000=k?bP3NclX05`3NclX00`000000g=C@0=cDd007
0=cDd0030000003QeL/0hMG;01P0hMG;00D000000>3Id03PfM00h=W@0000000I0>KLbP8000004`3/
iLL2000000P0lnnm00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`03000001@0oooo000i
0?ooo`030000003oool0oooo01h0oooo00<000000=S7b@3HalT03@3HalT00`000000f<c>0=S<cP0I
0=S<cP030000003KblX0fl_:01<0fl_:0P00000A0=[@c`030000003NclX0g/o:01P0g/o:00<00000
0=cDd03Le=001@3Le=000`000000hMG;0>7Eb`0J0>7Eb`80000000<0h=W@0000003Vg<X06@3Vg<X0
0`000000k>G70>cUa`0B0>cUa`030000003ckkd0lnnm00L0lnnm00<000000?ooo`3oool0I@3oool5
00000080oooo00<000000?ooo`3oool04P3oool003T0oooo00<000000?ooo`3oool07@3oool00`00
0000f<O90=S7b@0?0=S7b@8000006@3Hc<h00`000000fl_:0=_;bP0E0=_;bP030000003Jd<l0f]3?
00d0f]3?0P00000K0=k?bP8000001@3Le=000`000000hMG;0>7Eb`0L0>7Eb`030000003Vg<X0i]c:
01T0i]c:0P00000C0>cUa`800000203ckkd00`000000oooo0?ooo`1P0?ooo`D000001`3oool00`00
0000oooo0?ooo`0B0?ooo`00>@3oool00`000000oooo0?ooo`0M0?ooo`030000003HalT0f<O90140
f<O900<000000=S<cP3Hc<h05@3Hc<h00`000000fl_:0=_;bP0G0=_;bP8000003@3Jd<l2000001d0
g/o:00D000000=cDd03Le=00g=C@0000000O0>7Eb`<00000603Vg<X00`000000k^720>kQ`P020000
0100k>G700<000000?G/^@000000203ckkd00`000000oooo0?ooo`1K0?ooo`D00000303oool00`00
0000oooo0?ooo`0B0?ooo`00>@3oool00`000000oooo0?ooo`0L0?ooo`030000003HalT0f<O901<0
f<O90P00000E0=S<cP030000003KblX0fl_:01T0fl_:00<000000=[@c`3Jd<l02@3Jd<l00`000000
g/o:0000000N0=k?bP80000000<0g=C@0000003QeL/07@3QeL/01@000000imO50>OGa@3WelD00000
01L0i]c:00<000000>kQ`P3^hL800P3^hL800`000000k>G70>cUa`0=0>cUa`040000003ek;T0mNbi
000000P0lnnm00<000000?ooo`3oool0E@3oool500000140oooo00<000000?ooo`3oool04P3oool0
03T0oooo00<000000?ooo`3oool0703oool00`000000f<O90=S7b@0E0=S7b@030000003Hc<h0f<c>
0140f<c>00<000000=_;bP3KblX06`3KblX2000000T0f]3?00<000000=k?bP000000803NclX00`00
0000hMG;0>7Eb`0M0>7Eb`030000003WelD0imO50080imO500<000000>KLbP3Vg<X04`3Vg<X00`00
0000k^720>kQ`P040>kQ`P030000003/iLL0k>G700/0k>G700<000000?G/^@3ek;T00P3ek;T00`00
0000lnnm0??__@050??__@030000003oool0oooo0500oooo1@00000F0?ooo`030000003oool0oooo
0180oooo000i0?ooo`030000003oool0oooo01/0oooo00<000000=S7b@3HalT05`3HalT200000140
f<c>00<000000=_;bP3KblX07@3KblX00`000000f]3?0=[@c`050=[@c`040000003NclX0g/o:0000
0200g/o:0`00000L0>7Eb`030000003WelD0imO500@0imO50P00000C0>KLbP030000003^hL80k^72
00D0k^7200<000000>cUa`3/iLL02P3/iLL00`000000mNbi0?G/^@020?G/^@030000003ckkd0lnnm
00H0lnnm00<000000?ooo`3oool0BP3oool5000001/0oooo00<000000?ooo`3oool04P3oool003T0
oooo0P00000L0?ooo`030000003HalT0f<O901T0f<O900<000000=S<cP3Hc<h03@3Hc<h00`000000
fl_:0=_;bP0O0=_;bP8000001@3Jd<l010000000g/o:0=k?bP00000O0=k?bP050000003Rd<D0h]35
0>;@a@0000006`3QeL/00`000000imO50>OGa@060>OGa@030000003Vg<X0i]c:00l0i]c:00<00000
0>kQ`P3^hL801`3^hL800`000000k>G70>cUa`090>cUa`030000003ek;T0mNbi00<0mNbi00<00000
0??__@3ckkd01@3ckkd00`000000oooo0?ooo`150?ooo`D00000803oool00`000000oooo0?ooo`0B
0?ooo`00>@3oool00`000000oooo0?ooo`0J0?ooo`030000003HalT0f<O901/0f<O90P00000=0=S<
cP030000003KblX0fl_:0240fl_:00D000000=[@c`3Jd<l0f]3?000000030=k?bP030000003NclX0
g/o:01d0g/o:00<000000>;@a@3Rd<D00P3Rd<D2000001T0hMG;00<000000>OGa@3WelD01`3WelD2
000000l0i]c:00<000000>kQ`P3^hL80203^hL82000000P0k>G700<000000?G/^@3ek;T01@3ek;T0
0`000000lnnm0??__@040??__@030000003oool0oooo0400oooo1@00000U0?ooo`030000003oool0
oooo0180oooo000i0?ooo`030000003oool0oooo01X0oooo00<000000=S7b@3HalT07@3HalT00`00
0000f<c>0=S<cP090=S<cP030000003KblX0fl_:02<0fl_:0P0000000`3Jd<l000000=k?bP020=k?
bP030000003NclX0g/o:01`0g/o:00<000000>;@a@3Rd<D01@3Rd<D00`000000hMG;0>7Eb`0E0>7E
b`030000003WelD0imO500X0imO500<000000>KLbP3Vg<X02`3Vg<X00`000000k^720>kQ`P0;0>kQ
`P030000003/iLL0k>G700D0k>G700<000000?G/^@3ek;T01P3ek;T00`000000lnnm0??__@020??_
_@800000?@3oool5000002X0oooo00<000000?ooo`3oool04P3oool003T0oooo00<000000?ooo`3o
ool06@3oool00`000000f<O90=S7b@0O0=S7b@8000002@3Hc<h00`000000fl_:0=_;bP0U0=_;bP03
0000003NclX0g/o:0080g/o:00<000000=k?bP3NclX0703NclX00`000000h]350>;@a@060>;@a@80
00005@3QeL/00`000000imO50>OGa@0;0>OGa@030000003Vg<X0i]c:00X0i]c:00<000000>kQ`P3^
hL80303^hL800`000000k>G70>cUa`040>cUa`030000003ek;T0mNbi00H0mNbi00<000000??__@3c
kkd00P3ckkd2000003T0oooo1000000_0?ooo`030000003oool0oooo0180oooo000i0?ooo`030000
003oool0oooo01T0oooo00<000000=S7b@3HalT08@3HalT00`000000f<c>0=S<cP050=S<cP030000
003KblX0fl_:02H0fl_:0`0000020=k?bP030000003NclX0g/o:01/0g/o:00<000000>;@a@3Rd<D0
2@3Rd<D00`000000hMG;0>7Eb`0A0>7Eb`030000003WelD0imO500d0imO50P00000:0>KLbP030000
003^hL80k^7200d0k^7200<000000>cUa`3/iLL00P3/iLL00`000000mNbi0?G/^@080?G/^@060000
003ckkd0lnnm0000003_kY800000=03oool5000003<0oooo00<000000?ooo`3oool04P3oool003T0
oooo00<000000?ooo`3oool0603oool00`000000f<O90=S7b@0S0=S7b@8000001@3Hc<h00`000000
fl_:0=_;bP0U0=_;bP070000003Nb/D0g/[50=k:a@000000g/o:0000000M0=k?bP030000003Rd<D0
h]3500X0h]350P00000A0>7Eb`030000003WelD0imO500l0imO500<000000>KLbP3Vg<X01P3Vg<X0
0`000000k^720>kQ`P0?0>kQ`P8000000P3/iLL00`000000mNbi0?G/^@090?G/^@030000003ckkd0
00000080knjB00<000000?ooo`3oool0;03oool5000003P0oooo00<000000?ooo`3oool04P3oool0
03T0oooo00<000000?ooo`3oool0603oool00`000000f<O90=S7b@0U0=S7b@050000003Hc<h0f<c>
0=S<cP000000:03KblX00`000000g/[50=k:a@020=k:a@8000007@3NclX00`000000h]350>;@a@0<
0>;@a@030000003QeL/0hMG;00h0hMG;00<000000>OGa@3WelD0403WelD2000000H0i]c:00<00000
0>kQ`P3^hL804@3^hL82000000`0mNbi0P0000030>o^TP030000003oool0oooo02L0oooo1@00000m
0?ooo`030000003oool0oooo0180oooo000h0?ooo`030000003oool0oooo01P0oooo00<000000=S7
b@3HalT09`3HalT2000000030=S<cP000000fl_:02H0fl_:00<000000=k:a@3Nb/D0103Nb/D20000
01/0g/o:00<000000>;@a@3Rd<D03P3Rd<D00`000000hMG;0>7Eb`0<0>7Eb`030000003WelD0imO5
01<0imO500<000000>KLbP3Vg<X00P3Vg<X00`000000k^720>kQ`P0C0>kQ`P030000003ek;T0mNbi
00/0mNbi00D000000>o^TP3_kY80knjB0000000T0?ooo`D00000@P3oool00`000000oooo0?ooo`0B
0?ooo`00>03oool00`000000oooo0?ooo`0H0?ooo`030000003HalT0f<O902T0f<O900<000000=_;
bP3KblX09P3KblX00`000000g/[50=k:a@040=k:a@040000003Nb/D00000000001T0g/o:00<00000
0>;@a@3Rd<D03`3Rd<D2000000`0hMG;00<000000>OGa@3WelD0503WelD01@000000i]c:0>KLbP3V
g<X0000001D0k^720P00000<0?G/^@8000000P3_kY800`000000oooo0?ooo`0M0?ooo`D00000A`3o
ool00`000000oooo0?ooo`0B0?ooo`00>03oool00`000000oooo0?ooo`0G0?ooo`030000003HalT0
f<O902X0f<O90`00000U0=_;bP030000003Nb/D0g/[500D0g/[500@000000=k:a@3Nb/D0g/[50P00
000F0=k?bP030000003Rd<D0h]350180h]3500<000000>7Eb`3QeL/0203QeL/00`000000imO50>OG
a@0F0>OGa@<000005@3^hL800`000000mnRd0?OX]002000000X0mNbi0P0000020>o^TP030000003o
ool0oooo01P0oooo1@00001<0?ooo`030000003oool0oooo0180oooo000h0?ooo`030000003oool0
oooo01L0oooo00<000000=S7b@3HalT0:@3HalT01@000000flG40=_5a03KaL@0000002@0fl_:00<0
00000=k:a@3Nb/D01@3Nb/D00`000000g/[50=k:a@030=k:a@030000003NclX0g/o:01<0g/o:00<0
00000>;@a@3Rd<D04`3Rd<D2000000P0hMG;00<000000>OGa@3WelD0603WelD00`000000k^720>kQ
`P0C0>kQ`P030000003gj;@0mnRd0080mnRd00<000000?G/^@3ek;T01P3ek;T01P000000l>b=0?3/
S@000000knjB000001D0oooo1@00001A0?ooo`030000003oool0oooo0180oooo000h0?ooo`030000
003oool0oooo01H0oooo00<000000=S7b@3HalT0:P3HalT00`000000flG40=_5a0020=_5a0800000
8@3KblX00`000000g/[50=k:a@060=k:a@030000003Nb/D0g/[500@0g/[50P00000B0=k?bP030000
003Rd<D0h]3501H0h]3500<000000>7Eb`3QeL/01@3QeL/00`000000imO50>OGa@0H0>OGa@<00000
4P3^hL800`000000mnRd0?OX]0040?OX]0030000003ek;T0mNbi00D0mNbi00H000000?3/S@3`k8d0
00000>o^TP00000@0?ooo`D00000EP3oool00`000000oooo0?ooo`0B0?ooo`00>03oool00`000000
oooo0?ooo`0F0?ooo`030000003HalT0f<O902T0f<O900<000000=_5a03KaL@01@3KaL@00`000000
fl_:0=_;bP0N0=_;bP030000003Nb/D0g/[500H0g/[500<000000=k:a@3Nb/D01P3Nb/D00`000000
g/o:0=k?bP0?0=k?bP030000003Rd<D0h]3501L0h]350P0000040>7Eb`030000003WelD0imO501P0
imO500D000000>oL_@3_g;d0kmbm0000000A0>kQ`P030000003gj;@0mnRd00D0mnRd0P0000050?G/
^@040000003`k8d0l>b=0?3/S@8000002`3oool5000005/0oooo00<000000?ooo`3oool04P3oool0
03P0oooo00<000000?ooo`3oool05@3oool00`000000f<O90=S7b@0Z0=S7b@030000003KaL@0flG4
00H0flG40P00000M0=_;bP030000003Nb/D0g/[500L0g/[500<000000=k:a@3Nb/D01`3Nb/D20000
00h0g/o:00<000000>;@a@3Rd<D06P3Rd<D01@000000hMG;0>7Eb`3QeL/0000001X0imO500<00000
0>oL_@3_g;d00P3_g;d2000000h0k^7200<000000?OX]03gj;@0203gj;@00`000000mNbi0?G/^@02
0?G/^@060000003`k8d0l>b=0?3/S@000000knjB0P0000040?ooo`D00000H03oool00`000000oooo
0?ooo`0B0?ooo`006`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo00D0oooo
00<0oooO09a80018W=l02`3oool010000000oooo00000000000D0?ooo`<00000:@3HalT00`000000
flG40=_5a0090=_5a0030000003KblX0fl_:01X0fl_:00<000000=k:a@3Nb/D01`3Nb/D00`000000
g/[50=k:a@090=k:a@030000003NclX0g/o:00/0g/o:00<000000>;@a@3Rd<D06`3Rd<D3000001X0
imO500<000000>oL_@3_g;d01@3_g;d00`000000k^720>kQ`P0;0>kQ`P030000003gj;@0mnRd00T0
mnRd00@000000?G/^@3ek;T000001@3`k8d2000000030?ooo`000000000000800000IP3oool00`00
0000oooo0?ooo`0A0?ooo`006P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL
04P0001d_ol01P3oool00`3OW4P004RL0=ooo`0:0?ooo`8000005@3oool01@000000fL730=W1``3I
`L<0000002P0f<O900<000000=_5a03KaL@02P3KaL@2000001T0fl_:00<000000=k:a@3Nb/D0203N
b/D00`000000g/[50=k:a@0:0=k:a@8000002`3NclX00`000000h]350>;@a@0M0>;@a@030000003W
elD0imO501P0imO500<000000>oL_@3_g;d01P3_g;d2000000/0k^7200<000000?OX]03gj;@02P3g
j;@3000000D0l>b=0P0000020?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool04@3o
ool001T0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0:0?ooo`030?oOW01804P0
W=oo00X0oooo00<000000?ooo`3oool0503oool00`000000fL730=W1``020=W1``030000003HalT0
f<O902@0f<O900<000000=_5a03KaL@03@3KaL@00`000000fl_:0=_;bP0F0=_;bP030000003Nb/D0
g/[500P0g/[500<000000=k:a@3Nb/D0303Nb/D00`000000g/o:0=k?bP070=k?bP030000003Rd<D0
h]3501h0h]350`00000H0>OGa@030000003_g;d0kmbm00P0kmbm0P0000080>kQ`P030000003gj;@0
mnRd00d0mnRd200000020?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool04@3oool0
01T0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?noM0000000
000000@0000000<004RL0=ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030000003I`L<0
fL7300@0fL730P00000T0=S7b@030000003KaL@0flG400h0flG40P00000F0=_;bP030000003Nb/D0
g/[500P0g/[500<000000=k:a@3Nb/D03@3Nb/D2000000L0g/o:00<000000>;@a@3Rd<D07@3Rd<D0
10000000j=6o0>SA_`3XdKl2000001D0imO500<000000>oL_@3_g;d02`3_g;d00`000000k^720>kQ
`P050>kQ`P030000003gj;@0mnRd00d0mnRd00<000000?7YR03ajHP00`3ajHP200000080oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`0A0?ooo`006@3oool00`3ooml0W4P0001d_`03
0?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8B02Lgol00P3oool00`2oM00007Bo0?ooo`09
0?ooo`030000003oool0oooo01<0oooo00<000000=W1``3I`L<01P3I`L<00`000000f<O90=S7b@0Q
0=S7b@030000003KaL@0flG40100flG400<000000=_;bP3KblX04P3KblX00`000000g/[50=k:a@09
0=k:a@030000003Nb/D0g/[500l0g/[50P0000040=k?bP030000003Rd<D0h]3501h0h]3500<00000
0>SA_`3XdKl00`3XdKl00`000000imO50>OGa@0B0>OGa@030000003_g;d0kmbm00`0kmbm0P000004
0>kQ`P030000003gj;@0mnRd00d0mnRd00<000000?7YR03ajHP00`3ajHP2000000<0oooo00<00000
0?ooo`3oool0IP3oool00`000000oooo0?ooo`0A0?ooo`006P3oool00`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO00H0oooo00L0oono07@0M02oool0oooo0?noM000B9`0gooo00T0oooo00<0
00000?ooo`3oool04P3oool00`000000fL730=W1``080=W1``800000803HalT00`000000flG40=_5
a00B0=_5a0030000003KblX0fl_:0140fl_:00<000000=k:a@3Nb/D02@3Nb/D00`000000g/[50=k:
a@0A0=k:a@050000003NclX0g/o:0=k?bP0000007`3Rd<D00`000000j=6o0>SA_`050>SA_`800000
4@3WelD00`000000kmbm0>oL_@0?0>oL_@050000003^hL80k^720>kQ`P0000003`3gj;@00`000000
lNV80?7YR0020?7YR0<000000`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0140
oooo000J0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool01P3ogi`0B4RL
0=ooo`3ogi`0B01809cOo`T0oooo00<000000?ooo`3oool04P3oool00`000000fL730=W1``0:0=W1
``030000003HalT0f<O901d0f<O900<000000=_5a03KaL@04`3KaL@200000100fl_:00<000000=k:
a@3Nb/D02P3Nb/D00`000000g/[50=k:a@0B0=k:a@<00000803Rd<D00`000000j=6o0>SA_`070>SA
_`8000003`3WelD00`000000kmbm0>oL_@0@0>oL_@<00000403gj;@010000000lNV80?7YR03ajHP4
000000<0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0A0?ooo`006P3oool00`3o
gi`0B00004RLg`030?ooo`030;md0000B9`0gooo00L0oooo00D0okmd001d_`3ooml0W4P004RLg`09
0?ooo`030000003oool0oooo0140oooo00<000000=W1``3I`L<0303I`L<2000001`0f<O900<00000
0=_5a03KaL@05P3KaL@00`000000fl_:0=_;bP0=0=_;bP030000003Nb/D0g/[500X0g/[500<00000
0=k:a@3Nb/D0503Nb/D00`000000h]350>;@a@0N0>;@a@030000003XdKl0j=6o00T0j=6o00<00000
0>OGa@3WelD0303WelD00`000000kmbm0>oL_@0B0>oL_@8000003P3gj;@00`000000lNV80?7YR002
000000030?CWQP000000000000@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0A
0?ooo`006P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00@0gia8
04RLg`2oM00007Bo2@3oool00`000000oooo0?ooo`0A0?ooo`030000003I`L<0fL7300h0fL7300<0
00000=S7b@3HalT06@3HalT00`000000flG40=_5a00G0=_5a0800000303KblX00`000000g/[50=k:
a@0;0=k:a@030000003Nb/D0g/[501@0g/[50`00000M0>;@a@030000003XdKl0j=6o00/0j=6o0P00
000;0>OGa@030000003_g;d0kmbm01<0kmbm00<000000?WT[`0000000`00000:0?OX]0030000003a
jHP000000080m>N60`0000040?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool04@3o
ool001/0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`090?ooo`040=nLB01dM7@0
001d0;ooo`P0oooo00<000000?ooo`3oool0403oool00`000000fL730=W1``0@0=W1``030000003H
alT0f<O901L0f<O900<000000=_5a03KaL@06P3KaL@00`000000fl_:0=_;bP090=_;bP030000003N
b/D0g/[500/0g/[500<000000=k:a@3Nb/D04`3Nb/D01@000000hlZo0>?:_`3Sb[l0000001`0h]35
00<000000>SA_`3XdKl03@3XdKl2000000T0imO500<000000>oL_@3_g;d04P3_g;d00`000000nNB_
0?WT[`040?WT[`@000001P3gj;@200000080m>N6100000040?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool04@3oool001`0oooo00H0gia80000M02oool0oooO09a80018W=l;0?ooo`03
0;md000004P0W=oo00P0oooo00<000000?ooo`3oool0403oool00`000000fL730=W1``0A0=W1``80
00005`3HalT00`000000flG40=_5a00K0=_5a0800000203KblX00`000000g/[50=k:a@0<0=k:a@03
0000003Nb/D0g/[501<0g/[500<000000>?:_`3Sb[l00P3Sb[l2000001T0h]3500<000000>SA_`3X
dKl0403XdKl2000000L0imO500<000000>oL_@3_g;d04P3_g;d00`000000nNB_0?WT[`080?WT[`@0
000000<0mnRd0000000000000`3dihH4000000@0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`0A0?ooo`007@3oool0103OW4P0000000000000M;l<0?ooo`030?oog`2LB000B9cO00P0
oooo00<000000?ooo`3oool0403oool00`000000fL730=W1``0C0=W1``030000003HalT0f<O901<0
f<O900<000000=_5a03KaL@07P3KaL@00`000000fl_:0=_;bP050=_;bP030000003Nb/D0g/[500`0
g/[500<000000=k:a@3Nb/D04P3Nb/D00`000000hlZo0>?:_`050>?:_`030000003Rd<D0h]3501H0
h]3500<000000>SA_`3XdKl04P3XdKl00`000000imO50>OGa@030>OGa@030000003_g;d0kmbm01<0
kmbm00<000000?WT[`3ii:l0303ii:l2000000<0m>N6100000050?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool04@3oool003P0oooo00<000000?ooo`3oool03`3oool00`000000fL73
0=W1``0E0=W1``8000004`3HalT00`000000flG40=_5a00O0=_5a0800000103KblX00`000000g/[5
0=k:a@0=0=k:a@030000003Nb/D0g/[50180g/[500<000000>?:_`3Sb[l01P3Sb[l2000001H0h]35
00<000000>SA_`3XdKl04`3XdKl2000000<0imO500<000000>oL_@3_g;d04P3_g;d00`000000nNB_
0?WT[`0>0?WT[`050000003dihH0m>N60000003giHH00`0000050?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool04@3oool003P0oooo00<000000?ooo`3oool03`3oool00`000000fL73
0=W1``0G0=W1``030000003HalT0f<O900l0f<O900<000000=_5a03KaL@08P3KaL@01@000000fl_:
0=_;bP3KblX0000000l0g/[500<000000=k:a@3Nb/D04P3Nb/D00`000000hlZo0>?:_`080>?:_`03
0000003Rd<D0h]350180h]3500<000000>SA_`3XdKl05P3XdKl3000001D0kmbm00<000000?WT[`3i
i:l03@3ii:l01@000000m>N60?CWQP000000mnF600@000001@3oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo0140oooo000h0?ooo`030000003oool0oooo00h0oooo00<000000=W1``3I
`L<06@3I`L<00`000000f<O90=S7b@0>0=S7b@030000003KaL@0flG402<0flG40`00000@0=k:a@03
0000003Nb/D0g/[50140g/[500<000000>?:_`3Sb[l02P3Sb[l200000180h]3500<000000>SA_`3X
dKl0603XdKl2000001@0kmbm00<000000?WT[`3ii:l03@3ii:l01@000000m>N60?CWQP000000mnF6
00<000001P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0140oooo000h0?ooo`80
00003`3oool00`000000fL730=W1``0J0=W1``8000003P3HalT00`000000flG40=_5a00U0=_5a003
0000003Nb/D0g/[500h0g/[500<000000=k:a@3Nb/D04@3Nb/D00`000000hlZo0>?:_`0<0>?:_`03
0000003Rd<D0h]3500l0h]3500<000000>SA_`3XdKl0603XdKl010000000l=Jg00000000000A0>oL
_@030000003ii:l0nNB_00h0nNB_00H000000?CWQP000000mnF60000003khXT2000000H0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`0A0?ooo`00>03oool00`000000oooo0?ooo`0=
0?ooo`030000003I`L<0fL7301d0fL7300<000000=S7b@3HalT02P3HalT00`000000flG40=_5a00V
0=_5a0<000003P3Nb/D00`000000g/[50=k:a@0@0=k:a@030000003Sb[l0hlZo00h0hlZo0P00000>
0>;@a@030000003XdKl0j=6o01P0j=6o00<000000?3F]`3`e[L00P3`e[L2000000l0kmbm00<00000
0?WT[`3ii:l03@3ii:l00`000000m>N6000000020?OUQP@000001P3oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0140oooo000h0?ooo`030000003oool0oooo00d0oooo00<000000=W1
``3I`L<07P3I`L<2000000X0f<O900<000000=_5a03KaL@09@3KaL@01@000000g/>n0=k3_P3N`kh0
000000d0g/[500<000000=k:a@3Nb/D0403Nb/D00`000000hlZo0>?:_`0@0>?:_`800000303Rd<D0
0`000000j=6o0>SA_`0H0>SA_`030000003`e[L0l=Jg00@0l=Jg0P00000=0>oL_@030000003ii:l0
nNB_00d0nNB_00H000000?CWQP000000mnF60000003khXT2000000L0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`0A0?ooo`00>03oool00`000000oooo0?ooo`0<0?ooo`030000003I
`L<0fL730240fL7300<000000=S7b@3HalT01P3HalT00`000000flG40=_5a00V0=_5a0030000003N
`kh0g/>n0080g/>n0P00000;0=k:a@030000003Nb/D0g/[50100g/[500<000000>?:_`3Sb[l04P3S
b[l00`000000h]350>;@a@080>;@a@030000003XdKl0j=6o01T0j=6o00<000000?3F]`3`e[L01P3`
e[L2000000/0kmbm00<000000?WT[`3ii:l03@3ii:l2000000030?OUQP000000nn:900<000001`3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0140oooo000h0?ooo`030000003oool0
oooo00`0oooo00<000000=W1``3I`L<08P3I`L<2000000H0f<O900<000000=_5a03KaL@09@3KaL@0
0`000000g/>n0=k3_P050=k3_P030000003Nb/D0g/[500P0g/[500<000000=k:a@3Nb/D03`3Nb/D0
0`000000hlZo0>?:_`0D0>?:_`800000203Rd<D00`000000j=6o0>SA_`0H0>SA_`030000003`e[L0
l=Jg00T0l=Jg0P0000080>oL_@030000003ii:l0nNB_00h0nNB_00D000000?OUQP3giHH000000?_R
R@03000000L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0A0?ooo`00>03oool0
0`000000oooo0?ooo`0;0?ooo`030000003I`L<0fL7302D0fL7300<000000=S7b@3HalT00P3HalT0
0`000000flG40=_5a00V0=_5a0030000003N`kh0g/>n00H0g/>n00<000000=k:a@3Nb/D01`3Nb/D0
0`000000g/[50=k:a@0?0=k:a@030000003Sb[l0hlZo01H0hlZo00<000000>;@a@3Rd<D01@3Rd<D0
0`000000j=6o0>SA_`0H0>SA_`030000003`e[L0l=Jg00/0l=Jg0P0000060>oL_@030000003ii:l0
nNB_00d0nNB_0P000000103giHH000000?_RR@3khXT3000000L0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`0A0?ooo`00>03oool00`000000oooo0?ooo`0;0?ooo`030000003I`L<0
fL7302H0fL7300D000000=S7b@3HalT0f<O90000000X0=_5a0030000003N`kh0g/>n00L0g/>n0P00
00070=k:a@030000003Nb/D0g/[500h0g/[500<000000>?:_`3Sb[l0603Sb[l2000000@0h]3500<0
00000>SA_`3XdKl06@3XdKl00`000000l=Jg0?3F]`0=0?3F]`800000103_g;d00`000000nNB_0?WT
[`090?WT[`D000000P3giHH00`000000nn:900000002000000P0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`0A0?ooo`00>03oool00`000000oooo0?ooo`0;0?ooo`030000003I`L<0
fL7302L0fL730`00000X0=_5a0030000003N`kh0g/>n00X0g/>n00<000000=k:a@3Nb/D0103Nb/D0
0`000000g/[50=k:a@0>0=k:a@030000003Sb[l0hlZo01X0hlZo00D000000>;@a@3Rd<D0h]350000
000K0>SA_`030000003`e[L0l=Jg00l0l=Jg0P0000000`3_g;d000000?WT[`030?WT[`P00000103j
gjX00`000000mnF6000000020?_RR@<00000203oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0140oooo000h0?ooo`030000003oool0oooo00X0oooo00<000000=W1``3I`L<0:P3I`L<0
0`000000flG40=_5a00V0=_5a0030000003N`kh0g/>n00/0g/>n0P0000040=k:a@030000003Nb/D0
g/[500h0g/[500<000000>?:_`3Sb[l06`3Sb[l3000001/0j=6o00<000000?3F]`3`e[L04P3`e[L6
000000/0n]nZ00L000000?OUQP3giHH000000?_RR@000000o]n=00800000203oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo0140oooo000h0?ooo`030000003oool0oooo00X0oooo00<0
00000=W1``3I`L<0:P3I`L<2000002L0flG400<000000=k3_P3N`kh03@3N`kh01@000000g/[50=k:
a@3Nb/D0000000l0g/[500<000000>?:_`3Sb[l07P3Sb[l00`000000j=6o0>SA_`0I0>SA_`030000
003`e[L0l=Jg01<0l=Jg00<000000?[OZP3jgjX03@3jgjX00`000000mnF6000000020?_RR@<00000
2@3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0140oooo000>0?ooo`050=nLB000
000000000000B02Lgol0903oool00`000000oooo0?ooo`0:0?ooo`030000003I`L<0fL7302X0fL73
00<000000=Zn_@3J_[d00P00000T0=_5a0030000003N`kh0g/>n00l0g/>n0P0000000`3Nb/D00000
0=k:a@0>0=k:a@030000003Sb[l0hlZo01h0hlZo0`00000I0>SA_`030000003`e[L0l=Jg0180l=Jg
00<000000?[OZP3jgjX03P3jgjX00`000000mnF6000000020?_RR@<000002@3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo0140oooo000=0?ooo`070?noM0000000M;oo0?ooo`3ooml0
W4P004RLg`0S0?ooo`030000003oool0oooo00X0oooo00<000000=W1``3I`L<0:P3I`L<00`000000
f[jm0=Zn_@020=Zn_@030000003KaL@0flG40240flG400<000000=k3_P3N`kh04@3N`kh2000000l0
g/[500<000000>?:_`3Sb[l07@3Sb[l010000000j<^i0>S;^@3XbkT2000001H0j=6o00<000000?3F
]`3`e[L04`3`e[L00`000000n]nZ0?[OZP0>0?[OZP8000000P3khXT2000000030?kITP000000oooo
00P0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0A0?ooo`003@3oool00`3OW4P0
04RL0=ooo`030?ooo`030=oOg`3oool0oooo0240oooo00<000000?ooo`3oool02@3oool00`000000
fL730=W1``0[0=W1``030000003J_[d0f[jm00<0f[jm00<000000=_5a03KaL@07`3KaL@00`000000
g/>n0=k3_P0C0=k3_P8000003@3Nb/D00`000000hlZo0>?:_`0N0>?:_`030000003XbkT0j<^i00<0
j<^i0P00000D0>SA_`030000003`e[L0l=Jg01<0l=Jg00<000000?[OZP3jgjX03@3jgjX00`000000
mnF6000000020?_RR@<000002P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0140
oooo000=0?ooo`030?noM00007@0_ooo02L0oooo00<000000?ooo`3oool02@3oool00`000000fL73
0=W1``0Z0=W1``030000003J_[d0f[jm00D0f[jm0P00000O0=_5a0030000003N`kh0g/>n01<0g/>n
00<000000=k3_P000000303Nb/D00`000000hlZo0>?:_`0N0>?:_`030000003XbkT0j<^i00D0j<^i
0P00000B0>SA_`030000003`e[L0l=Jg01<0l=Jg00<000000?[OZP3jgjX03@3jgjX200000080nn:9
00@000000?kOS@00000000002P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0140
oooo000=0?ooo`030?oo_`1d0000M;oo02L0oooo00<000000?ooo`3oool0203oool00`000000fL73
0=W1``0[0=W1``030000003J_[d0f[jm00L0f[jm00<000000=_5a03KaL@0703KaL@00`000000g/>n
0=k3_P0C0=k3_P030000003N`kh0g/>n008000002@3Nb/D00`000000hlZo0>?:_`0N0>?:_`030000
003XbkT0j<^i00P0j<^i0P00000?0>SA_`030000003`e[L0l=Jg01<0l=Jg00<000000?[OZP3jgjX0
3P3jgjX200000080nn:90P0000000`3nfI8000000?ooo`090?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool04@3oool000h0oooo00L0gia80000M02oool0oooo0?oo_`1d0000M;oo0280
oooo0`0000080?ooo`030000003I`L<0fL7302/0fL7300<000000=Zn_@3J_[d0203J_[d00`000000
flG40=_5a00J0=_5a0030000003N`kh0g/>n01@0g/>n00<000000=k3_P3N`kh00P3N`kh00`000000
g/[50=k:a@060=k:a@030000003Sb[l0hlZo01h0hlZo00<000000>S;^@3XbkT02P3XbkT00`000000
j=6o0>SA_`0<0>SA_`030000003`e[L0l=Jg01<0l=Jg00<000000?[OZP3jgjX03P3jgjX010000000
nn:90?_RR@3khXT3000000/0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0A0?oo
o`003`3oool01P2oM000001d0;ooo`3oool0gia804RLgb80oooo00<000000?ooo`3oool01`3oool0
0`000000fL730=W1``0[0=W1``030000003J_[d0f[jm00X0f[jm0P00000J0=_5a0030000003N`kh0
g/>n01@0g/>n00<000000=k3_P3N`kh00`3N`kh00`000000g/[50=k:a@050=k:a@030000003Sb[l0
hlZo01h0hlZo00<000000>S;^@3XbkT02`3XbkT2000000`0j=6o00<000000?3F]`3`e[L04`3`e[L0
0`000000n]nZ0?[OZP0=0?[OZP8000000P3khXT010000000o]n=00000000000;0?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool04@3oool00100oooo00D0omnL04P000000000001809cO
o`0R0?ooo`030000003oool0oooo00L0oooo00<000000=W1``3I`L<0:`3I`L<00`000000f[jm0=Zn
_@0<0=Zn_@030000003KaL@0flG401L0flG400<000000=k3_P3N`kh0503N`kh00`000000g/>n0=k3
_P040=k3_P800000103Nb/D00`000000hlZo0>?:_`0N0>?:_`030000003XbkT0j<^i00h0j<^i0P00
000:0>SA_`030000003`e[L0l=Jg01<0l=Jg00<000000?[OZP3jgjX03@3jgjX010000000nn:90?_R
R@3khXT2000000030?kITP000000oooo00X0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`0A0?ooo`00=`3oool00`000000oooo0?ooo`080?ooo`030000003I`L<0fL7302T0fL7300<0
00000=Zn_@3J_[d03P3J_[d00`000000flG40=_5a00E0=_5a0030000003N`kh0g/>n01D0g/>n00<0
00000=k3_P3N`kh01P3N`kh01@000000g/[50=k:a@3Nb/D000000200hlZo00<000000>S;^@3XbkT0
403XbkT2000000L0j=6o00<000000?3F]`3`e[L04`3`e[L00`000000n]nZ0?[OZP0<0?[OZP<00000
0P3khXT01@000000o]n=0000003nfI80000000/0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`0A0?ooo`00=`3oool00`000000oooo0?ooo`090?ooo`800000:@3I`L<00`000000f[jm
0=Zn_@0?0=Zn_@8000005@3KaL@00`000000g/>n0=k3_P0E0=k3_P030000003N`kh0g/>n00L0g/>n
0`00000Q0>?:_`030000003XbkT0j<^i0180j<^i0P0000050>SA_`030000003`e[L0l=Jg01<0l=Jg
00<000000?[OZP3jgjX02P3jgjX200000080n]ZU00D000000?_RR@3khXT000000?kOS@02000000`0
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0A0?ooo`00=`3oool00`000000oooo
0?ooo`0;0?ooo`030000003I`L<0fL7302H0fL7300<000000=Zn_@3J_[d04@3J_[d00`000000flG4
0=_5a00A0=_5a0030000003N`kh0g/>n01H0g/>n00<000000=k3_P3N`kh02@3N`kh00`000000hlZo
0>?:_`0N0>?:_`030000003XbkT0j<^i01D0j<^i0P0000030>SA_`030000003`e[L0l=Jg01<0l=Jg
00<000000?[OZP3jgjX0203jgjX2000000@0n]ZU00L000000?_RR@000000o]n=0000003nfI800000
00`0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0A0?ooo`00=`3oool00`000000
oooo0?ooo`0<0?ooo`030000003I`L<0fL7302@0fL7300<000000=Zn_@3J_[d04`3J_[d00`000000
flG40=_5a00@0=_5a0030000003N`kh0g/>n01H0g/>n00<000000=k3_P3N`kh02@3N`kh3000001h0
hlZo00<000000>S;^@3XbkT05`3XbkT3000001H0l=Jg00<000000?[OZP3jgjX01P3jgjX2000000D0
n]ZU00P000000?_RR@3khXT000000?kOS@000000o]VB000000`0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`0A0?ooo`00=`3oool00`000000oooo0?ooo`0=0?ooo`800000903I`L<0
0`000000f[jm0=Zn_@0D0=Zn_@800000403KaL@00`000000g/>n0=k3_P0F0=k3_P030000003N`kh0
g/>n00P0g/>n00@000000>;2^03R`[P0h/:h0P00000L0>?:_`030000003XbkT0j<^i01T0j<^i0`00
000C0?3F]`030000003jgjX0n]nZ00D0n]nZ0P0000070?[JY@050000003khXT0nn:90000003nghd0
0P00000=0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool04@3oool003L0oooo00<0
00000?ooo`3oool03`3oool00`000000fL730=W1``0Q0=W1``030000003J_[d0f[jm01H0f[jm00<0
00000=_5a03KaL@0303KaL@00`000000g/>n0=k3_P0F0=k3_P030000003N`kh0g/>n00T0g/>n00<0
00000>;2^03R`[P00`3R`[P00`000000hlZo0>?:_`0H0>?:_`030000003XbkT0j<^i01X0j<^i00<0
00000?3@/@3`d;401000000?0?3F]`030000003jgjX0n]nZ00<0n]nZ0P0000090?[JY@070000003k
hXT000000?kOS@000000o]VB0000000=0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool04@3oool003L0oooo00<000000?ooo`3oool0403oool00`000000fL730=W1``0O0=W1``030000
003J_[d0f[jm01P0f[jm00<000000=_5a03KaL@02`3KaL@00`000000g/>n0=k3_P0F0=k3_P030000
003N`kh0g/>n00T0g/>n00<000000>;2^03R`[P0103R`[P2000001P0hlZo00<000000>S;^@3XbkT0
6@3XbkT00`000000l=2a0?3@/@050?3@/@@000002`3`e[L010000000n]nZ0?[OZP3jgjX2000000/0
n]ZU00L000000?_RR@000000o]n=0000003nfI80000000d0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`0A0?ooo`00=`3oool00`000000oooo0?ooo`0A0?ooo`030000003I`L<0fL73
01h0fL7300<000000=Zn_@3J_[d06@3J_[d2000000/0flG400<000000=k3_P3N`kh05P3N`kh00`00
0000g/>n0=k3_P090=k3_P030000003R`[P0h/:h00H0h/:h0P00000F0>?:_`030000003XbkT0j<^i
01T0j<^i00<000000?3@/@3`d;402@3`d;44000000L0l=Jg00@000000?[OZP00000000003@3jfZD2
000000040?kOS@000000o]VB000000h0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`0A0?ooo`00=`3oool00`000000oooo0?ooo`0B0?ooo`8000007P3I`L<00`000000f[jm0=Zn_@0K
0=Zn_@030000003KaL@0flG400L0flG400<000000=k3_P3N`kh05`3N`kh00`000000g/>n0=k3_P08
0=k3_P030000003R`[P0h/:h00T0h/:h00<000000>?:_`3Sb[l04`3Sb[l00`000000j<^i0>S;^@0I
0>S;^@030000003`d;40l=2a00d0l=2a100000020?3F]`<000003`3jfZD2000000040?kOS@000000
o]VB000000h0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0@0?ooo`00=`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003I`L<0fL7301X0fL7300<000000=Zn_@3J_[d07@3J_[d0
0`000000flG40=_5a0060=_5a0030000003N`kh0g/>n01L0g/>n00<000000=k3_P3N`kh0203N`kh0
0`000000h/:h0>;2^00:0>;2^08000004P3Sb[l00`000000j<^i0>S;^@0J0>S;^@030000003`d;40
l=2a0140l=2a0`00000A0?[JY@80000000@0o]n=0000003nfI8000003P3oool00`000000oooo0?oo
o`1W0?ooo`030000003oool0oooo0100oooo000g0?ooo`030000003oool0oooo01D0oooo00<00000
0=W1``3I`L<06@3I`L<00`000000f[jm0=Zn_@0N0=Zn_@8000001@3KaL@00`000000g/>n0=k3_P0H
0=k3_P030000003N`kh0g/>n00P0g/>n00<000000>;2^03R`[P0303R`[P00`000000hlZo0>?:_`0?
0>?:_`030000003XbkT0j<^i01T0j<^i00<000000?3@/@3`d;40503`d;400`000000n]ZU0?[JY@0>
0?[JY@80000000D0o]n=0000003nfI80o]VB0000000>0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0403oool003L0oooo0P00000G0?ooo`8000006@3I`L<00`000000f[jm0=Zn_@0P
0=Zn_@030000003KaL@0flG40080flG400<000000=k3_P3N`kh0603N`kh00`000000g/>n0=k3_P07
0=k3_P030000003R`[P0h/:h00h0h/:h0P00000?0>?:_`030000003XbkT0j<^i01T0j<^i00<00000
0?3@/@3`d;40503`d;400`000000n]ZU0?[JY@0>0?[JY@80000000@0o]n=0000003nfI8000003`3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0100oooo000g0?ooo`030000003oool0
oooo01P0oooo00<000000=W1``3I`L<05@3I`L<00`000000f[jm0=Zn_@0R0=Zn_@050000003KaL@0
flG40=_5a00000006P3N`kh00`000000g/>n0=k3_P070=k3_P030000003R`[P0h/:h0100h/:h0P00
000<0>?:_`030000003XbkT0j<^i01X0j<^i00<000000?3@/@3`d;404`3`d;400`000000n]ZU0?[J
Y@0?0?[JY@060000003nghd0o]n=0000003nfI8000003`3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo0100oooo000g0?ooo`030000003oool0oooo01T0oooo00<000000=W1``3I`L<0
503I`L<00`000000f[jm0=Zn_@0S0=Zn_@<000006`3N`kh00`000000g/>n0=k3_P070=k3_P030000
003R`[P0h/:h0180h/:h00<000000>?:_`3Sb[l02@3Sb[l00`000000j<^i0>S;^@0I0>S;^@030000
003`d;40l=2a01@0l=2a00<000000?[JY@3jfZD03`3jfZD00`000000o]n=000000020?kITP030000
003oool0oooo00d0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0@0?ooo`00=`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003I`L<0fL7301<0fL7300<000000=Zn_@3J_[d09@3J
_[d00`000000g/>n0=k3_P0I0=k3_P030000003N`kh0g/>n00L0g/>n00<000000>;2^03R`[P04`3R
`[P2000000T0hlZo00<000000>S;^@3XbkT06@3XbkT00`000000l=2a0?3@/@0D0?3@/@030000003j
fZD0n]ZU00h0n]ZU0P000000103nghd000000?kITP00000@0?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool0403oool003L0oooo00<000000?ooo`3oool06`3oool200000180fL7300<0
00000=Zn_@3J_[d09P3J_[d3000001T0g/>n00<000000=k3_P3N`kh01P3N`kh00`000000h/:h0>;2
^00F0>;2^08000001P3Sb[l00`000000j<^i0>S;^@0J0>S;^@030000003`d;40l=2a01@0l=2a00<0
00000?[JY@3jfZD03@3jfZD01`000000nM:P0000003nghd000000?kITP000000403oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0100oooo000g0?ooo`030000003oool0oooo01d0oooo
00<000000=W1``3I`L<03`3I`L<00`000000f[jm0=Zn_@0U0=Zn_@050000003L^kL0g;^g0=bk]`00
0000603N`kh00`000000g/>n0=k3_P060=k3_P030000003R`[P0h/:h01P0h/:h00<000000>?:_`3S
b[l00`3Sb[l00`000000j<^i0>S;^@0J0>S;^@030000003`d;40l=2a01@0l=2a00<000000?[JY@3j
fZD0303jfZD01@000000nM:P0000003nghd000000080o]VB00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo0100oooo000g0?ooo`030000003oool0oooo01h0
oooo00<000000=W1``3I`L<03P3I`L<00`000000f[jm0=Zn_@0U0=Zn_@030000003L^kL0g;^g0080
g;^g00<000000=k3_P3N`kh05@3N`kh00`000000g/>n0=k3_P060=k3_P030000003R`[P0h/:h01T0
h/:h0P0000030>?:_`030000003XbkT0j<^i01T0j<^i00<000000?3@/@3`d;40503`d;400`000000
n]ZU0?[JY@0<0?[JY@080000003idZ00nM:P0000003nghd000000?kITP00000A0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool0403oool003L0oooo00<000000?ooo`3oool07`3oool2
000000d0fL7300<000000=Zn_@3J_[d09P3J_[d00`000000g;^g0=bk]`030=bk]`8000005@3N`kh0
0`000000g/>n0=k3_P050=k3_P030000003R`[P0h/:h01`0h/:h0`00000L0>S;^@030000003`d;40
l=2a01@0l=2a00<000000?[JY@3jfZD02P3jfZD2000000<0nM:P00D000000?kOS@000000o]VB0000
000A0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0403oool003L0oooo00<00000
0?ooo`3oool08@3oool00`000000fL730=W1``0:0=W1``030000003J_[d0f[jm02H0f[jm00<00000
0=bk]`3L^kL01@3L^kL00`000000g/>n0=k3_P0B0=k3_P030000003N`kh0g/>n00D0g/>n00<00000
0>;2^03R`[P07P3R`[P00`000000j<^i0>S;^@0J0>S;^@030000003`d;40l=2a01@0l=2a00<00000
0?[JY@3jfZD02@3jfZD00`000000nM:P0?WBX0030?WBX08000000P3nfI800`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0403oool003L0oooo00<000000?oo
o`3oool08P3oool00`000000fL730=W1``080=W1``030000003J_[d0f[jm02H0f[jm00<000000=bk
]`3L^kL01`3L^kL00`000000g/>n0=k3_P0A0=k3_P030000003N`kh0g/>n00D0g/>n00<000000>;2
^03R`[P07P3R`[P3000001T0j<^i00<000000?3@/@3`d;405@3`d;400`000000n]ZU0?[JY@080?[J
Y@030000003idZ00nM:P00@0nM:P0P0000020?kITP030000003oool0oooo00l0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0@0?ooo`00=`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003I`L<0fL7300L0fL7300<000000=Zn_@3J_[d09P3J_[d00`000000g;^g0=bk]`080=bk]`80
00004@3N`kh00`000000g/>n0=k3_P050=k3_P030000003R`[P0h/:h01h0h/:h00<000000>O4/P3W
a;800P00000G0>S;^@030000003`d;40l=2a01@0l=2a00<000000?[JY@3jfZD0203jfZD00`000000
nM:P0?WBX0040?WBX08000000P3nfI800`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool0403oool003L0oooo00<000000?ooo`3oool0903oool2000000L0fL73
00<000000=Zn_@3J_[d09P3J_[d00`000000g;^g0=bk]`0:0=bk]`030000003N`kh0g/>n00h0g/>n
00<000000=k3_P3N`kh0103N`kh00`000000h/:h0>;2^00N0>;2^0030000003Wa;80ilBb00<0ilBb
0P00000E0>S;^@030000003`d;40l=2a01@0l=2a00<000000?[JY@3jfZD01`3jfZD00`000000nM:P
0?WBX0050?WBX08000000P3nfI800`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool0403oool003L0oooo00<000000?ooo`3oool09P3oool00`000000fL730=W1
``030=W1``030000003J_[d0f[jm02H0f[jm00<000000=bk]`3L^kL0303L^kL00`000000g/>n0=k3
_P0=0=k3_P030000003N`kh0g/>n00@0g/>n00<000000>;2^03R`[P07P3R`[P00`000000ilBb0>O4
/P050>O4/P8000004`3XbkT00`000000l=2a0?3@/@0D0?3@/@030000003jfZD0n]ZU00H0n]ZU00<0
00000?WBX03idZ001P3idZ0200000080o]VB00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`1W0?ooo`030000003oool0oooo0100oooo000f0?ooo`030000003oool0oooo02P0oooo00<00000
0=W1``3I`L<00P3I`L<00`000000f[jm0=Zn_@0V0=Zn_@030000003L^kL0g;^g00d0g;^g0P00000=
0=k3_P030000003N`kh0g/>n00@0g/>n00<000000>;2^03R`[P07P3R`[P00`000000ilBb0>O4/P07
0>O4/P800000403XbkT00`000000l=2a0?3@/@0E0?3@/@030000003jfZD0n]ZU00D0n]ZU00<00000
0?WBX03idZ001`3idZ0010000000o]VB0?kITP00000C0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0403oool001T0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Bo
o`030?ooo`050?oog`2LB000000000000000M;l02`3oool00`000000oooo0?ooo`0Y0?ooo`800000
0P3I`L<00`000000f[jm0=Zn_@0V0=Zn_@030000003L^kL0g;^g00l0g;^g00<000000=k3_P3N`kh0
2P3N`kh00`000000g/>n0=k3_P030=k3_P030000003R`[P0h/:h01l0h/:h00<000000>O4/P3Wa;80
2@3Wa;82000000h0j<^i00<000000?3@/@3`d;405@3`d;400`000000n]ZU0?[JY@040?[JY@030000
003idZ00nM:P00P0nM:P00@000000?kITP3nfI8000004`3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo0100oooo000H0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3o
gi`0B00007Boo`030?ooo`070=nLB000M;l0oooo0?oo_`1d000004RL0=ooo`090?ooo`@00000:P3o
ool2000002T0f[jm00<000000=bk]`3L^kL0403L^kL00`000000g/>n0=k3_P090=k3_P030000003N
`kh0g/>n00<0g/>n00<000000>;2^03R`[P07P3R`[P00`000000ilBb0>O4/P0<0>O4/P800000303X
bkT00`000000l=2a0?3@/@0D0?3@/@030000003jfZD0n]ZU00@0n]ZU00<000000?WBX03idZ00203i
dZ0200000080o]VB00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1W0?ooo`030000003o
ool0oooo0100oooo000G0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool0
0`3ooml0W4P007Boo`020?ooo`030?oOW0180000B9cO00T0oooo00<000000?ooo`3oool0;03oool0
0`000000f[jm0=Zn_@0V0=Zn_@030000003L^kL0g;^g0180g;^g0P0000090=k3_P030000003N`kh0
g/>n00<0g/>n00<000000>;2^03R`[P07P3R`[P00`000000ilBb0>O4/P0>0>O4/P8000002@3XbkT0
0`000000l=2a0?3@/@0E0?3@/@030000003jfZD0n]ZU00<0n]ZU00<000000?WBX03idZ002@3idZ00
10000000o]VB0?kITP00000E0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0403o
ool001L0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?oo_`1d
0000M;oo00<0oooo00<0_g@00000M02oool0203oool00`000000oooo0?ooo`0]0?ooo`030000003J
_[d0f[jm02D0f[jm00<000000=bk]`3L^kL0503L^kL00`000000g/>n0=k3_P060=k3_P030000003N
`kh0g/>n00<0g/>n00<000000>;2^03R`[P07P3R`[P00`000000ilBb0>O4/P0@0>O4/P8000001`3X
bkT00`000000l=2a0?3@/@0E0?3@/@040000003jfZD0n]ZU0?[JY@800000303idZ0010000000o]VB
0?kITP00000E0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0403oool001L0oooo
00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB00007Bo00<0oooo
00<0gia80000B02Lgol0203oool00`000000oooo0?ooo`0^0?ooo`030000003J_[d0f[jm02@0f[jm
00<000000=bk]`3L^kL05@3L^kL00`000000g/>n0=k3_P050=k3_P030000003N`kh0g/>n0080g/>n
00<000000>;2^03R`[P07`3R`[P00`000000ilBb0>O4/P0B0>O4/P8000001@3XbkT00`000000l=2a
0?3@/@0E0?3@/@040000003jfZD0n]ZU000000d0nM:P0P0000020?kITP030000003oool0oooo01<0
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0@0?ooo`00603oool00`2oM00004RL
0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0_g@00000M02oool00P3oool00`3OW4P00018
09cOo`080?ooo`030000003oool0oooo02l0oooo00<000000=Zn_@3J_[d08`3J_[d00`000000g;^g
0=bk]`0F0=bk]`8000001@3N`kh00`000000g/>n0=k3_P020=k3_P030000003R`[P0h/:h01l0h/:h
00<000000>O4/P3Wa;80503Wa;82000000<0j<^i00<000000?3@/@3`d;405@3`d;400`000000n]ZU
0000000>0?WBX080000000<0o]VB0000003oool05@3oool00`000000oooo0?ooo`1V0?ooo`030000
003oool0oooo0100oooo000H0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01P3o
ool0203o_g@0000004RLg`3oool0oooO09a80000B9`0gooo203oool00`000000oooo0?ooo`0`0?oo
o`030000003J_[d0f[jm0240f[jm00<000000=bk]`3L^kL06@3L^kL00`000000g/>n0=k3_P020=k3
_P030000003N`kh0g/>n0080g/>n00<000000>;2^03R`[P07P3R`[P00`000000ilBb0>O4/P0G0>O4
/P<000005`3`d;400`000000n]ZU0000000>0?WBX0050000003gb9/000000?kITP0000005P3oool0
0`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0100oooo000H0?ooo`030?oOW0180000B9cO
00<0oooo00<0_g@00018W03Oool01@3oool00`3ooml0W4P000000002000000030000M02oool0oooo
00P0oooo00<000000?ooo`3oool0<@3oool200000240f[jm00<000000=bk]`3L^kL06P3L^kL01@00
0000g/>n0=k3_P3N`kh0000000<0g/>n00<000000>;2^03R`[P07`3R`[P00`000000ilBb0>O4/P0I
0>O4/P`00000303`d;42000000h0nM:P00<000000?O8V`0000000P3nfI800`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0403oool001P0oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3OW4P004RL0=ooo`060?ooo`030?oo_`1d000007Bo00`0oooo00<00000
0?ooo`3oool0<`3oool00`000000f[jm0=Zn_@0N0=Zn_@030000003L^kL0g;^g01/0g;^g0P000000
0`3N`kh000000=k3_P020=k3_P030000003R`[P0h/:h01l0h/:h00<000000>O4/P3Wa;806@3Wa;80
0`000000klV[0>o9Z`090>o9Z`d000003`3idZ000`000000mlRK000000020?kITP030000003oool0
oooo01@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0@0?ooo`006@3oool00`3o
gi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00L0oooo00<0omnL04P00018W=l02`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003J_[d0f[jm01`0f[jm00<000000=bk]`3L^kL07P3L^kL20000
00<0g/>n00<000000>;2^03R`[P07`3R`[P00`000000ilBb0>O4/P0I0>O4/P030000003_bJ/0klV[
01D0klV[00<000000?WBX03idZ00303idZ001P000000mlRK0?O8V`000000o]VB000001L0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`0@0?ooo`006P3oool01P3OW4P0001d0;ooo`3o
oml0W4P004RLg`T0oooo00@0oooO09a8000007@0_ooo2@3oool00`000000oooo0?ooo`0e0?ooo`03
0000003J_[d0f[jm01/0f[jm00<000000=bk]`3L^kL07`3L^kL01@000000g/>n0=k3_P3N`kh00000
0200h/:h00<000000>O4/P3Wa;806@3Wa;800`000000klV[0>o9Z`0F0>o9Z`030000003idZ00nM:P
00`0nM:P00H000000?O8V`3gb9/000000?kITP00000G0?ooo`030000003oool0oooo06H0oooo00<0
00000?ooo`3oool0403oool001/0oooo00@0gia800000000000007Bo303oool0103ookl0M0000000
0018W=l70?ooo`030000003oool0oooo03H0oooo00<000000=Zn_@3J_[d06P3J_[d00`000000g;^g
0=bk]`0O0=bk]`@000008@3R`[P00`000000ilBb0>O4/P0I0>O4/P030000003_bJ/0klV[01H0klV[
00<000000?WBX03idZ002`3idZ001`000000mlRK0?O8V`3gb9/000000?kITP0000005`3oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo0100oooo000f0?ooo`030000003oool0oooo03L0
oooo00<000000=Zn_@3J_[d06@3J_[d00`000000g;^g0=bk]`0O0=bk]`040000003L^kL0g;^g0000
0240h/:h00<000000>O4/P3Wa;806@3Wa;800`000000klV[0>o9Z`0E0>o9Z`030000003idZ00nM:P
00/0nM:P00<000000?O8V`3gb9/00P3gb9/2000001P0oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`0@0?ooo`00=P3oool00`000000oooo0?ooo`0h0?ooo`030000003J_[d0f[jm01L0
f[jm00<000000=bk]`3L^kL0803L^kL00`000000g;^g0=bk]`0200000200h/:h00<000000>O4/P3W
a;806@3Wa;800`000000klV[0>o9Z`0E0>o9Z`030000003idZ00nM:P00/0nM:P00L000000?O8V`3g
b9/0mlRK0000003nfI80000001P0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0@
0?ooo`00=P3oool00`000000oooo0?ooo`0i0?ooo`030000003J_[d0f[jm01H0f[jm00<000000=bk
]`3L^kL0803L^kL01@000000g;^g0=bk]`000000g[Ra008000007@3R`[P00`000000ilBb0>O4/P0J
0>O4/P030000003_bJ/0klV[01D0klV[00<000000?WBX03idZ002P3idZ000`000000mlRK0?O8V`02
0?O8V`030000003nfI80000001P0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0@
0?ooo`00=P3oool00`000000oooo0?ooo`0j0?ooo`030000003J_[d0f[jm01D0f[jm00<000000=bk
]`3L^kL0803L^kL00`000000g;^g000000040=jh/@030000003R`[P0h/:h01X0h/:h00<000000>O4
/P3Wa;806P3Wa;800`000000klV[0>o9Z`0E0>o9Z`030000003idZ00nM:P00T0nM:P00<000000?O8
V`3gb9/00`3gb9/2000001T0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0@0?oo
o`00=P3oool2000003`0oooo00<000000=Zn_@3J_[d04`3J_[d00`000000g;^g0=bk]`0Q0=bk]`03
0000003L^kL0000000D0g[Ra00<000000>;2^03R`[P06@3R`[P00`000000ilBb0>O4/P0I0>O4/P03
0000003_bJ/0klV[01H0klV[00<000000?WBX03idZ002@3idZ000`000000mlRK0?O8V`030?O8V`80
00006@3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0100oooo000f0?ooo`030000
003oool0oooo03`0oooo0P00000C0=Zn_@030000003L^kL0g;^g0240g;^g00<000000=bk]`000000
1P3N^;42000001T0h/:h00<000000>O4/P3Wa;806@3Wa;800`000000klV[0>o9Z`0F0>o9Z`030000
003idZ00nM:P00P0nM:P00<000000?O8V`3gb9/0103gb9/2000001T0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`0@0?ooo`00=P3oool00`000000oooo0?ooo`0n0?ooo`030000003J
_[d0f[jm0100f[jm00<000000=bk]`3L^kL08@3L^kL00`000000g;^g000000080=jh/@030000003R
`[P0h/:h01H0h/:h00<000000>O4/P3Wa;806@3Wa;800`000000klV[0>o9Z`0E0>o9Z`030000003i
dZ00nM:P00T0nM:P00<000000?O8V`3gb9/0103gb9/2000001T0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`0@0?ooo`00=P3oool00`000000oooo0?ooo`0o0?ooo`030000003J_[d0
f[jm00l0f[jm00<000000=bk]`3L^kL08@3L^kL00`000000g;^g000000090=jh/@030000003R`[P0
h/:h01@0h/:h00<000000>O4/P3Wa;806P3Wa;800`000000klV[0>o9Z`0E0>o9Z`030000003idZ00
nM:P00P0nM:P00<000000?O8V`3gb9/01@3gb9/00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0403oool003H0oooo00<000000?ooo`3oool0@03oool00`00
0000f[jm0=Zn_@0=0=Zn_@030000003L^kL0g;^g0280g;^g0P00000;0=jh/@800000503R`[P00`00
0000ilBb0>O4/P0J0>O4/P030000003_bJ/0klV[01D0klV[00<000000?WBX03idZ001`3idZ000`00
0000mlRK0?O8V`050?O8V`8000006P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo
0100oooo000f0?ooo`030000003oool0oooo0440oooo00<000000=Zn_@3J_[d0303J_[d00`000000
g;^g0=bk]`0R0=bk]`8000003@3N^;400`000000h/:h0>;2^00A0>;2^0030000003Wa;80ilBb01X0
ilBb00<000000>o9Z`3_bJ/05@3_bJ/00`000000nM:P0?WBX0070?WBX0030000003gb9/0mlRK00D0
mlRK0P00000J0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0403oool003H0oooo
00<000000?ooo`3oool0@P3oool00`000000f[jm0=Zn_@0;0=Zn_@030000003L^kL0g;^g0280g;^g
0P00000>0=jh/@030000003R`[P0h/:h0100h/:h00<000000>O4/P3Wa;806@3Wa;800`000000klV[
0>o9Z`0F0>o9Z`030000003idZ00nM:P00H0nM:P00<000000?O8V`3gb9/01P3gb9/00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0403oool003H0oooo00<0
00000?ooo`3oool0@`3oool00`000000f[jm0=Zn_@0:0=Zn_@030000003L^kL0g;^g0280g;^g0P00
000?0=jh/@8000003`3R`[P00`000000ilBb0>O4/P0J0>O4/P030000003_bJ/0klV[01H0klV[00<0
00000?WBX03idZ001@3idZ000`000000mlRK0?O8V`070?O8V`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`0@0?ooo`00=P3oool00`000000oooo0?ooo`14
0?ooo`030000003J_[d0f[jm00P0f[jm00<000000=bk]`3L^kL08`3L^kL200000140g[Ra00<00000
0>;2^03R`[P0303R`[P00`000000ilBb0>O4/P0J0>O4/P030000003_bJ/0klV[01H0klV[00<00000
0?WBX03idZ001@3idZ000`000000mlRK0?O8V`070?O8V`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`0?0?ooo`00=P3oool00`000000oooo0?ooo`150?oo
o`030000003J_[d0f[jm00L0f[jm00<000000=bk]`3L^kL08`3L^kL00`000000g[Ra0=jh/@0A0=jh
/@030000003R`[P0h/:h00/0h/:h00<000000>O4/P3Wa;806P3Wa;800`000000klV[0>o9Z`0E0>o9
Z`030000003idZ00nM:P00D0nM:P00<000000?O8V`3gb9/01`3gb9/00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool003H0oooo00<000000?ooo`3o
ool0AP3oool00`000000f[jm0=Zn_@060=Zn_@030000003L^kL0g;^g02<0g;^g00<000000=jh/@3N
^;404P3N^;42000000/0h/:h00<000000>O4/P3Wa;806P3Wa;800`000000klV[0>o9Z`0E0>o9Z`03
0000003idZ00nM:P00@0nM:P00<000000?O8V`3gb9/0203gb9/00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool003H0oooo00<000000?ooo`3oool0
A`3oool2000000D0f[jm00<000000=bk]`3L^kL0903L^kL00`000000g[Ra0=jh/@0D0=jh/@030000
003R`[P0h/:h00P0h/:h00<000000>O4/P3Wa;806P3Wa;800`000000klV[0>o9Z`0E0>o9Z`030000
003idZ00nM:P00@0nM:P00<000000?O8V`3gb9/0203gb9/00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool003H0oooo00<000000?ooo`3oool0B@3o
ool00`000000f[jm0=Zn_@020=Zn_@030000003L^kL0g;^g02@0g;^g00<000000=jh/@3N^;405@3N
^;400`000000h/:h0>;2^0060>;2^0030000003Wa;80ilBb01X0ilBb00<000000>o9Z`3_bJ/05P3_
bJ/00`000000nM:P0?WBX0030?WBX0030000003gb9/0mlRK00P0mlRK00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo000f0?ooo`030000003oool0
oooo04X0oooo00D000000=Zn_@3J_[d0f[jm0000000U0=bk]`800000603N^;42000000H0h/:h00<0
00000>O4/P3Wa;806P3Wa;800`000000klV[0>o9Z`0F0>o9Z`030000003idZ00nM:P00<0nM:P00<0
00000?O8V`3gb9/0203gb9/00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool03`3oool003H0oooo00<000000?ooo`3oool0B`3oool010000000f[jm0=Zn_@00
000U0=bk]`8000006P3N^;400`000000h/:h0>;2^0030>;2^0030000003Wa;80ilBb01X0ilBb00<0
00000>o9Z`3_bJ/05P3_bJ/00`000000nM:P0?WBX0020?WBX0030000003gb9/0mlRK00T0mlRK00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo000e
0?ooo`<00000C@3oool2000002H0g;^g0P00000K0=jh/@030000003R`[P0h/:h0080h/:h00<00000
0>O4/P3Wa;806P3Wa;800`000000klV[0>o9Z`0F0>o9Z`050000003idZ00nM:P0?WBX0000000303g
b9/00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool03`3o
ool003D0oooo00<000000?ooo`3oool0CP3oool00`000000g;^g0=bk]`0T0=bk]`800000703N^;42
000000030>;2^0000000ilBb01`0ilBb00<000000>o9Z`3_bJ/05@3_bJ/00`000000nM:P0?WBX002
0?WBX0030000003gb9/0mlRK00T0mlRK00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo00l0oooo000e0?ooo`030000003oool0oooo04l0oooo00<000000=bk
]`3L^kL08`3L^kL2000001h0g[Ra0P00000M0>O4/P030000003_bJ/0klV[01D0klV[00D000000?WB
X03idZ00nM:P0000000<0?O8V`030000003oool0oooo01`0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`0?0?ooo`00=@3oool00`000000oooo0?ooo`1@0?ooo`030000003L^kL0g;^g
0240g;^g00<000000=jh/@0000007`3N^;400`000000ilBb0>O4/P0J0>O4/P030000003_bJ/0klV[
01H0klV[00@000000?WBX03idZ0000003@3gb9/00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool03`3oool003D0oooo00<000000?ooo`3oool0D@3oool00`00
0000g;^g0=bk]`0P0=bk]`030000003N^;40000001l0g[Ra0`00000J0>O4/P030000003_bJ/0klV[
01H0klV[00@000000?WBX03idZ000000303gb9/00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool03`3oool003D0oooo00<000000?ooo`3oool0DP3oool00`00
0000g;^g0=bk]`0O0=bk]`030000003N^;40000001l0g[Ra00<000000>2f[03P]Z`00P00000H0>O4
/P030000003_bJ/0klV[01H0klV[00<000000?WBX00000003@3gb9/00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool003D0oooo00<000000?ooo`3o
ool0D`3oool00`000000g;^g0=bk]`0N0=bk]`030000003N^;40000001l0g[Ra00<000000>2f[03P
]Z`00P3P]Z`2000001H0ilBb00<000000>o9Z`3_bJ/05P3_bJ/00`000000nM:P0000000=0?O8V`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0?0?ooo`00
=@3oool00`000000oooo0?ooo`1D0?ooo`030000003L^kL0g;^g01d0g;^g00<000000=jh/@000000
7P3N^;400`000000h;J/0>2f[0050>2f[0800000503Wa;800`000000klV[0>o9Z`0E0>o9Z`030000
003idZ00000000d0mlRK00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo00l0oooo000e0?ooo`030000003oool0oooo05D0oooo00<000000=bk]`3L^kL06`3L
^kL010000000g[Ra0=jh/@00000N0=jh/@030000003P]Z`0h;J/00L0h;J/0P00000B0>O4/P030000
003_bJ/0klV[01D0klV[0P00000>0?O8V`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`0?0?ooo`00=@3oool00`000000oooo0?ooo`1F0?ooo`030000003L
^kL0g;^g01X0g;^g00@000000=jh/@3N^;4000007P3N^;400`000000h;J/0>2f[0090>2f[0800000
3`3Wa;800`000000klV[0>o9Z`0F0>o9Z`8000003P3gb9/00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool003D0oooo00<000000?ooo`3oool0E`3o
ool00`000000g;^g0=bk]`0I0=bk]`040000003N^;40g[Ra000001h0g[Ra00<000000>2f[03P]Z`0
2`3P]Z`2000000d0ilBb00<000000>o9Z`3_bJ/05@3_bJ/2000000h0mlRK00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo000e0?ooo`030000003o
ool0oooo05P0oooo00<000000=bk]`3L^kL0603L^kL010000000g[Ra0=jh/@00000N0=jh/@030000
003P]Z`0h;J/00d0h;J/0P00000;0>O4/P030000003_bJ/0klV[0140klV[100000000`3_`:000000
0?O8V`0=0?O8V`030000003oool0oooo01l0oooo00<000000?ooo`3oool0I`3oool00`000000oooo
0?ooo`0?0?ooo`00=@3oool00`000000oooo0?ooo`1I0?ooo`030000003L^kL0g;^g01L0g;^g00@0
00000=jh/@3N^;4000007P3N^;400`000000h;J/0>2f[00?0>2f[08000002@3Wa;800`000000klV[
0>o9Z`0=0>o9Z`@000001@3_`:000`000000mlRK0?O8V`0<0?O8V`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0?0?ooo`00=@3oool00`000000oooo0?oo
o`1J0?ooo`030000003L^kL0g;^g01D0g;^g00D000000=jh/@3N^;40g[Ra0000000N0=jh/@030000
003P]Z`0h;J/0140h;J/0P0000070>O4/P030000003_bJ/0klV[00X0klV[0`0000090>o0X0030000
003gb9/0mlRK00/0mlRK00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo00l0oooo000e0?ooo`800000G03oool00`000000g;^g0=bk]`0D0=bk]`050000003N
^;40g[Ra0=jh/@0000007P3N^;400`000000h;J/0>2f[00C0>2f[08000001@3Wa;800`000000klV[
0>o9Z`060>o9Z`@00000303_`:000`000000mlRK0?O8V`0;0?O8V`030000003oool0oooo0200oooo
00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0?0?ooo`00=@3oool00`000000oooo0?oo
o`1L0?ooo`030000003L^kL0g;^g01<0g;^g00D000000=jh/@3N^;40g[Ra0000000M0=jh/@030000
003P]Z`0h;J/01H0h;J/0P0000020>O4/P030000003_bJ/0klV[00<0klV[1000000@0>o0X0030000
003gb9/0mlRK00/0mlRK00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo00l0oooo000e0?ooo`030000003oool0oooo05d0oooo00<000000=bk]`3L^kL04P3L
^kL01@000000g[Ra0=jh/@3N^;40000001d0g[Ra00<000000>2f[03P]Z`0603P]Z`3000000030>o9
Z`000000000000800000503_`:000`000000mlRK0?O8V`0;0?O8V`030000003oool0oooo0200oooo
00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0?0?ooo`00=@3oool00`000000oooo0?oo
o`1N0?ooo`030000003L^kL0g;^g0140g;^g00D000000=jh/@3N^;40g[Ra0000000M0=jh/@030000
003P]Z`0h;J/01X0h;J/0P00000G0>o0X0030000003gb9/0mlRK00/0mlRK00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo000e0?ooo`030000003o
ool0oooo05h0oooo00<000000=bk]`3L^kL0403L^kL00`000000g[Ra0=jh/@020=jh/@030000003N
^;40g[Ra01/0g[Ra00<000000>2f[03P]Z`06P3P]Z`00`000000kl2P0>o0X00F0>o0X0030000003g
b9/0mlRK00/0mlRK00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1W0?ooo`030000003o
ool0oooo00l0oooo000e0?ooo`030000003oool0oooo05l0oooo00<000000=bk]`3L^kL03`3L^kL0
0`000000g[Ra0=jh/@020=jh/@030000003N^;40g[Ra01/0g[Ra00<000000>2f[03P]Z`06P3P]Z`0
0`000000kl2P0>o0X00F0>o0X0030000003gb9/0mlRK00/0mlRK00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo000e0?ooo`030000003oool0oooo
0600oooo00<000000=bk]`3L^kL03P3L^kL00`000000g[Ra0=jh/@020=jh/@030000003N^;40g[Ra
01/0g[Ra00<000000>2f[03P]Z`06P3P]Z`00`000000kl2P0>o0X00F0>o0X0030000003gb9/0mlRK
00X0mlRK00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo
00l0oooo000e0?ooo`030000003oool0oooo0640oooo00<000000=bk]`3L^kL03@3L^kL00`000000
g[Ra0=jh/@020=jh/@030000003N^;40g[Ra01/0g[Ra00<000000>2f[03P]Z`06P3P]Z`00`000000
kl2P0>o0X00F0>o0X0030000003gb9/0mlRK00X0mlRK00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo000e0?ooo`030000003oool0oooo0680oooo
00<000000=bk]`3L^kL02`3L^kL00`000000g[Ra0=jh/@030=jh/@030000003N^;40g[Ra01/0g[Ra
00<000000>2f[03P]Z`06P3P]Z`00`000000kl2P0>o0X00F0>o0X0030000003gb9/0mlRK00X0mlRK
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo
000e0?ooo`030000003oool0oooo06<0oooo00<000000=bk]`3L^kL02P3L^kL00`000000g[Ra0=jh
/@030=jh/@030000003N^;40g[Ra01X0g[Ra00<000000>2f[03P]Z`06`3P]Z`00`000000kl2P0>o0
X00F0>o0X0030000003gb9/0mlRK00T0mlRK00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`1W0?ooo`030000003oool0oooo00l0oooo000e0?ooo`030000003oool0oooo06@0oooo00<00000
0=bk]`3L^kL02@3L^kL00`000000g[Ra0=jh/@020=jh/@030000003N^;40g[Ra01/0g[Ra00<00000
0>2f[03P]Z`06`3P]Z`00`000000kl2P0>o0X00F0>o0X0030000003gb9/0mlRK00T0mlRK00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo000e0?oo
o`030000003oool0oooo06D0oooo00<000000=bk]`3L^kL0203L^kL00`000000g[Ra0=jh/@020=jh
/@030000003N^;40g[Ra01/0g[Ra00<000000>2f[03P]Z`06P3P]Z`00`000000kl2P0>o0X00G0>o0
X0030000003gb9/0mlRK00T0mlRK00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo00l0oooo000e0?ooo`030000003oool0oooo06H0oooo00<000000=bk]`3L
^kL01`3L^kL00`000000g[Ra0=jh/@020=jh/@030000003N^;40g[Ra01/0g[Ra00<000000>2f[03P
]Z`06P3P]Z`00`000000kl2P0>o0X00G0>o0X0030000003gb9/0mlRK00P0mlRK00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo000e0?ooo`030000
003oool0oooo06L0oooo00<000000=bk]`3L^kL01@3L^kL00`000000g[Ra0=jh/@030=jh/@030000
003N^;40g[Ra01/0g[Ra00<000000>2f[03P]Z`06P3P]Z`00`000000kl2P0>o0X00G0>o0X0030000
003gb9/0mlRK00P0mlRK00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo00l0oooo000G0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0
0`3oool01P3ookl0M00000000000000004RL0=ooo`/0oooo00<000000?ooo`3oool0J03oool00`00
0000g;^g0=bk]`040=bk]`030000003N^;40g[Ra00<0g[Ra00<000000=jh/@3N^;406`3N^;400`00
0000h;J/0>2f[00J0>2f[0030000003_`:00kl2P01L0kl2P00<000000?O8V`3gb9/0203gb9/00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool001H0
oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo00<0oono
07@00018W=l00P3oool00`3OW4P0001d0;ooo`0:0?ooo`<00000J@3oool00`000000g;^g0=bk]`03
0=bk]`030000003N^;40g[Ra00<0g[Ra00<000000=jh/@3N^;406`3N^;400`000000h;J/0>2f[00J
0>2f[0030000003_`:00kl2P01L0kl2P00<000000?O8V`3gb9/0203gb9/00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool001D0oooo00<0oooO09a8
0018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?noM000B9`0gooo00<0oooo00<0_g@004RL
g`3oool0203oool2000006`0oooo00<000000=bk]`3L^kL00P3L^kL00`000000g[Ra0=jh/@030=jh
/@030000003N^;40g[Ra01X0g[Ra00<000000>2f[03P]Z`06`3P]Z`00`000000kl2P0>o0X00F0>o0
X0030000003gb9/0mlRK00P0mlRK00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo00l0oooo000E0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000
B9`0gooo1@3oool00`3o_g@004RL0=ooo`030?ooo`030;md0000M;l0oooo00T0oooo00<000000?oo
o`3oool0J`3oool01@000000g;^g0=bk]`3L^kL0000000D0g[Ra00<000000=jh/@3N^;406P3N^;40
0`000000h;J/0>2f[00K0>2f[0030000003_`:00kl2P01H0kl2P00<000000?O8V`3gb9/0203gb9/0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool0
01D0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB000M;oo
0080oooo00<0oono07@00018W=l02@3oool00`000000oooo0?ooo`1]0?ooo`030000003L^kL00000
00H0g[Ra00<000000=jh/@3N^;406P3N^;400`000000h;J/0>2f[00K0>2f[0030000003_`:00kl2P
01H0kl2P00<000000?O8V`3gb9/0203gb9/00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool03`3oool001H0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0
B00004RLg`070?ooo`060;md000004P0W=oO09a8000007@0_ooo2@3oool00`000000oooo0?ooo`1^
0?ooo`8000001P3N^;400`000000g[Ra0=jh/@0J0=jh/@030000003P]Z`0h;J/01/0h;J/00<00000
0>o0X03_`:005P3_`:000`000000mlRK0?O8V`070?O8V`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`0?0?ooo`005P3oool00`3OW4P0001809cOo`020?oo
o`030?oog`2LB00007Bo00P0oooo00D0oooO09a80000000004RL0=ooo`090?ooo`030000003oool0
oooo06l0oooo00<000000=jh/@3N^;40103N^;400`000000g[Ra0=jh/@0J0=jh/@030000003P]Z`0
h;J/01/0h;J/00<000000>o0X03_`:005P3_`:000`000000mlRK0?O8V`070?O8V`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0>0?ooo`005P3oool00`3o
gi`0B00004RLg`030?ooo`030;md0000B9`0gooo00L0oooo00H0_g@00000B02Lgol0omnL04Q8W03O
ool80?ooo`030000003oool0oooo0700oooo00<000000=jh/@3N^;400`3N^;400`000000g[Ra0=jh
/@0J0=jh/@030000003P]Z`0h;J/01/0h;J/00<000000>o0X03_`:005P3_`:000`000000mlRK0?O8
V`070?O8V`030000003oool0oooo02H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?oo
o`0>0?ooo`005P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00<0
omnL04P0001d_ol00P3oool00`3o_g@0B9cO0?ooo`070?ooo`030000003oool0oooo0740oooo00<0
00000=jh/@3N^;400P3N^;400`000000g[Ra0=jh/@0J0=jh/@030000003P]Z`0h;J/01/0h;J/00<0
00000>o0X03_`:005P3_`:000`000000mlRK0?O8V`060?O8V`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`0>0?ooo`005`3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo00H0oooo00<0omnL04P0B02Lgol00P3oool00`3o_g@004RL0=ooo`07
0?ooo`030000003oool0oooo0740oooo00<000000=jh/@3N^;400P3N^;400`000000g[Ra0=jh/@0J
0=jh/@030000003P]Z`0h;J/01/0h;J/00<000000>o0X03_`:005P3_`:000`000000mlRK0?O8V`06
0?O8V`030000003oool0oooo02L0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0>
0?ooo`00603oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00<0oooO09a80018W=l00P3o
ool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo0780oooo00D000000=jh/@3N^;40g[Ra
0000000K0=jh/@030000003P]Z`0h;J/01`0h;J/00<000000>o0X03_`:005P3_`:000`000000mlRK
0?O8V`060?O8V`030000003oool0oooo02L0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0>0?ooo`006@3oool0103OW4P0000000000000M;l90?ooo`050?oog`2LB000000000000000
M;l02@3oool00`000000oooo0?ooo`1c0?ooo`040000003N^;40g[Ra000001/0g[Ra00<000000>2f
[03P]Z`06`3P]Z`00`000000kl2P0>o0X00G0>o0X0030000003gb9/0mlRK00D0mlRK00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00h0oooo000d0?ooo`03
0000003oool0oooo07@0oooo00<000000=jh/@0000006`3N^;400`000000h;J/0>2f[00K0>2f[003
0000003_`:00kl2P01L0kl2P00<000000?O8V`3gb9/01@3gb9/00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool03P3oool003@0oooo00<000000?ooo`3oool0
M@3oool2000001/0g[Ra00<000000>2f[03P]Z`06`3P]Z`00`000000kl2P0>o0X00G0>o0X0030000
003gb9/0mlRK00D0mlRK00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo00h0oooo000d0?ooo`030000003oool0oooo07H0oooo00<000000=jh/@3N^;406@3N
^;400`000000h;J/0>2f[00K0>2f[0030000003_`:00kl2P01L0kl2P00<000000?O8V`3gb9/01@3g
b9/00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03P3o
ool003@0oooo00<000000?ooo`3oool0MP3oool00`000000g[Ra0=jh/@0I0=jh/@030000003P]Z`0
h;J/01/0h;J/00<000000>o0X03_`:005P3_`:000`000000mlRK0?O8V`050?O8V`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0>0?ooo`00=03oool00`00
0000oooo0?ooo`1f0?ooo`8000006P3N^;400`000000h;J/0>2f[00K0>2f[0030000003_`:00kl2P
01H0kl2P00<000000?O8V`3gb9/01@3gb9/00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool03P3oool003@0oooo0P00001g0?ooo`030000003oool0000001T0
g[Ra00<000000>2f[03P]Z`06`3P]Z`00`000000kl2P0>o0X00F0>o0X0030000003gb9/0mlRK00D0
mlRK00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00h0
oooo000d0?ooo`030000003oool0oooo07H0oooo00@000000?ooo`3oool000005`3N^;400`000000
h;J/0>2f[00L0>2f[0030000003_`:00kl2P01H0kl2P00<000000?O8V`3gb9/0103gb9/00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03P3oool003@0oooo
00<000000?ooo`3oool0MP3oool01@000000oooo0?ooo`3oool0000001H0g[Ra00<000000>2f[03P
]Z`0703P]Z`00`000000kl2P0>o0X00F0>o0X0030000003gb9/0mlRK00@0mlRK00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00h0oooo000d0?ooo`030000
003oool0oooo07H0oooo00D000000?ooo`3oool0oooo0000000F0=jh/@030000003P]Z`0h;J/01`0
h;J/00<000000>o0X03_`:005P3_`:000`000000mlRK0?O8V`040?O8V`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0>0?ooo`00=03oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo0080oooo00<000000=jh/@3N^;404`3N^;400`000000h;J/
0>2f[00L0>2f[0030000003_`:00kl2P01H0kl2P00<000000?O8V`3gb9/00`3gb9/00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03P3oool003@0oooo00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`030?ooo`030000003N^;40g[Ra0180g[Ra00<0
00000>2f[03P]Z`0703P]Z`00`000000kl2P0>o0X00F0>o0X0030000003gb9/0mlRK00<0mlRK00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00h0oooo000d
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0103oool00`000000g[Ra0=jh/@0A
0=jh/@030000003P]Z`0h;J/01`0h;J/00<000000>o0X03_`:005P3_`:000`000000mlRK0?O8V`03
0?O8V`030000003oool0oooo02/0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0>
0?ooo`00=03oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00D0oooo00<000000=jh
/@3N^;40403N^;400`000000h;J/0>2f[00L0>2f[0030000003_`:00kl2P01H0kl2P00<000000?O8
V`3gb9/00P3gb9/00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo06P0oooo00<000000?oo
o`3oool03P3oool003@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`050?ooo`03
0000003N^;40g[Ra00l0g[Ra00<000000>2f[03P]Z`07@3P]Z`00`000000kl2P0>o0X00F0>o0X003
0000003gb9/0mlRK0080mlRK00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo00h0oooo000d0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
1P3oool00`000000g[Ra0=jh/@0>0=jh/@030000003P]Z`0h;J/01`0h;J/00<000000>o0X03_`:00
5`3_`:000`000000mlRK0?O8V`020?O8V`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
J03oool00`000000oooo0?ooo`0>0?ooo`00=03oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo00L0oooo00<000000=jh/@3N^;403@3N^;400`000000h;J/0>2f[00L0>2f[0030000003_
`:00kl2P01L0kl2P00D000000?O8V`3gb9/0mlRK0000000_0?ooo`030000003oool0oooo06P0oooo
00<000000?ooo`3oool03P3oool003@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`080?ooo`030000003N^;40g[Ra00`0g[Ra00<000000>2f[03P]Z`0703P]Z`00`000000kl2P0>o0
X00G0>o0X0050000003gb9/0mlRK0?O8V`000000;`3oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo00h0oooo000d0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool02@3o
ool00`000000g[Ra0=jh/@0;0=jh/@030000003P]Z`0h;J/01`0h;J/00<000000>o0X03_`:005P3_
`:000`000000mlRK0?O8V`020?O8V`030000003oool0oooo02d0oooo00<000000?ooo`3oool0J03o
ool00`000000oooo0?ooo`0>0?ooo`00=03oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo00X0oooo00<000000=jh/@3N^;402P3N^;400`000000h;J/0>2f[00L0>2f[0030000003_`:00
kl2P01H0kl2P00<000000?O8V`3gb9/00P3gb9/00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo06P0oooo00<000000?ooo`3oool03P3oool003@0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0:0?ooo`030000003N^;40g[Ra00X0g[Ra00<000000>2f[03P]Z`0703P]Z`00`00
0000kl2P0>o0X00F0>o0X0050000003gb9/0mlRK0?O8V`000000<03oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo00h0oooo000c0?ooo`<00000M`3oool00`000000oooo0?ooo`0;0?oo
o`030000003N^;40g[Ra00T0g[Ra00<000000>2f[03P]Z`0703P]Z`00`000000kl2P0>o0X00F0>o0
X0050000003gb9/0mlRK0?O8V`000000<03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0
oooo00h0oooo000d0?ooo`030000003oool0oooo07<0oooo1@00000=0?ooo`030000003N^;40g[Ra
00L0g[Ra00<000000>2f[03P]Z`07@3P]Z`00`000000kl2P0>o0X00F0>o0X0050000003gb9/0mlRK
0?O8V`000000<03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00h0oooo000d0?oo
o`030000003oool0oooo06d0oooo1P0000050?ooo`<000002`3oool00`000000g[Ra0=jh/@060=jh
/@030000003P]Z`0h;J/01d0h;J/00<000000>o0X03_`:005P3_`:0010000000mlRK0?O8V`00000a
0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03P3oool003@0oooo00<000000?oo
o`3oool0IP3oool7000000h0oooo100000080?ooo`030000003N^;40g[Ra00D0g[Ra00<000000>2f
[03P]Z`07@3P]Z`00`000000kl2P0>o0X00F0>o0X0040000003gb9/0mlRK00000340oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`0>0?ooo`00<`3oool00`000000oooo0?ooo`1Q0?oo
o`H000006@3oool3000000D0oooo00<000000=jh/@3N^;401@3N^;400`000000h;J/0>2f[00M0>2f
[0030000003_`:00kl2P01H0kl2P00@000000?O8V`3gb9/00000<@3oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo00h0oooo000c0?ooo`030000003oool0oooo05/0oooo1P00000R0?oo
o`<000000`3oool00`000000g[Ra0=jh/@040=jh/@030000003P]Z`0h;J/01d0h;J/00<000000>o0
X03_`:005P3_`:000`000000mlRK0000000b0?ooo`030000003oool0oooo06P0oooo00<000000?oo
o`3oool03P3oool003<0oooo00<000000?ooo`3oool0E03oool7000002/0oooo0`0000000`3oool0
00000=jh/@040=jh/@030000003P]Z`0h;J/01d0h;J/00<000000>o0X03_`:005P3_`:000`000000
mlRK0000000b0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03P3oool003<0oooo
00<000000?ooo`3oool0CP3oool6000003D0oooo100000030=jh/@030000003P]Z`0h;J/01d0h;J/
00<000000>o0X03_`:005P3_`:000`000000mlRK0000000b0?ooo`030000003oool0oooo06P0oooo
00<000000?ooo`3oool03P3oool003<0oooo00<000000?ooo`3oool0A`3oool7000003h0oooo1@00
000N0>2f[0030000003_`:00kl2P01L0kl2P0P00000c0?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool03P3oool003<0oooo00<000000?ooo`3oool0@@3oool6000004H0oooo00<00000
0=jh/@0000000`00000L0>2f[0030000003_`:00kl2P01L0kl2P0P00000c0?ooo`030000003oool0
oooo06P0oooo00<000000?ooo`3oool03P3oool003<0oooo00<000000?ooo`3oool0>`3oool60000
04`0oooo00<000000=jh/@0000000`3P]Z`3000001T0h;J/00<000000>o0X03_`:005P3_`:000`00
0000mlRK0000000c0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03P3oool003<0
oooo00<000000?ooo`3oool0=03oool7000005<0oooo0P0000060>2f[0@000005@3P]Z`00`000000
kl2P0>o0X00F0>o0X0030000003gb9/0000003<0oooo00<000000?ooo`3oool0J03oool00`000000
oooo0?ooo`0>0?ooo`00<`3oool00`000000oooo0?ooo`0^0?ooo`H00000F`3oool00`000000h;J/
0>2f[0080>2f[0<000004P3P]Z`00`000000kl2P0>o0X00F0>o0X0800000=03oool00`000000oooo
0?ooo`1X0?ooo`030000003oool0oooo00h0oooo000c0?ooo`030000003oool0oooo02L0oooo1`00
001R0?ooo`030000003P]Z`0h;J/00X0h;J/0`00000?0>2f[0030000003_`:00kl2P01H0kl2P0P00
000d0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03P3oool003<0oooo00<00000
0?ooo`3oool08@3oool6000006T0oooo00<000000>2f[03P]Z`03@3P]Z`3000000`0h;J/00<00000
0>o0X03_`:005P3_`:02000003@0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0>
0?ooo`00<`3oool2000001/0oooo1`00001`0?ooo`030000003P]Z`0h;J/00l0h;J/100000080>2f
[0030000003_`:00kl2P01H0kl2P00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1Y0?oo
o`030000003oool0oooo00d0oooo000c0?ooo`030000003oool0oooo01@0oooo1P00001h0?ooo`03
0000003P]Z`0h;J/0180h;J/0`0000050>2f[0030000003_`:00kl2P01H0kl2P00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00d0oooo000c0?ooo`030000
003oool0oooo00h0oooo1P00001n0?ooo`030000003P]Z`0h;J/01D0h;J/0`0000020>2f[0030000
003_`:00kl2P01D0kl2P00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo00d0oooo000c0?ooo`030000003oool0oooo00L0oooo1`0000250?ooo`030000003P
]Z`0h;J/01L0h;J/0`00000G0>o0X0030000003oool0oooo03@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0=0?ooo`00<`3oool010000000oooo0?ooo`3oool6000008`0oooo00<0
00000>2f[03P]Z`06@3P]Z`500000180kl2P00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`1Y0?ooo`030000003oool0oooo00d0oooo000c0?ooo`@00000T`3oool00`000000h;J/0>2f[00H
0>2f[0030000003_`:00kl2P0080kl2P0`00000>0>o0X0030000003oool0oooo03H0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0=0?ooo`00=@3oool400000980oooo00<000000>2f
[03P]Z`05`3P]Z`00`000000kl2P0>o0X0050>o0X0<000002`3_`:000`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool03@3oool003T0oooo1000002>0?ooo`03
0000003P]Z`0h;J/01H0h;J/00<000000>o0X03_`:002@3_`:03000000L0kl2P00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00d0oooo000m0?ooo`@00000
R`3oool00`000000h;J/0>2f[00E0>2f[0030000003_`:00kl2P00`0kl2P100000020>o0X0030000
003oool0oooo03P0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0=0?ooo`00@@3o
ool4000008P0oooo00<000000>2f[03P]Z`0503P]Z`00`000000kl2P0>o0X00@0>o0X0<00000>P3o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00d0oooo00150?ooo`@00000Q03oool0
0`000000h;J/0>2f[00D0>2f[0030000003_`:00kl2P0140kl2P00<000000?ooo`0000000P00000g
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool03@3oool004T0oooo100000210?oo
o`030000003P]Z`0h;J/01<0h;J/00<000000>o0X03_`:00403_`:000`000000oooo0?ooo`030?oo
o`<00000=03oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00d0oooo001=0?ooo`<0
0000OP3oool00`000000h;J/0>2f[00C0>2f[0030000003_`:00kl2P0100kl2P00<000000?ooo`3o
ool01P3oool400000300oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0=0?ooo`00
D03oool4000007/0oooo00<000000>2f[03P]Z`04P3P]Z`00`000000kl2P0>o0X00?0>o0X0030000
003oool0oooo00/0oooo0`00000]0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
3@3oool005@0oooo1000001h0?ooo`030000003P]Z`0h;J/0140h;J/00<000000>o0X03_`:003P3_
`:000`000000oooo0?ooo`0?0?ooo`<00000:`3oool00`000000oooo0?ooo`1X0?ooo`030000003o
ool0oooo00d0oooo001H0?ooo`@00000M03oool00`000000h;J/0>2f[00A0>2f[0030000003_`:00
kl2P00h0kl2P00<000000?ooo`3oool04P3oool3000002P0oooo00<000000?ooo`3oool0J03oool0
0`000000oooo0?ooo`0=0?ooo`00G03oool400000740oooo00<000000>2f[03P]Z`0403P]Z`00`00
0000kl2P0>o0X00=0>o0X0030000003oool0oooo01H0oooo1000000T0?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool03@3oool00600oooo1000001^0?ooo`030000003P]Z`0h;J/00l0
h;J/00<000000>o0X03_`:00303_`:000`000000oooo0?ooo`0K0?ooo`<000008@3oool00`000000
oooo0?ooo`1X0?ooo`030000003oool0oooo00d0oooo001T0?ooo`<00000J`3oool00`000000h;J/
0>2f[00?0>2f[0030000003_`:00kl2P00`0kl2P00<000000?ooo`3oool07P3oool3000001h0oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0=0?ooo`00I`3oool4000006P0oooo00<0
00000>2f[03P]Z`03P3P]Z`00`000000kl2P0>o0X00;0>o0X0030000003oool0oooo0280oooo0`00
000K0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03@3oool006/0oooo1000001T
0?ooo`030000003P]Z`0h;J/00h0h;J/00<000000>o0X03_`:002P3_`:000`000000oooo0?ooo`0V
0?ooo`@000005`3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00d0oooo001_0?oo
o`@00000H@3oool00`000000h;J/0>2f[00=0>2f[0030000003_`:00kl2P00X0kl2P00<000000?oo
o`3oool0:P3oool3000001@0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0=0?oo
o`00L`3oool4000005h0oooo00<000000>2f[03P]Z`02`3P]Z`00`000000kl2P0>o0X00:0>o0X003
0000003oool0oooo02h0oooo0`00000A0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool03@3oool007L0oooo1000001J0?ooo`030000003P]Z`0h;J/00/0h;J/00<000000>o0X03_`:00
2@3_`:000`000000oooo0?ooo`0b0?ooo`<000003P3oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo00d0oooo001k0?ooo`@00000E`3oool00`000000h;J/0>2f[00:0>2f[0030000003_
`:00kl2P00T0kl2P00<000000?ooo`3oool0=@3oool4000000X0oooo00<000000?ooo`3oool0J03o
ool00`000000oooo0?ooo`0=0?ooo`00O`3oool3000005D0oooo00<000000>2f[03P]Z`02@3P]Z`0
0`000000kl2P0>o0X0080>o0X0030000003oool0oooo03X0oooo0`0000070?ooo`030000003oool0
oooo06P0oooo00<000000?ooo`3oool03@3oool00880oooo1000001A0?ooo`030000003P]Z`0h;J/
00T0h;J/00<000000>o0X03_`:001`3_`:000`000000oooo0?ooo`0n0?ooo`<00000103oool00`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo00d0oooo00260?ooo`@00000CP3oool00`000000
h;J/0>2f[0080>2f[0030000003_`:00kl2P00L0kl2P00<000000?ooo`3oool0@@3oool5000006X0
oooo00<000000?ooo`3oool03@3oool008X0oooo1000001;0?ooo`030000003P]Z`0h;J/00L0h;J/
00<000000>o0X03_`:001P3_`:000`000000oooo0?ooo`160?ooo`<00000J03oool00`000000oooo
0?ooo`0=0?ooo`00SP3oool4000004L0oooo00<000000>2f[03P]Z`01`3P]Z`00`000000kl2P0>o0
X0050>o0X0030000003oool0oooo04L0oooo00<000000?ooo`3oool00`00001U0?ooo`030000003o
ool0oooo00d0oooo002B0?ooo`@00000A03oool00`000000h;J/0>2f[0060>2f[0030000003_`:00
kl2P00D0kl2P00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`030?ooo`<00000HP3oool0
0`000000oooo0?ooo`0=0?ooo`00UP3oool400000400oooo00<000000>2f[03P]Z`01P3P]Z`00`00
0000kl2P0>o0X0040>o0X0030000003oool0oooo04P0oooo00<000000?ooo`3oool01P3oool40000
05h0oooo00<000000?ooo`3oool03@3oool009X0oooo0`00000n0?ooo`030000003P]Z`0h;J/00D0
h;J/00<000000>o0X03_`:000`3_`:000`000000oooo0?ooo`190?ooo`030000003oool0oooo00X0
oooo0`00001K0?ooo`030000003oool0oooo00d0oooo002M0?ooo`@00000>`3oool00`000000h;J/
0>2f[0040>2f[0030000003_`:00kl2P00<0kl2P00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0=0?ooo`<00000F03oool00`000000oooo0?ooo`0=0?ooo`00X@3oool4000003L0oooo00<0
00000>2f[03P]Z`0103P]Z`00`000000kl2P0>o0X0020>o0X0030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0403oool3000005D0oooo00<000000?ooo`3oool03@3oool00:D0oooo1000000d
0?ooo`030000003P]Z`0h;J/00<0h;J/00D000000>o0X03_`:00kl2P0000001=0?ooo`030000003o
ool0oooo01<0oooo1000001A0?ooo`030000003oool0oooo00d0oooo002Y0?ooo`@00000<@3oool0
1@000000h;J/0>2f[03P]Z`0000000@0kl2P00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`0G0?ooo`<00000CP3oool00`000000oooo0?ooo`0=0?ooo`00[@3oool4000002d0oooo00D00000
0>2f[03P]Z`0h;J/000000030>o0X0030000003oool0oooo04`0oooo00<000000?ooo`3oool06P3o
ool3000004/0oooo00<000000?ooo`3oool03@3oool00;40oooo0`00000[0?ooo`040000003P]Z`0
h;J/00000080kl2P00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0M0?ooo`<00000B03o
ool00`000000oooo0?ooo`0=0?ooo`00]03oool4000002L0oooo00@000000>2f[03P]Z`000000P3_
`:000`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0200oooo100000140?ooo`030000003o
ool0oooo00d0oooo002h0?ooo`@00000903oool01@000000h;J/0000003_`:0000000500oooo00<0
00000?ooo`3oool0903oool300000440oooo00<000000?ooo`3oool03@3oool00;`0oooo1000000Q
0?ooo`<00000D@3oool00`000000oooo0?ooo`0W0?ooo`<00000?`3oool00`000000oooo0?ooo`0<
0?ooo`00`03oool4000001d0oooo0`00001A0?ooo`030000003oool0oooo02X0oooo0`00000l0?oo
o`030000003oool0oooo00`0oooo00340?ooo`@000006P3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo02d0oooo1000000h0?ooo`030000003oool0oooo00`0oooo00380?ooo`@00000
J@3oool00`000000oooo0?ooo`0a0?ooo`<00000=@3oool00`000000oooo0?ooo`0<0?ooo`00c03o
ool3000006H0oooo00<000000?ooo`3oool0=03oool300000380oooo00<000000?ooo`3oool0303o
ool00<l0oooo1000001R0?ooo`030000003oool0oooo03L0oooo0`00000_0?ooo`030000003oool0
oooo00`0oooo003C0?ooo`@00000GP3oool00`000000oooo0?ooo`0j0?ooo`@00000:`3oool00`00
0000oooo0?ooo`0<0?ooo`00e`3oool4000005X0oooo00<000000?ooo`3oool0?P3oool3000002P0
oooo00<000000?ooo`3oool0303oool00=/0oooo1000001F0?ooo`030000003oool0oooo0440oooo
0`00000U0?ooo`030000003oool0oooo00`0oooo003O0?ooo`@00000DP3oool00`000000oooo0?oo
o`140?ooo`<000008P3oool00`000000oooo0?ooo`0<0?ooo`00h`3oool4000004h0oooo00<00000
0?ooo`3oool0A`3oool4000001h0oooo00<000000?ooo`3oool0303oool00>L0oooo0`00001;0?oo
o`030000003oool0oooo04/0oooo0`00000K0?ooo`030000003oool0oooo00`0oooo003Z0?ooo`@0
0000A`3oool00`000000oooo0?ooo`1>0?ooo`<00000603oool00`000000oooo0?ooo`0<0?ooo`00
kP3oool4000004<0oooo00<000000?ooo`3oool0D@3oool3000001D0oooo00<000000?ooo`3oool0
303oool00?80oooo1000000o0?ooo`030000003oool0oooo05@0oooo1000000A0?ooo`030000003o
ool0oooo00`0oooo003f0?ooo`@00000>`3oool00`000000oooo0?ooo`1H0?ooo`<000003P3oool0
0`000000oooo0?ooo`0<0?ooo`00nP3oool4000003L0oooo00<000000?ooo`3oool0F`3oool30000
00/0oooo00<000000?ooo`3oool0303oool00?h0oooo1000000c0?ooo`030000003oool0oooo05h0
oooo0`0000080?ooo`030000003oool0oooo00`0oooo003o0?ooo`<0oooo0`00000`0?ooo`030000
003oool0oooo0640oooo100000040?ooo`030000003oool0oooo00`0oooo003o0?ooo`H0oooo1000
000/0?ooo`030000003oool0oooo06D0oooo0`0000000`3oool000000?ooo`0=0?ooo`00o`3oool:
0?ooo`@00000:03oool00`000000oooo0?ooo`1U0?ooo`D000003P3oool00?l0oooo3P3oool40000
02@0oooo00<000000?ooo`3oool0F`3oool:000001<0oooo003o0?oooa80oooo1000000P0?ooo`03
0000003oool0oooo0540oooo2P00000M0?ooo`00o`3ooolF0?ooo`@00000703oool00`000000oooo
0?ooo`170?ooo`X000009`3oool00?l0oooo6P3oool3000001T0oooo00<000000?ooo`3oool0?@3o
ool:00000340oooo003o0?oooad0oooo1000000E0?ooo`030000003oool0oooo03@0oooo2@00000k
0?ooo`00o`3ooolQ0?ooo`@000004@3oool00`000000oooo0?ooo`0Z0?ooo`X00000A03oool00?l0
oooo9@3oool4000000d0oooo00<000000?ooo`3oool0803oool:000004h0oooo003o0?ooobT0oooo
100000090?ooo`030000003oool0oooo01H0oooo2P00001H0?ooo`00o`3oool]0?ooo`@000001@3o
ool00`000000oooo0?ooo`0<0?ooo`X00000HP3oool00?l0oooo<@3oool4000000030?ooo`000000
oooo00<0oooo2P00001/0?ooo`00o`3ooole0?ooo`H00000MP3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00<D0oooo00<0okmd0000000000000P0000000`00B9`0gooo0?ooo`1a0?ooo`040?oo_`1d
0000000004RLgfh0oooo00340?ooo`030?noM0000000B9cO00<0oooo00<0omnL04P0B02Lgol0L@3o
ool01@3ookl0M01809cOo`2oM00007Bo06d0oooo00340?ooo`030?noM00007@0_ooo00@0oooo00<0
gia8001d_`3oool0L`3oool00`3ookl0M00007Boo`1/0?ooo`00a@3oool0202oM000001d0;ooo`3o
ool0oooO09a800000000B9cOM@3oool00`3OW4P004RL0=ooo`1[0?ooo`00M03oool0303ogi`0B000
00000000B9`0gooo0;md0000000007Bo0?ooo`3OW4P004RL0=ooo`80oooo00D0_g@000000000M;l0
oono07@000030000000:04RLg`3oool0oooo0?noM0000000001809cOo`3oool0omnL04P000800000
00L0M;oo0=nLB000000004RL0=ooo`3oool0gia80080000000<0001809cOo`3oool00P3oool0103o
_g@000000000M02oool20?ooo`050=nLB000000000000000001d_ol01`3oool00`2oM00007Bo0?oo
o`050?ooo`050=nLB000000000000000001d_ol00`3oool01P3ookl0M000000000000000001d0;oo
o`<0oooo00@0_g@00000000004P0W=oo0P3oool01@3o_g@000000000000004P0W=oo00<0oooo00<0
gia80018W03Oool00P3oool01P2oM0000000001d_`3ooml0W4P0001d_`P0oooo00D0gia800000000
0000001809cOo`070?ooo`050=nLB000000000000000B02Lgol0103oool01@3OW4P0000000000000
0000M;oo0080oooo00@0okmd0000000007@0_ooo0P3oool01@3o_g@000000000000004P0W=oo00D0
oooo00L0_gAd0;ooo`3oool0oooo0?oOW018B9`0gooo00L0oooo00<0oono07@0000000000P000000
3P18W=l0oooo0?ooo`3ogi`0B00000000000B9`0gooo0;md0000000007Bo0?ooo`2oM00007Bo1@3o
ool00`3o_g@0001809cOo`020?ooo`0;0?oOW018000000000000001d_ol0gia800000000B9`0gooo
0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`020?ooo`050=nLB000000000000000001d_ol0DP3o
ool007@0oooo00`0omnL04P0B02Lgol0omnL04Qd_`2oM00007Bo0?noW02Lgol0okmd0000M02oool2
0?ooo`0P0=nLB000B9`0gkmd07Bog`2LB000M;oo0?ooo`3ogi`0B00007Boo`3oool0okmd0000B02L
gml0W7BL0=ooo`2oM00004RL0=ooo`3oool0_g@007AdM00007@0_mnL09boo`3ogi`0B01d0;ooo`3o
ool0oono07@00018W=l20?ooo`080?oOW01807@0_ono09bLg`3oool0omnL04P0001d_ol20?ooo`03
0;md0000M;l0oooo00D0oooo00<0okmd0000M02oool0103oool00`3ogi`0B00007Boo`020?ooo`07
0;md0000M;l0oooo0?ooo`3o_g@0001d0;ooo`060?ooo`0<0=nLB000B9`0gooO09adW03Oool0omnL
04P0B02Lgol0oooo0?oOW018000007Bo0P3oool00`3o_g@0001d0;ooo`020?ooo`060=nLB000B9`0
gkmd07Bog`2LB00007Bo1`3oool01`3o_g@0000007Boo`3oool0oooO09a80018W=l01@3oool01`3o
gi`0B01d0;ooo`3oool0oono07@00018W=l00P3oool00`3ogi`0B00007Boo`020?ooo`0?0;md0000
M;l0oooo0?oOW01807@0_ono09bLg`3oool0omnL04P0B02Lgol0oooo0?oOW018000007Bo00@0oooo
00P0_g@00000M02oool0oooo0?noM000000004RL0=ooo`H0oooo01@0oooO09a8001d_ol0oooo0?oO
W0180000M;oo0?ooo`3ogi`0B01809cOo`3ogi`0B7Bo0;md0000M;l0oknL09cOo`3o_g@0001d0;oo
o`@0oooo00<0oono07@00018W=l00P3oool0502oM00004RL0=ooo`3oool0_g@007AdM00007@0_mnL
09boo`3o_g@0000007Boo`3oool0oooO09a80018W=l0oooo0?oOW0180000M;oo0P3oool00`2oM000
07Bo0?ooo`1@0?ooo`00M03oool0303ooml0W4P004RLg`3oool0okmd07AdM000B9`0gooo0?ooo`3o
okl0M00004RLg`80oooo00h0omnL04P0B02Lgol0oooo0;mdM02oool0oooo0?oo_`1d0000M;oo0?oo
o`3ookl0M00007Boo`80oooo00<0_g@0001d_`3oool00P3oool01`2oM000000007Boo`3oool0oono
07@0001d_ol00P3oool0303ookl0M00007Boo`3oool0oono07@0001d_ol0gibL0;ooo`3OW4P004RL
0=ooo`<0oooo00<0gibL0;ooo`3oool0103oool00`3ogi`0B00007Boo`040?ooo`030=nLB000B9`0
gooo00<0oooo00H0gibL0;ooo`3oool0oooo0;md001d_ol60?ooo`030?noM00004P0W=oo0080oooo
00<0gia80018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0oono07@00018W=l00P3oool00`3o
gi`0B01809cOo`0:0?ooo`030=nLB000B9`0gooo00<0oooo00<0gmoO0?ooo`3oool00`3oool00`3o
okl0M00007Boo`020?ooo`070?oo_`1d0000M;oo0?ooo`3OW4P004RL0=ooo`030?ooo`0:0=nLW02o
ool0oono07@0001d_ol0gibL0;ooo`3OW4P004RL0=ooo`80oooo00<0omnL04P00018W=l00P3oool0
2@3ooml0W4P0001dM02LW=l0oooo0?noM00007@0_mnL07BLg`070?ooo`0C0;mdM02oool0oooo0?oo
_`1d0000M;oo0?ooo`3ooml0W4P004RLg`3oool0okmd07AdM000B9`0gooo0?ooo`3ogi`0B00007Bo
o`050?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo0`3oool01`2oM000000007Boo`3oool0gia8
0018W03Oool00`3oool01@3Ogml0oooo0=nLB000B9`0gooo00<0oooo00<0gibL0;ooo`3oool0C`3o
ool007D0oooo0100_g@00018W03Oool0oooo0;md000004P0W=oo0?ooo`3ooml0W4P00000M02oool0
oooo0?oog`2LB000B9cO103oool00`3OW4P0001d0;ooo`020?ooo`070;md0000M;l0oooo0?ooo`3o
_g@0001d0;ooo`020?ooo`030?oo_`1d0000B9cO0080oooo00<0_g@004RLg`3oool00P3oool01P3O
W4P004RL0=ooo`3oool0_g@004RLg`80oooo00D0okmd000000000000000004RLg`080?ooo`040?oo
g`2LB00004RL0=ooo`<0oooo00D0okmd000000000000000004RLg`040?ooo`030?oo_`1d00000000
0080000000L0M;oo0?ooo`3oool0oooo0?oo_`1d0000B9cO0080oooo00<0okmd0000M02oool00`3o
ool02`3OW4P0001d0;ooo`3ooml0W4P00000M02oool0oooo0?oog`2LB000B9cO00X0oooo00<0okmd
0000M02oool02P3oool00`2oM000B9cO0?ooo`020?ooo`040=nLB000B9`0gooo0?noM0<0000000<0
B9cO0?ooo`3oool00P3oool01`2oM000B9cO0?ooo`3oool0okmd0000M02oool00`3oool03P3OW4P0
001d0;ooo`3oool0oooO09a80018W=l0giad09cOo`3OW4P0001d0;ooo`3OW7@0W=oo2@3oool00`3O
W4P0001d0;ooo`020?ooo`0<0;md0000B9`0gooo0?ooo`2oM000001809cOo`3oool0oooO09a80000
B9`0gooo103oool01`3OW4P0001d0;ooo`3oool0okmd0000M02oool00P3oool01`3ookl0M00004RL
g`3oool0okmd0000M02oool01@3oool01@3o_g@00000000000000000B9cO05<0oooo001e0?ooo`07
0?noM00007@0_ooo0?ooo`3ookl0M00007Boo`020?ooo`030=nLB000B4P0B7Bo0080oooo00<0_g@0
001d_`3oool00P3oool00`3o_g@0001809cOo`030?ooo`070=nLB000B9`0gooo0?ooo`3ookl0M000
07Boo`030?ooo`070;md0000B9`0gooo0?ooo`3OW4P004RL0=ooo`020?ooo`0?0?oOW01804P0W=oo
0?ooo`3OW4P004RL0=ooo`3oool0oono07@0B02Lgol0oooo0=nLB0000000B9cO00L0oooo00<0_g@0
04QdM01dW=l00`3oool01`3ookl0M01809cOo`3oool0gia800000018W=l00P3oool01`2oM00004RL
0=ooo`3oool0omnL04P00018W=l00`3oool01`2oM00004RL0=ooo`3oool0oono07@0001d_ol00`3o
ool01`3ogi`0B01809cOo`3oool0gia80018B018M;l00P3oool00`2oM00007Bo0?ooo`090?ooo`03
0?oo_`1d0000M;oo00X0oooo00<0gia80018W03Oool00P3oool02P3ogi`0B01809cOo`3ookl0M018
09cOo`3oool0gia800000018W=l20?ooo`070=nLB000B9`0gooo0?ooo`3ookl0M00007Boo`030?oo
o`0>0?oOW01804P0W=oo0?ooo`3ookl0M00004RLg`3ooml0W9bo0=nLB00007@0_ooo0?oog`2LW;l8
0?ooo`030?noM00004P0W=oo00<0oooo00L0okmd0000M02oool0oooo0?oo_`1d0000M;oo0080oooo
00<0_g@004QdM01dW=l0103oool01`3ogi`0B00007Boo`3oool0oono07@0001d_ol00`3oool01P2o
M00004RL0=ooo`3ookl0M00007Boo`D0oooo00L0oono07@0B02Lgol0oooo0=nLB0000000B9cO0540
oooo001d0?ooo`040?oOg`3Ookl0M00007Boo`80oooo01L0_g@0001d_`3oool0oooo0?noM00007@0
_kmd04RLg`3oool0okmd0000M02oool0oooo0?oOW01804P0W=oo0?ooo`3OW7@0W=oo0?ooo`3ogi`0
B01809cOo`020?ooo`030?noM00007@0_ooo0080oooo00L0gia80000M02oool0oooo0?oOW01804P0
M;oO0080oooo00L0oono07@0001d_ol0oooo0?oOW01807@0_ooo0080oooo00L0okmd0018W03Oool0
oooo0?oo_`1d0000B9cO00H0oooo00@0okmd0018W02oW4P0M;oo0`3oool02P3o_g@004RL0=ooo`3o
ool0oono07@00018W=l0oooo0;md0000M;l30?ooo`030=nLB00007@0_ooo0080oooo00<0gia80000
B02Lgol00P3oool00`3OW4P0001d0;ooo`020?ooo`0<0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;no
M018W=l0oooo0?noM00007@0_ooo2P3oool01`3OW4P0001d0;ooo`3oool0oono07@0001d_ol01@3o
ool00`3ogi`0B01807Bog`020?ooo`0?0?oo_`1d0000M;oo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@00018W=l0oooo0?oOW01807@0_ooo0080oooo00<0gia80000M02oool00P3oool03`3ookl0M000
07Boo`3oool0oono07@0001d_ol0oooo0?noM000000004RL0=ooo`3oool0okmd07Boo`060?ooo`0:
0?oOW01804P0W=oo0?ooo`3OW7@0W=oo0?oOg`3Ookl0M00007Boo`80oooo00P0_g@0001d_`3oool0
oooo0?noM000B9`0_ia807Boo`<0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001d0;ooo`02
0?ooo`0C0=nLB00007@0_ooo0?ooo`3OW4P0001d0;ooo`3oool0oono07@0001d_ol0oooo0?noM000
B9`0gooo0?ooo`3ookl0M00004RLg`1@0?ooo`00M03oool0103ogi`0B7Bo0;md0000M;l20?ooo`0G
0?noM000B9`0gooo0?ooo`3ooml0W4P007Boo`3OW4P007Bo0?oOW01804P0W=oo0?ooo`3ogi`0B018
09cOo`3ooml0W4P007Boo`3oool0oooO09a80018W=l00`3oool0503OW4P0001d0;ooo`3oool0_g@0
0000B02Lgol0oooo0?oo_`1d0000B4Q804RLg`3oool0okmd0000B02Lgol0oooo0?oo_`1d0000M;oo
0`3oool01`3OW4P0001d0;ooo`3oool0gia80018W03Oool01@3oool04P3ookl0M01809cOo`2oM000
M7Ad0018W03Oool0oooo0=nLB00007@0_ooo0?ooo`3OW4P004RL0=ooo`3ogi`0B00004RLg`80oooo
00<0gia80000M02oool00P3oool00`3ogi`0B00004RLg`030?ooo`0D0;md000007@0_ooo0?ooo`3o
_g@0001d0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOo`3oool0oono07@00018
W=l70?ooo`060;md000007@0_ooo0?ooo`3OW4P0B9cO1@3oool0203ookl0M00004Q8B018W=l0oooo
0?noM00004P0W=oo0P3oool02P3OW4P0001d0;ooo`3oool0gia80018W03Oool0oono07@0001d_ol3
0?ooo`0;0;md000007@0_ooo0?ooo`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol00P3oool01P2o
M00004RL0=ooo`3oool0omnL04Qd_`H0oooo00X0omnL04P0B02Lgol0oooO09a8001d_ol0omnL04Qd
_`2oM00007Bo0P3oool03`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0_g@007AdM000B9`0gooo
0?ooo`2oM00004RL0=ooo`020?ooo`070=nLB00007@0_ooo0?ooo`2oM000001809cOo`020?ooo`06
0;md000007@0_ooo0?ooo`3OW4P0B9cO0P3oool01`3OW4P0001d0;ooo`3oool0gia80018W03Oool0
C`3oool007D0oooo00<0okmd00000000M;l00P3oool0303ogi`0B01809cOo`3ookl0M00000000018
W=l0oooo0?noM0000000001809cOo`80oooo00L0_g@0000000000000000004RLg`3ookl0M00000<0
000000T0M;oo0?ooo`3oool0omnL04P000000000B9bL07@00018W=l00P3oool00`2oM00007Bo0=nL
B0020000000604RLg`3oool0oooo0?ooo`2oM000B9cO103oool01@3ogi`0B000000000000000M;oo
00D0oooo00P0omnL04P000000000M;oo0?ooo`2oM000001d0;ooo`80oooo00D0omnL04P000000000
000007Boo`020?ooo`030?oo_`1d0000000000@0000000H0B9cO0?noM000000000000018W03Oool3
0?ooo`0C0?noM000000000000000001d_ol0oooo0?oo_`1d0000000004RLg`3oool0okmd00000000
04P0W=oo0?ooo`3ookl0M00004RLg`080?ooo`050?oOW018000000000000B02Lgol01P3oool00`2o
M00007Bo0=nLB0020000000304RLg`3oool0oooo0080oooo00D0omnL04P000000000000007Boo`02
0?ooo`030;md0018W=l0oooo00<0oooo00X0okmd000000000000000007Boo`3ooml0W4P000000000
07@0_ooo0P3oool01P3ogi`0B7Bo0?ooo`3ookl0M000001d_`L0oooo00T0_g@00000000000000000
04RLg`3oool0okmd00000000M;l00P3oool0303ogi`0B01809cOo`3ogi`0B0000000001d_ol0oooo
0;md000007@0_ono07@000<0000000T0M;oo0?ooo`3oool0omnL04P000000000B9bL07@00018W=l0
0`3oool01@3ogi`0B0000000000004P0W=oo00<0oooo00D0omnL04P000000000000007Boo`1@0?oo
o`00S`3oool00`3o_g@0001d0;ooo`0;0?ooo`030=nLB000B9`0gooo00H0oooo00<0gia80018W03O
ool0E03oool00`3OW4P004RL0=ooo`0>0?ooo`030=nLB000B9`0gooo03<0oooo00<0okmd0000B02L
gol0J@3oool00900oooo00<0giad09cOo`3oool02P3oool00`3ogi`0B01809cOo`060?ooo`030?oO
W01807@0_ooo05@0oooo00<0omnL04P0B02Lgol03P3oool00`3ogi`0B01d0;ooo`0c0?ooo`030?oo
g`2LB00007Bo06T0oooo002M0?ooo`030?oo_`1d0000B9cO00H0oooo00<0oooO09a8001d_ol0:03o
ool0103ookl0M0000018W03OoolX0?ooo`030?oo_`1d0000B9cO00h0oooo00<0oooO09a8001d_ol0
=03oool00`3o_g@0001d0;ooo`1X0?ooo`00WP3oool00`3OW4P007Bo0?ooo`060?ooo`030=nLB018
W=l0oooo05@0oooo00<0gia8001d_`3oool03P3oool00`3OW4P0B9cO0?ooo`0d0?ooo`050=nLB000
B9`0gooO09a80018W=l0I@3oool009`0oooo00D0oooO09a800000000001d0;ooo`040?ooo`040?oo
g`2LB0000000001d_e<0oooo00D0oooO09a800000000001d0;ooo`0<0?ooo`040?oog`2LB0000000
001d_cH0oooo00@0gia80000000004P0W=ooI@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {454.625, 0}} -> {-0.0846873, -0.0922074, \
0.00350177, 0.00350177}}]
}, Closed]],

Cell["\<\
\tThe following functions evaluate the population history and produce figures \
that combine the vector field with orbits in phase space.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[trajectory];\)\), "\[IndentingNewLine]", 
    \(trajectory[{a_, b_, c_}, {x0_, y0_}, tmax_, 
        opts___Rule] := {x[t], 
          y[t]} /. \(NDSolve[{\(x\^\[Prime]\)[
                  t] \[Equal] \((1 - x[t])\) 
                    x[t] - \(a\ x[t] y[t]\)\/\(x[t] + b\), \(y\^\[Prime]\)[
                  t] \[Equal] c\ \ y[t] \((1 - y[t]\/x[t])\), 
              x[0] \[Equal] x0, y[0] \[Equal] y0}, {x, y}, {t, 0, tmax}, 
            opts]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[PhaseAndField];\)\), "\[IndentingNewLine]", 
    \(PhaseAndField[{a_, b_, c_}, ic : {{_, _} .. }, xmax_, ymax_, tmin_, 
        tmax_, opts___Rule] := 
      With[{optParametricPlot\  = \ FilterOptions[ParametricPlot, opts], 
          optPlotField = FilterOptions[PlotVectorField, opts], 
          optND\  = 
            FilterOptions[NDSolve, 
              opts]}, \[IndentingNewLine]DisplayTogether[\[IndentingNewLine]\
PlotVectorField[\ {\((1 - x)\) x\  - \ \(a\ x\ y\)\/\(x + b\), 
              c\ \((1 - y\/x)\) y}, {x, 0.01, xmax}, {y, 0, ymax}, 
            PlotPoints \[Rule] Automatic, 
            optPlotField], \[IndentingNewLine]ParametricPlot[
            Evaluate[
              Table[trajectory[{a, b, c}, 
                  ic\[LeftDoubleBracket]i\[RightDoubleBracket], tmax, 
                  optND], {i, Length[ic]}]], {t, tmin, tmax}, 
            optParametricPlot], Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<prey\>", "\<predator\>"}, 
          PlotLabel \[Rule] "\<predator-prey model, {a,b,c}=\>" <> 
              ToString[{a, b, c}]]]\)}], "Input"],

Cell["\<\
Thus, we observe that all trajectories for a wide range of initial conditions \
rapidly spiral into a stable fixed.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ics = 
        Flatten[Table[{x0, y0}, {x0, 0.25, 1, 0.25}, {y0, 0.25, 1, 0.25}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(PhaseAndField[{0.5, 0.1, 0.2}, ics, 1, 1, 0, 100];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00997 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0143129 0.961878 0.0240469 0.961878 [
[.01431 -0.0125 -5 -15.6875 ]
[.01431 -0.0125 5 0 ]
[.20669 -0.0125 -9.5 -15.6875 ]
[.20669 -0.0125 9.5 0 ]
[.39906 -0.0125 -9.5 -15.6875 ]
[.39906 -0.0125 9.5 0 ]
[.59144 -0.0125 -9.625 -15.6875 ]
[.59144 -0.0125 9.625 0 ]
[.78381 -0.0125 -9.5 -15.6875 ]
[.78381 -0.0125 9.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.25 -31.375 ]
[.5 -0.0125 13.25 -15.6875 ]
[-0.0125 .02405 -10 -7.84375 ]
[-0.0125 .02405 0 7.84375 ]
[-0.0125 .21642 -19 -7.84375 ]
[-0.0125 .21642 0 7.84375 ]
[-0.0125 .4088 -19 -7.84375 ]
[-0.0125 .4088 0 7.84375 ]
[-0.0125 .60117 -19.25 -7.84375 ]
[-0.0125 .60117 0 7.84375 ]
[-0.0125 .79355 -19 -7.84375 ]
[-0.0125 .79355 0 7.84375 ]
[-0.0125 .98592 -10 -7.84375 ]
[-0.0125 .98592 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .50499 -34.9375 -23.625 ]
[-0.01875 .50499 -19.25 23.625 ]
[ 0 1.00997 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.02247 -110.813 0 ]
[.5 1.02247 110.813 15.6875 ]
[ 0 0 0 0 ]
[ 1 1.00997 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01431 0 m
.01431 .00625 L
s
gsave
.01431 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20669 0 m
.20669 .00625 L
s
gsave
.20669 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.39906 0 m
.39906 .00625 L
s
gsave
.39906 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59144 0 m
.59144 .00625 L
s
gsave
.59144 -0.0125 -70.625 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78381 0 m
.78381 .00625 L
s
gsave
.78381 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.06241 0 m
.06241 .00375 L
s
.1105 0 m
.1105 .00375 L
s
.15859 0 m
.15859 .00375 L
s
.25478 0 m
.25478 .00375 L
s
.30288 0 m
.30288 .00375 L
s
.35097 0 m
.35097 .00375 L
s
.44716 0 m
.44716 .00375 L
s
.49525 0 m
.49525 .00375 L
s
.54335 0 m
.54335 .00375 L
s
.63953 0 m
.63953 .00375 L
s
.68763 0 m
.68763 .00375 L
s
.73572 0 m
.73572 .00375 L
s
.83191 0 m
.83191 .00375 L
s
.88 0 m
.88 .00375 L
s
.9281 0 m
.9281 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.25 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(prey) show
85.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02405 m
.00625 .02405 L
s
gsave
-0.0125 .02405 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .21642 m
.00625 .21642 L
s
gsave
-0.0125 .21642 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .4088 m
.00625 .4088 L
s
gsave
-0.0125 .4088 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .60117 m
.00625 .60117 L
s
gsave
-0.0125 .60117 -80.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .79355 m
.00625 .79355 L
s
gsave
-0.0125 .79355 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .98592 m
.00625 .98592 L
s
gsave
-0.0125 .98592 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07214 m
.00375 .07214 L
s
0 .12023 m
.00375 .12023 L
s
0 .16833 m
.00375 .16833 L
s
0 .26452 m
.00375 .26452 L
s
0 .31261 m
.00375 .31261 L
s
0 .3607 m
.00375 .3607 L
s
0 .45689 m
.00375 .45689 L
s
0 .50499 m
.00375 .50499 L
s
0 .55308 m
.00375 .55308 L
s
0 .64927 m
.00375 .64927 L
s
0 .69736 m
.00375 .69736 L
s
0 .74546 m
.00375 .74546 L
s
0 .84164 m
.00375 .84164 L
s
0 .88974 m
.00375 .88974 L
s
0 .93783 m
.00375 .93783 L
s
.25 Mabswid
0 0 m
0 1.00997 L
s
gsave
-0.01875 .50499 -111.719 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
84.625 11.8438 translate
90 rotate
-84.625 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(predator) show
106.250 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01431 1.00372 m
.01431 1.00997 L
s
.20669 1.00372 m
.20669 1.00997 L
s
.39906 1.00372 m
.39906 1.00997 L
s
.59144 1.00372 m
.59144 1.00997 L
s
.78381 1.00372 m
.78381 1.00997 L
s
.97619 1.00372 m
.97619 1.00997 L
s
.125 Mabswid
.06241 1.00622 m
.06241 1.00997 L
s
.1105 1.00622 m
.1105 1.00997 L
s
.15859 1.00622 m
.15859 1.00997 L
s
.25478 1.00622 m
.25478 1.00997 L
s
.30288 1.00622 m
.30288 1.00997 L
s
.35097 1.00622 m
.35097 1.00997 L
s
.44716 1.00622 m
.44716 1.00997 L
s
.49525 1.00622 m
.49525 1.00997 L
s
.54335 1.00622 m
.54335 1.00997 L
s
.63953 1.00622 m
.63953 1.00997 L
s
.68763 1.00622 m
.68763 1.00997 L
s
.73572 1.00622 m
.73572 1.00997 L
s
.83191 1.00622 m
.83191 1.00997 L
s
.88 1.00622 m
.88 1.00997 L
s
.9281 1.00622 m
.9281 1.00997 L
s
.25 Mabswid
0 1.00997 m
1 1.00997 L
s
.99375 .02405 m
1 .02405 L
s
.99375 .21642 m
1 .21642 L
s
.99375 .4088 m
1 .4088 L
s
.99375 .60117 m
1 .60117 L
s
.99375 .79355 m
1 .79355 L
s
.99375 .98592 m
1 .98592 L
s
.125 Mabswid
.99625 .07214 m
1 .07214 L
s
.99625 .12023 m
1 .12023 L
s
.99625 .16833 m
1 .16833 L
s
.99625 .26452 m
1 .26452 L
s
.99625 .31261 m
1 .31261 L
s
.99625 .3607 m
1 .3607 L
s
.99625 .45689 m
1 .45689 L
s
.99625 .50499 m
1 .50499 L
s
.99625 .55308 m
1 .55308 L
s
.99625 .64927 m
1 .64927 L
s
.99625 .69736 m
1 .69736 L
s
.99625 .74546 m
1 .74546 L
s
.99625 .84164 m
1 .84164 L
s
.99625 .88974 m
1 .88974 L
s
.99625 .93783 m
1 .93783 L
s
.25 Mabswid
1 0 m
1 1.00997 L
s
gsave
.5 1.02247 -171.813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(predator) show
106.250 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
115.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(prey) show
139.875 15.813 moveto
(model) show
169.375 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
175.375 15.813 moveto
(8) show
179.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
185.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
188.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
194.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
197.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
202.938 15.813 moveto
(<) show
206.875 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
215.375 15.813 moveto
(8) show
219.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
234.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
240.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
255.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
261.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
276.688 15.813 moveto
(<) show
280.625 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.02393 .02405 m
.02397 .02405 L
s
% Start of user PostScript
0.01 0. 0.010035357 0. MAarrowhead1
% End of user PostScript
.02393 .09275 m
.02395 .09245 L
s
% Start of user PostScript
0.01 0.071428571 0.010023762 0.071115161 MAarrowhead1
% End of user PostScript
.02393 .16146 m
.02394 .16015 L
s
% Start of user PostScript
0.01 0.14285714 0.010012166 0.14150146 MAarrowhead1
% End of user PostScript
.02393 .23016 m
.02393 .22716 L
s
% Start of user PostScript
0.01 0.21428571 0.010000571 0.2111589 MAarrowhead1
% End of user PostScript
.02393 .29887 m
.02392 .29346 L
s
% Start of user PostScript
0.01 0.28571429 0.009988975 0.28008747 MAarrowhead1
% End of user PostScript
.02393 .36757 m
.02391 .35906 L
s
% Start of user PostScript
0.01 0.35714286 0.0099773794 0.34828719 MAarrowhead1
% End of user PostScript
.02393 .43628 m
.0239 .42396 L
s
% Start of user PostScript
0.01 0.42857143 0.0099657839 0.41575804 MAarrowhead1
% End of user PostScript
.02393 .50499 m
.02389 .48815 L
s
% Start of user PostScript
0.01 0.5 0.0099541884 0.48250003 MAarrowhead1
% End of user PostScript
.02393 .57369 m
.02388 .55165 L
s
% Start of user PostScript
0.01 0.57142857 0.0099425929 0.54851316 MAarrowhead1
% End of user PostScript
.02393 .6424 m
.02387 .61444 L
s
% Start of user PostScript
0.01 0.64285714 0.0099309973 0.61379742 MAarrowhead1
% End of user PostScript
.02393 .7111 m
.02385 .67654 L
s
% Start of user PostScript
0.01 0.71428571 0.0099194018 0.67835283 MAarrowhead1
% End of user PostScript
.02393 .77981 m
.02384 .73793 L
s
% Start of user PostScript
0.01 0.78571429 0.0099078063 0.74217937 MAarrowhead1
% End of user PostScript
.02393 .84851 m
.02383 .79862 L
s
% Start of user PostScript
0.01 0.85714286 0.0098962107 0.80527705 MAarrowhead1
% End of user PostScript
.02393 .91722 m
.02382 .85862 L
s
% Start of user PostScript
0.01 0.92857143 0.0098846152 0.86764587 MAarrowhead1
% End of user PostScript
.02393 .98592 m
.02381 .91791 L
s
% Start of user PostScript
0.01 1. 0.0098730197 0.92928583 MAarrowhead1
% End of user PostScript
.09195 .02405 m
.09221 .02405 L
s
% Start of user PostScript
0.080714286 0. 0.080979283 0. MAarrowhead1
% End of user PostScript
.09195 .09275 m
.09215 .09276 L
s
% Start of user PostScript
0.080714286 0.071428571 0.080922314 0.071434441 MAarrowhead1
% End of user PostScript
.09195 .16146 m
.0921 .16138 L
s
% Start of user PostScript
0.080714286 0.14285714 0.080865345 0.14277858 MAarrowhead1
% End of user PostScript
.09195 .23016 m
.09204 .22992 L
s
% Start of user PostScript
0.080714286 0.21428571 0.080808375 0.21403242 MAarrowhead1
% End of user PostScript
.09195 .29887 m
.09199 .29837 L
s
% Start of user PostScript
0.080714286 0.28571429 0.080751406 0.28519596 MAarrowhead1
% End of user PostScript
.09195 .36757 m
.09193 .36673 L
s
% Start of user PostScript
0.080714286 0.35714286 0.080694437 0.35626919 MAarrowhead1
% End of user PostScript
.09195 .43628 m
.09188 .43501 L
s
% Start of user PostScript
0.080714286 0.42857143 0.080637467 0.42725212 MAarrowhead1
% End of user PostScript
.09195 .50499 m
.09182 .5032 L
s
% Start of user PostScript
0.080714286 0.5 0.080580498 0.49814476 MAarrowhead1
% End of user PostScript
.09195 .57369 m
.09177 .5713 L
s
% Start of user PostScript
0.080714286 0.57142857 0.080523529 0.56894709 MAarrowhead1
% End of user PostScript
.09195 .6424 m
.09171 .63932 L
s
% Start of user PostScript
0.080714286 0.64285714 0.080466559 0.63965912 MAarrowhead1
% End of user PostScript
.09195 .7111 m
.09166 .70725 L
s
% Start of user PostScript
0.080714286 0.71428571 0.08040959 0.71028084 MAarrowhead1
% End of user PostScript
.09195 .77981 m
.0916 .77509 L
s
% Start of user PostScript
0.080714286 0.78571429 0.080352621 0.78081227 MAarrowhead1
% End of user PostScript
.09195 .84851 m
.09155 .84285 L
s
% Start of user PostScript
0.080714286 0.85714286 0.080295651 0.8512534 MAarrowhead1
% End of user PostScript
.09195 .91722 m
.09149 .91052 L
s
% Start of user PostScript
0.080714286 0.92857143 0.080238682 0.92160422 MAarrowhead1
% End of user PostScript
.09195 .98592 m
.09144 .9781 L
s
% Start of user PostScript
0.080714286 1. 0.080181713 0.99186474 MAarrowhead1
% End of user PostScript
.15997 .02405 m
.16041 .02405 L
s
% Start of user PostScript
0.15142857 0. 0.15188749 0. MAarrowhead1
% End of user PostScript
.15997 .09275 m
.16034 .09278 L
s
% Start of user PostScript
0.15142857 0.071428571 0.15181067 0.071455526 MAarrowhead1
% End of user PostScript
.15997 .16146 m
.16026 .16146 L
s
% Start of user PostScript
0.15142857 0.14285714 0.15173385 0.14286292 MAarrowhead1
% End of user PostScript
.15997 .23016 m
.16019 .2301 L
s
% Start of user PostScript
0.15142857 0.21428571 0.15165703 0.21422218 MAarrowhead1
% End of user PostScript
.15997 .29887 m
.16011 .2987 L
s
% Start of user PostScript
0.15142857 0.28571429 0.15158021 0.28553331 MAarrowhead1
% End of user PostScript
.15997 .36757 m
.16004 .36724 L
s
% Start of user PostScript
0.15142857 0.35714286 0.15150339 0.3567963 MAarrowhead1
% End of user PostScript
.15997 .43628 m
.15997 .43574 L
s
% Start of user PostScript
0.15142857 0.42857143 0.15142657 0.42801117 MAarrowhead1
% End of user PostScript
.15997 .50499 m
.15989 .50419 L
s
% Start of user PostScript
0.15142857 0.5 0.15134975 0.4991779 MAarrowhead1
% End of user PostScript
.15997 .57369 m
.15982 .5726 L
s
% Start of user PostScript
0.15142857 0.57142857 0.15127293 0.5702965 MAarrowhead1
% End of user PostScript
.15997 .6424 m
.15975 .64096 L
s
% Start of user PostScript
0.15142857 0.64285714 0.15119611 0.64136696 MAarrowhead1
% End of user PostScript
.15997 .7111 m
.15967 .70928 L
s
% Start of user PostScript
0.15142857 0.71428571 0.15111929 0.7123893 MAarrowhead1
% End of user PostScript
.15997 .77981 m
.1596 .77755 L
s
% Start of user PostScript
0.15142857 0.78571429 0.15104247 0.7833635 MAarrowhead1
% End of user PostScript
.15997 .84851 m
.15952 .84577 L
s
% Start of user PostScript
0.15142857 0.85714286 0.15096565 0.85428957 MAarrowhead1
% End of user PostScript
.15997 .91722 m
.15945 .91394 L
s
% Start of user PostScript
0.15142857 0.92857143 0.15088883 0.92516751 MAarrowhead1
% End of user PostScript
.15997 .98592 m
.15938 .98207 L
s
% Start of user PostScript
0.15142857 1. 0.15081201 0.99599731 MAarrowhead1
% End of user PostScript
.22799 .02405 m
.22858 .02405 L
s
% Start of user PostScript
0.22214286 0. 0.22275998 0. MAarrowhead1
% End of user PostScript
.22799 .09275 m
.2285 .09279 L
s
% Start of user PostScript
0.22214286 0.071428571 0.22267203 0.071463187 MAarrowhead1
% End of user PostScript
.22799 .16146 m
.22841 .16149 L
s
% Start of user PostScript
0.22214286 0.14285714 0.22258407 0.14289356 MAarrowhead1
% End of user PostScript
.22799 .23016 m
.22833 .23017 L
s
% Start of user PostScript
0.22214286 0.21428571 0.22249611 0.21429113 MAarrowhead1
% End of user PostScript
.22799 .29887 m
.22824 .29881 L
s
% Start of user PostScript
0.22214286 0.28571429 0.22240816 0.28565588 MAarrowhead1
% End of user PostScript
.22799 .36757 m
.22816 .36743 L
s
% Start of user PostScript
0.22214286 0.35714286 0.2223202 0.35698783 MAarrowhead1
% End of user PostScript
.22799 .43628 m
.22807 .43601 L
s
% Start of user PostScript
0.22214286 0.42857143 0.22223224 0.42828696 MAarrowhead1
% End of user PostScript
.22799 .50499 m
.22799 .50456 L
s
% Start of user PostScript
0.22214286 0.5 0.22214429 0.49955329 MAarrowhead1
% End of user PostScript
.22799 .57369 m
.2279 .57307 L
s
% Start of user PostScript
0.22214286 0.57142857 0.22205633 0.5707868 MAarrowhead1
% End of user PostScript
.22799 .6424 m
.22782 .64156 L
s
% Start of user PostScript
0.22214286 0.64285714 0.22196838 0.6419875 MAarrowhead1
% End of user PostScript
.22799 .7111 m
.22773 .71002 L
s
% Start of user PostScript
0.22214286 0.71428571 0.22188042 0.71315539 MAarrowhead1
% End of user PostScript
.22799 .77981 m
.22765 .77844 L
s
% Start of user PostScript
0.22214286 0.78571429 0.22179246 0.78429047 MAarrowhead1
% End of user PostScript
.22799 .84851 m
.22757 .84683 L
s
% Start of user PostScript
0.22214286 0.85714286 0.22170451 0.85539275 MAarrowhead1
% End of user PostScript
.22799 .91722 m
.22748 .91519 L
s
% Start of user PostScript
0.22214286 0.92857143 0.22161655 0.92646221 MAarrowhead1
% End of user PostScript
.22799 .98592 m
.2274 .98352 L
s
% Start of user PostScript
0.22214286 1. 0.22152859 0.99749886 MAarrowhead1
% End of user PostScript
.29601 .02405 m
.29672 .02405 L
s
% Start of user PostScript
0.29285714 0. 0.29359676 0. MAarrowhead1
% End of user PostScript
.29601 .09275 m
.29663 .09279 L
s
% Start of user PostScript
0.29285714 0.071428571 0.29350167 0.071467148 MAarrowhead1
% End of user PostScript
.29601 .16146 m
.29653 .16151 L
s
% Start of user PostScript
0.29285714 0.14285714 0.29340659 0.14290941 MAarrowhead1
% End of user PostScript
.29601 .23016 m
.29644 .2302 L
s
% Start of user PostScript
0.29285714 0.21428571 0.29331151 0.21432678 MAarrowhead1
% End of user PostScript
.29601 .29887 m
.29635 .29887 L
s
% Start of user PostScript
0.29285714 0.28571429 0.29321642 0.28571926 MAarrowhead1
% End of user PostScript
.29601 .36757 m
.29626 .36752 L
s
% Start of user PostScript
0.29285714 0.35714286 0.29312134 0.35708686 MAarrowhead1
% End of user PostScript
.29601 .43628 m
.29617 .43614 L
s
% Start of user PostScript
0.29285714 0.42857143 0.29302626 0.42842957 MAarrowhead1
% End of user PostScript
.29601 .50499 m
.29608 .50474 L
s
% Start of user PostScript
0.29285714 0.5 0.29293117 0.49974739 MAarrowhead1
% End of user PostScript
.29601 .57369 m
.29599 .57332 L
s
% Start of user PostScript
0.29285714 0.57142857 0.29283609 0.57104032 MAarrowhead1
% End of user PostScript
.29601 .6424 m
.29589 .64187 L
s
% Start of user PostScript
0.29285714 0.64285714 0.29274101 0.64230836 MAarrowhead1
% End of user PostScript
.29601 .7111 m
.2958 .7104 L
s
% Start of user PostScript
0.29285714 0.71428571 0.29264592 0.71355152 MAarrowhead1
% End of user PostScript
.29601 .77981 m
.29571 .7789 L
s
% Start of user PostScript
0.29285714 0.78571429 0.29255084 0.78476979 MAarrowhead1
% End of user PostScript
.29601 .84851 m
.29562 .84738 L
s
% Start of user PostScript
0.29285714 0.85714286 0.29245576 0.85596317 MAarrowhead1
% End of user PostScript
.29601 .91722 m
.29553 .91583 L
s
% Start of user PostScript
0.29285714 0.92857143 0.29236067 0.92713166 MAarrowhead1
% End of user PostScript
.29601 .98592 m
.29544 .98427 L
s
% Start of user PostScript
0.29285714 1. 0.29226559 0.99827526 MAarrowhead1
% End of user PostScript
.36402 .02405 m
.36482 .02405 L
s
% Start of user PostScript
0.36357143 0. 0.36439781 0. MAarrowhead1
% End of user PostScript
.36402 .09275 m
.36472 .09279 L
s
% Start of user PostScript
0.36357143 0.071428571 0.36429777 0.071469568 MAarrowhead1
% End of user PostScript
.36402 .16146 m
.36463 .16152 L
s
% Start of user PostScript
0.36357143 0.14285714 0.36419774 0.14291909 MAarrowhead1
% End of user PostScript
.36402 .23016 m
.36453 .23022 L
s
% Start of user PostScript
0.36357143 0.21428571 0.3640977 0.21434856 MAarrowhead1
% End of user PostScript
.36402 .29887 m
.36443 .29891 L
s
% Start of user PostScript
0.36357143 0.28571429 0.36399767 0.28575799 MAarrowhead1
% End of user PostScript
.36402 .36757 m
.36434 .36758 L
s
% Start of user PostScript
0.36357143 0.35714286 0.36389763 0.35714737 MAarrowhead1
% End of user PostScript
.36402 .43628 m
.36424 .43623 L
s
% Start of user PostScript
0.36357143 0.42857143 0.36379759 0.4285167 MAarrowhead1
% End of user PostScript
.36402 .50499 m
.36415 .50486 L
s
% Start of user PostScript
0.36357143 0.5 0.36369756 0.49986598 MAarrowhead1
% End of user PostScript
.36402 .57369 m
.36405 .57347 L
s
% Start of user PostScript
0.36357143 0.57142857 0.36359752 0.57119522 MAarrowhead1
% End of user PostScript
.36402 .6424 m
.36395 .64206 L
s
% Start of user PostScript
0.36357143 0.64285714 0.36349749 0.64250441 MAarrowhead1
% End of user PostScript
.36402 .7111 m
.36386 .71063 L
s
% Start of user PostScript
0.36357143 0.71428571 0.36339745 0.71379355 MAarrowhead1
% End of user PostScript
.36402 .77981 m
.36376 .77918 L
s
% Start of user PostScript
0.36357143 0.78571429 0.36329741 0.78506265 MAarrowhead1
% End of user PostScript
.36402 .84851 m
.36366 .84771 L
s
% Start of user PostScript
0.36357143 0.85714286 0.36319738 0.8563117 MAarrowhead1
% End of user PostScript
.36402 .91722 m
.36357 .91623 L
s
% Start of user PostScript
0.36357143 0.92857143 0.36309734 0.9275407 MAarrowhead1
% End of user PostScript
.36402 .98592 m
.36347 .98472 L
s
% Start of user PostScript
0.36357143 1. 0.36299731 0.99874965 MAarrowhead1
% End of user PostScript
.43204 .02405 m
.43289 .02405 L
s
% Start of user PostScript
0.43428571 0. 0.43516315 0. MAarrowhead1
% End of user PostScript
.43204 .09275 m
.43279 .09279 L
s
% Start of user PostScript
0.43428571 0.071428571 0.43505947 0.0714712 MAarrowhead1
% End of user PostScript
.43204 .16146 m
.43269 .16152 L
s
% Start of user PostScript
0.43428571 0.14285714 0.43495579 0.14292562 MAarrowhead1
% End of user PostScript
.43204 .23016 m
.43259 .23024 L
s
% Start of user PostScript
0.43428571 0.21428571 0.43485211 0.21436325 MAarrowhead1
% End of user PostScript
.43204 .29887 m
.43249 .29894 L
s
% Start of user PostScript
0.43428571 0.28571429 0.43474844 0.2857841 MAarrowhead1
% End of user PostScript
.43204 .36757 m
.43239 .36762 L
s
% Start of user PostScript
0.43428571 0.35714286 0.43464476 0.35718817 MAarrowhead1
% End of user PostScript
.43204 .43628 m
.43229 .43628 L
s
% Start of user PostScript
0.43428571 0.42857143 0.43454108 0.42857546 MAarrowhead1
% End of user PostScript
.43204 .50499 m
.43219 .50493 L
s
% Start of user PostScript
0.43428571 0.5 0.4344374 0.49994596 MAarrowhead1
% End of user PostScript
.43204 .57369 m
.43209 .57357 L
s
% Start of user PostScript
0.43428571 0.57142857 0.43433373 0.57129968 MAarrowhead1
% End of user PostScript
.43204 .6424 m
.43199 .64218 L
s
% Start of user PostScript
0.43428571 0.64285714 0.43423005 0.64263661 MAarrowhead1
% End of user PostScript
.43204 .7111 m
.43189 .71079 L
s
% Start of user PostScript
0.43428571 0.71428571 0.43412637 0.71395677 MAarrowhead1
% End of user PostScript
.43204 .77981 m
.43179 .77937 L
s
% Start of user PostScript
0.43428571 0.78571429 0.43402269 0.78526014 MAarrowhead1
% End of user PostScript
.43204 .84851 m
.43169 .84794 L
s
% Start of user PostScript
0.43428571 0.85714286 0.43391902 0.85654672 MAarrowhead1
% End of user PostScript
.43204 .91722 m
.43159 .91649 L
s
% Start of user PostScript
0.43428571 0.92857143 0.43381534 0.92781653 MAarrowhead1
% End of user PostScript
.43204 .98592 m
.43149 .98503 L
s
% Start of user PostScript
0.43428571 1. 0.43371166 0.99906955 MAarrowhead1
% End of user PostScript
.50006 .02405 m
.50092 .02405 L
s
% Start of user PostScript
0.505 0. 0.50589277 0. MAarrowhead1
% End of user PostScript
.50006 .09275 m
.50082 .09279 L
s
% Start of user PostScript
0.505 0.071428571 0.5057863 0.071472375 MAarrowhead1
% End of user PostScript
.50006 .16146 m
.50071 .16153 L
s
% Start of user PostScript
0.505 0.14285714 0.50567983 0.14293032 MAarrowhead1
% End of user PostScript
.50006 .23016 m
.50061 .23025 L
s
% Start of user PostScript
0.505 0.21428571 0.50557336 0.21437383 MAarrowhead1
% End of user PostScript
.50006 .29887 m
.50051 .29895 L
s
% Start of user PostScript
0.505 0.28571429 0.50546689 0.2858029 MAarrowhead1
% End of user PostScript
.50006 .36757 m
.50041 .36765 L
s
% Start of user PostScript
0.505 0.35714286 0.50536043 0.35721755 MAarrowhead1
% End of user PostScript
.50006 .43628 m
.50031 .43632 L
s
% Start of user PostScript
0.505 0.42857143 0.50525396 0.42861776 MAarrowhead1
% End of user PostScript
.50006 .50499 m
.5002 .50499 L
s
% Start of user PostScript
0.505 0.5 0.50514749 0.50000354 MAarrowhead1
% End of user PostScript
.50006 .57369 m
.5001 .57364 L
s
% Start of user PostScript
0.505 0.57142857 0.50504102 0.57137488 MAarrowhead1
% End of user PostScript
.50006 .6424 m
.5 .64228 L
s
% Start of user PostScript
0.505 0.64285714 0.50493455 0.64273179 MAarrowhead1
% End of user PostScript
.50006 .7111 m
.4999 .7109 L
s
% Start of user PostScript
0.505 0.71428571 0.50482809 0.71407427 MAarrowhead1
% End of user PostScript
.50006 .77981 m
.49979 .77951 L
s
% Start of user PostScript
0.505 0.78571429 0.50472162 0.78540232 MAarrowhead1
% End of user PostScript
.50006 .84851 m
.49969 .8481 L
s
% Start of user PostScript
0.505 0.85714286 0.50461515 0.85671593 MAarrowhead1
% End of user PostScript
.50006 .91722 m
.49959 .91668 L
s
% Start of user PostScript
0.505 0.92857143 0.50450868 0.92801511 MAarrowhead1
% End of user PostScript
.50006 .98592 m
.49949 .98525 L
s
% Start of user PostScript
0.505 1. 0.50440221 0.99929986 MAarrowhead1
% End of user PostScript
.56808 .02405 m
.56892 .02405 L
s
% Start of user PostScript
0.57571429 0. 0.57658667 0. MAarrowhead1
% End of user PostScript
.56808 .09275 m
.56881 .0928 L
s
% Start of user PostScript
0.57571429 0.071428571 0.57647799 0.071473262 MAarrowhead1
% End of user PostScript
.56808 .16146 m
.56871 .16153 L
s
% Start of user PostScript
0.57571429 0.14285714 0.57636932 0.14293386 MAarrowhead1
% End of user PostScript
.56808 .23016 m
.56861 .23026 L
s
% Start of user PostScript
0.57571429 0.21428571 0.57626064 0.2143818 MAarrowhead1
% End of user PostScript
.56808 .29887 m
.5685 .29897 L
s
% Start of user PostScript
0.57571429 0.28571429 0.57615197 0.28581709 MAarrowhead1
% End of user PostScript
.56808 .36757 m
.5684 .36767 L
s
% Start of user PostScript
0.57571429 0.35714286 0.5760433 0.35723971 MAarrowhead1
% End of user PostScript
.56808 .43628 m
.56829 .43636 L
s
% Start of user PostScript
0.57571429 0.42857143 0.57593462 0.42864967 MAarrowhead1
% End of user PostScript
.56808 .50499 m
.56819 .50503 L
s
% Start of user PostScript
0.57571429 0.5 0.57582595 0.50004697 MAarrowhead1
% End of user PostScript
.56808 .57369 m
.56808 .57369 L
s
% Start of user PostScript
0.57571429 0.57142857 0.57571727 0.57143161 MAarrowhead1
% End of user PostScript
.56808 .6424 m
.56798 .64235 L
s
% Start of user PostScript
0.57571429 0.64285714 0.5756086 0.64280359 MAarrowhead1
% End of user PostScript
.56808 .7111 m
.56787 .71098 L
s
% Start of user PostScript
0.57571429 0.71428571 0.57549992 0.71416291 MAarrowhead1
% End of user PostScript
.56808 .77981 m
.56777 .77961 L
s
% Start of user PostScript
0.57571429 0.78571429 0.57539125 0.78550957 MAarrowhead1
% End of user PostScript
.56808 .84851 m
.56766 .84823 L
s
% Start of user PostScript
0.57571429 0.85714286 0.57528258 0.85684357 MAarrowhead1
% End of user PostScript
.56808 .91722 m
.56756 .91683 L
s
% Start of user PostScript
0.57571429 0.92857143 0.5751739 0.92816491 MAarrowhead1
% End of user PostScript
.56808 .98592 m
.56746 .98542 L
s
% Start of user PostScript
0.57571429 1. 0.57506523 0.99947359 MAarrowhead1
% End of user PostScript
.6361 .02405 m
.63688 .02405 L
s
% Start of user PostScript
0.64642857 0. 0.64724485 0. MAarrowhead1
% End of user PostScript
.6361 .09275 m
.63678 .0928 L
s
% Start of user PostScript
0.64642857 0.071428571 0.64713439 0.071473954 MAarrowhead1
% End of user PostScript
.6361 .16146 m
.63667 .16153 L
s
% Start of user PostScript
0.64642857 0.14285714 0.64702393 0.14293663 MAarrowhead1
% End of user PostScript
.6361 .23016 m
.63656 .23026 L
s
% Start of user PostScript
0.64642857 0.21428571 0.64691346 0.21438804 MAarrowhead1
% End of user PostScript
.6361 .29887 m
.63646 .29898 L
s
% Start of user PostScript
0.64642857 0.28571429 0.646803 0.28582817 MAarrowhead1
% End of user PostScript
.6361 .36757 m
.63635 .36768 L
s
% Start of user PostScript
0.64642857 0.35714286 0.64669254 0.35725702 MAarrowhead1
% End of user PostScript
.6361 .43628 m
.63625 .43638 L
s
% Start of user PostScript
0.64642857 0.42857143 0.64658208 0.4286746 MAarrowhead1
% End of user PostScript
.6361 .50499 m
.63614 .50506 L
s
% Start of user PostScript
0.64642857 0.5 0.64647161 0.5000809 MAarrowhead1
% End of user PostScript
.6361 .57369 m
.63603 .57374 L
s
% Start of user PostScript
0.64642857 0.57142857 0.64636115 0.57147593 MAarrowhead1
% End of user PostScript
.6361 .6424 m
.63593 .6424 L
s
% Start of user PostScript
0.64642857 0.64285714 0.64625069 0.64285968 MAarrowhead1
% End of user PostScript
.6361 .7111 m
.63582 .71105 L
s
% Start of user PostScript
0.64642857 0.71428571 0.64614022 0.71423216 MAarrowhead1
% End of user PostScript
.6361 .77981 m
.63571 .77969 L
s
% Start of user PostScript
0.64642857 0.78571429 0.64602976 0.78559336 MAarrowhead1
% End of user PostScript
.6361 .84851 m
.63561 .84832 L
s
% Start of user PostScript
0.64642857 0.85714286 0.6459193 0.85694329 MAarrowhead1
% End of user PostScript
.6361 .91722 m
.6355 .91694 L
s
% Start of user PostScript
0.64642857 0.92857143 0.64580884 0.92828194 MAarrowhead1
% End of user PostScript
.6361 .98592 m
.6354 .98555 L
s
% Start of user PostScript
0.64642857 1. 0.64569837 0.99960931 MAarrowhead1
% End of user PostScript
.70412 .02405 m
.70481 .02405 L
s
% Start of user PostScript
0.71714286 0. 0.71786732 0. MAarrowhead1
% End of user PostScript
.70412 .09275 m
.70471 .0928 L
s
% Start of user PostScript
0.71714286 0.071428571 0.71775538 0.07147451 MAarrowhead1
% End of user PostScript
.70412 .16146 m
.7046 .16154 L
s
% Start of user PostScript
0.71714286 0.14285714 0.71764343 0.14293886 MAarrowhead1
% End of user PostScript
.70412 .23016 m
.70449 .23027 L
s
% Start of user PostScript
0.71714286 0.21428571 0.71753149 0.21439304 MAarrowhead1
% End of user PostScript
.70412 .29887 m
.70438 .29899 L
s
% Start of user PostScript
0.71714286 0.28571429 0.71741955 0.28583706 MAarrowhead1
% End of user PostScript
.70412 .36757 m
.70428 .3677 L
s
% Start of user PostScript
0.71714286 0.35714286 0.71730761 0.35727092 MAarrowhead1
% End of user PostScript
.70412 .43628 m
.70417 .4364 L
s
% Start of user PostScript
0.71714286 0.42857143 0.71719567 0.42869461 MAarrowhead1
% End of user PostScript
.70412 .50499 m
.70406 .50509 L
s
% Start of user PostScript
0.71714286 0.5 0.71708373 0.50010814 MAarrowhead1
% End of user PostScript
.70412 .57369 m
.70395 .57377 L
s
% Start of user PostScript
0.71714286 0.57142857 0.71697179 0.5715115 MAarrowhead1
% End of user PostScript
.70412 .6424 m
.70384 .64244 L
s
% Start of user PostScript
0.71714286 0.64285714 0.71685984 0.64290471 MAarrowhead1
% End of user PostScript
.70412 .7111 m
.70374 .7111 L
s
% Start of user PostScript
0.71714286 0.71428571 0.7167479 0.71428775 MAarrowhead1
% End of user PostScript
.70412 .77981 m
.70363 .77976 L
s
% Start of user PostScript
0.71714286 0.78571429 0.71663596 0.78566062 MAarrowhead1
% End of user PostScript
.70412 .84851 m
.70352 .8484 L
s
% Start of user PostScript
0.71714286 0.85714286 0.71652402 0.85702334 MAarrowhead1
% End of user PostScript
.70412 .91722 m
.70341 .91703 L
s
% Start of user PostScript
0.71714286 0.92857143 0.71641208 0.92837588 MAarrowhead1
% End of user PostScript
.70412 .98592 m
.70331 .98565 L
s
% Start of user PostScript
0.71714286 1. 0.71630014 0.99971827 MAarrowhead1
% End of user PostScript
.77214 .02405 m
.77271 .02405 L
s
% Start of user PostScript
0.78785714 0. 0.78845406 0. MAarrowhead1
% End of user PostScript
.77214 .09275 m
.7726 .0928 L
s
% Start of user PostScript
0.78785714 0.071428571 0.78834088 0.071474966 MAarrowhead1
% End of user PostScript
.77214 .16146 m
.77249 .16154 L
s
% Start of user PostScript
0.78785714 0.14285714 0.78822769 0.14294068 MAarrowhead1
% End of user PostScript
.77214 .23016 m
.77238 .23027 L
s
% Start of user PostScript
0.78785714 0.21428571 0.78811451 0.21439714 MAarrowhead1
% End of user PostScript
.77214 .29887 m
.77227 .29899 L
s
% Start of user PostScript
0.78785714 0.28571429 0.78800133 0.28584436 MAarrowhead1
% End of user PostScript
.77214 .36757 m
.77216 .36771 L
s
% Start of user PostScript
0.78785714 0.35714286 0.78788814 0.35728232 MAarrowhead1
% End of user PostScript
.77214 .43628 m
.77206 .43641 L
s
% Start of user PostScript
0.78785714 0.42857143 0.78777496 0.42871103 MAarrowhead1
% End of user PostScript
.77214 .50499 m
.77195 .50511 L
s
% Start of user PostScript
0.78785714 0.5 0.78766177 0.50013049 MAarrowhead1
% End of user PostScript
.77214 .57369 m
.77184 .5738 L
s
% Start of user PostScript
0.78785714 0.57142857 0.78754859 0.5715407 MAarrowhead1
% End of user PostScript
.77214 .6424 m
.77173 .64248 L
s
% Start of user PostScript
0.78785714 0.64285714 0.7874354 0.64294165 MAarrowhead1
% End of user PostScript
.77214 .7111 m
.77162 .71115 L
s
% Start of user PostScript
0.78785714 0.71428571 0.78732222 0.71433336 MAarrowhead1
% End of user PostScript
.77214 .77981 m
.77151 .77981 L
s
% Start of user PostScript
0.78785714 0.78571429 0.78720903 0.78571581 MAarrowhead1
% End of user PostScript
.77214 .84851 m
.7714 .84846 L
s
% Start of user PostScript
0.78785714 0.85714286 0.78709585 0.85708902 MAarrowhead1
% End of user PostScript
.77214 .91722 m
.77129 .91711 L
s
% Start of user PostScript
0.78785714 0.92857143 0.78698266 0.92845297 MAarrowhead1
% End of user PostScript
.77214 .98592 m
.77119 .98574 L
s
% Start of user PostScript
0.78785714 1. 0.78686948 0.99980767 MAarrowhead1
% End of user PostScript
.84015 .02405 m
.84057 .02405 L
s
% Start of user PostScript
0.85857143 0. 0.85900509 0. MAarrowhead1
% End of user PostScript
.84015 .09275 m
.84046 .0928 L
s
% Start of user PostScript
0.85857143 0.071428571 0.85889085 0.071475347 MAarrowhead1
% End of user PostScript
.84015 .16146 m
.84035 .16154 L
s
% Start of user PostScript
0.85857143 0.14285714 0.85877661 0.14294221 MAarrowhead1
% End of user PostScript
.84015 .23016 m
.84024 .23027 L
s
% Start of user PostScript
0.85857143 0.21428571 0.85866236 0.21440057 MAarrowhead1
% End of user PostScript
.84015 .29887 m
.84013 .299 L
s
% Start of user PostScript
0.85857143 0.28571429 0.85854812 0.28585045 MAarrowhead1
% End of user PostScript
.84015 .36757 m
.84002 .36772 L
s
% Start of user PostScript
0.85857143 0.35714286 0.85843387 0.35729184 MAarrowhead1
% End of user PostScript
.84015 .43628 m
.83991 .43643 L
s
% Start of user PostScript
0.85857143 0.42857143 0.85831963 0.42872474 MAarrowhead1
% End of user PostScript
.84015 .50499 m
.8398 .50513 L
s
% Start of user PostScript
0.85857143 0.5 0.85820538 0.50014916 MAarrowhead1
% End of user PostScript
.84015 .57369 m
.83969 .57382 L
s
% Start of user PostScript
0.85857143 0.57142857 0.85809114 0.57156508 MAarrowhead1
% End of user PostScript
.84015 .6424 m
.83958 .64251 L
s
% Start of user PostScript
0.85857143 0.64285714 0.85797689 0.64297251 MAarrowhead1
% End of user PostScript
.84015 .7111 m
.83947 .71118 L
s
% Start of user PostScript
0.85857143 0.71428571 0.85786265 0.71437146 MAarrowhead1
% End of user PostScript
.84015 .77981 m
.83936 .77985 L
s
% Start of user PostScript
0.85857143 0.78571429 0.8577484 0.78576191 MAarrowhead1
% End of user PostScript
.84015 .84851 m
.83925 .84851 L
s
% Start of user PostScript
0.85857143 0.85714286 0.85763416 0.85714388 MAarrowhead1
% End of user PostScript
.84015 .91722 m
.83914 .91717 L
s
% Start of user PostScript
0.85857143 0.92857143 0.85751992 0.92851735 MAarrowhead1
% End of user PostScript
.84015 .98592 m
.83903 .98581 L
s
% Start of user PostScript
0.85857143 1. 0.85740567 0.99988234 MAarrowhead1
% End of user PostScript
.90817 .02405 m
.9084 .02405 L
s
% Start of user PostScript
0.92928571 0. 0.92952041 0. MAarrowhead1
% End of user PostScript
.90817 .09275 m
.90829 .0928 L
s
% Start of user PostScript
0.92928571 0.071428571 0.92940525 0.07147567 MAarrowhead1
% End of user PostScript
.90817 .16146 m
.90818 .16154 L
s
% Start of user PostScript
0.92928571 0.14285714 0.92929009 0.1429435 MAarrowhead1
% End of user PostScript
.90817 .23016 m
.90807 .23028 L
s
% Start of user PostScript
0.92928571 0.21428571 0.92917493 0.21440348 MAarrowhead1
% End of user PostScript
.90817 .29887 m
.90795 .29901 L
s
% Start of user PostScript
0.92928571 0.28571429 0.92905977 0.28585562 MAarrowhead1
% End of user PostScript
.90817 .36757 m
.90784 .36773 L
s
% Start of user PostScript
0.92928571 0.35714286 0.92894461 0.35729992 MAarrowhead1
% End of user PostScript
.90817 .43628 m
.90773 .43644 L
s
% Start of user PostScript
0.92928571 0.42857143 0.92882945 0.42873637 MAarrowhead1
% End of user PostScript
.90817 .50499 m
.90762 .50514 L
s
% Start of user PostScript
0.92928571 0.5 0.9287143 0.50016498 MAarrowhead1
% End of user PostScript
.90817 .57369 m
.90751 .57384 L
s
% Start of user PostScript
0.92928571 0.57142857 0.92859914 0.57158575 MAarrowhead1
% End of user PostScript
.90817 .6424 m
.9074 .64253 L
s
% Start of user PostScript
0.92928571 0.64285714 0.92848398 0.64299867 MAarrowhead1
% End of user PostScript
.90817 .7111 m
.90729 .71122 L
s
% Start of user PostScript
0.92928571 0.71428571 0.92836882 0.71440376 MAarrowhead1
% End of user PostScript
.90817 .77981 m
.90718 .77989 L
s
% Start of user PostScript
0.92928571 0.78571429 0.92825366 0.78580099 MAarrowhead1
% End of user PostScript
.90817 .84851 m
.90707 .84856 L
s
% Start of user PostScript
0.92928571 0.85714286 0.9281385 0.85719039 MAarrowhead1
% End of user PostScript
.90817 .91722 m
.90696 .91722 L
s
% Start of user PostScript
0.92928571 0.92857143 0.92802334 0.92857194 MAarrowhead1
% End of user PostScript
.90817 .98592 m
.90685 .98587 L
s
% Start of user PostScript
0.92928571 1. 0.92790818 0.99994565 MAarrowhead1
% End of user PostScript
.97619 .02405 m
.97619 .02405 L
s
% Start of user PostScript
1. 0. MAarrowzero1
% End of user PostScript
.97619 .09275 m
.97608 .0928 L
s
% Start of user PostScript
1. 0.071428571 0.99988404 0.071475947 MAarrowhead1
% End of user PostScript
.97619 .16146 m
.97597 .16154 L
s
% Start of user PostScript
1. 0.14285714 0.99976809 0.14294461 MAarrowhead1
% End of user PostScript
.97619 .23016 m
.97586 .23028 L
s
% Start of user PostScript
1. 0.21428571 0.99965213 0.21440598 MAarrowhead1
% End of user PostScript
.97619 .29887 m
.97574 .29901 L
s
% Start of user PostScript
1. 0.28571429 0.99953618 0.28586006 MAarrowhead1
% End of user PostScript
.97619 .36757 m
.97563 .36773 L
s
% Start of user PostScript
1. 0.35714286 0.99942022 0.35730685 MAarrowhead1
% End of user PostScript
.97619 .43628 m
.97552 .43645 L
s
% Start of user PostScript
1. 0.42857143 0.99930427 0.42874636 MAarrowhead1
% End of user PostScript
.97619 .50499 m
.97541 .50516 L
s
% Start of user PostScript
1. 0.5 0.99918831 0.50017857 MAarrowhead1
% End of user PostScript
.97619 .57369 m
.9753 .57386 L
s
% Start of user PostScript
1. 0.57142857 0.99907236 0.5716035 MAarrowhead1
% End of user PostScript
.97619 .6424 m
.97519 .64255 L
s
% Start of user PostScript
1. 0.64285714 0.9989564 0.64302114 MAarrowhead1
% End of user PostScript
.97619 .7111 m
.97508 .71124 L
s
% Start of user PostScript
1. 0.71428571 0.99884045 0.71443149 MAarrowhead1
% End of user PostScript
.97619 .77981 m
.97496 .77992 L
s
% Start of user PostScript
1. 0.78571429 0.99872449 0.78583455 MAarrowhead1
% End of user PostScript
.97619 .84851 m
.97485 .8486 L
s
% Start of user PostScript
1. 0.85714286 0.99860854 0.85723032 MAarrowhead1
% End of user PostScript
.97619 .91722 m
.97474 .91726 L
s
% Start of user PostScript
1. 0.92857143 0.99849258 0.9286188 MAarrowhead1
% End of user PostScript
.97619 .98592 m
.97463 .98592 L
s
% Start of user PostScript
1. 1. 0.99837663 1. MAarrowhead1
% End of user PostScript
.5 Mabswid
.25478 .26452 m
.26673 .26466 L
.27808 .26502 L
.29175 .26569 L
.30521 .26657 L
.33031 .26866 L
.35906 .27163 L
.42823 .28066 L
.49324 .29138 L
.55787 .30466 L
.61106 .31861 L
.65652 .33441 L
.67621 .34323 L
.694 .35298 L
.70773 .36238 L
.71937 .3726 L
.72479 .37855 L
.72895 .38398 L
.7325 .38953 L
.7352 .39466 L
.73726 .39945 L
.73904 .40471 L
.74038 .41001 L
.74092 .4129 L
.74132 .4156 L
.74179 .42058 L
.74193 .42511 L
.74189 .42761 L
.74178 .43033 L
.74135 .43525 L
.7407 .4399 L
.7399 .44425 L
.73744 .45406 L
.7343 .46347 L
.73022 .4734 L
.71211 .50567 L
.69069 .53338 L
.666 .55786 L
.65368 .56773 L
.64093 .57643 L
.63028 .58252 L
.61964 .58751 L
.60957 .59118 L
.60106 .59342 L
.59666 .59424 L
.59464 .59454 L
.59277 .59477 L
.59174 .59487 L
.59064 .59497 L
.58964 .59504 L
Mistroke
.58875 .59509 L
.58772 .59513 L
.58663 .59516 L
.58565 .59517 L
.58474 .59517 L
.58326 .59513 L
.58169 .59506 L
.58092 .595 L
.58011 .59493 L
.5787 .59478 L
.5761 .59439 L
.5739 .59395 L
.57154 .59333 L
.56922 .59256 L
.56562 .59094 L
.56288 .58924 L
.56089 .58758 L
.55929 .58575 L
.55863 .58474 L
.55816 .58384 L
.55783 .58298 L
.55771 .58258 L
.55761 .58221 L
.55757 .582 L
.55753 .58178 L
.55748 .5814 L
.55746 .58119 L
.55745 .58097 L
.55744 .58078 L
.55744 .58058 L
.55745 .58037 L
.55746 .58018 L
.5575 .57983 L
.55753 .57964 L
.55756 .57946 L
.55766 .57908 L
.55786 .57847 L
.55813 .57787 L
.55841 .57738 L
.55875 .57691 L
.55943 .57617 L
.56024 .57553 L
.56116 .57499 L
.56197 .57465 L
.56241 .57451 L
.56281 .57441 L
.56317 .57433 L
.56336 .5743 L
.56355 .57427 L
.56372 .57425 L
Mistroke
.5639 .57423 L
.56406 .57422 L
.5642 .57422 L
.56439 .57421 L
.56448 .57421 L
.56457 .57421 L
.56474 .57422 L
.5649 .57422 L
.56498 .57423 L
.56507 .57424 L
.56523 .57425 L
.56556 .5743 L
.56582 .57436 L
.56605 .57442 L
.56651 .57459 L
.56684 .57476 L
.56709 .57492 L
.56731 .57512 L
.56739 .57522 L
.56746 .57531 L
.56751 .5754 L
.56755 .57549 L
.56759 .57558 L
.5676 .57562 L
.56761 .57567 L
.56762 .57571 L
.56762 .57576 L
.56762 .5758 L
.56762 .57583 L
.56762 .57586 L
.56762 .57588 L
.56762 .5759 L
.56762 .57592 L
.56761 .57596 L
.5676 .576 L
.56758 .57606 L
.56755 .57612 L
.56752 .57617 L
.56748 .57623 L
.56741 .57631 L
.56733 .57638 L
.56722 .57645 L
.56712 .57649 L
.56704 .57652 L
.56699 .57654 L
.56695 .57654 L
.56693 .57655 L
.5669 .57655 L
.56688 .57655 L
.56687 .57655 L
Mistroke
.56684 .57655 L
.56683 .57655 L
.56682 .57655 L
.5668 .57655 L
.56679 .57655 L
.56678 .57655 L
.56677 .57655 L
.56676 .57655 L
.56675 .57655 L
.56673 .57655 L
.56671 .57654 L
.56668 .57654 L
.56665 .57653 L
.5666 .57651 L
.56658 .5765 L
.56656 .57649 L
.56653 .57647 L
.56651 .57645 L
.5665 .57644 L
.56649 .57643 L
.56649 .57642 L
.56648 .57641 L
.56648 .5764 L
.56648 .5764 L
.56648 .5764 L
.56648 .57639 L
.56648 .57639 L
.56648 .57638 L
.56648 .57638 L
.56648 .57637 L
.56648 .57637 L
.56648 .57637 L
.56648 .57636 L
.56648 .57636 L
.56648 .57635 L
.56649 .57634 L
.56649 .57634 L
.56649 .57633 L
.5665 .57632 L
.56651 .57631 L
.56653 .57631 L
.56654 .5763 L
.56654 .5763 L
.56655 .5763 L
.56655 .5763 L
.56655 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
Mistroke
.56656 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56658 .5763 L
.56658 .5763 L
.56658 .5763 L
.56659 .5763 L
.56659 .5763 L
.56659 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
Mistroke
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.25478 .50499 m
.25612 .49359 L
.25781 .48404 L
.2603 .47391 L
.26316 .46517 L
.26945 .45147 L
.27365 .4447 L
.27793 .43903 L
.28813 .42875 L
.29464 .42382 L
.30118 .41976 L
.3156 .41304 L
.32439 .41005 L
.33285 .40778 L
.34143 .40596 L
.35093 .40441 L
.36022 .4033 L
.36887 .40258 L
.37934 .40204 L
.38535 .40188 L
.39094 .40183 L
.40137 .40193 L
.41254 .40232 L
.42236 .40288 L
.43296 .40369 L
.45215 .40566 L
.47481 .40879 L
.49504 .41229 L
.53742 .42196 L
.57169 .43268 L
.60254 .44583 L
.61528 .45286 L
.62716 .46081 L
.64217 .47434 L
.64818 .48199 L
.65233 .48897 L
.65499 .49506 L
.65612 .49847 L
.65694 .50162 L
.65758 .50492 L
.65797 .5079 L
.65811 .50953 L
.65821 .51128 L
.65824 .51444 L
.65809 .51745 L
.65783 .52015 L
.65736 .52322 L
.65678 .52609 L
.65544 .53105 L
.65358 .53626 L
Mistroke
.6481 .54722 L
.64187 .55628 L
.62734 .57123 L
.61885 .57753 L
.61126 .58203 L
.60433 .5853 L
.5974 .58778 L
.59189 .58921 L
.58895 .58975 L
.58633 .59011 L
.58493 .59025 L
.5842 .59031 L
.58345 .59036 L
.5828 .59039 L
.5821 .59042 L
.58088 .59044 L
.57974 .59043 L
.57856 .59039 L
.57747 .59032 L
.57651 .59024 L
.57542 .59011 L
.57444 .58997 L
.57236 .58959 L
.57051 .58912 L
.56872 .58854 L
.56587 .58729 L
.56379 .58601 L
.56207 .58454 L
.5614 .58379 L
.56082 .58299 L
.56042 .5823 L
.56014 .58168 L
.56001 .58134 L
.55991 .58097 L
.55983 .58065 L
.55978 .58036 L
.55975 .5801 L
.55973 .57985 L
.55973 .57959 L
.55974 .57932 L
.55977 .57905 L
.55978 .57892 L
.55981 .57878 L
.55992 .57832 L
.55999 .57808 L
.56008 .57787 L
.56029 .57742 L
.56078 .5767 L
.56131 .57616 L
.56192 .57569 L
Mistroke
.56259 .57531 L
.56323 .57506 L
.56358 .57495 L
.5639 .57487 L
.56407 .57484 L
.56426 .57481 L
.56443 .57479 L
.56458 .57477 L
.56472 .57476 L
.56486 .57475 L
.565 .57475 L
.56508 .57475 L
.56515 .57475 L
.56528 .57476 L
.56539 .57477 L
.56552 .57478 L
.56563 .57479 L
.56583 .57482 L
.56601 .57486 L
.5662 .57491 L
.56636 .57496 L
.56665 .57509 L
.5669 .57524 L
.56709 .57539 L
.56717 .57548 L
.56723 .57556 L
.56727 .57563 L
.56731 .5757 L
.56732 .57573 L
.56733 .57577 L
.56734 .5758 L
.56735 .57584 L
.56735 .57587 L
.56736 .57589 L
.56736 .57592 L
.56736 .57595 L
.56736 .57598 L
.56735 .57601 L
.56735 .57603 L
.56735 .57605 L
.56734 .57608 L
.56733 .57611 L
.56731 .57616 L
.56729 .57621 L
.56725 .57625 L
.56719 .57633 L
.56712 .57638 L
.56705 .57642 L
.56698 .57645 L
.56695 .57647 L
Mistroke
.56691 .57648 L
.56688 .57648 L
.56685 .57649 L
.56684 .57649 L
.56682 .57649 L
.56681 .57649 L
.5668 .57649 L
.56679 .57649 L
.56677 .5765 L
.56676 .5765 L
.56675 .5765 L
.56673 .57649 L
.56673 .57649 L
.56672 .57649 L
.56671 .57649 L
.56669 .57649 L
.56668 .57649 L
.56666 .57648 L
.56663 .57648 L
.5666 .57647 L
.56657 .57645 L
.56655 .57644 L
.56653 .57642 L
.56652 .57641 L
.56652 .5764 L
.56652 .5764 L
.56651 .57639 L
.56651 .57639 L
.56651 .57638 L
.56651 .57638 L
.56651 .57638 L
.56651 .57637 L
.56651 .57637 L
.56651 .57637 L
.56651 .57637 L
.56651 .57636 L
.56651 .57636 L
.56651 .57636 L
.56651 .57636 L
.56651 .57635 L
.56651 .57635 L
.56651 .57635 L
.56651 .57634 L
.56652 .57633 L
.56652 .57633 L
.56652 .57633 L
.56653 .57632 L
.56654 .57631 L
.56654 .57631 L
.56655 .57631 L
Mistroke
.56655 .57631 L
.56656 .57631 L
.56656 .57631 L
.56656 .57631 L
.56656 .57631 L
.56657 .57631 L
.56657 .57631 L
.56657 .57631 L
.56657 .57631 L
.56657 .57631 L
.56657 .57631 L
.56657 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56659 .57631 L
.56659 .57631 L
.56659 .57631 L
.56659 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57633 L
.5666 .57633 L
.56659 .57633 L
.56659 .57633 L
Mistroke
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.25478 .74545 m
.23889 .68157 L
.22653 .62222 L
.21866 .57422 L
.21622 .55533 L
.21427 .53674 L
.21275 .51649 L
.21207 .49943 L
.21207 .48272 L
.2124 .47392 L
.21291 .46612 L
.21431 .45309 L
.21613 .44225 L
.21883 .43091 L
.22198 .42123 L
.22583 .41224 L
.22982 .40492 L
.23464 .39785 L
.24045 .39109 L
.2464 .38556 L
.25232 .38107 L
.26524 .37374 L
.27318 .37043 L
.28105 .3678 L
.29017 .3654 L
.30049 .36334 L
.30587 .3625 L
.31188 .36172 L
.31731 .36114 L
.3232 .36065 L
.33466 .36 L
.34564 .35974 L
.35737 .35978 L
.36338 .35991 L
.37004 .36014 L
.38205 .36075 L
.39341 .36154 L
.41959 .36405 L
.44792 .36772 L
.4991 .37671 L
.5424 .38691 L
.58699 .40085 L
.60696 .40881 L
.62531 .4176 L
.63897 .42553 L
.65153 .43443 L
.66086 .44267 L
.6678 .45037 L
.67327 .45813 L
.67576 .46256 L
Mistroke
.67764 .46657 L
.67904 .47013 L
.68027 .47395 L
.68127 .47797 L
.68194 .48172 L
.68234 .48511 L
.68256 .48878 L
.68256 .49258 L
.68237 .49609 L
.68203 .49934 L
.68159 .50227 L
.68094 .50561 L
.6802 .50872 L
.6781 .51561 L
.6753 .52264 L
.66911 .53452 L
.66122 .54611 L
.65158 .55736 L
.64283 .56575 L
.63352 .5732 L
.61729 .58317 L
.60878 .58699 L
.60137 .58953 L
.59735 .5906 L
.59387 .59134 L
.59201 .59166 L
.59005 .59193 L
.58827 .59214 L
.58667 .59227 L
.58518 .59236 L
.5838 .59241 L
.58261 .59242 L
.58134 .5924 L
.58 .59235 L
.57935 .59231 L
.57864 .59225 L
.57742 .59214 L
.57631 .592 L
.57427 .59167 L
.57252 .5913 L
.56903 .59026 L
.56742 .58962 L
.56607 .58898 L
.5635 .58742 L
.5616 .58583 L
.56083 .585 L
.56016 .58413 L
.55969 .58336 L
.55929 .58254 L
.55915 .58219 L
Mistroke
.55903 .58181 L
.55894 .58147 L
.55888 .58116 L
.55884 .58096 L
.55882 .58078 L
.5588 .58059 L
.55878 .58038 L
.55877 .58021 L
.55877 .58002 L
.55878 .57984 L
.55879 .57968 L
.55882 .5794 L
.55884 .57923 L
.55887 .57909 L
.55893 .5788 L
.55901 .5785 L
.55921 .57798 L
.55947 .57746 L
.55974 .57704 L
.56006 .57663 L
.56074 .57598 L
.56141 .5755 L
.56215 .57511 L
.56282 .57485 L
.56317 .57475 L
.56354 .57466 L
.56372 .57462 L
.56391 .57459 L
.56408 .57457 L
.56424 .57455 L
.56439 .57454 L
.56455 .57453 L
.5647 .57453 L
.56478 .57453 L
.56486 .57453 L
.56499 .57453 L
.56512 .57454 L
.56525 .57455 L
.56538 .57456 L
.5656 .57459 L
.56579 .57462 L
.56619 .57472 L
.56639 .57479 L
.56656 .57486 L
.56688 .57504 L
.5671 .5752 L
.56719 .57529 L
.56727 .57538 L
.56733 .57546 L
.56737 .57553 L
Mistroke
.56741 .5756 L
.56743 .57567 L
.56744 .57571 L
.56745 .57574 L
.56746 .57578 L
.56746 .5758 L
.56747 .57582 L
.56747 .57586 L
.56747 .57589 L
.56747 .57592 L
.56747 .57595 L
.56746 .57598 L
.56746 .576 L
.56745 .57602 L
.56744 .57608 L
.56742 .57612 L
.56739 .57617 L
.56733 .57626 L
.56729 .57631 L
.56725 .57634 L
.56718 .5764 L
.56711 .57644 L
.56703 .57648 L
.56695 .5765 L
.56691 .57651 L
.56688 .57651 L
.56686 .57652 L
.56685 .57652 L
.56683 .57652 L
.56682 .57652 L
.56681 .57652 L
.5668 .57652 L
.56679 .57652 L
.56678 .57652 L
.56676 .57652 L
.56675 .57652 L
.56674 .57652 L
.56673 .57652 L
.56671 .57652 L
.56669 .57651 L
.56666 .57651 L
.56664 .5765 L
.5666 .57649 L
.56657 .57647 L
.56655 .57645 L
.56652 .57644 L
.56651 .57642 L
.5665 .57641 L
.5665 .5764 L
.5665 .5764 L
Mistroke
.5665 .57639 L
.5665 .57639 L
.5665 .57638 L
.56649 .57638 L
.56649 .57638 L
.56649 .57637 L
.56649 .57637 L
.56649 .57637 L
.56649 .57636 L
.5665 .57636 L
.5665 .57636 L
.5665 .57635 L
.5665 .57635 L
.5665 .57635 L
.56651 .57634 L
.56651 .57633 L
.56651 .57633 L
.56652 .57632 L
.56653 .57631 L
.56654 .57631 L
.56654 .57631 L
.56655 .57631 L
.56655 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56658 .5763 L
.56658 .5763 L
.56658 .5763 L
.56658 .5763 L
.56658 .5763 L
.56659 .57631 L
.56659 .57631 L
.56659 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57632 L
.5666 .57632 L
Mistroke
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.25478 .98592 m
.19506 .74083 L
.17783 .64992 L
.16652 .57859 L
.16189 .54384 L
.15811 .51031 L
.15568 .48327 L
.15421 .46094 L
.15337 .43936 L
.15328 .41835 L
.15354 .40877 L
.15404 .39915 L
.1555 .38341 L
.15774 .36905 L
.16045 .35737 L
.1641 .34616 L
.16875 .33585 L
.17391 .3274 L
.1794 .32055 L
.18487 .31521 L
.19135 .31021 L
.19781 .30627 L
.20549 .3026 L
.21415 .29942 L
.22284 .297 L
.23151 .29518 L
.23987 .29386 L
.25004 .29272 L
.26019 .29198 L
.27184 .29153 L
.28329 .29143 L
.29642 .29163 L
.30406 .29189 L
.31121 .29221 L
.32518 .29304 L
.34099 .29423 L
.37429 .29752 L
.43784 .30602 L
.49724 .31634 L
.56298 .33103 L
.61411 .34615 L
.63804 .3551 L
.66027 .36518 L
.67658 .37427 L
.69098 .38426 L
.70133 .39337 L
.70885 .40178 L
.71472 .4103 L
.71887 .41841 L
.72065 .42298 L
Mistroke
.72214 .42784 L
.72318 .43241 L
.72385 .43655 L
.72414 .43909 L
.72432 .44142 L
.72443 .44397 L
.72446 .44665 L
.7243 .45115 L
.7241 .45369 L
.72385 .45605 L
.72317 .46068 L
.72218 .46567 L
.71977 .47461 L
.71677 .48312 L
.71351 .49079 L
.7048 .50732 L
.69388 .52376 L
.67317 .54809 L
.65308 .56608 L
.64168 .57433 L
.63013 .5813 L
.61989 .58635 L
.61117 .58977 L
.607 .59111 L
.60267 .59229 L
.5991 .5931 L
.59534 .59377 L
.59349 .59403 L
.59155 .59426 L
.59051 .59436 L
.58958 .59443 L
.58779 .59454 L
.58621 .5946 L
.58454 .59461 L
.58301 .59458 L
.58165 .59452 L
.58043 .59444 L
.57917 .59432 L
.57697 .59404 L
.57454 .59361 L
.57248 .59312 L
.56872 .59191 L
.56707 .59121 L
.56545 .5904 L
.56264 .5886 L
.56065 .58683 L
.55934 .58525 L
.5588 .58438 L
.5584 .58359 L
.55808 .58277 L
Mistroke
.55797 .58239 L
.55788 .58203 L
.55784 .58183 L
.5578 .58162 L
.55775 .58125 L
.55773 .58104 L
.55772 .58083 L
.55772 .58063 L
.55772 .58045 L
.55772 .58027 L
.55774 .58007 L
.55777 .57973 L
.5578 .57955 L
.55783 .57938 L
.55792 .579 L
.55812 .57841 L
.55838 .57782 L
.55868 .57731 L
.55904 .57682 L
.55978 .57606 L
.56064 .57542 L
.56116 .57512 L
.56164 .57489 L
.56249 .57458 L
.56292 .57447 L
.56336 .57438 L
.56354 .57435 L
.56374 .57432 L
.5639 .57431 L
.56407 .57429 L
.56417 .57429 L
.56427 .57428 L
.56445 .57428 L
.56461 .57428 L
.56478 .57428 L
.56493 .57429 L
.5651 .5743 L
.56525 .57432 L
.56539 .57433 L
.56563 .57437 L
.56587 .57443 L
.56614 .5745 L
.56636 .57458 L
.56673 .57474 L
.567 .57491 L
.56721 .57508 L
.56737 .57526 L
.56744 .57535 L
.56749 .57544 L
.56754 .57554 L
Mistroke
.56755 .57558 L
.56757 .57563 L
.56758 .57568 L
.56758 .5757 L
.56758 .57572 L
.56759 .57576 L
.56759 .5758 L
.56759 .57584 L
.56759 .57588 L
.56759 .57591 L
.56758 .57595 L
.56757 .57598 L
.56757 .57601 L
.56755 .57607 L
.56752 .57613 L
.56748 .57619 L
.5674 .5763 L
.56731 .57638 L
.56721 .57644 L
.56712 .57649 L
.56703 .57652 L
.56699 .57653 L
.56694 .57654 L
.56692 .57654 L
.5669 .57654 L
.56688 .57654 L
.56686 .57655 L
.56684 .57655 L
.56682 .57655 L
.56681 .57655 L
.56679 .57655 L
.56677 .57655 L
.56675 .57654 L
.56674 .57654 L
.56672 .57654 L
.5667 .57654 L
.56667 .57653 L
.56662 .57652 L
.5666 .57651 L
.56658 .5765 L
.56655 .57648 L
.56652 .57646 L
.5665 .57644 L
.5665 .57643 L
.56649 .57642 L
.56649 .57641 L
.56648 .5764 L
.56648 .57639 L
.56648 .57639 L
.56648 .57639 L
Mistroke
.56648 .57638 L
.56648 .57638 L
.56648 .57638 L
.56648 .57638 L
.56648 .57637 L
.56648 .57637 L
.56648 .57636 L
.56648 .57636 L
.56649 .57635 L
.56649 .57635 L
.56649 .57634 L
.5665 .57633 L
.5665 .57632 L
.56651 .57632 L
.56652 .57631 L
.56653 .57631 L
.56654 .5763 L
.56654 .5763 L
.56655 .5763 L
.56655 .5763 L
.56655 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56658 .5763 L
.56658 .5763 L
.56658 .5763 L
.56658 .5763 L
.56659 .5763 L
.56659 .57631 L
.56659 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
Mistroke
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.49525 .26452 m
.56115 .27704 L
.61569 .28998 L
.6653 .30536 L
.70555 .32296 L
.721 .33219 L
.73445 .34244 L
.74427 .35231 L
.75113 .36156 L
.7557 .36998 L
.75768 .37479 L
.75916 .37932 L
.76036 .3841 L
.76115 .38848 L
.76172 .39354 L
.76196 .39836 L
.76197 .40094 L
.76189 .40372 L
.76153 .40877 L
.76092 .41367 L
.76016 .41817 L
.75778 .42837 L
.7544 .43903 L
.74716 .4565 L
.73748 .47501 L
.71171 .51291 L
.68541 .54244 L
.65959 .565 L
.63657 .5802 L
.61788 .58903 L
.60835 .59223 L
.60403 .59336 L
.60025 .59418 L
.59658 .59481 L
.5929 .59527 L
.59107 .59543 L
.58941 .59554 L
.58764 .59561 L
.58668 .59563 L
.58582 .59563 L
.58429 .59561 L
.58293 .59556 L
.58148 .59547 L
.58 .59534 L
.57876 .5952 L
.57764 .59505 L
.5752 .59462 L
.57261 .59401 L
.57037 .59333 L
.56671 .59186 L
Mistroke
.56354 .59008 L
.56217 .58909 L
.56091 .58801 L
.5599 .58696 L
.55913 .58601 L
.55854 .58513 L
.55803 .58418 L
.55769 .58336 L
.55746 .58261 L
.55737 .58221 L
.5573 .58186 L
.55725 .58145 L
.55723 .58108 L
.55722 .58072 L
.55723 .58052 L
.55724 .58033 L
.55728 .57996 L
.5573 .57976 L
.55734 .57958 L
.55749 .57897 L
.55758 .57867 L
.5577 .57837 L
.558 .57775 L
.55838 .57716 L
.55918 .57624 L
.55962 .57586 L
.56009 .5755 L
.56098 .57498 L
.56194 .57458 L
.56247 .57442 L
.56295 .57431 L
.56316 .57427 L
.56339 .57423 L
.56358 .57421 L
.56378 .57419 L
.56396 .57417 L
.56415 .57416 L
.56433 .57416 L
.56448 .57416 L
.56466 .57416 L
.56475 .57417 L
.56485 .57417 L
.56501 .57418 L
.56516 .5742 L
.56548 .57424 L
.56565 .57428 L
.56579 .57431 L
.56627 .57445 L
.56649 .57453 L
.56669 .57463 L
Mistroke
.56701 .57482 L
.56724 .575 L
.56735 .57511 L
.56743 .57521 L
.5675 .57531 L
.56755 .57541 L
.5676 .57551 L
.56761 .57556 L
.56763 .5756 L
.56763 .57563 L
.56764 .57566 L
.56764 .57568 L
.56765 .57571 L
.56765 .57575 L
.56765 .57578 L
.56765 .5758 L
.56765 .57584 L
.56765 .57586 L
.56764 .57588 L
.56764 .57592 L
.56763 .57596 L
.56761 .57603 L
.56759 .57607 L
.56758 .57611 L
.56751 .57622 L
.56747 .57627 L
.56742 .57632 L
.56733 .57639 L
.56724 .57645 L
.56714 .5765 L
.56706 .57653 L
.56701 .57654 L
.56696 .57655 L
.56694 .57655 L
.56692 .57655 L
.56689 .57656 L
.56687 .57656 L
.56686 .57656 L
.56684 .57656 L
.56682 .57656 L
.5668 .57656 L
.56678 .57656 L
.56676 .57656 L
.56675 .57656 L
.56673 .57655 L
.5667 .57655 L
.56667 .57654 L
.56664 .57653 L
.56661 .57652 L
.56657 .5765 L
Mistroke
.56654 .57648 L
.56652 .57647 L
.56651 .57646 L
.56649 .57644 L
.56649 .57642 L
.56648 .57641 L
.56648 .57641 L
.56648 .5764 L
.56648 .5764 L
.56648 .5764 L
.56648 .57639 L
.56648 .57639 L
.56648 .57639 L
.56647 .57638 L
.56647 .57638 L
.56648 .57638 L
.56648 .57637 L
.56648 .57637 L
.56648 .57637 L
.56648 .57636 L
.56648 .57636 L
.56648 .57635 L
.56648 .57635 L
.56649 .57634 L
.56649 .57633 L
.5665 .57632 L
.56651 .57631 L
.56652 .57631 L
.56653 .57631 L
.56654 .5763 L
.56654 .5763 L
.56655 .5763 L
.56655 .5763 L
.56655 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56658 .5763 L
.56658 .5763 L
.56658 .5763 L
.56659 .5763 L
.56659 .5763 L
Mistroke
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
Mistroke
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.49525 .50499 m
.50018 .50505 L
.50461 .5052 L
.50966 .50549 L
.51436 .50587 L
.52252 .50679 L
.53102 .50809 L
.53991 .50985 L
.54872 .51204 L
.56283 .51665 L
.57497 .52208 L
.58411 .52757 L
.59176 .53381 L
.59504 .53734 L
.59745 .54054 L
.59935 .54373 L
.60018 .54546 L
.60083 .54706 L
.60134 .54854 L
.60177 .55012 L
.60207 .55153 L
.60226 .5528 L
.60234 .55353 L
.60241 .5543 L
.60246 .55567 L
.60245 .55649 L
.60241 .55726 L
.60236 .55794 L
.60229 .55867 L
.60219 .55937 L
.60206 .56013 L
.60173 .56164 L
.60135 .563 L
.60093 .56423 L
.6 .56641 L
.59884 .56856 L
.5964 .572 L
.59341 .57514 L
.5899 .57792 L
.58649 .57995 L
.58331 .58137 L
.58057 .58228 L
.57909 .58265 L
.57777 .58291 L
.5771 .58302 L
.5764 .58311 L
.57581 .58317 L
.57519 .58323 L
.57481 .58325 L
.57447 .58326 L
Mistroke
.57415 .58328 L
.57381 .58328 L
.57349 .58328 L
.57319 .58328 L
.57264 .58326 L
.57206 .58323 L
.57177 .58321 L
.57147 .58318 L
.57047 .58306 L
.56993 .58296 L
.56939 .58285 L
.56847 .58262 L
.56768 .58236 L
.56692 .58206 L
.56575 .58147 L
.56478 .58078 L
.56434 .58038 L
.56401 .58 L
.56377 .57968 L
.56356 .57934 L
.56343 .57906 L
.56332 .57876 L
.56327 .5786 L
.56324 .57845 L
.56323 .57837 L
.56322 .57829 L
.56321 .57821 L
.5632 .57814 L
.5632 .57801 L
.5632 .57787 L
.5632 .57781 L
.56321 .57774 L
.56323 .57761 L
.56325 .57749 L
.56328 .57737 L
.56336 .57713 L
.56346 .57692 L
.56357 .57674 L
.56385 .57639 L
.56402 .57622 L
.5642 .57609 L
.5645 .5759 L
.56483 .57575 L
.56499 .57569 L
.56517 .57564 L
.56533 .5756 L
.5654 .57559 L
.56547 .57558 L
.56554 .57557 L
.5656 .57557 L
Mistroke
.56566 .57556 L
.56574 .57556 L
.5658 .57556 L
.56584 .57556 L
.56587 .57556 L
.56593 .57556 L
.56599 .57556 L
.56605 .57557 L
.56611 .57557 L
.56621 .57559 L
.5663 .57561 L
.56638 .57563 L
.56653 .57568 L
.56661 .57572 L
.56668 .57575 L
.56678 .57582 L
.56683 .57586 L
.56687 .57591 L
.5669 .57594 L
.56692 .57598 L
.56694 .57602 L
.56695 .57605 L
.56696 .57607 L
.56696 .57609 L
.56696 .5761 L
.56696 .57611 L
.56696 .57612 L
.56696 .57613 L
.56697 .57613 L
.56696 .57615 L
.56696 .57616 L
.56696 .57617 L
.56696 .57617 L
.56696 .57618 L
.56696 .5762 L
.56696 .57621 L
.56695 .57623 L
.56694 .57625 L
.56693 .57627 L
.5669 .57631 L
.56686 .57634 L
.56682 .57637 L
.56679 .57639 L
.56676 .5764 L
.56674 .5764 L
.56672 .5764 L
.56671 .5764 L
.56671 .57641 L
.5667 .57641 L
.56669 .57641 L
Mistroke
.56668 .57641 L
.56668 .57641 L
.56668 .57641 L
.56667 .57641 L
.56667 .57641 L
.56666 .57641 L
.56666 .57641 L
.56665 .57641 L
.56665 .57641 L
.56664 .57641 L
.56663 .5764 L
.56662 .5764 L
.56661 .5764 L
.56659 .57639 L
.56659 .57639 L
.56658 .57639 L
.56657 .57638 L
.56656 .57637 L
.56656 .57637 L
.56655 .57636 L
.56655 .57636 L
.56655 .57636 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57633 L
.56655 .57633 L
.56655 .57633 L
.56656 .57633 L
.56656 .57632 L
.56656 .57632 L
.56657 .57632 L
.56657 .57632 L
.56657 .57632 L
.56657 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
Mistroke
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
Mistroke
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
Mfstroke
.49525 .74545 m
.47003 .71075 L
.45324 .6801 L
.44632 .66388 L
.44131 .64938 L
.43914 .64173 L
.43725 .63373 L
.43594 .6268 L
.43504 .62056 L
.43446 .61467 L
.43414 .60859 L
.4341 .60525 L
.43416 .60216 L
.4345 .59656 L
.43517 .59097 L
.43607 .58606 L
.43734 .58095 L
.43902 .57583 L
.4428 .56744 L
.44718 .56048 L
.45169 .55496 L
.45712 .54973 L
.46376 .54474 L
.4704 .54084 L
.47806 .53735 L
.48656 .53444 L
.4909 .53328 L
.49565 .53223 L
.49984 .53149 L
.50428 .53086 L
.50825 .53044 L
.51049 .53026 L
.51259 .53012 L
.51623 .52997 L
.51826 .52992 L
.52011 .52991 L
.52346 .52995 L
.52697 .53008 L
.53023 .53028 L
.53312 .53052 L
.53646 .53088 L
.53997 .53135 L
.54607 .53241 L
.55204 .53375 L
.55787 .53541 L
.56701 .53885 L
.57439 .54268 L
.5797 .54639 L
.58209 .54847 L
.58427 .55075 L
Mistroke
.58596 .55292 L
.58719 .55485 L
.58816 .55678 L
.58884 .55854 L
.58912 .5595 L
.58933 .56036 L
.5895 .56129 L
.58962 .56225 L
.58968 .56301 L
.58969 .56381 L
.58967 .56454 L
.58962 .5652 L
.58953 .56596 L
.5894 .56676 L
.58923 .5675 L
.58905 .56816 L
.58854 .56959 L
.58798 .57083 L
.58642 .57333 L
.5848 .57521 L
.58294 .57686 L
.58079 .57832 L
.57877 .57937 L
.57661 .58019 L
.57545 .58051 L
.57443 .58074 L
.57357 .58088 L
.5731 .58094 L
.57267 .58098 L
.57222 .58101 L
.57183 .58103 L
.57161 .58104 L
.57138 .58104 L
.57098 .58104 L
.57064 .58103 L
.57028 .581 L
.56991 .58097 L
.56958 .58094 L
.56901 .58085 L
.56844 .58074 L
.56786 .58059 L
.56729 .5804 L
.5663 .57997 L
.56559 .57952 L
.56508 .57909 L
.5647 .57864 L
.56454 .57839 L
.56444 .57816 L
.56437 .57797 L
.56434 .57787 L
Mistroke
.56432 .57777 L
.5643 .57767 L
.56429 .57758 L
.56429 .57753 L
.56429 .57748 L
.56429 .57739 L
.5643 .5773 L
.56431 .57722 L
.56432 .57715 L
.56434 .57707 L
.56439 .57692 L
.56444 .57678 L
.56458 .57656 L
.56475 .57636 L
.56495 .57618 L
.56515 .57605 L
.56526 .576 L
.56538 .57594 L
.56548 .57591 L
.56559 .57587 L
.56568 .57585 L
.56578 .57583 L
.56583 .57582 L
.56588 .57582 L
.56592 .57581 L
.56597 .57581 L
.56601 .57581 L
.56605 .57581 L
.56608 .57581 L
.56612 .57581 L
.56615 .57581 L
.56619 .57581 L
.56623 .57581 L
.56626 .57582 L
.56633 .57583 L
.56639 .57584 L
.56645 .57586 L
.56651 .57588 L
.56661 .57591 L
.56668 .57596 L
.56674 .57601 L
.56677 .57603 L
.56679 .57606 L
.56681 .57609 L
.56682 .57611 L
.56683 .57613 L
.56684 .57615 L
.56684 .57616 L
.56684 .57617 L
.56684 .57618 L
Mistroke
.56684 .57619 L
.56684 .5762 L
.56684 .57621 L
.56684 .57621 L
.56684 .57622 L
.56684 .57623 L
.56684 .57624 L
.56684 .57625 L
.56683 .57626 L
.56682 .57628 L
.56682 .57629 L
.5668 .57632 L
.56678 .57633 L
.56677 .57634 L
.56675 .57635 L
.56672 .57636 L
.5667 .57637 L
.56669 .57638 L
.56668 .57638 L
.56667 .57638 L
.56667 .57638 L
.56666 .57638 L
.56666 .57638 L
.56666 .57638 L
.56665 .57638 L
.56665 .57638 L
.56665 .57638 L
.56664 .57638 L
.56664 .57638 L
.56664 .57638 L
.56663 .57638 L
.56663 .57638 L
.56662 .57638 L
.56662 .57638 L
.56661 .57638 L
.5666 .57637 L
.5666 .57637 L
.56659 .57637 L
.56658 .57636 L
.56657 .57636 L
.56657 .57635 L
.56657 .57635 L
.56656 .57635 L
.56656 .57635 L
.56656 .57634 L
.56656 .57634 L
.56656 .57634 L
.56656 .57634 L
.56656 .57634 L
.56656 .57634 L
Mistroke
.56656 .57634 L
.56656 .57634 L
.56656 .57634 L
.56656 .57634 L
.56656 .57634 L
.56656 .57634 L
.56656 .57633 L
.56656 .57633 L
.56656 .57633 L
.56656 .57633 L
.56656 .57633 L
.56657 .57633 L
.56657 .57633 L
.56657 .57632 L
.56657 .57632 L
.56657 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.49525 .98592 m
.42821 .89191 L
.38304 .80815 L
.34893 .7255 L
.33586 .68482 L
.32707 .65084 L
.32089 .61891 L
.31879 .60358 L
.31802 .59623 L
.31739 .58842 L
.31682 .57602 L
.31677 .56941 L
.31687 .56358 L
.31751 .55286 L
.31861 .54337 L
.3201 .53492 L
.32214 .52655 L
.32448 .51921 L
.32693 .51301 L
.33022 .50623 L
.33425 .49952 L
.3427 .48888 L
.34776 .48398 L
.3536 .47927 L
.36513 .47207 L
.37275 .46844 L
.38034 .46549 L
.39539 .46117 L
.40344 .45951 L
.41222 .45813 L
.41986 .45723 L
.42426 .45684 L
.42843 .45654 L
.43299 .45629 L
.43782 .45611 L
.44197 .45602 L
.44651 .45599 L
.45143 .45603 L
.45669 .45616 L
.46166 .45636 L
.46616 .4566 L
.47424 .45718 L
.48273 .45798 L
.49768 .45987 L
.51323 .46247 L
.5295 .46592 L
.55588 .47338 L
.57682 .48147 L
.59466 .49074 L
.60237 .49584 L
Mistroke
.60931 .50136 L
.61483 .50671 L
.6189 .51155 L
.6222 .51644 L
.62454 .52089 L
.62625 .52518 L
.6269 .52731 L
.62747 .52962 L
.62789 .53192 L
.62806 .53319 L
.62818 .53434 L
.62831 .53654 L
.62832 .5386 L
.62823 .54048 L
.62804 .54245 L
.62781 .5441 L
.62748 .54589 L
.62648 .54974 L
.62526 .55319 L
.62197 .55983 L
.61752 .56622 L
.61224 .57191 L
.60703 .57628 L
.60213 .57959 L
.59755 .58208 L
.59243 .58425 L
.58802 .58564 L
.58581 .58617 L
.58381 .58655 L
.58172 .58685 L
.58058 .58696 L
.57958 .58704 L
.57856 .58708 L
.57765 .5871 L
.57718 .5871 L
.57667 .5871 L
.57615 .58708 L
.57567 .58706 L
.57482 .58701 L
.57406 .58694 L
.57325 .58684 L
.57244 .58673 L
.57116 .58649 L
.56989 .58618 L
.56786 .58552 L
.56586 .58461 L
.5644 .58369 L
.56321 .58269 L
.5627 .58214 L
.56231 .58163 L
Mistroke
.56179 .58075 L
.5616 .5803 L
.56146 .57983 L
.56141 .57958 L
.56137 .57935 L
.56136 .57922 L
.56135 .57911 L
.56134 .57898 L
.56134 .57885 L
.56135 .57875 L
.56135 .57864 L
.56137 .57844 L
.5614 .57824 L
.56142 .57813 L
.56144 .57803 L
.56155 .57768 L
.56167 .57738 L
.56185 .57706 L
.56203 .57678 L
.56242 .57633 L
.5629 .57593 L
.56343 .57561 L
.56368 .5755 L
.56393 .57539 L
.56415 .57532 L
.56439 .57526 L
.5646 .57521 L
.56478 .57518 L
.56489 .57516 L
.565 .57515 L
.56511 .57514 L
.56522 .57513 L
.56531 .57513 L
.56541 .57513 L
.5655 .57513 L
.56558 .57513 L
.56568 .57514 L
.56577 .57515 L
.56586 .57516 L
.56595 .57517 L
.56612 .5752 L
.56625 .57524 L
.5665 .57532 L
.56669 .57541 L
.56687 .57553 L
.56699 .57564 L
.56709 .57576 L
.56712 .57582 L
.56713 .57585 L
.56715 .57588 L
Mistroke
.56715 .5759 L
.56716 .57593 L
.56717 .57596 L
.56717 .57597 L
.56717 .57598 L
.56717 .57601 L
.56717 .57603 L
.56717 .57605 L
.56717 .57608 L
.56717 .5761 L
.56717 .57611 L
.56716 .57615 L
.56714 .57619 L
.56713 .57622 L
.56708 .57628 L
.56706 .57631 L
.56703 .57634 L
.56698 .57638 L
.56692 .57641 L
.56689 .57642 L
.56686 .57643 L
.56684 .57644 L
.56681 .57644 L
.56679 .57645 L
.56678 .57645 L
.56677 .57645 L
.56675 .57645 L
.56674 .57645 L
.56674 .57645 L
.56673 .57645 L
.56672 .57645 L
.56672 .57645 L
.56671 .57645 L
.5667 .57645 L
.56669 .57645 L
.56668 .57645 L
.56667 .57645 L
.56666 .57645 L
.56664 .57645 L
.56662 .57644 L
.56661 .57644 L
.56659 .57643 L
.56657 .57642 L
.56655 .57641 L
.56655 .5764 L
.56654 .57639 L
.56653 .57638 L
.56653 .57638 L
.56653 .57637 L
.56653 .57637 L
Mistroke
.56653 .57637 L
.56653 .57636 L
.56653 .57636 L
.56653 .57636 L
.56653 .57636 L
.56653 .57636 L
.56653 .57635 L
.56653 .57635 L
.56653 .57635 L
.56653 .57635 L
.56653 .57635 L
.56653 .57634 L
.56653 .57634 L
.56653 .57634 L
.56653 .57633 L
.56654 .57633 L
.56654 .57632 L
.56655 .57632 L
.56655 .57632 L
.56655 .57632 L
.56656 .57631 L
.56656 .57631 L
.56656 .57631 L
.56657 .57631 L
.56657 .57631 L
.56657 .57631 L
.56657 .57631 L
.56657 .57631 L
.56657 .57631 L
.56657 .57631 L
.56657 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56659 .57631 L
.56659 .57631 L
.56659 .57631 L
.56659 .57631 L
.56659 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
Mistroke
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.56659 .57632 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.73572 .26452 m
.7518 .27218 L
.766 .28059 L
.776 .28804 L
.7847 .29628 L
.78901 .3014 L
.79237 .30617 L
.79503 .31069 L
.79745 .31571 L
.79907 .31993 L
.80046 .32451 L
.80155 .32938 L
.80224 .33397 L
.80266 .33918 L
.80275 .34405 L
.80267 .34686 L
.80253 .34941 L
.80227 .35237 L
.80196 .35516 L
.80119 .36026 L
.80029 .36496 L
.79763 .37561 L
.79117 .39437 L
.78246 .4141 L
.73495 .4904 L
.70451 .52661 L
.67622 .55376 L
.64988 .57352 L
.63777 .58075 L
.6272 .58606 L
.61837 .58971 L
.60929 .5927 L
.60516 .59377 L
.6009 .59469 L
.59865 .59509 L
.59663 .5954 L
.59479 .59563 L
.59284 .59584 L
.59091 .59599 L
.58915 .59608 L
.58749 .59613 L
.58599 .59614 L
.58443 .59611 L
.58276 .59603 L
.58195 .59598 L
.58109 .59591 L
.57958 .59575 L
.5768 .59536 L
.57437 .59487 L
.57029 .59372 L
Mistroke
.56825 .59295 L
.56629 .59206 L
.56332 .59034 L
.56182 .58923 L
.56062 .58817 L
.55965 .58715 L
.5589 .5862 L
.55829 .58527 L
.55785 .58445 L
.55747 .58356 L
.55731 .58308 L
.55719 .58264 L
.5571 .58223 L
.55704 .5818 L
.557 .58138 L
.55698 .58114 L
.55698 .58093 L
.55699 .58055 L
.55702 .58021 L
.55706 .57985 L
.5571 .57967 L
.55714 .57948 L
.55731 .57884 L
.55752 .5783 L
.55782 .57772 L
.55814 .57722 L
.55879 .57643 L
.55958 .57573 L
.56047 .57514 L
.56132 .57472 L
.56224 .5744 L
.56275 .57428 L
.56319 .57419 L
.56341 .57416 L
.56364 .57414 L
.56383 .57412 L
.56403 .57411 L
.56414 .5741 L
.56425 .5741 L
.56436 .5741 L
.56447 .5741 L
.56466 .57411 L
.56476 .57411 L
.56486 .57412 L
.56504 .57413 L
.5652 .57415 L
.56549 .5742 L
.56578 .57426 L
.56607 .57434 L
.56652 .5745 L
Mistroke
.56686 .57468 L
.56716 .57488 L
.5674 .57511 L
.56749 .57523 L
.56756 .57535 L
.56761 .57546 L
.56763 .57551 L
.56765 .57556 L
.56766 .57561 L
.56766 .57563 L
.56767 .57565 L
.56767 .5757 L
.56768 .57574 L
.56768 .57578 L
.56768 .57582 L
.56767 .57586 L
.56767 .57589 L
.56767 .57591 L
.56765 .57598 L
.56764 .57602 L
.56763 .57605 L
.56759 .57612 L
.56756 .57618 L
.56749 .57628 L
.5674 .57636 L
.5673 .57643 L
.56719 .57649 L
.56714 .57651 L
.56708 .57653 L
.56703 .57654 L
.56698 .57655 L
.56693 .57656 L
.5669 .57656 L
.56689 .57656 L
.56688 .57656 L
.56686 .57657 L
.56684 .57657 L
.56682 .57657 L
.56681 .57657 L
.5668 .57657 L
.56679 .57656 L
.56678 .57656 L
.56676 .57656 L
.56674 .57656 L
.56672 .57656 L
.56669 .57655 L
.56665 .57654 L
.5666 .57652 L
.56656 .5765 L
.56653 .57648 L
Mistroke
.56652 .57647 L
.5665 .57646 L
.56649 .57645 L
.56649 .57643 L
.56648 .57642 L
.56648 .57641 L
.56647 .57641 L
.56647 .5764 L
.56647 .57639 L
.56647 .57639 L
.56647 .57639 L
.56647 .57639 L
.56647 .57638 L
.56647 .57638 L
.56647 .57638 L
.56647 .57637 L
.56647 .57637 L
.56647 .57637 L
.56647 .57636 L
.56647 .57636 L
.56648 .57635 L
.56648 .57635 L
.56648 .57634 L
.56649 .57633 L
.5665 .57632 L
.5665 .57632 L
.56651 .57631 L
.56653 .57631 L
.56653 .5763 L
.56654 .5763 L
.56654 .5763 L
.56655 .5763 L
.56655 .5763 L
.56655 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56658 .5763 L
.56658 .5763 L
.56658 .5763 L
.56659 .5763 L
.56659 .5763 L
.5666 .57631 L
Mistroke
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
Mistroke
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.73572 .50499 m
.70687 .53287 L
.67765 .55761 L
.64958 .5768 L
.62689 .58828 L
.61525 .59254 L
.60523 .5952 L
.60016 .59616 L
.59574 .59676 L
.59354 .59697 L
.59231 .59706 L
.59119 .59713 L
.59003 .59718 L
.58899 .59721 L
.58781 .59722 L
.58671 .59722 L
.58492 .59717 L
.58334 .59709 L
.5825 .59703 L
.58159 .59696 L
.58001 .59679 L
.57711 .59636 L
.57464 .59585 L
.57215 .5952 L
.56965 .59437 L
.56748 .59349 L
.56538 .59246 L
.56217 .59041 L
.55988 .58839 L
.55903 .58744 L
.55827 .58643 L
.5577 .58551 L
.55727 .58468 L
.55691 .58375 L
.55676 .58327 L
.55664 .58278 L
.55656 .58237 L
.55651 .58198 L
.55647 .58158 L
.55646 .58115 L
.55646 .58091 L
.55647 .5807 L
.55649 .58047 L
.55652 .58023 L
.55655 .58002 L
.55658 .57983 L
.55667 .57942 L
.55689 .57874 L
.55719 .57806 L
.55753 .57748 L
Mistroke
.55793 .57692 L
.55876 .57604 L
.55985 .57523 L
.56088 .57469 L
.56185 .57434 L
.56238 .57419 L
.56285 .5741 L
.56326 .57404 L
.56348 .57401 L
.56368 .57399 L
.56389 .57398 L
.56408 .57398 L
.56418 .57397 L
.56429 .57397 L
.56448 .57398 L
.56466 .57399 L
.56483 .574 L
.565 .57401 L
.56518 .57404 L
.56546 .57408 L
.56574 .57414 L
.56603 .57422 L
.56632 .57432 L
.56675 .57451 L
.56713 .57476 L
.56728 .57488 L
.5674 .57499 L
.56756 .57521 L
.56763 .57532 L
.56768 .57543 L
.5677 .57548 L
.56771 .57553 L
.56772 .57558 L
.56773 .57563 L
.56774 .57567 L
.56774 .57571 L
.56774 .57575 L
.56774 .57579 L
.56774 .57584 L
.56773 .57588 L
.56772 .57592 L
.56771 .57596 L
.56768 .57604 L
.56765 .57611 L
.56758 .57622 L
.5675 .57631 L
.5674 .5764 L
.5673 .57646 L
.5672 .57651 L
.56709 .57655 L
Mistroke
.56704 .57656 L
.56701 .57656 L
.56698 .57657 L
.56696 .57657 L
.56693 .57658 L
.56691 .57658 L
.56689 .57658 L
.56687 .57658 L
.56685 .57658 L
.56683 .57658 L
.56681 .57658 L
.56679 .57658 L
.56677 .57658 L
.56676 .57657 L
.56674 .57657 L
.56671 .57657 L
.56668 .57656 L
.56665 .57655 L
.56662 .57654 L
.56658 .57652 L
.56654 .5765 L
.56651 .57648 L
.56649 .57645 L
.56648 .57644 L
.56648 .57643 L
.56647 .57642 L
.56647 .57641 L
.56647 .57641 L
.56647 .5764 L
.56647 .5764 L
.56647 .57639 L
.56647 .57639 L
.56647 .57639 L
.56647 .57639 L
.56647 .57638 L
.56647 .57638 L
.56647 .57637 L
.56647 .57637 L
.56647 .57637 L
.56647 .57636 L
.56647 .57635 L
.56648 .57634 L
.56648 .57634 L
.56649 .57633 L
.5665 .57632 L
.56651 .57631 L
.56652 .57631 L
.56653 .5763 L
.56654 .5763 L
.56654 .5763 L
Mistroke
.56655 .5763 L
.56655 .5763 L
.56655 .5763 L
.56655 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56658 .5763 L
.56658 .5763 L
.56658 .5763 L
.56659 .5763 L
.56659 .5763 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.56659 .57633 L
Mistroke
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.73572 .74546 m
.71926 .74525 L
.70519 .74471 L
.68993 .7437 L
.67638 .74237 L
.66455 .74085 L
.65419 .7392 L
.63254 .73468 L
.61297 .72915 L
.59374 .72209 L
.57578 .71374 L
.56126 .70547 L
.53668 .68743 L
.51687 .66732 L
.50382 .64904 L
.49555 .63261 L
.49244 .62387 L
.49053 .61637 L
.48982 .61239 L
.48952 .61021 L
.48931 .60824 L
.48908 .60472 L
.48904 .603 L
.48905 .60114 L
.4892 .5979 L
.4895 .59505 L
.48972 .59352 L
.49001 .5919 L
.49065 .58905 L
.49138 .5865 L
.49229 .58391 L
.49425 .57958 L
.49695 .57507 L
.50033 .57077 L
.50741 .56441 L
.51191 .56149 L
.51686 .55898 L
.52118 .55726 L
.52593 .55579 L
.53009 .55483 L
.53226 .55443 L
.53453 .5541 L
.53649 .55387 L
.53752 .55377 L
.53862 .55368 L
.54052 .55357 L
.54226 .55351 L
.54403 .55349 L
.54592 .55352 L
.54767 .5536 L
Mistroke
.54924 .55371 L
.55077 .55385 L
.55211 .554 L
.555 .55443 L
.55818 .55508 L
.56087 .55578 L
.56353 .55664 L
.56615 .55768 L
.56989 .55961 L
.57296 .56177 L
.57414 .56284 L
.57522 .564 L
.57599 .56502 L
.57665 .56608 L
.57711 .56702 L
.5773 .56751 L
.57747 .56802 L
.5776 .56849 L
.5777 .56891 L
.57776 .5693 L
.57781 .56971 L
.57784 .57018 L
.57785 .5706 L
.57784 .57083 L
.57783 .57107 L
.57778 .5715 L
.57772 .57189 L
.57763 .57229 L
.57742 .57298 L
.57711 .57374 L
.57676 .57439 L
.5758 .57568 L
.57483 .5766 L
.5737 .57739 L
.57262 .57794 L
.57211 .57815 L
.57163 .57831 L
.57078 .57854 L
.57035 .57862 L
.57013 .57865 L
.5699 .57868 L
.56968 .5787 L
.56947 .57872 L
.56926 .57873 L
.56904 .57873 L
.56885 .57873 L
.56866 .57872 L
.56851 .57872 L
.56834 .5787 L
.56816 .57868 L
Mistroke
.56801 .57866 L
.56768 .57861 L
.56739 .57854 L
.56714 .57847 L
.56665 .57829 L
.56641 .57817 L
.56622 .57806 L
.5659 .57781 L
.56569 .57759 L
.5656 .57747 L
.56552 .57734 L
.56547 .57722 L
.56545 .57717 L
.56544 .57712 L
.56543 .57707 L
.56542 .57702 L
.56542 .57697 L
.56541 .57693 L
.56541 .57689 L
.56542 .57684 L
.56542 .57682 L
.56542 .5768 L
.56543 .57675 L
.56544 .57672 L
.56545 .57668 L
.56547 .5766 L
.5655 .57654 L
.56554 .57648 L
.56563 .57636 L
.56573 .57627 L
.56585 .57619 L
.56596 .57613 L
.56607 .5761 L
.56612 .57608 L
.56617 .57607 L
.5662 .57607 L
.56623 .57607 L
.56625 .57606 L
.56627 .57606 L
.56629 .57606 L
.5663 .57606 L
.56631 .57606 L
.56632 .57606 L
.56634 .57606 L
.56636 .57606 L
.56637 .57606 L
.56638 .57606 L
.5664 .57606 L
.56643 .57607 L
.56647 .57607 L
Mistroke
.5665 .57608 L
.56653 .57609 L
.56656 .5761 L
.5666 .57612 L
.56664 .57614 L
.56667 .57616 L
.56669 .57619 L
.5667 .5762 L
.56671 .57622 L
.56671 .57622 L
.56671 .57623 L
.56672 .57623 L
.56672 .57624 L
.56672 .57624 L
.56672 .57625 L
.56672 .57625 L
.56672 .57625 L
.56672 .57626 L
.56672 .57626 L
.56672 .57626 L
.56672 .57627 L
.56672 .57627 L
.56672 .57627 L
.56672 .57628 L
.56672 .57628 L
.56671 .57629 L
.56671 .5763 L
.56671 .57631 L
.5667 .57631 L
.56669 .57632 L
.56668 .57633 L
.56667 .57634 L
.56666 .57635 L
.56665 .57635 L
.56664 .57635 L
.56664 .57635 L
.56663 .57635 L
.56663 .57635 L
.56663 .57635 L
.56663 .57635 L
.56663 .57635 L
.56662 .57635 L
.56662 .57635 L
.56662 .57635 L
.56662 .57635 L
.56661 .57635 L
.56661 .57635 L
.56661 .57635 L
.56661 .57635 L
.5666 .57635 L
Mistroke
.5666 .57635 L
.56659 .57635 L
.56659 .57635 L
.56658 .57634 L
.56658 .57634 L
.56658 .57634 L
.56658 .57634 L
.56658 .57634 L
.56658 .57634 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.73572 .98592 m
.68248 .96909 L
.63366 .94771 L
.59386 .92496 L
.56209 .90262 L
.49898 .84391 L
.45506 .78716 L
.42266 .73112 L
.40262 .6841 L
.39544 .66178 L
.38989 .63913 L
.38797 .62851 L
.38714 .62288 L
.38651 .61767 L
.38606 .61297 L
.3857 .60799 L
.38541 .5996 L
.38543 .59491 L
.38557 .59073 L
.38586 .58629 L
.38632 .58175 L
.38741 .57447 L
.3882 .57055 L
.38906 .56701 L
.39295 .55534 L
.39567 .54945 L
.39848 .54446 L
.40575 .53457 L
.41043 .52972 L
.41508 .52567 L
.42433 .51928 L
.43503 .51385 L
.44465 .51025 L
.44987 .5087 L
.45544 .5073 L
.46041 .50626 L
.4659 .50532 L
.47088 .50463 L
.47559 .50412 L
.47851 .50387 L
.48167 .50365 L
.48718 .5034 L
.49029 .50332 L
.49357 .5033 L
.49635 .50331 L
.4994 .50338 L
.50479 .5036 L
.50779 .50378 L
.5105 .50398 L
.52052 .50502 L
Mistroke
.52558 .50572 L
.53022 .50648 L
.53856 .50811 L
.5555 .51266 L
.56799 .51736 L
.57917 .52297 L
.58878 .52956 L
.59257 .53294 L
.59599 .53666 L
.59833 .53982 L
.60028 .54315 L
.60165 .54624 L
.60252 .54898 L
.60284 .55038 L
.60306 .55166 L
.60323 .55305 L
.60332 .55452 L
.60332 .55595 L
.60329 .55665 L
.60324 .55741 L
.60308 .55873 L
.60288 .55993 L
.60261 .56113 L
.60232 .56222 L
.60164 .5642 L
.60076 .56621 L
.59965 .56826 L
.59686 .57216 L
.59347 .57559 L
.59039 .57796 L
.58695 .58001 L
.58355 .58152 L
.58193 .58209 L
.58046 .58251 L
.5792 .58282 L
.57785 .58307 L
.57655 .58326 L
.57586 .58333 L
.57523 .58338 L
.57461 .58341 L
.57427 .58342 L
.57395 .58343 L
.57333 .58343 L
.57299 .58342 L
.57268 .58341 L
.57215 .58337 L
.57159 .58333 L
.57108 .58327 L
.57063 .58321 L
.56966 .58303 L
Mistroke
.56869 .5828 L
.56776 .58251 L
.56699 .58221 L
.56577 .5816 L
.56474 .58088 L
.56437 .58054 L
.56403 .58018 L
.56357 .57954 L
.56341 .57922 L
.56334 .57906 L
.56328 .57889 L
.56323 .57875 L
.56319 .57859 L
.56317 .57845 L
.56315 .57833 L
.56313 .5782 L
.56313 .57807 L
.56313 .57797 L
.56313 .57786 L
.56314 .57774 L
.56316 .57761 L
.56318 .57751 L
.56321 .5774 L
.56328 .57718 L
.56338 .57697 L
.5635 .57676 L
.56363 .57658 L
.56388 .5763 L
.56418 .57606 L
.56436 .57594 L
.56455 .57584 L
.56473 .57576 L
.5649 .57569 L
.56506 .57565 L
.56523 .5756 L
.56539 .57557 L
.56552 .57556 L
.56559 .57555 L
.56563 .57555 L
.56567 .57554 L
.56574 .57554 L
.5658 .57554 L
.56583 .57554 L
.56587 .57554 L
.56593 .57554 L
.56596 .57555 L
.566 .57555 L
.56606 .57555 L
.56612 .57556 L
.56618 .57557 L
Mistroke
.56627 .57559 L
.56636 .57561 L
.56646 .57564 L
.5666 .5757 L
.56672 .57577 L
.56681 .57583 L
.56688 .5759 L
.5669 .57594 L
.56693 .57598 L
.56695 .57601 L
.56695 .57603 L
.56696 .57605 L
.56696 .57606 L
.56697 .57608 L
.56697 .57609 L
.56697 .5761 L
.56697 .57612 L
.56697 .57613 L
.56697 .57615 L
.56697 .57616 L
.56697 .57618 L
.56697 .57618 L
.56697 .57619 L
.56696 .57622 L
.56695 .57624 L
.56694 .57626 L
.56691 .5763 L
.56689 .57632 L
.56687 .57634 L
.56684 .57636 L
.5668 .57638 L
.56678 .57639 L
.56676 .5764 L
.56675 .5764 L
.56673 .5764 L
.56672 .57641 L
.56671 .57641 L
.5667 .57641 L
.5667 .57641 L
.56669 .57641 L
.56668 .57641 L
.56668 .57641 L
.56667 .57641 L
.56666 .57641 L
.56666 .57641 L
.56665 .57641 L
.56664 .57641 L
.56663 .57641 L
.56662 .5764 L
.56661 .5764 L
Mistroke
.5666 .5764 L
.56659 .57639 L
.56658 .57638 L
.56657 .57638 L
.56656 .57637 L
.56656 .57637 L
.56655 .57637 L
.56655 .57636 L
.56655 .57636 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57633 L
.56655 .57633 L
.56655 .57633 L
.56656 .57633 L
.56656 .57632 L
.56656 .57632 L
.56657 .57632 L
.56657 .57632 L
.56657 .57632 L
.56657 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57631 L
.56658 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.97619 .26452 m
.7921 .422 L
.73335 .49818 L
.70288 .53126 L
.67162 .55916 L
.64441 .57789 L
.62232 .58881 L
.61274 .5922 L
.608 .59355 L
.60322 .59468 L
.59924 .59543 L
.5972 .59574 L
.59508 .59601 L
.59318 .5962 L
.5915 .59633 L
.58985 .59642 L
.58832 .59647 L
.58656 .59649 L
.5856 .59648 L
.58473 .59646 L
.58316 .59639 L
.58157 .59628 L
.58019 .59615 L
.57894 .596 L
.57624 .59556 L
.57356 .59498 L
.57131 .59434 L
.56695 .59266 L
.56393 .59103 L
.56134 .58913 L
.5595 .5873 L
.55826 .58564 L
.55775 .58472 L
.55739 .58391 L
.5571 .58304 L
.55699 .58261 L
.55691 .58216 L
.55685 .58177 L
.55682 .58142 L
.55681 .58102 L
.55682 .58066 L
.55684 .58033 L
.55687 .58004 L
.55693 .57973 L
.557 .5794 L
.55719 .57876 L
.55746 .57812 L
.55777 .57756 L
.55809 .5771 L
.55849 .5766 L
Mistroke
.55898 .57611 L
.55992 .57538 L
.56093 .57482 L
.56142 .57461 L
.56187 .57445 L
.56227 .57434 L
.56269 .57423 L
.56311 .57416 L
.56331 .57413 L
.56353 .5741 L
.56365 .57409 L
.56377 .57408 L
.56387 .57407 L
.56398 .57407 L
.56417 .57406 L
.56436 .57406 L
.56447 .57406 L
.56457 .57406 L
.56468 .57407 L
.56479 .57407 L
.56497 .57409 L
.56515 .57411 L
.56547 .57416 L
.56579 .57422 L
.56606 .5743 L
.56629 .57438 L
.5667 .57456 L
.56705 .57477 L
.56728 .57496 L
.56747 .57516 L
.56755 .57528 L
.5676 .57538 L
.56763 .57544 L
.56765 .5755 L
.56767 .57555 L
.56768 .5756 L
.56769 .57565 L
.56769 .57569 L
.5677 .57574 L
.5677 .57577 L
.5677 .57579 L
.5677 .57583 L
.56769 .57587 L
.56769 .57591 L
.56768 .57595 L
.56765 .57602 L
.56763 .57609 L
.56759 .57616 L
.56754 .57622 L
.56746 .57632 L
Mistroke
.56736 .5764 L
.56726 .57646 L
.56715 .57651 L
.5671 .57653 L
.56706 .57654 L
.56702 .57655 L
.56697 .57656 L
.56695 .57656 L
.56692 .57657 L
.5669 .57657 L
.56688 .57657 L
.56686 .57657 L
.56684 .57657 L
.56682 .57657 L
.56681 .57657 L
.56678 .57657 L
.56677 .57657 L
.56676 .57657 L
.56675 .57656 L
.56673 .57656 L
.5667 .57656 L
.56666 .57655 L
.56662 .57653 L
.56657 .57651 L
.56654 .57649 L
.56651 .57647 L
.56649 .57645 L
.56649 .57644 L
.56648 .57643 L
.56648 .57642 L
.56647 .57641 L
.56647 .57641 L
.56647 .5764 L
.56647 .5764 L
.56647 .57639 L
.56647 .57639 L
.56647 .57638 L
.56647 .57638 L
.56647 .57638 L
.56647 .57637 L
.56647 .57637 L
.56647 .57636 L
.56647 .57636 L
.56648 .57635 L
.56648 .57635 L
.56648 .57634 L
.56649 .57633 L
.5665 .57632 L
.56652 .57631 L
.56653 .5763 L
Mistroke
.56654 .5763 L
.56654 .5763 L
.56655 .5763 L
.56655 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56656 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56657 .5763 L
.56658 .5763 L
.56658 .5763 L
.56658 .5763 L
.56658 .5763 L
.56659 .5763 L
.56659 .5763 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57631 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57632 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.56659 .57633 L
Mistroke
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.97619 .50499 m
.74245 .57851 L
.68476 .59989 L
.65987 .60747 L
.63961 .61221 L
.63007 .61385 L
.62532 .61449 L
.62049 .61502 L
.61658 .61535 L
.61442 .61549 L
.61244 .6156 L
.60905 .61571 L
.60554 .61575 L
.60213 .61569 L
.60026 .61562 L
.59856 .61553 L
.59554 .61531 L
.59244 .615 L
.58952 .61462 L
.58688 .6142 L
.58223 .61326 L
.57705 .6119 L
.57212 .61023 L
.56462 .60679 L
.55832 .60269 L
.55548 .60028 L
.55328 .59801 L
.55042 .59414 L
.54929 .59203 L
.54852 .59013 L
.54805 .58854 L
.54786 .58767 L
.54774 .58686 L
.54765 .58604 L
.54762 .58531 L
.54762 .58452 L
.54764 .58414 L
.54767 .58372 L
.54776 .58301 L
.54788 .58235 L
.54801 .58178 L
.54818 .58119 L
.54866 .57992 L
.54919 .57884 L
.55038 .5771 L
.55186 .57557 L
.5536 .57425 L
.55526 .57332 L
.55619 .57292 L
.5572 .57256 L
Mistroke
.55814 .57228 L
.55898 .57209 L
.5598 .57194 L
.56017 .57189 L
.56055 .57185 L
.56095 .57181 L
.56131 .57179 L
.56169 .57178 L
.5619 .57178 L
.5621 .57177 L
.56244 .57178 L
.56275 .57179 L
.56303 .57181 L
.56332 .57183 L
.56363 .57187 L
.56394 .57191 L
.56449 .572 L
.56504 .57212 L
.56557 .57227 L
.56641 .57258 L
.56716 .57296 L
.5678 .57341 L
.56821 .5738 L
.56838 .57402 L
.56852 .57422 L
.56862 .57441 L
.5687 .5746 L
.56873 .57468 L
.56876 .57477 L
.56878 .57485 L
.56879 .57493 L
.56881 .57502 L
.56881 .57506 L
.56881 .57511 L
.56882 .57519 L
.56882 .57528 L
.56881 .57536 L
.5688 .57544 L
.56879 .57551 L
.56877 .57557 L
.56873 .57571 L
.56867 .57586 L
.56859 .57599 L
.56851 .57611 L
.56835 .5763 L
.56818 .57644 L
.56798 .57658 L
.56778 .57667 L
.56759 .57674 L
.56748 .57677 L
Mistroke
.56739 .57679 L
.56734 .5768 L
.56729 .5768 L
.56725 .57681 L
.5672 .57681 L
.56716 .57682 L
.56711 .57682 L
.56709 .57682 L
.56707 .57682 L
.56702 .57682 L
.56699 .57681 L
.56695 .57681 L
.56692 .57681 L
.56689 .5768 L
.56683 .5768 L
.56677 .57678 L
.56671 .57677 L
.56666 .57675 L
.56657 .57671 L
.5665 .57667 L
.56644 .57663 L
.56642 .5766 L
.5664 .57658 L
.56638 .57655 L
.56637 .57653 L
.56636 .57651 L
.56636 .57649 L
.56635 .57648 L
.56635 .57647 L
.56635 .57646 L
.56635 .57645 L
.56635 .57644 L
.56635 .57643 L
.56635 .57643 L
.56635 .57642 L
.56635 .57641 L
.56635 .5764 L
.56636 .57639 L
.56637 .57637 L
.56637 .57636 L
.56639 .57633 L
.5664 .57632 L
.56642 .57631 L
.56644 .5763 L
.56646 .57629 L
.56648 .57628 L
.56649 .57628 L
.56651 .57627 L
.56651 .57627 L
.56652 .57627 L
Mistroke
.56652 .57627 L
.56653 .57627 L
.56653 .57627 L
.56654 .57627 L
.56654 .57627 L
.56654 .57627 L
.56655 .57627 L
.56655 .57627 L
.56655 .57627 L
.56656 .57627 L
.56656 .57627 L
.56657 .57627 L
.56657 .57627 L
.56658 .57628 L
.56659 .57628 L
.56659 .57628 L
.5666 .57629 L
.56661 .57629 L
.56661 .5763 L
.56661 .5763 L
.56661 .5763 L
.56661 .5763 L
.56662 .5763 L
.56662 .57631 L
.56662 .57631 L
.56662 .57631 L
.56662 .57631 L
.56662 .57631 L
.56662 .57631 L
.56662 .57631 L
.56662 .57631 L
.56662 .57631 L
.56662 .57631 L
.56662 .57631 L
.56662 .57632 L
.56662 .57632 L
.56661 .57632 L
.56661 .57632 L
.56661 .57632 L
.56661 .57633 L
.56661 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
Mistroke
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.5666 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.97619 .74546 m
.9068 .75285 L
.84644 .75838 L
.82104 .76023 L
.79893 .76148 L
.78047 .76222 L
.76174 .76262 L
.74254 .7626 L
.72292 .76204 L
.71359 .76155 L
.70393 .76088 L
.6874 .75929 L
.67205 .75727 L
.65837 .75497 L
.63483 .74971 L
.61269 .743 L
.59176 .73476 L
.56009 .71778 L
.54403 .70647 L
.53097 .69546 L
.51135 .6746 L
.49682 .6534 L
.49153 .64321 L
.48713 .63253 L
.48446 .62388 L
.48338 .61924 L
.48263 .61515 L
.48213 .61146 L
.4818 .60758 L
.48169 .60404 L
.48174 .60088 L
.48197 .5974 L
.48219 .59551 L
.48243 .59381 L
.48301 .59078 L
.48377 .58773 L
.4859 .58173 L
.48739 .57861 L
.48893 .57588 L
.49245 .57092 L
.49622 .56683 L
.50099 .56279 L
.50564 .55971 L
.51383 .55571 L
.51861 .55402 L
.5231 .55279 L
.52551 .55226 L
.52779 .55183 L
.52984 .55151 L
.53201 .55123 L
Mistroke
.53432 .55099 L
.53644 .55084 L
.53771 .55078 L
.5389 .55074 L
.54109 .55071 L
.54284 .55073 L
.54471 .5508 L
.54662 .55092 L
.54835 .55107 L
.55135 .55142 L
.55439 .55191 L
.55773 .55263 L
.56065 .55342 L
.56549 .55515 L
.56955 .55712 L
.5731 .55945 L
.57453 .56066 L
.57584 .56197 L
.57677 .56309 L
.5776 .5643 L
.57817 .56535 L
.57863 .56643 L
.57883 .56702 L
.57897 .56755 L
.57908 .56807 L
.57916 .56854 L
.5792 .56898 L
.57923 .56943 L
.57923 .56981 L
.57922 .57022 L
.57918 .57065 L
.57912 .5711 L
.57904 .57151 L
.57896 .57188 L
.57872 .57264 L
.57838 .57342 L
.57797 .57418 L
.57753 .57484 L
.57664 .57588 L
.57558 .57681 L
.57435 .57762 L
.57304 .57826 L
.57195 .57863 L
.57135 .57878 L
.57082 .57888 L
.57055 .57892 L
.57028 .57896 L
.57005 .57898 L
.5698 .579 L
.56967 .579 L
Mistroke
.56955 .57901 L
.56941 .57901 L
.56928 .57901 L
.56905 .57901 L
.56893 .57901 L
.56881 .579 L
.5686 .57899 L
.5684 .57897 L
.56805 .57892 L
.5677 .57885 L
.56735 .57876 L
.5668 .57858 L
.56633 .57835 L
.566 .57814 L
.56573 .5779 L
.56561 .57777 L
.5655 .57763 L
.56543 .57751 L
.56537 .57739 L
.56533 .57728 L
.56531 .57722 L
.5653 .57716 L
.56529 .57711 L
.56528 .57707 L
.56528 .57702 L
.56528 .57697 L
.56528 .57692 L
.56528 .57687 L
.56529 .57684 L
.56529 .57682 L
.5653 .57677 L
.56533 .57668 L
.56536 .5766 L
.5654 .57653 L
.56545 .57645 L
.56557 .57631 L
.5657 .57622 L
.56582 .57614 L
.56593 .5761 L
.56599 .57608 L
.56605 .57606 L
.56611 .57605 L
.56617 .57604 L
.5662 .57603 L
.56623 .57603 L
.56624 .57603 L
.56626 .57603 L
.56627 .57603 L
.56629 .57603 L
.56631 .57603 L
Mistroke
.56634 .57603 L
.56636 .57603 L
.56638 .57603 L
.5664 .57604 L
.56642 .57604 L
.56646 .57605 L
.5665 .57605 L
.56653 .57606 L
.56659 .57609 L
.56663 .57611 L
.56667 .57614 L
.5667 .57617 L
.56671 .57618 L
.56672 .57619 L
.56672 .5762 L
.56673 .57622 L
.56673 .57622 L
.56673 .57623 L
.56673 .57623 L
.56673 .57624 L
.56673 .57624 L
.56673 .57625 L
.56673 .57625 L
.56673 .57625 L
.56673 .57626 L
.56673 .57627 L
.56673 .57627 L
.56673 .57627 L
.56673 .57628 L
.56673 .57629 L
.56672 .5763 L
.56672 .57631 L
.56671 .57631 L
.5667 .57632 L
.56669 .57633 L
.56668 .57634 L
.56666 .57635 L
.56665 .57635 L
.56665 .57635 L
.56664 .57635 L
.56664 .57636 L
.56663 .57636 L
.56663 .57636 L
.56663 .57636 L
.56663 .57636 L
.56662 .57636 L
.56662 .57636 L
.56662 .57636 L
.56662 .57636 L
.56662 .57636 L
Mistroke
.56662 .57636 L
.56661 .57636 L
.56661 .57636 L
.56661 .57636 L
.5666 .57635 L
.5666 .57635 L
.56659 .57635 L
.56659 .57635 L
.56658 .57635 L
.56658 .57634 L
.56658 .57634 L
.56658 .57634 L
.56658 .57634 L
.56658 .57634 L
.56657 .57634 L
.56657 .57633 L
.56657 .57633 L
.56657 .57633 L
.56657 .57633 L
.56657 .57633 L
.56657 .57633 L
.56657 .57633 L
.56657 .57633 L
.56657 .57633 L
.56657 .57633 L
.56657 .57633 L
.56657 .57633 L
.56657 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57633 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
.97619 .98592 m
.92545 .98527 L
.88421 .98356 L
.84143 .98034 L
.80495 .97612 L
.77413 .97126 L
.74783 .96601 L
.69482 .95167 L
.64885 .93417 L
.60521 .912 L
.5661 .88638 L
.53453 .86078 L
.48287 .80631 L
.44806 .7568 L
.4332 .73059 L
.42011 .70334 L
.41114 .6809 L
.40381 .65824 L
.40066 .64609 L
.39839 .63544 L
.39676 .62573 L
.39613 .62096 L
.39559 .61598 L
.39499 .60767 L
.39482 .60028 L
.39488 .59595 L
.39506 .59197 L
.39569 .58481 L
.39617 .58128 L
.3968 .57751 L
.39844 .57026 L
.40036 .564 L
.4025 .5585 L
.4084 .54744 L
.41232 .54197 L
.41628 .53741 L
.42308 .53108 L
.43107 .52537 L
.44055 .52023 L
.44992 .51644 L
.45515 .51475 L
.46093 .51318 L
.46609 .51203 L
.4716 .51102 L
.4766 .51029 L
.48211 .50967 L
.48712 .50927 L
.49179 .50902 L
.49685 .50889 L
.49966 .50888 L
Mistroke
.50218 .5089 L
.50707 .50904 L
.5116 .50928 L
.51415 .50946 L
.51682 .50968 L
.52152 .51016 L
.53173 .5116 L
.54008 .51319 L
.5474 .51494 L
.56226 .51964 L
.57348 .52457 L
.5818 .52942 L
.58927 .53523 L
.59213 .53809 L
.59438 .54077 L
.59634 .5436 L
.59776 .54616 L
.59896 .54895 L
.59944 .55038 L
.59983 .55187 L
.6001 .5532 L
.6003 .5546 L
.60041 .55589 L
.60045 .55705 L
.60044 .55774 L
.60041 .55838 L
.60036 .55906 L
.60029 .55978 L
.60012 .56096 L
.59986 .56222 L
.59925 .56436 L
.59854 .56621 L
.59649 .56999 L
.59418 .57303 L
.59174 .57549 L
.589 .57765 L
.58591 .57956 L
.58271 .58104 L
.58129 .58156 L
.57983 .58201 L
.57859 .58232 L
.57729 .58258 L
.57615 .58275 L
.57566 .58281 L
.57513 .58286 L
.57453 .58291 L
.57397 .58293 L
.57345 .58295 L
.57298 .58295 L
.57248 .58293 L
Mistroke
.57195 .58291 L
.57141 .58287 L
.57092 .58282 L
.56996 .58268 L
.56913 .58251 L
.56829 .58229 L
.56748 .58202 L
.5662 .58145 L
.56527 .58088 L
.56457 .5803 L
.56427 .57999 L
.56401 .57967 L
.56382 .57939 L
.56366 .57909 L
.56354 .57883 L
.56346 .57859 L
.56342 .57844 L
.56339 .57829 L
.56338 .57817 L
.56337 .57804 L
.56336 .57796 L
.56336 .5779 L
.56336 .57782 L
.56337 .57775 L
.56338 .57763 L
.56339 .57756 L
.5634 .5775 L
.56342 .57738 L
.56345 .57727 L
.56352 .57708 L
.56361 .57689 L
.56373 .5767 L
.56396 .57641 L
.56424 .57615 L
.5645 .57598 L
.56479 .57583 L
.56494 .57576 L
.56511 .57571 L
.56525 .57567 L
.5654 .57564 L
.56547 .57563 L
.56554 .57562 L
.56561 .57561 L
.56566 .5756 L
.56572 .5756 L
.56578 .5756 L
.56583 .57559 L
.56589 .57559 L
.56592 .5756 L
.56596 .5756 L
Mistroke
.56599 .5756 L
.56602 .5756 L
.56607 .5756 L
.56613 .57561 L
.56623 .57563 L
.56634 .57565 L
.56643 .57567 L
.56651 .5757 L
.56664 .57576 L
.56675 .57583 L
.56683 .5759 L
.56689 .57597 L
.56691 .57601 L
.56693 .57605 L
.56693 .57607 L
.56694 .57608 L
.56694 .5761 L
.56694 .57611 L
.56695 .57612 L
.56695 .57613 L
.56695 .57614 L
.56695 .57614 L
.56695 .57616 L
.56695 .57617 L
.56695 .57617 L
.56694 .57618 L
.56694 .5762 L
.56694 .57621 L
.56694 .57622 L
.56693 .57624 L
.56692 .57626 L
.56689 .5763 L
.56686 .57633 L
.56683 .57635 L
.5668 .57637 L
.56677 .57639 L
.56675 .57639 L
.56673 .5764 L
.56672 .5764 L
.5667 .5764 L
.56669 .5764 L
.56669 .5764 L
.56668 .5764 L
.56668 .5764 L
.56667 .5764 L
.56666 .5764 L
.56666 .5764 L
.56666 .5764 L
.56665 .5764 L
.56665 .5764 L
Mistroke
.56664 .5764 L
.56664 .5764 L
.56663 .5764 L
.56661 .5764 L
.56661 .57639 L
.56659 .57639 L
.56658 .57638 L
.56657 .57637 L
.56656 .57637 L
.56656 .57636 L
.56655 .57636 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57635 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57634 L
.56655 .57633 L
.56655 .57633 L
.56656 .57633 L
.56656 .57633 L
.56656 .57632 L
.56656 .57632 L
.56657 .57632 L
.56657 .57632 L
.56657 .57632 L
.56657 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56658 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57633 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mistroke
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
.56659 .57632 L
Mfstroke
0 0 m
1 0 L
1 1.00997 L
0 1.00997 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{285.125, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006[0001[b000`400?l00000o`00003oo`3ooon/
0?ooo`00o`3ooon/0?ooo`00h03oool00`3ooml0W4P0000000020000000307Boo`3oool0oooo0140
oooo00@0gia800000000B9`0gooo[P3oool00>80oooo00<0okmd0000M02oool0503oool01@3o_g@0
04RL0=oOW018B9`0gooo0:d0oooo003R0?ooo`030?oo_`1d0000M;oo01L0oooo00<0omnL04Qd_`3o
ool0[03oool00>80oooo00<0oooO09a80018W=l0603oool00`3o_g@0M;oo0?ooo`2[0?ooo`00h`3o
ool00`3OW4P00000000000020000000607Boo`3oool0oooo0?ooo`2oM00007Bo1P3oool01@3OW4P0
0000000000000000M;oo00@0oooo00<0okmd0000001d_ol0Z`3oool00><0oooo00L0okmd0000B02L
gol0oooo0?oog`2LB00007Bo0080oooo00<0okmd0000M02oool0103oool00`3ogi`0B00007Boo`02
0?ooo`030;md0000M;l0oooo0080oooo00@0gia80000M01dM4P0W=ooZP3oool00><0oooo00<0oono
07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0omnL04P0001d_ol0103oool00`3OW4P004RL
0=ooo`030?ooo`090=nLW02oool0oooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0:T0oooo003S0?oo
o`030?oog`2LB000B9cO00<0oooo00L0omnL04P0B02Lgol0oooO09a80000B9`0gooo00<0oooo00D0
okmd000000000000000004RLg`050?ooo`050;md0000B9`0gooo0?oOW01dW=l0Z@3oool00>@0oooo
00<0gia80000M02oool00P3oool01`3ooml0W4P004RLg`3oool0_g@004QdM01dW=l00`3oool01`3o
okl0M01809cOo`3oool0gia800000018W=l00P3oool00`3ooml0W4P0001d_`020?ooo`030=nLW02o
ool0oooo0:L0oooo003T0?ooo`040?noM000000004RL0=ooo`80oooo00L0gia8001d_`3oool0okmd
0018W02oW4P0M;oo00<0oooo00/0okmd0018W03Oool0oooo0?oo_`1d0000B9cO0?ooo`3ooml0W4P0
001d_`020?ooo`030?oo_`1dM;l0oooo0:L0oooo003T0?ooo`0K0?oo_`1d0000M9bL04P0M02oool0
oooO09a80000M;l0oooo0?oo_`1d04P0W=oo0;md001dM7@004RL0=ooo`3oool0gia80000M02oool0
oooo0=nLB000B9`0gooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0M02oool0Y`3oool00><0oooo
0140omnL04P000000000B9cO0?oo_`1d000000000000M02oool0omnL04P000000000M;oo0?ooo`2o
M000001d0;ooo`020?ooo`090?oOW018000000000000001d_ol0_g@00000000004P0W=oo0080oooo
00<0gia80018W03Oool0Y`3oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0
oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0
oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0
oooo[03oool00?l0oooo[03oool00?l0oooo[03oool004L0oooo00@0_g@0000000000000M;oo>03o
ool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0gia8000000000000
0`0000000`18W=l0oooo0?ooo`0^0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d
_ol01@3oool00`3ooml0W4P004RLg`0a0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0
001d_ol00`3oool01@3ooml0W4P000000000000007Bo0340oooo00@0_g@0000000000000M;oo0`3o
ool00`3ogi`0B00007Boo`030?ooo`060?oo_`1d0000000000000000B9`0gooo=03oool00`3ookl0
M000000000020000000304RLg`3oool0oooo0100oooo00160?ooo`060=nLB000M;l0oooo0?oOW018
0000B9cO=P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo02d0oooo00H0gia8001d_`3oool0omnL
04P00018W=l20?ooo`030?oOW0180000M;oo00H0oooo00<0gia80018W03Oool0;`3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool01`3OW4P007Bo0?ooo`3o
okl0M0000018W03Oool0;P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0
001d_ol00P3oool00`3ookl0M00004RLg`020?ooo`030=nLB00007@0_ooo03D0oooo00<0okmd0000
001d_ol04`3oool004D0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0d0?ooo`03
0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3o_g@007Bo0?ooo`0`0?ooo`03
0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol02P3oool00`3ogi`0B01809cOo`0^0?ooo`03
0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3ooml0W4P007Boo`020?ooo`03
0?oOW0180000B9cO02d0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`060?ooo`03
0?noM000B9`0gooo00<0oooo00<0_g@004RLg`3oool0=03oool00`3ooml0W4P0001d_`0C0?ooo`00
A@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oooc<0oooo00<0oooO09a80018
W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030?noM000M;l0oooo02l0oooo00<0oooO09a8
0018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?noM0000000000000@0000000<004RL
0=ooo`3oool0:`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0
oono07@0001d_ol00`3oool00`2oM000001d0;ooo`0/0?ooo`030?oog`2LB000B9cO0080oooo00@0
oooO09a80000B9`0gooo1@3oool00`3o_g@004RL0=ooo`030?ooo`030;md0000M;l0oooo03D0oooo
00<0gia80018W03Oool04P3oool004D0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cO
o`0c0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol02@3oool00`3o_g@0B9cO0?oo
o`0^0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4Q809cO
o`020?ooo`030;md0000M;l0oooo02d0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cO
o`050?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol0;03oool00`3ooml0W4P0001d
_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8001d_ol00P3oool00`3ookl0M00004RL
g`0f0?ooo`030?oOW01804P0W=oo0180oooo00160?ooo`030;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l0=03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0gia8
04RLg`3oool0;P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00L0oono
07@0M02oool0oooo0?noM000B9`0gooo02h0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B000
04RLg`060?ooo`030;md000007@0_ooo0080oooo00<0gia80000B02Lgol0;@3oool00`2oM00004RL
0=ooo`020?ooo`030?oOW0180000B9cO00L0oooo00H0_g@00000B02Lgml0W4P00000M02ooolf0?oo
o`030?oo_`1d0000M;oo0180oooo00160?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000
M;l0=03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00/0oooo00<0_g@007Boo`3o
ool0;@3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00L0oooo00H0omnL04Q8W03O
ool0omnL04P0B02Lgol^0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01P3oool0
203o_g@0000004RLg`3oool0oooO09a80000B9`0gooo;@3oool00`3OW4P0001809cOo`020?ooo`03
0?oog`2LB00007Bo00P0oooo00D0oooO09a80000000004RL0=ooo`0g0?ooo`030;md0000M;l0oooo
0140oooo00160?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0<`3oool00`3ogi`0
B00004RLg`030?ooo`030;md0000B9`0gooo00X0oooo00<0omnL04P0M02oool0;@3oool00`3ogi`0
B00004RLg`030?ooo`030;md0000B9`0gooo00L0oooo00D0okmd001d_`3ooml0W4P004RLg`0^0?oo
o`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01@3oool00`3ooml0W4P0000000020000
00030000M02oool0oooo02d0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`070?oo
o`060;md000004P0W=oo0?oOW018B9`0gooo=P3oool00`3OW4P004RL0=ooo`0A0?ooo`00AP3oool0
103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo03<0oooo00@0oooO09a80000B9`0gooo
0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030?oog`2LB000M;oo02d0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`040=nLB018W=l0_g@0001d_bh0oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3OW4P004RL0=ooo`060?ooo`030?oo_`1d000007Bo0340oooo00@0oooO
09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`060?ooo`030?oOW0180000M;oo0080oooo00<0
okmd04RLg`3oool0=@3oool00`3ogi`0B01809cOo`0A0?ooo`00A`3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo03@0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:
0?ooo`030?oo_`1d0000B9cO02h0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`09
0?ooo`040=nLB01dM7@0001d0;ooobh0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?oo
o`070?ooo`030?oOW0180000B9cO0340oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?oo
o`060?ooo`030?oOW01804P0W=oo0080oooo00<0okmd0018W03Oool0=@3oool00`3ookl0M00007Bo
o`0A0?ooo`00B03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgcH0oooo00H0gia80000M02oool0
oooO09a80018W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`0_0?ooo`060=nLB000
07@0_ooo0?oog`2LB000B9cO2`3oool00`2oM000001809cOo`0_0?ooo`060=nLB00007@0_ooo0?oo
g`2LB000B9cO2@3oool0103ooml0W4P00000M02oool`0?ooo`060=nLB00007@0_ooo0?oog`2LB000
B9cO1`3oool00`3ooml0W4P004RLg`020?ooo`030;md0000M;l0oooo03H0oooo00<0_g@0001d_`3o
ool0403oool004T0oooo00@0gia800000000000007Bo>03oool0103OW4P0000000000000M;l90?oo
o`050?oOW018000000000000001d_ol0<@3oool0103OW4P0000000000000M;l<0?ooo`030?oog`2L
B000B9cO0300oooo00@0gia800000000000007Bo303oool0103ookl0M00000000018W=l_0?ooo`04
0=nLB00000000000001d_`T0oooo00D0oooO09a8000000000000001d_`0f0?ooo`050?oo_`1d0000
00000000M02oool0403oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo
[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo
[03oool004@0ooooo`00001N000000X0oooo00140?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`00=P3oool0102oM00000000000001d_ol:0?ooo`030000003oool0oooo0?l0ooooFP3oool00`00
0000oooo0?ooo`080?ooo`00=@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`T0oooo00<00000
0?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo00P0oooo000d0?ooo`030?oog`2LB000B9cO
0080oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?oo
o`3oool0203oool003@0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool70?oo
o`030000003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`080?ooo`00=03oool00`3ooml0
W4P0001d_`030?ooo`030=nLB00004P0W=oo00L0oooo00<000000?ooo`0000000`00000C0?ooo`@0
0000503oool4000001@0oooo1000000C0?ooo`@00000503oool4000001@0oooo1000000D0?ooo`@0
00004`3oool4000001@0oooo1000000D0?ooo`@000004`3oool4000001@0oooo1000000C0?ooo`@0
00008`3oool00`000000oooo0?ooo`080?ooo`00=@3oool00`2oM00004RL0=ooo`020?ooo`030?oO
W0180000B9cO00L0oooo2P00000?0?ooo`P00000403oool800000100oooo2000000?0?ooo`P00000
403oool800000100oooo2000000@0?ooo`P000003`3oool800000100oooo2000000@0?ooo`P00000
3`3oool800000100oooo2000000?0?ooo`P000005`3oool00`000000oooo0?ooo`030?ooo`<00000
2P3oool003D0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`030000003o
ool0000000D000004@3oool600000180oooo1P00000B0?ooo`H000004@3oool600000180oooo1P00
000B0?ooo`H000004P3oool600000140oooo1P00000B0?ooo`H000004P3oool600000140oooo1P00
000B0?ooo`H000004@3oool600000240oooo00<000000?ooo`3oool0203oool003D0oooo00<0omnL
04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`040000003oool00000000001D0oooo0P00
000F0?ooo`8000005P3oool2000001D0oooo0P00000F0?ooo`8000005P3oool2000001H0oooo0P00
000E0?ooo`8000005P3oool2000001H0oooo0P00000E0?ooo`8000005P3oool2000001D0oooo0P00
000U0?ooo`030000003oool0oooo00P0oooo000e0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool01P3oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool0203o
ool003H0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`060?ooo`030000003oool0
oooo0?l0ooooFP3oool00`000000oooo0?ooo`080?ooo`00=`3oool01P3OW4P0001d0;ooo`3ooml0
W4P004RLg`L0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo00P0oooo000h
0?ooo`040=nLB00000000000001d_`P0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003o
ool0oooo00P0oooo00140?ooo`030000003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`08
0?ooo`00A03oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool0203oool004@0
oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000
003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?oo
o`3o0?oooeX0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0o`3ooomJ
0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo0?l0ooooFP3oool00`00
0000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3o
ool0203oool004@0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo00P0oooo
00140?ooo`030000003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`080?ooo`00A03oool2
00000?l0ooooFP3oool2000000X0oooo00140?ooo`030000003oool0oooo0?l0ooooFP3oool00`00
0000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3o
ool0203oool004@0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo00P0oooo
00140?ooo`030000003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`080?ooo`00A03oool0
0`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?oo
o`3oool05P3oool4000001@0oooo1000000D0?ooo`@000004`3oool4000001@0oooo1000000D0?oo
o`@00000503oool4000001<0oooo1000000D0?ooo`@000004`3oool4000001@0oooo1000000D0?oo
o`@000004`3oool4000002<0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3o
ool01@3oool2000000l0oooo2000000@0?ooo`P00000403oool8000000l0oooo2000000@0?ooo`P0
0000403oool800000100oooo2000000?0?ooo`P00000403oool8000000l0oooo2000000@0?ooo`P0
0000403oool8000000l0oooo2000000G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool004@0oooo00<000000?ooo`3oool01@3oool2000000l0oooo1P00000B0?ooo`H00000
4P3oool600000140oooo1P00000B0?ooo`H000004P3oool600000180oooo1P00000A0?ooo`H00000
4P3oool600000140oooo1P00000B0?ooo`H000004P3oool600000140oooo1P00000Q0?ooo`030000
003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00@0oooo0P00000@0?ooo`8000005P3o
ool2000001H0oooo0P00000E0?ooo`8000005P3oool2000001H0oooo0P00000F0?ooo`8000005@3o
ool2000001H0oooo0P00000E0?ooo`8000005P3oool2000001H0oooo0P00000E0?ooo`8000009@3o
ool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`030?ooo`<00000o`3ooomD
0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00<0oooo0`00003o0?oo
oe@0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool00P3oool400000?l0
ooooE03oool00`000000oooo0?ooo`080?ooo`00A03oool010000000oooo0?ooo`3oool400000?l0
ooooE@3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`030?ooo`800000
o`3ooomE0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo0?l0ooooFP3o
ool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`3o0?oooeX0oooo00<00000
0?ooo`3oool0203oool004@0oooo0P00003o0?oooeX0oooo0P00000:0?ooo`00A03oool00`000000
oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0
o`3ooomJ0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo0?l0ooooFP3o
ool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`3o0?oooeX0oooo00<00000
0?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo
00P0oooo00140?ooo`030000003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`080?ooo`00
A03oool00`000000oooo0?ooo`3o0?ooocT0oooo1000000M0?ooo`030000003oool0oooo00P0oooo
00140?ooo`030000003oool0oooo0?l0oooo7`3oool00`000000oooo0?ooo`0G0?ooo`@000006@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00140?ooo`030000003oool0oooo0?l0oooo7P3o
ool3000001P0oooo0`00000I0?ooo`<000000P3oool00`000000oooo0?ooo`080?ooo`00A03oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0E0?ooo`<00000603oool3000001T0oooo0`0000020?ooo`030000003oool0
oooo00P0oooo00140?ooo`030000003oool0oooo04L0oooo0`00000D0?ooo`<000005@3oool30000
01@0oooo0P00000F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool30000
01@0oooo0`00000E0?ooo`<000005@3oool5000001P0oooo0P00000H0?ooo`D0000000<0oooo0000
003oool02@3oool004@0oooo00<000000?ooo`3oool0AP3oool500000180oooo1@00000C0?ooo`D0
00004`3oool4000001@0oooo0`00000E0?ooo`<00000503oool500000180oooo1@00000D0?ooo`D0
0000503oool5000001L0oooo0P00000G0?ooo`D000000P3oool00`000000oooo0?ooo`080?ooo`00
A03oool00`000000oooo0?ooo`0F0?ooo`@00000503oool4000001@0oooo1`00000@0?ooo`L00000
4@3oool700000140oooo1P00000A0?ooo`H000004P3oool600000180oooo1`00000@0?ooo`L00000
4@3oool7000001D0oooo0`00000G0?ooo`030000003oool0oooo01H0oooo0`0000040?ooo`030000
003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00D0oooo0P00000?0?ooo`P00000403o
ool8000001@0oooo1000000?0?ooo`P00000403oool800000100oooo2000000?0?ooo`P00000403o
ool800000100oooo2000000?0?ooo`P00000503oool4000001H0oooo0P00000F0?ooo`030000003o
ool0oooo01D0oooo0P0000060?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0
oooo00D0oooo0P00000?0?ooo`H000004P3oool600000?l0oooo9P3oool00`000000oooo0?ooo`08
0?ooo`00A03oool00`000000oooo0?ooo`050?ooo`8000003`3oool2000001H0oooo0P00003o0?oo
obX0oooo00<000000?ooo`3oool0203oool004@0oooo0P0000050?ooo`<00000o`3ooomB0?ooo`80
00002P3oool004@0oooo00<000000?ooo`3oool0103oool300000?l0ooooD`3oool00`000000oooo
0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`030?ooo`@00000o`3ooomC0?ooo`030000003o
ool0oooo00P0oooo00140?ooo`030000003oool0oooo00<0oooo1000003o0?oooe<0oooo00<00000
0?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool01@3oool200000?l0ooooD`3oool00`00
0000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3o
ool0203oool004@0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo00P0oooo
00140?ooo`030000003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`080?ooo`00A03oool0
0`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?oo
o`3oool0o`3ooomJ0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo0?l0
ooooFP3oool00`000000oooo0?ooo`080?ooo`00:03oool0102oM00000000000001d_ol30?ooo`03
0?oOW0180000M;oo0080oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`070?ooo`03
0000003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`080?ooo`009`3oool01P3OW4P007Bo
0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?oo
o`030;mdM02oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo
00P0oooo000V0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3o_g@0
07Bo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`080?ooo`00
9P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0okmd001d_`3o
ool02P3oool00`000000oooo0?ooo`3o0?ooob40oooo1000000D0?ooo`@000007@3oool00`000000
oooo0?ooo`080?ooo`009P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00T0oooo
00<0okmd04RLg`3oool02@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool0
5`3oool4000001@0oooo1000000M0?ooo`030000003oool0oooo00P0oooo000W0?ooo`030;md0000
B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`080?ooo`<00000o`3o
ool60?ooo`<000006@3oool3000001@0oooo0`00000L0?ooo`<000002P3oool002L0oooo00<0gia8
0000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo00L0oooo00<00000
0?ooo`3oool0Y@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`<000006@3oool3000001@0oooo0`00000K
0?ooo`040000003oool0oooo000000X0oooo000W0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@0
0018W03Oool02P3oool00`3ogi`0B01d0;ooo`070?ooo`030000003oool0oooo0:D0oooo0`00000E
0?ooo`<000005@3oool3000001@0oooo0`00000E0?ooo`D00000603oool2000001H0oooo0P00000J
0?ooo`<0000000<0oooo0000003oool02@3oool002L0oooo00@0oooO09a80000B9`0gooo0P3oool0
0`3OW4P004RL0=ooo`0:0?ooo`030?oog`2LB000M;oo00L0oooo00<000000?ooo`3oool0;P3oool2
000001H0oooo0P00000E0?ooo`8000005P3oool2000001H0oooo0P00000E0?ooo`D000004`3oool5
000001<0oooo1@00000C0?ooo`D00000503oool5000001L0oooo0P00000F0?ooo`800000603oool5
000000030?ooo`000000oooo00T0oooo000X0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d
_`3oool02P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool09P3oool600000180oooo1P00000A0?ooo`H000004P3oool600000180oooo1P00000A0?oo
o`L000004@3oool700000140oooo1`00000@0?ooo`L000005@3oool3000001P0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0F0?ooo`P000002P3oool002T0oooo00H0gia80000M02o
ool0oooO09a80018W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`P00000
403oool8000000l0oooo2000000@0?ooo`P00000403oool8000000l0oooo2000000@0?ooo`P00000
403oool8000001<0oooo1000000F0?ooo`8000005`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01D0oooo100000040?ooo`030000003oool0oooo00P0oooo000Z0?ooo`040=nLB000
00000000001d_`T0oooo00D0omnL04P000000000000007Boo`080?ooo`030000003oool0oooo00D0
oooo0P00000D0?ooo`8000004@3oool600000180oooo1P00000A0?ooo`H000004P3oool600000180
oooo1P0000360?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00D0oooo
0P00000C0?ooo`<000004@3oool2000001H0oooo0P00000E0?ooo`8000005P3oool2000001H0oooo
0P00003:0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00@0oooo0`00
000A0?ooo`@00000o`3oooln0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0
oooo00@0oooo0`00000@0?ooo`@00000o`3ooolo0?ooo`030000003oool0oooo00P0oooo00140?oo
o`030000003oool0oooo00@0oooo1000000@0?ooo`<00000o`3ooolo0?ooo`030000003oool0oooo
00P0oooo00140?ooo`030000003oool0oooo00@0oooo1000000A0?ooo`030000003oool0oooo0?l0
oooo?P3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`3o0?oooeX0oooo
00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003o
ool0oooo00P0oooo00140?ooo`030000003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`08
0?ooo`00A03oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool0203oool004@0
oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo00P0oooo00140?ooo`800000
E`3oool;000004T0oooo0`00001@0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
103oool2000000X0oooo00140?ooo`030000003oool0oooo0640oooo2`0000110?ooo`H00000B`3o
ool200000500oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`00A03oool0
0`000000oooo0?ooo`1/0?ooo`T00000?P3oool6000004L0oooo0P00001=0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0M@3oool90000
03/0oooo1P0000130?ooo`800000B@3oool2000000X0oooo00<000000?ooo`3oool0203oool004@0
oooo00<000000?ooo`3oool0OP3oool8000003T0oooo100000110?ooo`800000AP3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo08H0oooo
2000000e0?ooo`@00000?`3oool2000004<0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`2>0?ooo`P00000<@3oool3000003h0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo0014
0?ooo`030000003oool0oooo09H0oooo2000000/0?ooo`@00000>`3oool2000003h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`2N0?oo
o`P00000:03oool4000003T0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0;0?oo
o`040000003oool0oooo000000X0oooo00140?ooo`030000003oool0oooo05l0oooo0`0000140?oo
o`H000009P3oool3000003L0oooo00<000000?ooo`3oool0=`3oool2000000d0oooo0`0000000`3o
ool000000?ooo`090?ooo`00A03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04P0
oooo3`0000030?oooaD000005P3oool2000001D0oooo0P0000060?ooo`@00000303oool2000001H0
oooo1@00000B0?ooo`800000803oool00`000000oooo0?ooo`0H0?ooo`8000005@3oool2000000@0
oooo00<000000?ooo`3oool02`3oool5000000030?ooo`000000oooo00T0oooo00140?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0@P3oool6000000d0oooo1P00000B0?ooo`P00000
403oool600000140oooo1P0000060?ooo`@00000203oool600000180oooo2000000?0?ooo`H00000
7@3oool00`000000oooo0?ooo`0C0?ooo`H000004@3oool6000000<0oooo00<000000?ooo`3oool0
2`3oool8000000X0oooo00140?ooo`030000003oool0oooo00D0oooo0P00000F0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool03`3oool3000000<0oooo00<000000?ooo`3oool03@3o
ool800000100oooo3P00000:0?ooo`P000003`3oool8000000P0oooo1@0000030?ooo`P00000403o
ool<000000/0oooo2000000G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool8000000l0oooo200000020?ooo`030000003oool0oooo00/0oooo100000040?ooo`030000003o
ool0oooo00P0oooo00140?ooo`030000003oool0oooo00D0oooo0P00000F0?ooo`030000003oool0
oooo01<0oooo0P00000@0?ooo`800000103oool200000100oooo1P00000B0?ooo`H00000203oool8
00000080oooo1P00000A0?ooo`H000003`3oool900000180oooo1P0000060?ooo`@000001`3oool6
000001l0oooo00<000000?ooo`3oool04@3oool600000140oooo1P0000000`3oool000000?ooo`0E
0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00@0oooo0`00000E0?oo
o`<000004`3oool3000000h0oooo0P0000040?ooo`@00000403oool2000001H0oooo0P00000D0?oo
o`P000004@3oool2000001H0oooo1@00000C0?ooo`8000003P3oool3000000@0oooo0P00000S0?oo
o`030000003oool0oooo01D0oooo0P00000E0?ooo`<000005`3oool00`000000oooo0?ooo`080?oo
o`00A03oool00`000000oooo0?ooo`040?ooo`<000005@3oool300000140oooo1000000>0?ooo`03
0000003oool0oooo0080oooo1@0000170?ooo`L000009`3oool400000280oooo0P00000X0?ooo`03
0000003oool0oooo02/0oooo0P00000H0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000
003oool0oooo00@0oooo1000000D0?ooo`<00000403oool4000000d0oooo0P0000040?ooo`D00000
C`3oool6000002D0oooo1000000P0?ooo`8000009`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0203oool004@0oooo0P0000050?ooo`@00000503o
ool300000140oooo0`00000<0?ooo`030000003oool0oooo00D0oooo1000001E0?ooo`L000008P3o
ool4000001h0oooo0`00000T0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0603o
ool2000000X0oooo00140?ooo`030000003oool0oooo01/0oooo1@00000A0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1K0?ooo`H00000803oool4
000001d0oooo0P00000S0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`0K0?ooo`D000007@3oool00`00
0000oooo0?ooo`1]0?ooo`@00000803oool3000001`0oooo0P00000Q0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo0780oooo1@00000N0?ooo`<000006`3oool2000001l0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00P0
oooo00140?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0N03oool5000001`0oooo
0`00000J0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool2000001l0oooo
00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`1n0?ooo`@000006`3oool4000001L0oooo0P00000M0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo08<0oooo1000000K0?ooo`<000005P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`08
0?ooo`00A03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo08L0oooo0`00000K0?oo
o`8000005@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo08/0oooo0`00000J0?ooo`800000503oool2000001T0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0S`3oool3000001T0oooo0P00000D0?ooo`800000
603oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool004@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2B0?ooo`<00000603o
ool2000001@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`2F0?ooo`<000005`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0603oool2000002L0oooo00<000000?ooo`3oool0203oool0
04@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`2I0?ooo`<000005@3oool20000
0180oooo00<000000?ooo`3oool01`3oool5000000P0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0W03oool3000001@0oooo0P0000000`3oool000000?ooo`0>0?ooo`03
0000003oool0oooo00H0oooo1@0000080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0203oool004@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`D00000
4`3oool300000100oooo00<000000?ooo`3oool01P3oool3000000P0oooo00<000000?ooo`3oool0
3@3oool4000000D0oooo00<000000?ooo`3oool0303oool3000001X0oooo00<000000?ooo`3oool0
203oool004@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1F0?ooo`8000005@3o
ool3000001D0oooo0`00000D0?ooo`D0000000@0oooo00000000000000003`3oool6000000l0oooo
00<000000?ooo`3oool01@3oool3000000P0oooo00<000000?ooo`3oool03@3oool5000000<0oooo
00<000000?ooo`3oool03@3oool4000001L0oooo00<000000?ooo`0000002P3oool004@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03T0oooo3`00
000=0?ooo`@00000503oool4000001@0oooo1000000D0?ooo`D000000`3oool2000000h0oooo1000
00000`3oool000000000000>0?ooo`030000003oool0oooo00@0oooo0`0000080?ooo`030000003o
ool0oooo00`0oooo1@0000030?ooo`030000003oool0oooo00d0oooo1000000F0?ooo`<0000000<0
oooo0000003oool02@3oool004@0oooo0P0000060?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool03P3oool2000001D0oooo0P0000090?ooo`T00000103oool2000000T0oooo2`000002
0?ooo`H000004@3oool600000180oooo1P00000E0?ooo`@00000103oool3000000d0oooo0`000002
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool3000000P0oooo00<00000
0?ooo`3oool0303oool3000000<0oooo0P00000?0?ooo`<000005`3oool6000000X0oooo00140?oo
o`030000003oool0oooo00D0oooo0P00000]0?ooo`030000003oool0oooo00l0oooo1P00000A0?oo
o`/000003@3oool600000100oooo2@00000@0?ooo`L000004@3oool7000001H0oooo0P0000070?oo
o`800000303oool2000000<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool3000000<0oooo00<000000?oo
o`3oool03`3oool2000001H0oooo2000000:0?ooo`00A03oool00`000000oooo0?ooo`050?ooo`80
00005P3oool00`000000oooo0?ooo`0D0?ooo`800000403oool8000000l0oooo2000000@0?ooo`P0
0000503oool;000000`0oooo1000000D0?ooo`@000005`3oool00`000000oooo0?ooo`060?ooo`80
0000303oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo2@00000:0?ooo`00A03oool00`000000
oooo0?ooo`040?ooo`<000005P3oool00`000000oooo0?ooo`0C0?ooo`8000004@3oool6000000l0
oooo2000000B0?ooo`H000008@3oool6000004@0oooo0P00000?0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0103oool3000001D0oooo
0`00000C0?ooo`<000004@3oool200000140oooo0P0000020?ooo`8000005P3oool2000002/0oooo
1P0000100?ooo`8000003P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00P0oooo
00140?ooo`030000003oool0oooo00@0oooo1000000D0?ooo`<000004@3oool5000002<0oooo00<0
00000?ooo`3oool0C@3oool5000003d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00@0oooo1000000D
0?ooo`<00000403oool500000280oooo0P00001E0?ooo`@00000>P3oool2000000`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo0P00000e
0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo01`0oooo0`00000A0?oo
o`@000008@3oool00`000000oooo0?ooo`1I0?ooo`@00000>03oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3o
ool06`3oool500000140oooo00<000000?ooo`0000007`3oool200000600oooo1000000e0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`080?ooo`00
A03oool00`000000oooo0?ooo`0K0?ooo`D000004`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo06@0oooo0`00000c0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0J03oool300000340oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00P0oooo000X0?ooo`040;md00000000
000007Boo`<0oooo00<0omnL04P0001d_ol01@3oool00`3ooml0W4P004RLg`0:0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1/0?ooo`<00000;`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0203o
ool002L0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00H0oooo
00<0gia80018W03Oool02@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0K`3oool4000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool2000003`0oooo
00<000000?ooo`3oool0203oool002H0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cO
o`0:0?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo07@0oooo0`00000Z0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`080?ooo`009P3oool00`3ooml0W4P004RLg`02
0?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0okmd000000000000100000000`00B9`0gooo0?oo
o`060?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0Y0?oooaP00000=`3oool3000002P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia8
0000B02Lgol01@3oool00`3ooml0W4Q809cOo`020?ooo`030;md0000M;l0oooo00P0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02<0oooo1`00000H
0?ooo`d00000;@3oool3000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00P0oooo000W0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P0
0018W=l01P3oool01`3ookl0M01d0;ooo`3oool0okmd0018W03Oool0203oool3000003<0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0P0?ooo`<00000;03oool5000002/0oooo0`00
000S0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?@3oool3000000X0oooo000W
0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool01P3ogi`0B4RL0=ooo`3o
gi`0B01809cOo`P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01h0oooo0`00000d0?ooo`@00000:P3oool200000280oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00P0oooo000N0?ooo`030;nLW03O
ool0oooo00H0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`050?noM000
M;l0oooO09a80018W=l0203oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool06`3oool3000003/0oooo1000000X0?ooo`800000803oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`800000@`3oool00`000000oooo0?ooo`080?ooo`00703oool0103ookl0M0000018
W03Oool70?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0203oool0103OW4P0
B9cO0;md0000M;l80?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0J0?ooo`800000@P3oool5000002D0oooo0P00000I0?ooo`@000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0203oool001P0
oooo00<0oono07@0000000000`0000000`00B9`0gooo0?ooo`070?ooo`030?oOW0180000M;oo0080
oooo00<0gia8001d_`3oool02@3oool0103OW4P0M7Ad0000M02oool70?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?ooo`800000B@3oool50000
0240oooo0`00000G0?ooo`@000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`080?ooo`004P3oool0103ookl0W9cO0?oo_`1d000400000006001d_`3oool0oooo
0?ooo`2oW9`0gooo2@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`/0oooo00<0_g@00000B02L
gol01`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`1>0?ooo`@000006`3oool4000000030?ooo`000000000001D0
oooo0`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`@0000000<0oooo0000003oool0503oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00180oooo00D0omnL04P000000000
0000001d_`030?ooo`030;mdM02oool0oooo00d0oooo00@0gia800000000000007Bo303oool00`3o
oml0W4P004RLg`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01H0oooo0P00001E0?ooo`<000005`3oool50000
00<0oooo00<000000?ooo`3oool04P3oool3000000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`00000E0?oo
o`<000005@3oool2000001T0oooo00<000000?ooo`3oool0203oool001<0oooo00<0oono07A8W03O
ool0103oool00`3OW9`0_ooo0?ooo`0W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo0P00001J0?ooo`<0
00005@3oool5000000<0oooo00<000000?ooo`3oool04P3oool2000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo1@00000E0?ooo`@0
0000503oool4000001H0oooo00<000000?ooo`0000002P3oool00180oooo00<0oooO09a8M02oool0
103oool00`3ookl0M7Bo0?ooo`0X0?ooo`030000003oool0oooo00D0oooo0P00000/0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`800000
5P3oool2000001D0oooo0P00000F0?ooo`8000000P3oool3000001@0oooo100000030?ooo`800000
4P3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo100000000`3oool000000?ooo`0C0?ooo`H000004@3oool6000001@0oooo
0`0000000`3oool000000?ooo`090?ooo`004P3oool00`3ogi`0M9cO0?ooo`030?ooo`030?oo_`1d
07@0_ooo02T0oooo00<000000?ooo`3oool01@3oool2000001H0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3o
ool600000180oooo1P00000A0?ooo`H000004P3oool6000000040?ooo`0000000000000001<0oooo
0P0000050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool3000000030?oo
o`000000oooo01<0oooo1@00000B0?ooo`D00000503oool7000000X0oooo000B0?ooo`080?noM000
M;l0oooo0?ooo`3ooml0W4P00000M02ooolZ0?ooo`030000003oool0oooo00@0oooo0`00000F0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?oo
o`P00000403oool8000000l0oooo2000000@0?ooo`P000000P3oool300000180oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000020?oo
o`030000003oool0oooo0180oooo0P00000E0?ooo`8000005P3oool9000000X0oooo000C0?ooo`05
0;md0000000000000000B02Lgol0;03oool00`000000oooo0?ooo`040?ooo`<000005@3oool30000
01@0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo00@000000?ooo`3oool0oooo0P00000A0?ooo`H000004P3oool600000140oooo1P00000B
0?ooo`H000001`3oool2000001L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0103oool4
000001@0oooo0`00000D0?ooo`@000004@3oool010000000oooo0?ooo`3oool2000000l0oooo00@0
00000?ooo`3oool0oooo0`00000A0?ooo`8000005P3oool2000001D0oooo0P00000F0?ooo`800000
3@3oool3000001D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00001=0?ooo`030000003oool0oooo
00P0oooo00140?ooo`030000003oool0oooo00@0oooo1000000D0?ooo`<00000503oool400000140
oooo00@000000?ooo`3oool0oooo0P00000>0?ooo`030000003oool0oooo00@00000J`3oool20000
01@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000004d0oooo00<000000?ooo`3oool0203o
ool001P0oooo00@0oono07@0000007@0_ooo:03oool00`000000oooo0?ooo`0L0?ooo`<00000503o
ool400000140oooo00@000000?ooo`3oool0oooo0`00000<0?ooo`030000003oool0oooo00D00000
K@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000CP3oool00`00
0000oooo0?ooo`080?ooo`004P3oool0103ookl0W9cO0?oo_`1d00040000000307Boo`3oool0oooo
02L0oooo00<000000?ooo`3oool06`3oool5000001<0oooo1000000A0?ooo`040000003oool0oooo
0?ooo`<00000303oool010000000oooo0?ooo`3oool3000006l0oooo0P00000C0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool00000C`3oool00`000000oooo0?ooo`080?ooo`004P3oool01P3ogi`0B000
000000000000001809cOob`0oooo00<000000?ooo`3oool06`3oool5000001<0oooo1@00000@0?oo
o`030000003oool0oooo00@00000303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001@0?ooo`030000003o
ool0oooo00P0oooo000C0?ooo`030?oo_`1d0000M;oo02h0oooo0P00000d0?ooo`D00000403oool0
0`000000oooo0?ooo`04000000/0oooo00<000000?ooo`3oool0<P3ooolI000002`0oooo0P00000A
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool000000500oooo0P00000:0?ooo`004`3oool00`2oM7@0_ooo0?ooo`0^
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo02`0oooo1P00000I0?ooo`D00000:@3oool200000100oooo00<00000
0?ooo`3oool03P3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool000000580oooo00<000000?ooo`3oool0203oool00180oooo00@0okmd00000000B9`0
gooo;P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0Y0?ooo`@00000903oool6000002D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0203oool0
04@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool09@3oool4000002h0oooo1000000R0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000020?ooo`070000003oool0
oooo0?ooo`000000oooo0000001C0?ooo`030000003oool0oooo00P0oooo000E0?ooo`060=nLB000
000000000000000004P0W=oo:@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0R0?ooo`<00000=P3oool300000200
oooo0P00000=0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000005@0oooo00<000000?ooo`3oool0203oool001<0oooo00T0oono
07@00018W=l0omnL09boo`3oool0gia80018W03Oool0:03oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?ooo`80
0000?03oool4000001h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`04
0000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`00001E0?ooo`030000003o
ool0oooo00P0oooo000C0?ooo`090;mdM02oool0oooo0?noW02Lgol0oooo0?oo_`1d07@0_ooo02P0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`100?ooo`<00000703oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`02000005H0oooo00<000000?ooo`3oool0203oool00180oooo00T0omnL09boo`3o
ool0oooO09adW03Oool0oooo0?oOW018M;l0:@3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0N0?ooo`800000AP3o
ool2000001/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool000000080oooo00H000000?ooo`3oool000000?ooo`00001F0?ooo`030000003oool0oooo00P0
oooo000B0?ooo`090?noW02Lgol0oooo0;md001d_ol0oooo0=nLB00007@0_ooo02T0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`180?ooo`8000006@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`02000005L0oooo00<000000?ooo`3oool0203oool00180oooo00@0oono07@000000000M;oo;P3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04/0oooo0P00000H0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00800000F03oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo04h0oooo0P00000F0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool01@000000oooo0000003oool000000080oooo0P00001I0?ooo`030000003o
ool0oooo00P0oooo000F0?ooo`050=nLB000000000000000001d_ol0:@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01X0oooo0P00001C0?ooo`8000005@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000P3oool010000000oooo0?oo
o`00001J0?ooo`030000003oool0oooo00P0oooo000D0?ooo`030?oOW0180000B9cO0080oooo00<0
omnL04P0M02oool0:03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0E@3oool2000001<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`050000003oool000000?ooo`0000000P3oool2000002P0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`080?ooo`004`3oool00`3ogi`0B4RL0=ooo`030?ooo`030?oo_`1d
B9`0gooo02P0oooo00<000000?ooo`3oool01@3oool2000002`0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0E`3o
ool200000180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`050000003o
ool000000?ooo`0000000P3oool2000002P0oooo0`00000F0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0203oool00180oooo00<0oooO09adW03Oool0103oool00`2oM000M;oo0?oo
o`0X0?ooo`030000003oool0oooo00D0oooo0P00000/0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00H0
00000?ooo`000000oooo0000003oool2000002P0oooo1000000D0?ooo`<000005`3oool00`000000
oooo0000000:0?ooo`004P3oool00`3ogkl0_moo0?ooo`020?ooo`030?oog`2LB000M;oo02X0oooo
00<000000?ooo`3oool0103oool3000002d0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;`3oool2000001H0oooo
0P00000B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`060000003oool000000?ooo`000000oooo0P00000D0?ooo`8000004P3oool60000
0180oooo1@00000D0?ooo`<0000000<0oooo0000003oool02@3oool00180oooo00X0okmd07Boo`3o
ool0oooo0?oOW01804P0W=no07@00000B9`0gooo:03oool00`000000oooo0?ooo`040?ooo`<00000
5P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0300oooo3@00000;0?ooo`H00000
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0000003oool300000140oooo1P00000A0?ooo`D000004P3oool700000180
oooo1`00000:0?ooo`004P3oool00`3ooml0W4P000000005000000030018W03Oool0oooo02L0oooo
0P0000050?ooo`@000005@3oool00`000000oooo0?ooo`0D0?ooo`8000004@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`060?oooa/00000103oool8000000h0oooo0P0000070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000003oool0
0`0000030?ooo`030000003oool0oooo00X0oooo2000000@0?ooo`8000005@3oool4000001<0oooo
2P00000:0?ooo`003P3oool0102oW9`0gooo0?oo_`1d00040000000507Boo`3oool0oooo0;mdM02o
ool0:@3oool00`000000oooo0?ooo`040?ooo`@00000503oool3000001D0oooo0P00000A0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool04`3oool2000000H0oooo0`0000070?ooo`h0
00000`3oool=00000180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo0P0000001@3oool000000000003oool000000080oooo00<000000?oo
o`3oool03@3oool6000003/0oooo0`0000090?ooo`030000003oool0oooo00P0oooo000=0?ooo`03
0?oog`2LB00000000080000000<0M;oo0?ooo`3oool0;`3oool00`000000oooo0?ooo`0L0?ooo`<0
00005@3oool300000100oooo00<000000?ooo`3oool00P3oool2000001D0oooo0`0000090?ooo`03
0000003oool0oooo00T0oooo0`00000B0?ooo`@000000`3oool3000000D0oooo1`00000<0?ooo`h0
00005@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool010000000oooo0000003oool300000080oooo00<000000?ooo`3oool04P3oool20000
03L0oooo1000000<0?ooo`030000003oool0oooo00P0oooo000=0?ooo`030?oo_`2LW=l0oooo03@0
oooo00<000000?ooo`3oool0703oool3000001D0oooo0`00000@0?ooo`030000003oool0oooo0080
oooo0P00000E0?ooo`<000002@3oool00`000000oooo0?ooo`090?ooo`<00000403oool500000080
oooo0P0000050?ooo`<000006@3oool:000001<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`000000oooo0`0000020?oo
o`030000003oool0oooo04T0oooo0`00000@0?ooo`030000003oool0oooo00P0oooo000F0?ooo`05
0;md00000000000000000018W=l0:@3oool00`000000oooo0?ooo`0L0?ooo`<000005@3oool30000
0100oooo00<000000?ooo`3oool00P3oool3000001@0oooo0`0000080?ooo`030000003oool0oooo
00X0oooo0`00000?0?ooo`D0000000<0oooo000000000000103oool300000280oooo1P00000B0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`80000000@0oooo00000000000000000P3oool00`000000oooo0?ooo`170?ooo`<000004`3oool0
0`000000oooo0?ooo`080?ooo`00503oool00`3OW4P0000007Boo`020?ooo`030?oOW01807@0_ooo
02P0oooo00<000000?ooo`3oool06`3oool5000001@0oooo0`00000@0?ooo`030000003oool0oooo
0080oooo0`00000D0?ooo`<00000203oool00`000000oooo0?ooo`0:0?ooo`<00000403oool50000
00@0oooo0P00000W0?ooo`H000004@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool2000000040?ooo`000000000000000080oooo00<00000
0?ooo`3oool0A@3oool3000001H0oooo00<000000?ooo`3oool0203oool001<0oooo00<0gia804RL
g`3oool00`3oool00`3ogi`0B7Bo0?ooo`0X0?ooo`030000003oool0oooo01/0oooo1@00000C0?oo
o`D000003`3oool010000000oooo0?ooo`3oool4000001<0oooo1@0000060?ooo`030000003oool0
oooo00X0oooo1@00000@0?ooo`800000103oool2000002/0oooo1P00000?0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000<000000P3oool00`000000oooo0?ooo`120?ooo`@000006@3oool00`000000oooo0?ooo`08
0?ooo`004P3oool00`3ogi`0M9cO0?ooo`030?ooo`030?noW018M9`0gooo02T0oooo00<000000?oo
o`3oool0<`3oool5000000l0oooo00@000000?ooo`3oool0oooo1000000C0?ooo`D000001P3oool0
0`000000oooo0?ooo`0:0?ooo`D000003`3oool00`000000oooo0?ooo`020?ooo`800000;`3oool6
000000d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000000P000000103oool000000?ooo`0000120?ooo`<000007@3o
ool00`000000oooo0?ooo`080?ooo`004P3oool00`3o_g@007Bo0?ooo`020?ooo`050?oOW018M7@0
M0000018W03Oool0:03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0L0?ooo`8000000`3oool2000003@0oooo0P00
00000`3oool000000?ooo`0;0?ooo`800000203oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000P000000103oool000000?ooo`0000100?ooo`<00000
803oool00`000000oooo0?ooo`080?ooo`004`3oool00`3o_g@0000000000004000000030018W03O
ool0oooo02L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo4P00000=0?ooo`8000003@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000040?ooo`00
0000oooo000003h0oooo0`00000S0?ooo`030000003oool0oooo00P0oooo000B0?ooo`050?oOW018
0000000000000018W=l00P3oool00`2oM4P0W=oo0?ooo`0X0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`@000004P3oool4000000X0oooo
0P00000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080000000@0oooo0000003oool00000>`3oool4000002H0
oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0180oooo0`00000J0?ooo`8000002@3oool3000000X0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00P000000?ooo`00
000000000?ooo`000000oooo000003T0oooo0`00000Z0?ooo`030000003oool0oooo00P0oooo0014
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`8000007`3o
ool2000000P0oooo0P00000:0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000050?ooo`050000003oool000000000003oool00`00000g0?ooo`<00000;@3oool00`000000
oooo0?ooo`080?ooo`004P3oool01@3ogkl0_moo0?ooo`3oool0_g@000<0000000<0001d0;ooo`3o
ool09`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0Q0?ooo`8000001`3oool2000000T0oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000001000000f0?oo
o`<00000<03oool00`000000oooo0?ooo`080?ooo`004P3oool00`2oM00000000000000200000005
0000M02oool0oooo0;nLW03Oool0:03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0oooo
0?ooo`0000004@3oool2000002H0oooo0P0000050?ooo`<00000203oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`000000103oool7000003@0oooo0`00000c0?ooo`030000003o
ool0oooo00P0oooo000@0?ooo`050;md0000000000000018W03Oool00`3oool00`3ooml0W4P007Bo
o`0Y0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`800000
:P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo000000@0oooo0P0000001@3oool000000000003oool000000340oooo1000000f0?oo
o`030000003oool0oooo00P0oooo000B0?ooo`030?noW02Lgol0oooo02l0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`000000403oool00`00
0000oooo0?ooo`0E0?ooo`d000002@3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo0P0000000`3oool0000000000002
000002l0oooo0`00000j0?ooo`030000003oool0oooo00P0oooo00140?ooo`8000001P3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0C
0?ooo`<000000`3oool=000000H0oooo0P0000030?ooo`8000001`3oool00`000000oooo00000003
000000050?ooo`000000oooo0?ooo`0000000`3oool6000002h0oooo0`00000l0?ooo`8000002P3o
ool001D0oooo00H0omnL04P00000000000000000B02LgolY0?ooo`030000003oool0oooo00D0oooo
0P00000_0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0H0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool04P3oool2000000<0
oooo0`00000:0?ooo`@000001P3oool010000000oooo0?ooo`3oool2000000H0oooo00<000000?oo
o`3oool01@0000020?ooo`040000003oool0oooo0?ooo`H00000303oool00`000000oooo0?ooo`0M
0?ooo`<00000@03oool00`000000oooo0?ooo`080?ooo`00503oool00`2oM000000007Boo`020?oo
o`030?oog`2LM9`0gooo02P0oooo00<000000?ooo`3oool01@3oool2000002l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01L0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000`00000@
0?ooo`<00000103oool010000000oooo0?ooo`3oool2000000H0oooo00@000000?ooo`3oool0oooo
0`0000020?ooo`040000003oool0oooo0?ooo`H00000303oool3000001L0oooo00<000000?ooo`3o
ool0100000130?ooo`030000003oool0oooo00P0oooo000C0?ooo`030=nLB018W=l0oooo00@0oooo
00<0gibL0;ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`<00000<03oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05`3oool01@000000oooo
0?ooo`3oool0000000h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000F0?ooo`80
00000`3oool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool00P3oool30000
00030?ooo`000000oooo0080oooo1@00000>0?ooo`@000005@3oool4000001D0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo000B0?ooo`03
0?oOW01dW=l0oooo00@0oooo00<0oooO09adW03Oool0:03oool00`000000oooo0?ooo`040?ooo`<0
0000<03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool05`3oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool03`3oool20000
0080oooo00<000000?ooo`3oool05@3oool200000080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00<0oooo0P0000000`3oool000000?ooo`020?ooo`D000003P3oool4
000001@0oooo1@00000D0?ooo`@00000503oool3000001L0oooo00<000000?ooo`0000002P3oool0
0180oooo00<0oknL09cOo`3oool00`3oool00`3ooml0W4P007Boo`0Y0?ooo`030000003oool0oooo
00@0oooo1000000_0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`000000103oool2000000P0oooo00<00000
0?ooo`3oool02P3oool2000000<0oooo00<000000?ooo`3oool00P00000H0?ooo`8000000P3oool0
0`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool00`3oool4000000<0oooo1@00000>
0?ooo`<000004`3oool900000180oooo1@00000C0?ooo`D00000503oool3000000030?ooo`000000
oooo00T0oooo000B0?ooo`030?oOW018M;l0oooo0080oooo00<0gia800000018W=l0:P3oool00`00
0000oooo0?ooo`040?ooo`@000005@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool00000
0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo
0?ooo`000000103oool6000000<0oooo00<000000?ooo`3oool02`3oool6000000030?ooo`000000
oooo0180oooo1@0000020?ooo`8000000P3oool010000000oooo0000000000040?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool500000100oooo0P00000@0?ooo`@00000
0P3oool500000180oooo2000000@0?ooo`L000004P3oool7000000X0oooo000C0?ooo`060?noM000
0000000000000000B9`0gooo:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0000000A0?ooo`030000003oool0oooo0080
00005P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01@3oool010000000oooo0?ooo`0000050?ooo`P0000000<0oooo0000003oool0303oool80000
0140oooo0P0000000`3oool000000000000200000080oooo0P0000000`3oool000000?ooo`020000
00@0oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000000`3oool00000000000030000
0100oooo00<000000?ooo`3oool03@3oool3000000D0oooo0P00000E0?ooo`D000004`3oool40000
01@0oooo2@00000:0?ooo`00A03oool00`000000oooo0?ooo`0M0?ooo`8000005P3oool300000140
oooo00D000000?ooo`3oool0oooo0000000F0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000D0oooo10000004
0?ooo`030000003oool0oooo00`0oooo100000000`3oool000000?ooo`0B0?ooo`030000003oool0
000000T0000000<0oooo000000000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080000000<0oooo0000000000000`00000O0?ooo`<00000E`3oool00`000000oooo0?ooo`08
0?ooo`00A03oool00`000000oooo0?ooo`0M0?ooo`8000005P3oool300000140oooo00<000000?oo
o`3oool00P00000E0?ooo`<000001@3oool00`000000oooo0?ooo`0=0?ooo`<000001P3oool01000
0000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`0<000000@0oooo00@000000?ooo`3oool0oooo0P000000103oool00000
0000003oool6000001h0oooo0P00001J0?ooo`030000003oool0oooo00P0oooo000H0?ooo`040?oo
_`1d0000001d0;ooobP0oooo00<000000?ooo`3oool0703oool3000001D0oooo1000000B0?ooo`04
0000003oool00000000001D0oooo0`0000050?ooo`030000003oool0oooo00d0oooo0`0000060?oo
o`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0oooo00X000000P3oool4000000<0oooo100000000`3oool000000000
0004000001d0oooo0`00001L0?ooo`030000003oool0oooo00P0oooo000B0?ooo`040?oo_`2LW=l0
oono07@000@0000000<0M;oo0?ooo`3oool02`3oool0102oM00000000000001d_ol30?ooo`030?oO
W0180000M;oo00<0oooo00D0oooO09a8000000000000001d_`0:0?ooo`030000003oool0oooo01`0
oooo0`00000E0?ooo`@000004P3oool00`000000oooo00000002000001@0oooo0`0000060?ooo`03
0000003oool0oooo00`0oooo0`0000050?ooo`050000003oool0oooo0?ooo`0000003@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool0300000040?oo
o`@0000000<0oooo0000000000001@00000M0?ooo`800000G`3oool00`000000oooo0?ooo`080?oo
o`004P3oool01P3ogi`0B000000000000000001809cOo`l0oooo00H0gia8001d_`3oool0omnL04P0
0018W=l20?ooo`030?oOW0180000M;oo00<0oooo00L0gia8001d_`3oool0oono07@00000B9`0gooo
00P0oooo00<000000?ooo`3oool0703oool4000001@0oooo1@00000A0?ooo`030000003oool00000
00800000503oool3000000H0oooo00<000000?ooo`3oool0303oool3000000D0oooo00D000000?oo
o`3oool0oooo0000000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000004`3oool0
10000000oooo0?ooo`3oool6000000<0oooo200000000`3oool0000000000005000001`0oooo0`00
001Q0?ooo`030000003oool0oooo00P0oooo000C0?ooo`030?oo_`1d0000M;oo0100oooo00<0oooO
09a80018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?oog`2LB000M;oo0080oooo00<0omnL
04P00018W=l0203oool00`000000oooo0?ooo`0L0?ooo`@00000503oool500000140oooo1@00000C
0?ooo`D000001@3oool00`000000oooo0?ooo`0;0?ooo`D00000103oool01@000000oooo0?ooo`3o
ool0000000d0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000C0?ooo`030000
003oool0oooo0080oooo5@00000M0?ooo`800000I03oool00`000000oooo0?ooo`080?ooo`004`3o
ool00`2oM7@0_ooo0?ooo`0@0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo
1@3oool00`3ookl0M00007Boo`030?ooo`030;md000007@0_ooo00L0oooo00<000000?ooo`3oool0
=03oool3000000030?ooo`000000oooo0100oooo1@00000C0?ooo`D000001@3oool00`000000oooo
0?ooo`0;0?ooo`D00000103oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool03P3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00<0oooo3`00000N0?oo
o`<00000IP3oool00`000000oooo0?ooo`080?ooo`004P3oool0103o_g@000000018W03Oool@0?oo
o`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P0001d_`030?oo
o`030=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0
000000`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000F0?ooo`030000003oool0
oooo00D0oooo2P00000N0?ooo`800000J@3oool00`000000oooo0?ooo`080?ooo`009`3oool00`2o
M00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0_g@00000M02oool00P3oool00`3O
W4P0001809cOo`070?ooo`<00000>03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0000000`0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0000000G0?ooo`030000003oool0oooo02T0oooo0`00001Y
0?ooo`<000002P3oool002L0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?oo
o`080?noM0000000B9cO0?ooo`3ooml0W4P00018W03Oool70?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo
00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`00
0000603oool00`000000oooo0?ooo`0U0?ooo`<00000KP3oool00`000000oooo0?ooo`080?ooo`00
9`3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00D0oooo00<0oooO09a800000000
0P0000000`0007@0_ooo0?ooo`070?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000006@3oool200000280
oooo0`00001a0?ooo`030000003oool0oooo00P0oooo000W0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool01P3oool00`3ookl0M000001d_`0;0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0
oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00h0oooo00@000000?oo
o`00000000006P3oool2000001/0oooo1@00001d0?ooo`030000003oool0oooo00P0oooo000X0?oo
o`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01`3oool00`3ogi`0B00004RLg`0:0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0>
0?ooo`040000003oool0oooo000001`0oooo0P00000D0?ooo`D00000N@3oool00`000000oooo0?oo
o`080?ooo`00:@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`T0oooo00@0oooO09a8000007@0
_ooo203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3o
ool00000303oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000001h0oooo5000001n
0?ooo`030000003oool0oooo00P0oooo000Z0?ooo`040=nLB00000000000001d_``0oooo00@0oono
07@000000000B9cO1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo00@0
00000?ooo`3oool00000303oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo00000;00
oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool01@3oool200000380oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo
00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
0;00oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool01@3oool2000003<0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo
00000:l0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0103oool30000
03<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0
oooo00000:l0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0103oool3
000003<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01<0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0?0?ooo`040000003o
ool0oooo00000:h0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0103o
ool400000380oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00l0oooo
00@000000?ooo`3oool00000I@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo
0?ooo`040?ooo`@00000<P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`00001S0?ooo`<000005@3oool3000001@0oooo0`00000G0?oo
o`030000003oool0000000X0oooo00140?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0503oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00l0oooo00D000000?oo
o`3oool0oooo0000000d0?ooo`8000005P3oool2000001<0oooo1@00000B0?ooo`D000004`3oool4
000001D0oooo0`0000000`3oool000000?ooo`090?ooo`00A03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00h0oooo0P00000F0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0503oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00l0oooo00@00000
0?ooo`3oool00000<@3oool500000180oooo1P00000A0?ooo`L00000403oool800000100oooo1`00
000B0?ooo`L000002P3oool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>
0?ooo`8000005P3oool2000000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0000000A0?ooo`030000003o
ool0oooo008000005P3oool00`000000oooo0?ooo`0E0?ooo`L00000403oool800000100oooo1000
000C0?ooo`T000003`3oool800000100oooo2@00000:0?ooo`00A03oool00`000000oooo0?ooo`0M
0?ooo`8000005P3oool2000000@0oooo00<000000?ooo`3oool03P3oool3000001D0oooo0P000009
0?ooo`030000003oool0oooo00X0oooo0P0000080?ooo`040000003oool0oooo000000X0oooo00@0
00000?ooo`3oool000004@3oool010000000oooo00000000000a0?ooo`@00000503oool4000005l0
oooo00<000000?ooo`3oool0203oool004@0oooo0P00000N0?ooo`8000005P3oool2000000@0oooo
00<000000?ooo`3oool03P3oool3000001D0oooo0`0000080?ooo`030000003oool0oooo00X0oooo
0`0000070?ooo`040000003oool0oooo000000T0oooo0P0000020?ooo`030000003oool0oooo00l0
oooo1@00002Z0?ooo`8000002P3oool004@0oooo00<000000?ooo`3oool0703oool3000001D0oooo
0`0000040?ooo`030000003oool0oooo00h0oooo0`00000E0?ooo`<00000203oool00`000000oooo
0?ooo`0:0?ooo`<000001`3oool010000000oooo0?ooo`0000090?ooo`8000000P3oool00`000000
oooo0?ooo`0@0?ooo`<0000000<0oooo0000003oool0Z@3oool00`000000oooo0?ooo`080?ooo`00
A03oool00`000000oooo0?ooo`0L0?ooo`@00000503oool3000000@0oooo00<000000?ooo`3oool0
3P3oool4000001D0oooo0`0000070?ooo`030000003oool0oooo00/0oooo0`0000060?ooo`050000
003oool0oooo0?ooo`000000203oool300000080oooo00<000000?ooo`3oool03`3oool300000003
0?ooo`000000oooo0:T0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0
703oool4000001@0oooo100000040?ooo`030000003oool0oooo00d0oooo1000000E0?ooo`<00000
203oool00`000000oooo0?ooo`0:0?ooo`@000001P3oool010000000oooo0?ooo`0000080?ooo`<0
00000P3oool00`000000oooo0?ooo`0?0?ooo`<000000P3oool00`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo01`0oooo0P00000F0?ooo`@00000
103oool00`000000oooo0?ooo`0=0?ooo`D00000503oool4000000L0oooo00<000000?ooo`3oool0
2P3oool3000000L0oooo00@000000?ooo`3oool000001`3oool4000000<0oooo00<000000?ooo`3o
ool03@3oool500000080oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`080?ooo`00
A03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo1000000E0?ooo`800000
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00001`3oool4000000<0oooo00<000000?ooo`3oool03@3oool500000080oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`050000
003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?oo
o`000000Y`3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`04
0000003oool0oooo000000h0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0
00000:H0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool01000
0000oooo0?ooo`00000>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2S0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01@0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`080?ooo`00A03oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000>
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2Q
0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0503oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo00P0oooo00140?oo
o`030000003oool0oooo00D0oooo0P00000f0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool01@3oool2000003H0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo00D000000?oo
o`3oool0oooo0000000>0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo
00@0oooo0`00000g0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0D0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0203oool0
04@0oooo00<000000?ooo`3oool0103oool3000003L0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool000003`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo0P00002M0?ooo`030000003oool0
oooo00P0oooo00140?ooo`030000003oool0oooo00@0oooo1000000f0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo
000000l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo09X0oooo00<000000?ooo`3oool0203oool004@0oooo0P0000050?ooo`@00000=P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool01000
0000oooo0?ooo`00000@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`2H0?ooo`8000002P3oool004@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0F
0?ooo`800000103oool2000009T0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo00000100oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`0000002P3oool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool00`3oool2000003D0oooo0P00000F0?ooo`8000005@3oool2
000001H0oooo0P00000D0?ooo`<0000000<0oooo0000003oool02@3oool004@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`800000;`3oool600000180oooo1P00000A
0?ooo`H000004P3oool600000180oooo1`00000:0?ooo`00A03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01D0oooo0P00000F0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02P3oool2000000D0oooo00<000000?ooo`3oool03P3oool2000000l0oooo00<000000?oo
o`3oool0103oool2000000l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`800000103oool0
10000000oooo00000000000C0?ooo`@00000503oool800000100oooo2000000?0?ooo`P00000403o
ool800000100oooo2@00000:0?ooo`00A03oool00`000000oooo0?ooo`0M0?ooo`8000005P3oool2
000000P0oooo00<000000?ooo`3oool02P3oool2000000D0oooo00<000000?ooo`3oool03P3oool2
00000100oooo00<000000?ooo`3oool00`3oool200000100oooo00D000000?ooo`3oool000000?oo
o`02000000d0oooo00<000000?ooo`3oool01`3oool200000140oooo00<000000?ooo`3oool00P3o
ool2000000030?ooo`00000000000180oooo1`00000D0?ooo`@00000503oool4000001<0oooo1000
000D0?ooo`@00000603oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`0L
0?ooo`<000005P3oool2000000P0oooo00<000000?ooo`3oool02P3oool2000000D0oooo00<00000
0?ooo`3oool03P3oool3000000l0oooo00<000000?ooo`3oool00`3oool3000000l0oooo00@00000
0?ooo`3oool0oooo0`00000>0?ooo`030000003oool0oooo00H0oooo1000000@0?ooo`040000003o
ool0oooo0?ooo`@0000000<0oooo0000000000004P3oool5000007L0oooo00<000000?ooo`3oool0
203oool004@0oooo00<000000?ooo`3oool0703oool3000001D0oooo100000080?ooo`030000003o
ool0oooo00T0oooo0`0000050?ooo`030000003oool0oooo00d0oooo0`00000?0?ooo`030000003o
ool0oooo00<0oooo1000000>0?ooo`040000003oool0oooo0?ooo`@000003P3oool00`000000oooo
0?ooo`060?ooo`D000003`3oool200000080oooo1@000000103oool0000000000000000@0?ooo`<0
0000N03oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`0L0?ooo`@00000
503oool4000000P0oooo00<000000?ooo`3oool02@3oool3000000D0oooo00<000000?ooo`3oool0
3@3oool4000000l0oooo00<000000?ooo`3oool00P3oool4000000l0oooo00@000000?ooo`3oool0
oooo0`00000>0?ooo`030000003oool0oooo00L0oooo0`00000B0?ooo`80000000@0oooo00000000
000000001@3oool200000100oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`080?oo
o`00A03oool00`000000oooo0?ooo`0L0?ooo`@00000503oool5000000L0oooo00<000000?ooo`3o
ool02@3oool4000000@0oooo00<000000?ooo`3oool03@3oool4000000l0oooo00<000000?ooo`3o
ool00P3oool5000000h0oooo00<000000?ooo`3oool01000000?0?ooo`030000003oool0oooo00H0
oooo0`00000D0?ooo`@000001`3oool2000008L0oooo00<000000?ooo`3oool0203oool004@0oooo
00<000000?ooo`3oool0=03oool3000000T0oooo00<000000?ooo`3oool02@3oool4000000@0oooo
00<000000?ooo`3oool03@3oool5000000h0oooo00<000000?ooo`3oool00P3oool400000100oooo
00<000000?ooo`0000000`00000@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
5@3oool2000000T0oooo0`0000240?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`<000004@3o
ool010000000oooo0?ooo`3oool200000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01l0oooo0P00000:0?ooo`<00000P@3oool00`000000oooo
0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`000000
4@3oool00`000000oooo0?ooo`0Q0?ooo`8000002`3oool5000007`0oooo00<000000?ooo`3oool0
203oool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0R0?ooo`8000003P3o
ool6000007H0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`0S0?ooo`8000004P3oool8000006h0oooo00<000000?ooo`3oool0203oool004@0oooo00<00000
0?ooo`3oool01@3oool2000003X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003o
ool0oooo02D0oooo0`00000G0?oooa000000GP3oool00`000000oooo0?ooo`080?ooo`00A03oool2
000000H0oooo0P00000j0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?oo
o`0W0?ooo`@000008`3oool3000004h0oooo1P0000060?ooo`8000002P3oool004@0oooo00<00000
0?ooo`3oool0103oool3000003/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0G
0?ooo`050000003oool0oooo0?ooo`000000?`3oool4000006@0oooo3000000=0?ooo`030000003o
ool0oooo00P0oooo00140?ooo`030000003oool0oooo00@0oooo0`00000k0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0000004<0oooo1000
001D0?ooo``000006@3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`04
0?ooo`@00000>P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01L0oooo00D00000
0?ooo`3oool0oooo000000160?ooo`D00000A@3oool:000002D0oooo00<000000?ooo`3oool0203o
ool004@0oooo00<000000?ooo`3oool0103oool4000003X0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`000000BP3oool:00000340oooo2P00
000_0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01L0oooo00D00000
0?ooo`3oool0oooo0000001D0?ooo`h000003@3ooolF000003T0oooo00<000000?ooo`3oool0203o
ool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool000000640oooo3@00
001?0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01P0oooo00D00000
0?ooo`3oool0oooo0000002l0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo01P0oooo00D000000?ooo`3oool0oooo0000002;0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0H
0?ooo`050000003oool0oooo0?ooo`000000R03oool3000001@0oooo0`00000G0?ooo`030000003o
ool0000000X0oooo00140?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo1000000D0?ooo`@00000503oool4
00000180oooo1@00000C0?ooo`@000005@3oool3000000030?ooo`000000oooo00T0oooo000X0?oo
o`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00`3oool01P3ookl0M00000000000
000004RL0=ooo`T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`800000
5P3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo000001<0oooo0P0000050?ooo`05
0000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0E0?ooo`8000005@3oool80000
0100oooo2000000@0?ooo`P00000403oool700000100oooo2000000@0?ooo`030000003oool00000
00H000002P3oool002L0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000
M;oo0080oooo00<0oono07@00018W=l00P3oool00`3OW4P0001d0;ooo`080?ooo`030000003oool0
oooo01d0oooo0P00000F0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool2
000001H0oooo0P00000F0?ooo`80000000<0oooo0000003oool04P3oool2000000H0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`8000005P3oool5000001<0oooo1P00000B0?ooo`H000004P3o
ool6000000l0oooo2000000@0?ooo`P00000403oool9000000X0oooo000V0?ooo`030?oog`2LB000
B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3o_g@004RL0=ooo`030?ooo`030;md0018W=l0
oooo00L0oooo00<000000?ooo`3oool07@3oool2000001H0oooo0P00000>0?ooo`030000003oool0
oooo00@0oooo0P00000F0?ooo`8000005`3oool2000000030?ooo`000000oooo0180oooo0P000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool3000001H0oooo1P00000E
0?ooo`8000005P3oool2000001H0oooo0P0000170?ooo`030000003oool0oooo00P0oooo000V0?oo
o`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3o_g@004RL0=ooo`03
0?ooo`030;md0000M;l0oooo00L0oooo00<000000?ooo`3oool0703oool3000001H0oooo0P00000>
0?ooo`030000003oool0oooo00@0oooo0`00000E0?ooo`<000005P3oool4000001<0oooo0P000006
0?ooo`050000003oool0oooo0?ooo`000000303oool4000001D0oooo1000002?0?ooo`030000003o
ool0oooo00P0oooo000V0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01@3oool0
0`3ooml0W4P007Boo`020?ooo`030?oo_`1d0000B9cO00P0oooo00<000000?ooo`3oool0703oool3
000001D0oooo1000000=0?ooo`030000003oool0oooo00D0oooo0`00000E0?ooo`<000005@3oool4
000001<0oooo0`0000060?ooo`050000003oool0oooo0?ooo`0000002`3oool5000001D0oooo0`00
002?0?ooo`030000003oool0oooo00P0oooo000W0?ooo`030;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l01`3oool01P2oM000001809cOg`2LB000001d0;ooo`P0oooo0`00000L0?ooo`@00000
503oool4000000d0oooo00<000000?ooo`3oool01@3oool3000001D0oooo0`00000E0?ooo`D00000
4P3oool4000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`<00000
5`3oool00`000000oooo0?ooo`2<0?ooo`<000002P3oool002L0oooo00<0gia80000B02Lgol00P3o
ool00`3ooml0W4P0001d_`080?ooo`050?oog`2LB00000000018W03Oool0203oool00`000000oooo
0?ooo`0L0?ooo`@00000503oool5000000d0oooo00<000000?ooo`3oool0103oool4000001@0oooo
1000000E0?ooo`@000004`3oool4000000D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`<0
0000Z03oool00`000000oooo0?ooo`080?ooo`009`3oool00`3ogi`0B00004RLg`030?ooo`030;md
0000B9`0gooo00L0oooo00H0_g@00000B02Lgol0omnL04Q8W03Oool70?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0;03oool3000000l0oooo00<000000?ooo`3oool0103oool20000
01H0oooo0P00000G0?ooo`050000003oool0oooo0?ooo`0000004P3oool2000000P0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0203o
ool002L0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`060?ooo`030?oOW018
0000M;oo0080oooo00<0okmd04RLg`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0K0?ooo`050000003o
ool0oooo0?ooo`000000]03oool00`000000oooo0?ooo`080?ooo`00:03oool00`3ogi`0B00007Bo
o`020?ooo`030=nLB000M;l0oooo00H0oooo00<0omnL04P0B02Lgol00P3oool00`3o_g@004RL0=oo
o`060?ooo`030000003oool0oooo00D0oooo0P00000o0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool06P3oool01@000000oooo0?ooo`3oool000000;@0oooo00<000000?ooo`3oool0
203oool002T0oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`030?oog`2LB000B9cO0080
oooo00<0_g@0001d_`3oool01P3oool00`000000oooo0?ooo`050?ooo`800000@03oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo0000002c0?oo
o`030000003oool0oooo00P0oooo000Z0?ooo`040=nLB00000000000001d_`T0oooo00D0oooO09a8
000000000000001d_`080?ooo`030000003oool0oooo00@0oooo0`0000100?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0703oool01@000000oooo0?ooo`3oool000000;80oooo00<0
00000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0103oool300000400oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`000000/@3o
ool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`040?ooo`@00000?`3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2^0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo
00@0oooo100000100?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0203oool004@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:`0
oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0203oool004@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:X0oooo00<0
00000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool0203oool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0:P0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0
203oool004@0oooo0P0000060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2S0?ooo`@000002P3oool004@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1J0?ooo`@000004`3oool4000001@0oooo1000000B0?ooo`D0000000<0oooo
0000003oool02@3oool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?oo
o`8000005P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool00000000001H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo0P00000F
0?ooo`8000001@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01@0oooo1000000D
0?ooo`@00000503oool8000000l0oooo2000000@0?ooo`P00000403oool9000000X0oooo00140?oo
o`030000003oool0oooo01d0oooo0P00000F0?ooo`8000004`3oool010000000oooo00000000000F
0?ooo`8000005P3oool2000000`0oooo00<000000?ooo`3oool01P3oool2000001L0oooo0P000005
0?ooo`030000003oool0oooo00d0oooo0`00000E0?ooo`P00000403oool700000180oooo1P00000A
0?ooo`H000004P3oool6000001@0oooo1@00000:0?ooo`00A03oool00`000000oooo0?ooo`0L0?oo
o`<000005P3oool2000001@0oooo0`00000F0?ooo`8000005P3oool2000000d0oooo00<000000?oo
o`3oool01@3oool2000001L0oooo0`0000050?ooo`030000003oool0oooo00d0oooo0`00000F0?oo
o`D000004`3oool5000001H0oooo0P00000E0?ooo`8000005P3oool2000001P0oooo00<000000?oo
o`3oool0203oool004@0oooo00<000000?ooo`3oool0703oool3000001D0oooo0`00000D0?ooo`@0
00005@3oool3000001D0oooo0`00000<0?ooo`030000003oool0oooo00D0oooo0`00000G0?ooo`@0
0000103oool00`000000oooo0?ooo`0<0?ooo`D000005@3oool4000001@0oooo0`00001P0?ooo`03
0000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
503oool4000001@0oooo0`00000D0?ooo`D000005@3oool3000001D0oooo0`00000<0?ooo`030000
003oool0oooo00D0oooo0`00000G0?ooo`@00000103oool00`000000oooo0?ooo`0<0?ooo`D00000
5P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
203oool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`@00000503o
ool4000001<0oooo1@00000E0?ooo`<000005@3oool3000000`0oooo00<000000?ooo`3oool01@3o
ool3000001L0oooo0`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo00/0oooo1000
002@0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00D0oooo0P00000E
0?ooo`8000005P3oool4000001@0oooo1@00000D0?ooo`@00000503oool4000000`0oooo00<00000
0?ooo`3oool0103oool4000001L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`00A03oool0
0`000000oooo0?ooo`050?ooo`800000;@3oool2000001H0oooo0`00000F0?ooo`8000005P3oool2
000000h0oooo00<000000?ooo`3oool0103oool2000001h0oooo00<000000?ooo`3oool00P3oool2
000009h0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0103oool30000
04D0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000
oooo0?ooo`040?ooo`<00000A@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00P0
oooo00140?ooo`030000003oool0oooo00@0oooo100000150?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0103oool4000004D0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0V03oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00<0oooo0P00002H0?ooo`030000003oool0oooo00P0oooo00140?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2E0?oo
o`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo02L0oooo0P0000050?ooo`03
0000003oool0oooo09@0oooo00<000000?ooo`3oool0203oool004@0oooo0P0000060?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00<0oooo0P00002C0?ooo`8000002P3oool004@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0203o
ool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`040?ooo`800000T@3oool0
0`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo0P00002>0?ooo`030000003oool0oooo00P0
oooo00140?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0A`3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo02X0oooo0P0000070?ooo`800000S03oool00`000000oooo
0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01P3oool2000008T0oooo00<00000
0?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo02`0oooo0P0000080?ooo`800000J`3oool4000001<0oooo100000000`3o
ool000000?ooo`090?ooo`00A03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0
oooo0P00000F0?ooo`030000003oool0oooo01@0oooo0P0000020?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`8000000`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`8000001P3oool2000001H0oooo2000000@0?ooo`P000003`3oool800000100
oooo2000000?0?ooo`P0000000<0oooo0000003oool02@3oool004@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0E0?ooo`8000005P3oool2000001D0oooo0P0000020?ooo`030000
003oool0oooo0140oooo0P00000F0?ooo`8000005@3oool2000000@0oooo00<000000?ooo`3oool0
3`3oool2000001L0oooo0P0000030?ooo`030000003oool0oooo00P0oooo0P0000050?ooo`<00000
5@3oool700000140oooo1`00000A0?ooo`H000004P3oool600000140oooo1P0000000`3oool00000
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo0`00
000F0?ooo`8000005@3oool2000000<0oooo00<000000?ooo`3oool0403oool2000001H0oooo0`00
000E0?ooo`8000000`3oool00`000000oooo0?ooo`0@0?ooo`8000005`3oool300000080oooo0P00
000:0?ooo`800000103oool4000001D0oooo1000000D0?ooo`@00000503oool4000001H0oooo0P00
000E0?ooo`80000000<0oooo0000003oool02@3oool004@0oooo00<000000?ooo`3oool01@3oool2
000001D0oooo0`00000E0?ooo`<000005@3oool300000080oooo00<000000?ooo`3oool0403oool3
000001D0oooo0`00000E0?ooo`800000103oool00`000000oooo0?ooo`0?0?ooo`<000005P3oool5
00000080oooo00<000000?ooo`3oool02@3oool200000080oooo1P00000D0?ooo`<000005P3oool2
000001H0oooo0P00000`0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo
00D0oooo0P00000E0?ooo`@00000503oool3000001D0oooo100000000`3oool000000?ooo`0B0?oo
o`<000005@3oool3000001@0oooo0`0000040?ooo`030000003oool0oooo00h0oooo1000000F0?oo
o`@000000`3oool2000000/0oooo0P0000000`3oool0000000000002000001L0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`040?ooo`<0
00005@3oool4000001@0oooo1000000D0?ooo`@0000000<0oooo0000003oool04P3oool3000001D0
oooo1000000C0?ooo`@00000103oool00`000000oooo0?ooo`0=0?ooo`D000005P3oool2000000H0
oooo0P00000;0?ooo`D00000N03oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo
0?ooo`040?ooo`<00000;@3oool4000001@0oooo1@0000000`3oool000000?ooo`0A0?ooo`@00000
503oool3000001D0oooo100000030?ooo`030000003oool0oooo00h0oooo0`00000H0?ooo`030000
003oool0oooo00H0oooo0P00000;0?ooo`<00000N03oool00`000000oooo0?ooo`080?ooo`00A03o
ool00`000000oooo0?ooo`040?ooo`@00000A03oool3000000<0oooo00<000000?ooo`3oool0403o
ool2000001H0oooo00<000000?ooo`3oool05@3oool2000000H0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00/0oooo0P00001f0?ooo`030000003o
ool0oooo00P0oooo00140?ooo`8000001@3oool4000004X0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0c0?ooo`8000003@3oool300000780oooo0P00000:0?ooo`00A03oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0d0?ooo`8000003P3oool300000700oooo00<000000?ooo`3oool0203oool004@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0=P3oool2000000l0oooo0P00001^0?ooo`030000003oool0oooo00P0
oooo00140?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo03L0oooo0P00000?0?ooo`<00000J`3oool00`000000oooo
0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`0h0?ooo`800000403oool3000006P0oooo00<0
00000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0>@3oool300000100oooo1000001T
0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo03`0oooo0P00000B0?oo
o`<00000H@3oool00`000000oooo0?ooo`080?ooo`00A03oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0m0?ooo`80
00004`3oool4000005d0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
?P3oool3000001@0oooo1000001I0?ooo`030000003oool0oooo00P0oooo00140?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo0400oooo0P00000F0?ooo`@00000E@3oool00`000000oooo0?ooo`080?ooo`00A03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`120?ooo`<000005`3oool500000500oooo00<000000?ooo`3oool0203oool0
03@0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
04@0oooo0`00000I0?ooo`D00000B`3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`3o_g@0
000007Boo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo04H0oooo0`00000K0?ooo`D00000AP3oool00`000000
oooo0?ooo`080?ooo`00=P3oool00`3ooml0W4P0001d_`0;0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo04P0oooo
0`00000M0?ooo`T00000?@3oool00`000000oooo0?ooo`080?ooo`00=`3oool00`3OW4P004RL0=oo
o`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0B`3oool3000002<0oooo3P00
000_0?ooo`030000003oool0oooo00P0oooo000g0?ooo`030?oOW01804P0W=oo00X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool0C@3oool3000002T0oooo100000000`3oool000000000000<000000D0oooo1000000C
0?ooo`@0000000<0oooo0000003oool02@3oool003L0oooo00<0oono07@0001d_ol02P3oool30000
00D0oooo00<000000?ooo`3oool05@3oool2000001H0oooo00<000000?ooo`3oool0503oool20000
00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01@0oooo0P00000E0?ooo`8000005`3oool00`000000oooo0?ooo`0D0?ooo`8000005P3oool80000
0080oooo0P00000<0?ooo`P000003`3oool8000000l0oooo8P00000:0?ooo`00>03oool00`2oM000
07Bo0?ooo`090?ooo`030000003oool0oooo01d0oooo0P00000F0?ooo`8000005@3oool2000001H0
oooo0P00000F0?ooo`8000005@3oool2000001L0oooo0P00000F0?ooo`8000005@3oool5000001<0
oooo1`00000A0?ooo`L000004@3oool600000180oooo1P00000A0?ooo`H0000000<0oooo0000003o
ool02@3oool003P0oooo00<0gia80018W03Oool02@3oool00`000000oooo0?ooo`0L0?ooo`<00000
5P3oool2000001D0oooo0`00000E0?ooo`8000005P3oool3000001D0oooo0P00000F0?ooo`<00000
5P3oool3000001@0oooo1P00000C0?ooo`@00000503oool4000001H0oooo0P00000F0?ooo`800000
5@3oool2000000030?ooo`000000oooo00T0oooo000h0?ooo`030?oOW01804P0W=oo00T0oooo00<0
00000?ooo`3oool0703oool4000001@0oooo0`00000E0?ooo`<000005@3oool3000001D0oooo0`00
000E0?ooo`<000005P3oool4000001D0oooo1000000C0?ooo`D000005@3oool2000001H0oooo0P00
00180?ooo`030000003oool0oooo00P0oooo000h0?ooo`030?oo_`1d0000M;oo00T0oooo00<00000
0?ooo`3oool0703oool4000001@0oooo0`00000E0?ooo`@000005@3oool3000001D0oooo0`00000D
0?ooo`@000005P3oool4000001D0oooo0P00000F0?ooo`800000N03oool00`000000oooo0?ooo`08
0?ooo`00>@3oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo01`0oooo0P00000F0?oo
o`@00000503oool4000001D0oooo0`00000E0?ooo`@000004`3oool5000001D0oooo0`00000G0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`080?oo
o`00=`3oool01@3ookl0M0000000000007@0_ooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0_0?ooo`@000003@3oool00`000000oooo0?ooo`040?ooo`D00000503oool40000
01@0oooo0`0000080?ooo`030000003oool0oooo00X0oooo0`00000G0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo0`0000070?ooo`030000003oool0oooo00`0
oooo0`00000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool004@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`00A03ooooo000005h000002P3oool00?l0oooo[03o
ool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo[03oool00?l0oooo[03o
ool004h0oooo00<0oooO09a8000000000P0000000`1d_ol0oooo0?ooo`150?ooo`030?oog`2LB000
00000080000000<0M;oo0?ooo`3oool04@3oool0103OW4P000000018W03Ooom30?ooo`030;md0000
04P0W=oo02<0oooo00@0omnL04P00000B9`0gooo4P3oool00`2oM000001809cOo`1F0?ooo`040?oO
W018000004RL0=oooaL0oooo001@0?ooo`030?noM00007@0_ooo04X0oooo00<0okmd0000M02oool0
503oool01@3o_g@004RL0=oOW018B9`0gooo0440oooo00<0gia80000M02oool09@3oool00`3ookl0
M000001d_`0A0?ooo`030=nLB00007@0_ooo05P0oooo00<0oono07@00000M;l05`3oool00500oooo
00<0oono07@0001d_ol0BP3oool00`3ookl0M00007Boo`0G0?ooo`030?oOW018M;l0oooo03@0oooo
00<0oono07@0M02oool0203oool00`3ooml0W4P004RLg`0:0?ooo`030?oo_`1d07@0_ooo00/0oooo
00<0oono07@0M02oool0303oool00`3OW4P004RL0=ooo`0?0?ooo`030?oog`2LB000B9cO01L0oooo
00<0oono07@0M02oool07@3oool00`3ookl0M01d0;ooo`0P0?ooo`030=nLB000B9`0gooo01H0oooo
001@0?ooo`030?oog`2LB000B9cO04X0oooo00<0oooO09a80018W=l0603oool00`3o_g@0M;oo0?oo
o`0d0?ooo`030?oOW01807@0_ooo00L0oooo00<0oooO09a80018W=l02`3oool00`3ogi`0B01d0;oo
o`0;0?ooo`030?oOW01807@0_ooo00/0oooo00<0gia80018W03Oool03`3oool00`3ooml0W4P004RL
g`0H0?ooo`030?oOW01807@0_ooo01d0oooo00<0omnL04P0M02oool07`3oool00`3OW4P004RL0=oo
o`0F0?ooo`00D@3oool00`3OW4P00000000000020000000607Boo`3oool0oooo0?ooo`2oM00007Bo
1P3oool01@3OW4P00000000000000000M;oo0080oooo00/0oono07@000000000001d0;ooo`3OW4P0
000004RLg`3oool0omnL04P000020000000907Boo`3OW4P000000018W03Oool0okmd0000000004P0
W=oo0080oooo00D0okmd000000000000001809cOo`030?ooo`030;md0000M;l0oooo0180oooo00<0
gia80000000000000P0000001P1d_ol0oooo0?ooo`3oool0_g@0001d_`H0oooo00D0gia800000000
0000000007Boo`040?ooo`030?noM0000000M;oo00L0oooo00`0gia80018W03Oool0oooo0?noM000
07@0_ooo0?ooo`3ooml0W4P00000001d_ol20?ooo`050?noM000000000000000B02Lgol00`3oool0
203ookl0M0000000000007@0_ooo0=nLB0000000B9cO0P3oool01@3OW4P00000000000000000M;oo
0080oooo00@0okmd0000000007@0_ooo0`3oool00`2oM000M;oo0?ooo`060?ooo`060?oog`2LB000
B9cO0?ooo`3ogi`0B0000P0000001@1d_ol0gia800000000B9`0gooo0080oooo00D0_g@007Boo`3o
ool0oooo0=nLB002000000030000B02Lgol0oooo00@0oooo00D0_g@007Boo`3oool0oooo0=nLB002
000000030000B02Lgol0oooo00<0oooo00<0gia80018W03Oool03`3oool00`3ooml0W4P004RLg`03
0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool01P3ogi`0B0000000
0000000004RL0=ooo`@0oooo00<0_g@007Boo`3oool01`3oool0102oM00000000000001d_ol30?oo
o`030?oOW0180000M;oo0080oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`020?oo
o`030;md001d_ol0oooo00L0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool00P3oool00`3OW4P004RL0=ooo`0F
0?ooo`00D@3oool01`3o_g@0001809cOo`3oool0oooO09a80000M;l00P3oool00`3o_g@0001d0;oo
o`040?ooo`030?oOW0180000M;oo0080oooo0240_g@0001d_`3oool0gia80018W03Oool0oono07@0
M02o_g@0001d09bLM02Lgol0_g@00018W03Oool0oooo0;md001dM7@0001d0;oOW02L_ol0okmd0000
B02Lgml0W7BL0=ooo`3ogi`0B01809cOo`3oool0omnL04P00000M;l00P3oool00`3o_g@0001d0;oo
o`0B0?ooo`070?noM00004P0W=oo0?ooo`3ooml0W4P0001d_`020?ooo`030?noM00007@0_ooo00@0
oooo00<0omnL04P0001d_ol00P3oool00`2oM00007Bo0?ooo`020?ooo`040=nLB00007@0M7A809cO
o`H0oooo00L0okmd0000B02Lgol0oooo0?oo_`1d0000M;oo0080oooo00/0_g@0001d_`2oM7@0_ooo
0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`020?ooo`0<0=nLB000B9`0gooo0?oo_`1d07@0_kmd
0000M02LW7@0W=oo0?oOW0180000M;oo0P3oool01`2oM00007Bo0?ooo`3ogi`0B01d0;oo_`2LW=l0
0P3oool00`3ogi`0B00007Boo`070?ooo`0I0?oog`2LB000B9cO0?ooo`2oM00004RL0=ooo`3oool0
_g@007AdM00007@0_mnL09boo`3oool0omnL04P0001d_ol0oooo0?oOW01807@0_ooo0?ooo`3ookl0
M00004RLg`030?ooo`0;0?oOW0180000M;oo0?ooo`3o_g@0000007Boo`3oool0oooO09a80018W=l0
0`3oool00`3OW4P004RL0=ooo`0?0?ooo`030?oog`2LB000B9cO0080oooo00H0gia8001d_`3oool0
omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo00H0okmd0000001d_ol0oooo0?oOW018
M;l30?ooo`030?oOW0180000M;oo00L0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`03
0?oOW0180000M;oo00@0oooo00<0okmd0000001d_ol0103oool00`3ogi`0B00007Boo`070?ooo`06
0=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`030?noM000M;l0
oooo0080oooo00<0_gAd0;ooo`3oool00P3oool00`3OW4P004RL0=ooo`0F0?ooo`00D@3oool00`3o
okl0M00007Boo`020?ooo`070?oog`2LB000B9cO0?ooo`3ogi`0B00007Boo`040?ooo`030=nLB000
B9`0gooo00<0oooo00@0gibL0;ooo`2oM00007Bo0P3oool01`3ookl0M4Q804P0B02Lgol0oooo0;md
0000M;l00`3oool01`2oM000000007Boo`3oool0oono07@0001d_ol00P3oool00`3OW4P004RL0=oo
o`020?ooo`070?oOW0180000B9cO0?ooo`3ogi`0B00007Boo`0B0?ooo`030?oo_`1d0000M;oo0080
oooo00L0oooO09a80018W=l0oooo0?oOW0180000M;oo00@0oooo00<0gia80018W03Oool00`3oool0
2@3OW9`0_ooo0?ooo`3oool0gia80018W03Ooml0W7BL0=ooo`050?ooo`070?oo_`1d0000B9cO0?oo
o`3ooml0W4P0001d_`020?ooo`070=nLB000B9`0gooo0?ooo`3OW4P004RL0=ooo`020?ooo`060?oO
W0180000B9cO0?ooo`2oM00007Bo0P3oool0203ookl0M4Q804P0B02Lgol0oooo0=nLB000B9`0gooo
0`3oool01`3OW9`0_ooo0?oo_`1d0000M;oo0=nLW02oool02`3oool01P3ooml0W4P004RLg`3oool0
_g@0001d_`<0oooo00<0_g@00000001d_ol01P3oool00`3ookl0M00007Boo`020?ooo`030?oo_`1d
0000M;oo00H0oooo00<0gia80018W03Oool00`3oool02P3Ogml0oooo0?ooo`3oool0gia80018W03O
ool0oooo0?oog`2LB0080000000;04RLg`3oool0oooo0?ooo`3ooml0W4P004RLg`3oool0oooO09a8
0018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo00X0oooo00<0oooO09a8
0018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?oog`2LB00007Bo00d0oooo00<0oooO09a8
0018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo00H0oooo00<0gia80018
W03Oool05P3oool00540oooo00<0oooO09a80018W=l00`3oool01`3ogi`0B01809cOo`3ooml0W4P0
0018W03Oool00`3oool01@3o_g@00000000000000000B9cO00<0oooo00<0okmd0018W03Oool00P3o
ool01`3o_g@0000004RLg`3oool0okmd0000M02oool00P3oool00`3ookl0M00004RLg`020?ooo`07
0;md0000M;l0oooo0?ooo`3o_g@0001d0;ooo`030?ooo`070=nLB00007@0_ooo0?oog`2LB00004RL
0=ooo`0A0?ooo`030?oog`2LB000B9cO00<0oooo00L0omnL04P0B02Lgol0oooO09a80000B9`0gooo
00<0oooo00D0okmd000000000000000004RLg`050?ooo`050;md0000B9`0gooo0?oOW01dW=l01@3o
ool0403ooml0W4P00018W03Oool0oooo0=nLB0000000M;oo0?ooo`3ogi`0B01809cOo`3oool0okmd
0000M02oool30?ooo`060=nLB00007@0_ooo0?noM000B9`0gooo0P3oool01@3o_g@0000004RLg`3o
ool0okmd00<0000000<0B9cO0?ooo`3oool00P3oool00`2oM000B9cO0?ooo`0<0?ooo`070?oo_`1d
0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00L0oooo00<0_g@004RLg`3o
ool00P3oool00`3OW4P004RL0=ooo`050?ooo`030?noM00007@0_ooo00L0oooo00<0okmd0000M02o
ool03`3oool01`3ookl0M00007Boo`3oool0oooO09a80018W=l00P3oool0103ooml0W4P00018W03O
ool:0?ooo`030?oo_`1d07@0_ooo00X0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018
W03Oool80?ooo`030=nLB000B9`0gooo00`0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P0
0018W03Oool80?ooo`030?noM000M;l0oooo00D0oooo00<0okmd0000M02oool05P3oool00580oooo
00<0gia80000M02oool00P3oool01`3ooml0W4P004RLg`3oool0_g@004QdM01dW=l00`3oool02`3o
okl0M01809cOo`3oool0gia800000018W=l0oooo0?oo_`1d0000M;oo0080oooo00L0oooO09a80000
M;l0oooo0?oo_`1d0000M;oo00<0oooo00/0_g@00018W03Oool0oooo0=nLB000B9`0gooo0?ooo`3o
okl0M00007Boo`030?ooo`070?oOW01804P0W=oo0?ooo`2oM000B7Ad07BLg`030?ooo`030?oog`2L
B000000000L0000000<0B9cO0?ooo`3oool00P3oool00`3OW4P0001d0;ooo`020?ooo`070?oog`2L
B000B9cO0?ooo`2oM000B7Ad07BLg`030?ooo`070?oo_`1d04P0W=oo0?ooo`3OW4P0000004RLg`02
0?ooo`030?oog`2LB00007Bo0080oooo00<0gibL0;ooo`3oool0103oool03`3OW4P004Q807BLg`3o
ool0okmd0000M01dM7@0_ooo0?oog`2LB000B9cO0?ooo`3ookl0M00007Boo`030?ooo`060?oOW018
04P0W=oo0?oo_`1d0000M;oo0P3oool02`3ooml0W4P0001d_`3oool0oono07@0B02Lgol0oooo0=nL
B0000000B9cO0080oooo00<0gia80018W03Oool02`3oool00`3ogi`0B01809cOo`020?ooo`030?oo
_`1d0000M;oo00<0oooo00<0_g@00018W03Oool01P3oool00`3OW4P004RL0=ooo`020?ooo`030?oO
W01804P0W=oo00D0oooo00<0oono07@0001d_ol0203oool00`3ogi`0B01809cOo`0=0?ooo`030?oO
W01804P0W=oo0080oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`0:0?ooo`030?oo
g`2LB000M;oo00X0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`080?ooo`030?oO
W01804P0W=oo00`0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`090?ooo`030?no
M018W=l0oooo00D0oooo00<0omnL04P0B02Lgol05@3oool00580oooo00@0okmd00000000B9`0gooo
0P3oool01`3OW4P007Bo0?ooo`3o_g@004RL0;nLB01d_ol00`3oool02`3o_g@004RL0=ooo`3oool0
oono07@00018W=l0oooo0?noM00007@0_ooo0080oooo00L0gia80000M02oool0oooo0?noM00007@0
_ooo0080oooo00L0gia80000M02oool0oooo0?oOW01804P0W=oo0080oooo00<0gia80000M02oool0
0P3oool0203ookl0M00007Boo`3oool0okmd0018W02oW4P0M;oo4@3oool0103o_g@000000018W03O
ool20?ooo`070=nLB000M;l0oooo0?noM000B9`0_ia807Boo`030?ooo`0;0?noM000B9`0gooo0?oo
o`3ookl0M00004RLg`3oool0oooO09a80000M;l00P3oool00`3ookl0M7Bo0?ooo`040?ooo`0@0?no
M00007@0W9ad09cOo`3ookl0M00007Bo_`1dM;l0oooo0;md0000B9`0gooo0?ooo`3OW4P0001d0;oo
o`80oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00l0gia80000M02oool0oooo
0?noM000B9`0gooo0?ooo`3ookl0M00004RLg`3oool0omnL04P0M02oool0303oool00`3ookl0M000
07Boo`020?ooo`030?noM00007@0_ooo0080oooo00<0gia80000M02oool01P3oool00`3ogi`0B018
07Bog`020?ooo`030?oo_`1d0000M;oo00H0oooo00L0gia80000M02oool0oooo0?oo_`1d0000M;oo
0080oooo00<0okmd0000M02oool03`3oool00`3ookl0M00007Boo`020?ooo`030;md0000B9`0gooo
0080oooo00<0omnL04P00018W=l02P3oool00`3ookl0M00004RLg`0;0?ooo`030;md0000B9`0gooo
0080oooo00<0omnL04P00018W=l0203oool00`3ookl0M00007Boo`0=0?ooo`030;md0000B9`0gooo
0080oooo00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`030?ooo`030?noM00007@0_ooo
01H0oooo001B0?ooo`0P0?oo_`1d0000M9bL04P0M02oool0oooO09a80000M;l0oooo0?oo_`1d04P0
W=oo0;md001dM7@004RL0=ooo`3oool0gia80000M02oool0oooo0=nLB000B9`0gooo0?ooo`3OW4P0
001d0;ooo`3oool0_g@00000B02Lgol20?ooo`0;0=nLB00007@0_ooo0?ooo`2oM000001809cOo`3o
ool0oooO09a80018W=l00`3oool03`2oM000001d0;ooo`3oool0okmd0000M02oool0oooo0?oo_`1d
04P0W=oo0;md001dM7@004RL0=ooo`0>0?ooo`0K0?oo_`1d0000M9bL04P0M02oool0oooO09a80000
M;l0oooo0?oo_`1d04P0W=oo0;md001dM7@004RL0=ooo`3oool0gia80000M02oool0oooo0=nLB000
B9`0gooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0M02oool0103oool0303ookl0M01809cOg`2L
B4P0W=oO09a80018W=l0okmd001d_`3o_g@0001d0;ooo`80oooo00L0_g@00000M02oool0oooo0?no
M00007@0_ooo0080oooo00L0gia80000M02oool0oooo0;md000004P0W=oo0080oooo00X0gia80000
M02oool0oooo0=nLB000B9`0gooo0?oo_`1d0000M;oo303oool00`3ooml0W4P004RLg`030?ooo`07
0=nLB00007@0_ooo0?ooo`2oM000001809cOo`060?ooo`080?oo_`1d0000B4Q804RLg`3oool0okmd
0000B02Lgol70?ooo`060;md000007@0_ooo0?ooo`3OW4P0B9cO0P3oool01P3OW4P004RL0=ooo`3o
ool0oooO09a800P0000000L0B9cO0?ooo`3oool0oooo0?oog`2LB000B9cO0080oooo00<0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`0:0?ooo`030?noM0000000M;oo00/0oooo00<0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`090?ooo`030;md0000M;l0oooo00`0oooo00<0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo0080oooo00<0gia80018
W03Oool05P3oool00540oooo0140omnL04P000000000B9cO0?oo_`1d000000000000M02oool0omnL
04P000000000M;oo0?ooo`2oM000001d0;ooo`020?ooo`050?oOW018000000000000001d_ol00`3o
ool01P3ogi`0B00000000018W;l0W4P004RLg`<0oooo00P0omnL04P000000000B9bL07@00018W=l0
oono07@000<0000000@0M;oo0?ooo`3oool0okmd0`0000002P1d_ol0oooo0?oOW0180000000007Bo
o`3oool0_g@00000M02oool=0?ooo`0A0?oOW0180000000004RLg`3ookl0M0000000000007@0_ooo
0?oOW0180000000007Boo`3oool0_g@00000M02oool00P3oool02@3ogi`0B000000000000000M;oo
0;md00000000001809cOo`020?ooo`030=nLB000B9`0gooo00<0oooo00d0oono07@000000000B9cO
0?oog`2LB000000004RLg`3oool0okmd00000000B9`0gooo00<0oooo00D0okmd0000000000000000
07Boo`040?ooo`060?oOW0180000000004RL_`2LB000B9cO0`3oool01@3ogi`0B000000000000000
M;oo0080oooo00<0_g@004RLg`3oool02`3oool00`3ooml0W4P004RLg`040?ooo`060?oOW0180000
000004RLW01d0000B9cO1`3oool00`2oM00007Bo0=nLB0020000000304RLg`3oool0oooo00L0oooo
00D0omnL04P000000000001809cOo`020?ooo`030=nLB000B9`0gooo00l0oooo00<0oooO09a80018
W=l00P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00H0oooo00H0omoO0=ooo`3o
_g@000000000M02oool;0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0203oool0
0`3OW4P004RL0=ooo`0<0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool02P3oool0
0`3ogi`0B01d0;ooo`020?ooo`030=nLB000B9`0gooo01H0oooo001`0?ooo`030;md0000M;l0oooo
00X0oooo00<0okmd0000M02oool0G`3oool00`2oM00007Bo0?ooo`090?ooo`030=nLB000B9`0gooo
00/0oooo00<0oooO09a80018W=l04@3oool00`3OW4P004RL0=ooo`0C0?ooo`030=nLB000B9`0gooo
00l0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0
gooo00H0oooo00D0oono07@000000000001809cOo`0<0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0gia80018W03Oool0203oool00`3ogi`0B01809cOo`0<0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool02P3oool00`3ooml0W4P007Boo`020?ooo`030=nLB000B9`0gooo01H0
oooo001`0?ooo`030?noM00007@0_ooo00/0oooo00<0giad09cOo`3oool0GP3oool00`3o_g@0001d
0;ooo`090?ooo`030?oOW01807@0_ooo00/0oooo00<0oooO09a80018W=l04@3oool00`3ogi`0B018
09cOo`0C0?ooo`030=nLB000B9`0gooo00l0oooo00<0oooO09a80018W=l00`3oool00`3ogi`0B000
07Boo`020?ooo`030=nLB000M;l0oooo00L0oooo00<0gibL0;ooo`3oool03P3oool00`3ogi`0B000
07Boo`020?ooo`030=nLB000M;l0oooo00P0oooo00<0oono07@0001d_ol03@3oool00`3ogi`0B000
07Boo`020?ooo`030=nLB000M;l0oooo00X0oooo00<0oono07@00018W=l00P3oool00`3OW4P004RL
0=ooo`0F0?ooo`00L03oool00`3ogi`0B01809cOo`1/0?ooo`030?oOW01804P0W=oo00T0oooo00<0
oooO09a8001d_ol02`3oool00`3ooml0W4P004RLg`0A0?ooo`030?oo_`1d0000B9cO01<0oooo00<0
gia80018W03Oool03`3oool00`3ooml0W4P004RLg`040?ooo`060=nLB00007@0_ooo0?oog`2LB000
B9cO203oool00`3ogi`0M9cO0?ooo`0?0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO2P3oool0
0`2oM00007Bo0?ooo`0=0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool01`3o_g@004RL
0=ooo`3oool0gia80000B02Lgol00P3oool00`3OW4P004RL0=ooo`0F0?ooo`00L03oool00`3ooml0
W4P004RLg`1/0?ooo`030?oog`2LB000B9cO00X0oooo00<0gia804RLg`3oool02`3oool00`3OW4P0
001d0;ooo`0A0?ooo`030=nLB000M;l0oooo0140oooo00<0oono07@00000M;l04@3oool00`3OW4P0
001d0;ooo`040?ooo`040=nLB00000000000001d_`X0oooo00D0_g@0000000000000000004RLg`0=
0?ooo`040=nLB00000000000001d_`T0oooo00D0oono07@000000000001d0;ooo`0>0?ooo`040=nL
B00000000000001d_`T0oooo00D0omnL04P000000000000007Boo`020?ooo`030?oo_`1d000007Bo
01L0oooo001_0?ooo`040?oo_`1d00000000001d_f/0oooo00@0oono07@00000000007Bo203oool0
103ooml0W4P000000000M;l<0?ooo`040?oog`2LB000001809cOo`h0oooo00D0oooO09a800000000
001d0;ooo`0@0?ooo`040?oOW018000004RL0=oooa40oooo00@0oooO09a8000004P0W=ooEP3oool0
103ogi`0B0000018W03OoolG0?ooo`00o`3ooon/0?ooo`00o`3ooon/0?ooo`00o`3ooon/0?ooo`00
o`3ooon/0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 426.688}, {430.875, 0}} -> {-0.21995, -0.178555, \
0.00447983, 0.00447983}}]
}, Closed]],

Cell["\<\
Conversely, the figure below shows that trajectories for initial conditions \
near an unstable fixed point spiral out while those for more distant initial \
conditions spiral in toward a band that is suggestive of a common asymptotic \
orbit. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ics = 
        Flatten[Table[{x0, y0}, {x0, 0.1, 0.5, 0.1}, {y0, 0.1, 0.5, 0.1}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(PhaseAndField[{1.5, 0.1, 0.2}, ics, 1, 0.5, 0, 100];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5052 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0146021 0.961588 0.0120286 0.961588 [
[.0146 -0.0125 -5 -15.6875 ]
[.0146 -0.0125 5 0 ]
[.20692 -0.0125 -9.5 -15.6875 ]
[.20692 -0.0125 9.5 0 ]
[.39924 -0.0125 -9.5 -15.6875 ]
[.39924 -0.0125 9.5 0 ]
[.59156 -0.0125 -9.625 -15.6875 ]
[.59156 -0.0125 9.625 0 ]
[.78387 -0.0125 -9.5 -15.6875 ]
[.78387 -0.0125 9.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.25 -31.375 ]
[.5 -0.0125 13.25 -15.6875 ]
[-0.0125 .01203 -10 -7.84375 ]
[-0.0125 .01203 0 7.84375 ]
[-0.0125 .10819 -19 -7.84375 ]
[-0.0125 .10819 0 7.84375 ]
[-0.0125 .20435 -19 -7.84375 ]
[-0.0125 .20435 0 7.84375 ]
[-0.0125 .30051 -19 -7.84375 ]
[-0.0125 .30051 0 7.84375 ]
[-0.0125 .39666 -19 -7.84375 ]
[-0.0125 .39666 0 7.84375 ]
[-0.0125 .49282 -19 -7.84375 ]
[-0.0125 .49282 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2526 -34.6875 -23.625 ]
[-0.01875 .2526 -19 23.625 ]
[ 0 .5052 .125 0 ]
[ 1 0 .125 0 ]
[.5 .5177 -110.813 0 ]
[.5 .5177 110.813 15.6875 ]
[ 0 0 0 0 ]
[ 1 .5052 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0146 0 m
.0146 .00625 L
s
gsave
.0146 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20692 0 m
.20692 .00625 L
s
gsave
.20692 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.39924 0 m
.39924 .00625 L
s
gsave
.39924 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59156 0 m
.59156 .00625 L
s
gsave
.59156 -0.0125 -70.625 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78387 0 m
.78387 .00625 L
s
gsave
.78387 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.06268 0 m
.06268 .00375 L
s
.11076 0 m
.11076 .00375 L
s
.15884 0 m
.15884 .00375 L
s
.255 0 m
.255 .00375 L
s
.30308 0 m
.30308 .00375 L
s
.35116 0 m
.35116 .00375 L
s
.44732 0 m
.44732 .00375 L
s
.4954 0 m
.4954 .00375 L
s
.54348 0 m
.54348 .00375 L
s
.63963 0 m
.63963 .00375 L
s
.68771 0 m
.68771 .00375 L
s
.73579 0 m
.73579 .00375 L
s
.83195 0 m
.83195 .00375 L
s
.88003 0 m
.88003 .00375 L
s
.92811 0 m
.92811 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.25 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(prey) show
85.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01203 m
.00625 .01203 L
s
gsave
-0.0125 .01203 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .10819 m
.00625 .10819 L
s
gsave
-0.0125 .10819 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .20435 m
.00625 .20435 L
s
gsave
-0.0125 .20435 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .30051 m
.00625 .30051 L
s
gsave
-0.0125 .30051 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .39666 m
.00625 .39666 L
s
gsave
-0.0125 .39666 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .49282 m
.00625 .49282 L
s
gsave
-0.0125 .49282 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03126 m
.00375 .03126 L
s
0 .05049 m
.00375 .05049 L
s
0 .06972 m
.00375 .06972 L
s
0 .08896 m
.00375 .08896 L
s
0 .12742 m
.00375 .12742 L
s
0 .14665 m
.00375 .14665 L
s
0 .16588 m
.00375 .16588 L
s
0 .18511 m
.00375 .18511 L
s
0 .22358 m
.00375 .22358 L
s
0 .24281 m
.00375 .24281 L
s
0 .26204 m
.00375 .26204 L
s
0 .28127 m
.00375 .28127 L
s
0 .31974 m
.00375 .31974 L
s
0 .33897 m
.00375 .33897 L
s
0 .3582 m
.00375 .3582 L
s
0 .37743 m
.00375 .37743 L
s
0 .4159 m
.00375 .4159 L
s
0 .43513 m
.00375 .43513 L
s
0 .45436 m
.00375 .45436 L
s
0 .47359 m
.00375 .47359 L
s
.25 Mabswid
0 0 m
0 .5052 L
s
gsave
-0.01875 .2526 -111.469 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
84.625 11.8438 translate
90 rotate
-84.625 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(predator) show
106.250 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0146 .49895 m
.0146 .5052 L
s
.20692 .49895 m
.20692 .5052 L
s
.39924 .49895 m
.39924 .5052 L
s
.59156 .49895 m
.59156 .5052 L
s
.78387 .49895 m
.78387 .5052 L
s
.97619 .49895 m
.97619 .5052 L
s
.125 Mabswid
.06268 .50145 m
.06268 .5052 L
s
.11076 .50145 m
.11076 .5052 L
s
.15884 .50145 m
.15884 .5052 L
s
.255 .50145 m
.255 .5052 L
s
.30308 .50145 m
.30308 .5052 L
s
.35116 .50145 m
.35116 .5052 L
s
.44732 .50145 m
.44732 .5052 L
s
.4954 .50145 m
.4954 .5052 L
s
.54348 .50145 m
.54348 .5052 L
s
.63963 .50145 m
.63963 .5052 L
s
.68771 .50145 m
.68771 .5052 L
s
.73579 .50145 m
.73579 .5052 L
s
.83195 .50145 m
.83195 .5052 L
s
.88003 .50145 m
.88003 .5052 L
s
.92811 .50145 m
.92811 .5052 L
s
.25 Mabswid
0 .5052 m
1 .5052 L
s
.99375 .01203 m
1 .01203 L
s
.99375 .10819 m
1 .10819 L
s
.99375 .20435 m
1 .20435 L
s
.99375 .30051 m
1 .30051 L
s
.99375 .39666 m
1 .39666 L
s
.99375 .49282 m
1 .49282 L
s
.125 Mabswid
.99625 .03126 m
1 .03126 L
s
.99625 .05049 m
1 .05049 L
s
.99625 .06972 m
1 .06972 L
s
.99625 .08896 m
1 .08896 L
s
.99625 .12742 m
1 .12742 L
s
.99625 .14665 m
1 .14665 L
s
.99625 .16588 m
1 .16588 L
s
.99625 .18511 m
1 .18511 L
s
.99625 .22358 m
1 .22358 L
s
.99625 .24281 m
1 .24281 L
s
.99625 .26204 m
1 .26204 L
s
.99625 .28127 m
1 .28127 L
s
.99625 .31974 m
1 .31974 L
s
.99625 .33897 m
1 .33897 L
s
.99625 .3582 m
1 .3582 L
s
.99625 .37743 m
1 .37743 L
s
.99625 .4159 m
1 .4159 L
s
.99625 .43513 m
1 .43513 L
s
.99625 .45436 m
1 .45436 L
s
.99625 .47359 m
1 .47359 L
s
.25 Mabswid
1 0 m
1 .5052 L
s
gsave
.5 .5177 -171.813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(predator) show
106.250 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
115.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(prey) show
139.875 15.813 moveto
(model) show
169.375 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
175.375 15.813 moveto
(8) show
179.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
185.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
188.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
194.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
197.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
202.938 15.813 moveto
(<) show
206.875 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
215.375 15.813 moveto
(8) show
219.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
234.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
240.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
255.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
261.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
276.688 15.813 moveto
(<) show
280.625 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.02422 .01203 m
.02429 .01203 L
s
% Start of user PostScript
0.01 0. 0.010072152 0. MAarrowhead1
% End of user PostScript
.02422 .04637 m
.02425 .04624 L
s
% Start of user PostScript
0.01 0.035714286 0.010036658 0.035580422 MAarrowhead1
% End of user PostScript
.02422 .08071 m
.02422 .0801 L
s
% Start of user PostScript
0.01 0.071428571 0.010001164 0.070789002 MAarrowhead1
% End of user PostScript
.02422 .11506 m
.02418 .1136 L
s
% Start of user PostScript
0.01 0.10714286 0.0099656701 0.10562574 MAarrowhead1
% End of user PostScript
.02422 .1494 m
.02415 .14674 L
s
% Start of user PostScript
0.01 0.14285714 0.0099301761 0.14009063 MAarrowhead1
% End of user PostScript
.02422 .18374 m
.02412 .17952 L
s
% Start of user PostScript
0.01 0.17857143 0.009894682 0.17418369 MAarrowhead1
% End of user PostScript
.02422 .21808 m
.02408 .21195 L
s
% Start of user PostScript
0.01 0.21428571 0.009859188 0.2079049 MAarrowhead1
% End of user PostScript
.02422 .25243 m
.02405 .24402 L
s
% Start of user PostScript
0.01 0.25 0.0098236939 0.24125426 MAarrowhead1
% End of user PostScript
.02422 .28677 m
.02401 .27573 L
s
% Start of user PostScript
0.01 0.28571429 0.0097881998 0.27423179 MAarrowhead1
% End of user PostScript
.02422 .32111 m
.02398 .30708 L
s
% Start of user PostScript
0.01 0.32142857 0.0097527058 0.30683747 MAarrowhead1
% End of user PostScript
.02422 .35545 m
.02395 .33808 L
s
% Start of user PostScript
0.01 0.35714286 0.0097172117 0.33907131 MAarrowhead1
% End of user PostScript
.02422 .3898 m
.02391 .36871 L
s
% Start of user PostScript
0.01 0.39285714 0.0096817176 0.37093331 MAarrowhead1
% End of user PostScript
.02422 .42414 m
.02388 .39899 L
s
% Start of user PostScript
0.01 0.42857143 0.0096462236 0.40242346 MAarrowhead1
% End of user PostScript
.02422 .45848 m
.02384 .42892 L
s
% Start of user PostScript
0.01 0.46428571 0.0096107295 0.43354177 MAarrowhead1
% End of user PostScript
.02422 .49282 m
.02381 .45848 L
s
% Start of user PostScript
0.01 0.5 0.0095752355 0.46428824 MAarrowhead1
% End of user PostScript
.09222 .01203 m
.09274 .01203 L
s
% Start of user PostScript
0.080714286 0. 0.08125506 0. MAarrowhead1
% End of user PostScript
.09222 .04637 m
.09257 .0464 L
s
% Start of user PostScript
0.080714286 0.035714286 0.081080676 0.035743309 MAarrowhead1
% End of user PostScript
.09222 .08071 m
.0924 .08073 L
s
% Start of user PostScript
0.080714286 0.071428571 0.080906292 0.071440549 MAarrowhead1
% End of user PostScript
.09222 .11506 m
.09223 .11501 L
s
% Start of user PostScript
0.080714286 0.10714286 0.080731908 0.10709172 MAarrowhead1
% End of user PostScript
.09222 .1494 m
.09207 .14924 L
s
% Start of user PostScript
0.080714286 0.14285714 0.080557525 0.14269682 MAarrowhead1
% End of user PostScript
.09222 .18374 m
.0919 .18344 L
s
% Start of user PostScript
0.080714286 0.17857143 0.080383141 0.17825586 MAarrowhead1
% End of user PostScript
.09222 .21808 m
.09173 .21759 L
s
% Start of user PostScript
0.080714286 0.21428571 0.080208757 0.21376882 MAarrowhead1
% End of user PostScript
.09222 .25243 m
.09156 .25169 L
s
% Start of user PostScript
0.080714286 0.25 0.080034373 0.24923572 MAarrowhead1
% End of user PostScript
.09222 .28677 m
.09139 .28575 L
s
% Start of user PostScript
0.080714286 0.28571429 0.079859989 0.28465654 MAarrowhead1
% End of user PostScript
.09222 .32111 m
.09123 .31977 L
s
% Start of user PostScript
0.080714286 0.32142857 0.079685605 0.3200313 MAarrowhead1
% End of user PostScript
.09222 .35545 m
.09106 .35374 L
s
% Start of user PostScript
0.080714286 0.35714286 0.079511221 0.35535999 MAarrowhead1
% End of user PostScript
.09222 .3898 m
.09089 .38767 L
s
% Start of user PostScript
0.080714286 0.39285714 0.079336837 0.39064261 MAarrowhead1
% End of user PostScript
.09222 .42414 m
.09072 .42155 L
s
% Start of user PostScript
0.080714286 0.42857143 0.079162454 0.42587916 MAarrowhead1
% End of user PostScript
.09222 .45848 m
.09056 .45539 L
s
% Start of user PostScript
0.080714286 0.46428571 0.07898807 0.46106964 MAarrowhead1
% End of user PostScript
.09222 .49282 m
.09039 .48918 L
s
% Start of user PostScript
0.080714286 0.5 0.078813686 0.49621405 MAarrowhead1
% End of user PostScript
.16021 .01203 m
.16111 .01203 L
s
% Start of user PostScript
0.15142857 0. 0.15236508 0. MAarrowhead1
% End of user PostScript
.16021 .04637 m
.16089 .04641 L
s
% Start of user PostScript
0.15142857 0.035714286 0.15212993 0.035754066 MAarrowhead1
% End of user PostScript
.16021 .08071 m
.16066 .08077 L
s
% Start of user PostScript
0.15142857 0.071428571 0.15189478 0.071483576 MAarrowhead1
% End of user PostScript
.16021 .11506 m
.16044 .1151 L
s
% Start of user PostScript
0.15142857 0.10714286 0.15165963 0.10718853 MAarrowhead1
% End of user PostScript
.16021 .1494 m
.16021 .14941 L
s
% Start of user PostScript
0.15142857 0.14285714 0.15142449 0.14286893 MAarrowhead1
% End of user PostScript
.16021 .18374 m
.15998 .1837 L
s
% Start of user PostScript
0.15142857 0.17857143 0.15118934 0.17852477 MAarrowhead1
% End of user PostScript
.16021 .21808 m
.15976 .21796 L
s
% Start of user PostScript
0.15142857 0.21428571 0.15095419 0.21415606 MAarrowhead1
% End of user PostScript
.16021 .25243 m
.15953 .2522 L
s
% Start of user PostScript
0.15142857 0.25 0.15071904 0.24976279 MAarrowhead1
% End of user PostScript
.16021 .28677 m
.15931 .28641 L
s
% Start of user PostScript
0.15142857 0.28571429 0.15048389 0.28534497 MAarrowhead1
% End of user PostScript
.16021 .32111 m
.15908 .3206 L
s
% Start of user PostScript
0.15142857 0.32142857 0.15024875 0.32090259 MAarrowhead1
% End of user PostScript
.16021 .35545 m
.15885 .35477 L
s
% Start of user PostScript
0.15142857 0.35714286 0.1500136 0.35643565 MAarrowhead1
% End of user PostScript
.16021 .3898 m
.15863 .38892 L
s
% Start of user PostScript
0.15142857 0.39285714 0.14977845 0.39194416 MAarrowhead1
% End of user PostScript
.16021 .42414 m
.1584 .42304 L
s
% Start of user PostScript
0.15142857 0.42857143 0.1495433 0.42742812 MAarrowhead1
% End of user PostScript
.16021 .45848 m
.15818 .45714 L
s
% Start of user PostScript
0.15142857 0.46428571 0.14930815 0.46288752 MAarrowhead1
% End of user PostScript
.16021 .49282 m
.15795 .49121 L
s
% Start of user PostScript
0.15142857 0.5 0.149073 0.49832236 MAarrowhead1
% End of user PostScript
.22821 .01203 m
.22942 .01203 L
s
% Start of user PostScript
0.22214286 0. 0.22340221 0. MAarrowhead1
% End of user PostScript
.22821 .04637 m
.22916 .04641 L
s
% Start of user PostScript
0.22214286 0.035714286 0.22313297 0.035757974 MAarrowhead1
% End of user PostScript
.22821 .08071 m
.22891 .08078 L
s
% Start of user PostScript
0.22214286 0.071428571 0.22286374 0.07149921 MAarrowhead1
% End of user PostScript
.22821 .11506 m
.22865 .11513 L
s
% Start of user PostScript
0.22214286 0.10714286 0.2225945 0.10722371 MAarrowhead1
% End of user PostScript
.22821 .1494 m
.22839 .14947 L
s
% Start of user PostScript
0.22214286 0.14285714 0.22232527 0.14293146 MAarrowhead1
% End of user PostScript
.22821 .18374 m
.22813 .18379 L
s
% Start of user PostScript
0.22214286 0.17857143 0.22205603 0.17862248 MAarrowhead1
% End of user PostScript
.22821 .21808 m
.22787 .21809 L
s
% Start of user PostScript
0.22214286 0.21428571 0.2217868 0.21429676 MAarrowhead1
% End of user PostScript
.22821 .25243 m
.22761 .25238 L
s
% Start of user PostScript
0.22214286 0.25 0.22151756 0.2499543 MAarrowhead1
% End of user PostScript
.22821 .28677 m
.22735 .28665 L
s
% Start of user PostScript
0.22214286 0.28571429 0.22124833 0.2855951 MAarrowhead1
% End of user PostScript
.22821 .32111 m
.22709 .32091 L
s
% Start of user PostScript
0.22214286 0.32142857 0.22097909 0.32121917 MAarrowhead1
% End of user PostScript
.22821 .35545 m
.22683 .35515 L
s
% Start of user PostScript
0.22214286 0.35714286 0.22070986 0.35682649 MAarrowhead1
% End of user PostScript
.22821 .3898 m
.22658 .38937 L
s
% Start of user PostScript
0.22214286 0.39285714 0.22044062 0.39241708 MAarrowhead1
% End of user PostScript
.22821 .42414 m
.22632 .42358 L
s
% Start of user PostScript
0.22214286 0.42857143 0.22017138 0.42799092 MAarrowhead1
% End of user PostScript
.22821 .45848 m
.22606 .45777 L
s
% Start of user PostScript
0.22214286 0.46428571 0.21990215 0.46354803 MAarrowhead1
% End of user PostScript
.22821 .49282 m
.2258 .49195 L
s
% Start of user PostScript
0.22214286 0.5 0.21963291 0.4990884 MAarrowhead1
% End of user PostScript
.29621 .01203 m
.29766 .01203 L
s
% Start of user PostScript
0.29285714 0. 0.29436645 0. MAarrowhead1
% End of user PostScript
.29621 .04637 m
.29738 .04642 L
s
% Start of user PostScript
0.29285714 0.035714286 0.2940754 0.035759995 MAarrowhead1
% End of user PostScript
.29621 .08071 m
.2971 .08079 L
s
% Start of user PostScript
0.29285714 0.071428571 0.29378435 0.071507293 MAarrowhead1
% End of user PostScript
.29621 .11506 m
.29682 .11515 L
s
% Start of user PostScript
0.29285714 0.10714286 0.2934933 0.10724189 MAarrowhead1
% End of user PostScript
.29621 .1494 m
.29654 .1495 L
s
% Start of user PostScript
0.29285714 0.14285714 0.29320225 0.1429638 MAarrowhead1
% End of user PostScript
.29621 .18374 m
.29626 .18384 L
s
% Start of user PostScript
0.29285714 0.17857143 0.2929112 0.17867301 MAarrowhead1
% End of user PostScript
.29621 .21808 m
.29598 .21816 L
s
% Start of user PostScript
0.29285714 0.21428571 0.29262014 0.21436951 MAarrowhead1
% End of user PostScript
.29621 .25243 m
.2957 .25248 L
s
% Start of user PostScript
0.29285714 0.25 0.29232909 0.25005333 MAarrowhead1
% End of user PostScript
.29621 .28677 m
.29542 .28678 L
s
% Start of user PostScript
0.29285714 0.28571429 0.29203804 0.28572444 MAarrowhead1
% End of user PostScript
.29621 .32111 m
.29514 .32107 L
s
% Start of user PostScript
0.29285714 0.32142857 0.29174699 0.32138286 MAarrowhead1
% End of user PostScript
.29621 .35545 m
.29486 .35534 L
s
% Start of user PostScript
0.29285714 0.35714286 0.29145594 0.35702858 MAarrowhead1
% End of user PostScript
.29621 .3898 m
.29458 .38961 L
s
% Start of user PostScript
0.29285714 0.39285714 0.29116489 0.39266161 MAarrowhead1
% End of user PostScript
.29621 .42414 m
.2943 .42386 L
s
% Start of user PostScript
0.29285714 0.42857143 0.29087384 0.42828194 MAarrowhead1
% End of user PostScript
.29621 .45848 m
.29402 .4581 L
s
% Start of user PostScript
0.29285714 0.46428571 0.29058278 0.46388957 MAarrowhead1
% End of user PostScript
.29621 .49282 m
.29374 .49233 L
s
% Start of user PostScript
0.29285714 0.5 0.29029173 0.4994845 MAarrowhead1
% End of user PostScript
.36421 .01203 m
.36583 .01203 L
s
% Start of user PostScript
0.36357143 0. 0.36525781 0. MAarrowhead1
% End of user PostScript
.36421 .04637 m
.36554 .04642 L
s
% Start of user PostScript
0.36357143 0.035714286 0.36495159 0.03576123 MAarrowhead1
% End of user PostScript
.36421 .08071 m
.36524 .08079 L
s
% Start of user PostScript
0.36357143 0.071428571 0.36464538 0.071512232 MAarrowhead1
% End of user PostScript
.36421 .11506 m
.36495 .11516 L
s
% Start of user PostScript
0.36357143 0.10714286 0.36433917 0.10725301 MAarrowhead1
% End of user PostScript
.36421 .1494 m
.36465 .14952 L
s
% Start of user PostScript
0.36357143 0.14285714 0.36403296 0.14298355 MAarrowhead1
% End of user PostScript
.36421 .18374 m
.36436 .18387 L
s
% Start of user PostScript
0.36357143 0.17857143 0.36372675 0.17870387 MAarrowhead1
% End of user PostScript
.36421 .21808 m
.36406 .21821 L
s
% Start of user PostScript
0.36357143 0.21428571 0.36342054 0.21441397 MAarrowhead1
% End of user PostScript
.36421 .25243 m
.36377 .25254 L
s
% Start of user PostScript
0.36357143 0.25 0.36311432 0.25011383 MAarrowhead1
% End of user PostScript
.36421 .28677 m
.36347 .28685 L
s
% Start of user PostScript
0.36357143 0.28571429 0.36280811 0.28580347 MAarrowhead1
% End of user PostScript
.36421 .32111 m
.36318 .32116 L
s
% Start of user PostScript
0.36357143 0.32142857 0.3625019 0.32148288 MAarrowhead1
% End of user PostScript
.36421 .35545 m
.36289 .35546 L
s
% Start of user PostScript
0.36357143 0.35714286 0.36219569 0.35715206 MAarrowhead1
% End of user PostScript
.36421 .3898 m
.36259 .38975 L
s
% Start of user PostScript
0.36357143 0.39285714 0.36188948 0.39281102 MAarrowhead1
% End of user PostScript
.36421 .42414 m
.3623 .42403 L
s
% Start of user PostScript
0.36357143 0.42857143 0.36158327 0.42845974 MAarrowhead1
% End of user PostScript
.36421 .45848 m
.362 .4583 L
s
% Start of user PostScript
0.36357143 0.46428571 0.36127706 0.46409824 MAarrowhead1
% End of user PostScript
.36421 .49282 m
.36171 .49256 L
s
% Start of user PostScript
0.36357143 0.5 0.36097084 0.49972652 MAarrowhead1
% End of user PostScript
.43221 .01203 m
.43393 .01203 L
s
% Start of user PostScript
0.43428571 0. 0.43607627 0. MAarrowhead1
% End of user PostScript
.43221 .04637 m
.43362 .04642 L
s
% Start of user PostScript
0.43428571 0.035714286 0.43575891 0.035762063 MAarrowhead1
% End of user PostScript
.43221 .08071 m
.43332 .0808 L
s
% Start of user PostScript
0.43428571 0.071428571 0.43544155 0.071515563 MAarrowhead1
% End of user PostScript
.43221 .11506 m
.43301 .11517 L
s
% Start of user PostScript
0.43428571 0.10714286 0.43512419 0.1072605 MAarrowhead1
% End of user PostScript
.43221 .1494 m
.43271 .14953 L
s
% Start of user PostScript
0.43428571 0.14285714 0.43480684 0.14299688 MAarrowhead1
% End of user PostScript
.43221 .18374 m
.4324 .18389 L
s
% Start of user PostScript
0.43428571 0.17857143 0.43448948 0.17872469 MAarrowhead1
% End of user PostScript
.43221 .21808 m
.4321 .21824 L
s
% Start of user PostScript
0.43428571 0.21428571 0.43417212 0.21444394 MAarrowhead1
% End of user PostScript
.43221 .25243 m
.43179 .25257 L
s
% Start of user PostScript
0.43428571 0.25 0.43385476 0.25015463 MAarrowhead1
% End of user PostScript
.43221 .28677 m
.43149 .28691 L
s
% Start of user PostScript
0.43428571 0.28571429 0.4335374 0.28585676 MAarrowhead1
% End of user PostScript
.43221 .32111 m
.43118 .32123 L
s
% Start of user PostScript
0.43428571 0.32142857 0.43322004 0.32155033 MAarrowhead1
% End of user PostScript
.43221 .35545 m
.43088 .35554 L
s
% Start of user PostScript
0.43428571 0.35714286 0.43290268 0.35723533 MAarrowhead1
% End of user PostScript
.43221 .3898 m
.43057 .38985 L
s
% Start of user PostScript
0.43428571 0.39285714 0.43258532 0.39291177 MAarrowhead1
% End of user PostScript
.43221 .42414 m
.43027 .42415 L
s
% Start of user PostScript
0.43428571 0.42857143 0.43226797 0.42857965 MAarrowhead1
% End of user PostScript
.43221 .45848 m
.42996 .45844 L
s
% Start of user PostScript
0.43428571 0.46428571 0.43195061 0.46423896 MAarrowhead1
% End of user PostScript
.43221 .49282 m
.42966 .49272 L
s
% Start of user PostScript
0.43428571 0.5 0.43163325 0.49988972 MAarrowhead1
% End of user PostScript
.5002 .01203 m
.50196 .01203 L
s
% Start of user PostScript
0.505 0. 0.50682185 0. MAarrowhead1
% End of user PostScript
.5002 .04637 m
.50164 .04642 L
s
% Start of user PostScript
0.505 0.035714286 0.50649595 0.035762662 MAarrowhead1
% End of user PostScript
.5002 .08071 m
.50133 .0808 L
s
% Start of user PostScript
0.505 0.071428571 0.50617005 0.071517961 MAarrowhead1
% End of user PostScript
.5002 .11506 m
.50102 .11517 L
s
% Start of user PostScript
0.505 0.10714286 0.50584415 0.1072659 MAarrowhead1
% End of user PostScript
.5002 .1494 m
.5007 .14954 L
s
% Start of user PostScript
0.505 0.14285714 0.50551825 0.14300647 MAarrowhead1
% End of user PostScript
.5002 .18374 m
.50039 .1839 L
s
% Start of user PostScript
0.505 0.17857143 0.50519235 0.17873968 MAarrowhead1
% End of user PostScript
.5002 .21808 m
.50008 .21826 L
s
% Start of user PostScript
0.505 0.21428571 0.50486645 0.21446552 MAarrowhead1
% End of user PostScript
.5002 .25243 m
.49976 .2526 L
s
% Start of user PostScript
0.505 0.25 0.50454055 0.25018401 MAarrowhead1
% End of user PostScript
.5002 .28677 m
.49945 .28694 L
s
% Start of user PostScript
0.505 0.28571429 0.50421465 0.28589513 MAarrowhead1
% End of user PostScript
.5002 .32111 m
.49914 .32127 L
s
% Start of user PostScript
0.505 0.32142857 0.50388875 0.32159888 MAarrowhead1
% End of user PostScript
.5002 .35545 m
.49882 .3556 L
s
% Start of user PostScript
0.505 0.35714286 0.50356285 0.35729528 MAarrowhead1
% End of user PostScript
.5002 .3898 m
.49851 .38992 L
s
% Start of user PostScript
0.505 0.39285714 0.50323695 0.39298431 MAarrowhead1
% End of user PostScript
.5002 .42414 m
.4982 .42423 L
s
% Start of user PostScript
0.505 0.42857143 0.50291105 0.42866597 MAarrowhead1
% End of user PostScript
.5002 .45848 m
.49788 .45853 L
s
% Start of user PostScript
0.505 0.46428571 0.50258515 0.46434028 MAarrowhead1
% End of user PostScript
.5002 .49282 m
.49757 .49283 L
s
% Start of user PostScript
0.505 0.5 0.50225925 0.50000722 MAarrowhead1
% End of user PostScript
.5682 .01203 m
.56991 .01203 L
s
% Start of user PostScript
0.57571429 0. 0.57749453 0. MAarrowhead1
% End of user PostScript
.5682 .04637 m
.56959 .04642 L
s
% Start of user PostScript
0.57571429 0.035714286 0.57716188 0.035763114 MAarrowhead1
% End of user PostScript
.5682 .08071 m
.56927 .0808 L
s
% Start of user PostScript
0.57571429 0.071428571 0.57682923 0.07151977 MAarrowhead1
% End of user PostScript
.5682 .11506 m
.56895 .11518 L
s
% Start of user PostScript
0.57571429 0.10714286 0.57649657 0.10726997 MAarrowhead1
% End of user PostScript
.5682 .1494 m
.56863 .14955 L
s
% Start of user PostScript
0.57571429 0.14285714 0.57616392 0.1430137 MAarrowhead1
% End of user PostScript
.5682 .18374 m
.56831 .18391 L
s
% Start of user PostScript
0.57571429 0.17857143 0.57583127 0.17875098 MAarrowhead1
% End of user PostScript
.5682 .21808 m
.56799 .21827 L
s
% Start of user PostScript
0.57571429 0.21428571 0.57549861 0.2144818 MAarrowhead1
% End of user PostScript
.5682 .25243 m
.56767 .25262 L
s
% Start of user PostScript
0.57571429 0.25 0.57516596 0.25020617 MAarrowhead1
% End of user PostScript
.5682 .28677 m
.56736 .28697 L
s
% Start of user PostScript
0.57571429 0.28571429 0.5748333 0.28592407 MAarrowhead1
% End of user PostScript
.5682 .32111 m
.56704 .32131 L
s
% Start of user PostScript
0.57571429 0.32142857 0.57450065 0.32163551 MAarrowhead1
% End of user PostScript
.5682 .35545 m
.56672 .35564 L
s
% Start of user PostScript
0.57571429 0.35714286 0.574168 0.3573405 MAarrowhead1
% End of user PostScript
.5682 .3898 m
.5664 .38997 L
s
% Start of user PostScript
0.57571429 0.39285714 0.57383534 0.39303902 MAarrowhead1
% End of user PostScript
.5682 .42414 m
.56608 .42429 L
s
% Start of user PostScript
0.57571429 0.42857143 0.57350269 0.42873109 MAarrowhead1
% End of user PostScript
.5682 .45848 m
.56576 .45861 L
s
% Start of user PostScript
0.57571429 0.46428571 0.57317004 0.4644167 MAarrowhead1
% End of user PostScript
.5682 .49282 m
.56544 .49291 L
s
% Start of user PostScript
0.57571429 0.5 0.57283738 0.50009585 MAarrowhead1
% End of user PostScript
.6362 .01203 m
.6378 .01203 L
s
% Start of user PostScript
0.64642857 0. 0.64809433 0. MAarrowhead1
% End of user PostScript
.6362 .04637 m
.63748 .04642 L
s
% Start of user PostScript
0.64642857 0.035714286 0.64775621 0.035763468 MAarrowhead1
% End of user PostScript
.6362 .08071 m
.63715 .0808 L
s
% Start of user PostScript
0.64642857 0.071428571 0.64741808 0.071521183 MAarrowhead1
% End of user PostScript
.6362 .11506 m
.63683 .11518 L
s
% Start of user PostScript
0.64642857 0.10714286 0.64707995 0.10727315 MAarrowhead1
% End of user PostScript
.6362 .1494 m
.6365 .14955 L
s
% Start of user PostScript
0.64642857 0.14285714 0.64674182 0.14301936 MAarrowhead1
% End of user PostScript
.6362 .18374 m
.63618 .18392 L
s
% Start of user PostScript
0.64642857 0.17857143 0.64640369 0.17875982 MAarrowhead1
% End of user PostScript
.6362 .21808 m
.63585 .21828 L
s
% Start of user PostScript
0.64642857 0.21428571 0.64606557 0.21449452 MAarrowhead1
% End of user PostScript
.6362 .25243 m
.63553 .25264 L
s
% Start of user PostScript
0.64642857 0.25 0.64572744 0.25022348 MAarrowhead1
% End of user PostScript
.6362 .28677 m
.6352 .28699 L
s
% Start of user PostScript
0.64642857 0.28571429 0.64538931 0.28594668 MAarrowhead1
% End of user PostScript
.6362 .32111 m
.63488 .32134 L
s
% Start of user PostScript
0.64642857 0.32142857 0.64505118 0.32166413 MAarrowhead1
% End of user PostScript
.6362 .35545 m
.63455 .35568 L
s
% Start of user PostScript
0.64642857 0.35714286 0.64471306 0.35737582 MAarrowhead1
% End of user PostScript
.6362 .3898 m
.63423 .39001 L
s
% Start of user PostScript
0.64642857 0.39285714 0.64437493 0.39308177 MAarrowhead1
% End of user PostScript
.6362 .42414 m
.6339 .42434 L
s
% Start of user PostScript
0.64642857 0.42857143 0.6440368 0.42878196 MAarrowhead1
% End of user PostScript
.6362 .45848 m
.63358 .45866 L
s
% Start of user PostScript
0.64642857 0.46428571 0.64369867 0.4644764 MAarrowhead1
% End of user PostScript
.6362 .49282 m
.63325 .49298 L
s
% Start of user PostScript
0.64642857 0.5 0.64336055 0.50016509 MAarrowhead1
% End of user PostScript
.7042 .01203 m
.70562 .01203 L
s
% Start of user PostScript
0.71714286 0. 0.71862124 0. MAarrowhead1
% End of user PostScript
.7042 .04637 m
.70529 .04642 L
s
% Start of user PostScript
0.71714286 0.035714286 0.71827859 0.035763751 MAarrowhead1
% End of user PostScript
.7042 .08071 m
.70496 .0808 L
s
% Start of user PostScript
0.71714286 0.071428571 0.71793594 0.071522317 MAarrowhead1
% End of user PostScript
.7042 .11506 m
.70463 .11518 L
s
% Start of user PostScript
0.71714286 0.10714286 0.71759328 0.1072757 MAarrowhead1
% End of user PostScript
.7042 .1494 m
.7043 .14956 L
s
% Start of user PostScript
0.71714286 0.14285714 0.71725063 0.14302389 MAarrowhead1
% End of user PostScript
.7042 .18374 m
.70397 .18393 L
s
% Start of user PostScript
0.71714286 0.17857143 0.71690797 0.17876691 MAarrowhead1
% End of user PostScript
.7042 .21808 m
.70364 .21829 L
s
% Start of user PostScript
0.71714286 0.21428571 0.71656532 0.21450473 MAarrowhead1
% End of user PostScript
.7042 .25243 m
.70331 .25265 L
s
% Start of user PostScript
0.71714286 0.25 0.71622266 0.25023737 MAarrowhead1
% End of user PostScript
.7042 .28677 m
.70298 .28701 L
s
% Start of user PostScript
0.71714286 0.28571429 0.71588001 0.28596483 MAarrowhead1
% End of user PostScript
.7042 .32111 m
.70265 .32136 L
s
% Start of user PostScript
0.71714286 0.32142857 0.71553736 0.3216871 MAarrowhead1
% End of user PostScript
.7042 .35545 m
.70233 .3557 L
s
% Start of user PostScript
0.71714286 0.35714286 0.7151947 0.35740418 MAarrowhead1
% End of user PostScript
.7042 .3898 m
.702 .39004 L
s
% Start of user PostScript
0.71714286 0.39285714 0.71485205 0.39311608 MAarrowhead1
% End of user PostScript
.7042 .42414 m
.70167 .42438 L
s
% Start of user PostScript
0.71714286 0.42857143 0.71450939 0.4288228 MAarrowhead1
% End of user PostScript
.7042 .45848 m
.70134 .45871 L
s
% Start of user PostScript
0.71714286 0.46428571 0.71416674 0.46452433 MAarrowhead1
% End of user PostScript
.7042 .49282 m
.70101 .49304 L
s
% Start of user PostScript
0.71714286 0.5 0.71382408 0.50022068 MAarrowhead1
% End of user PostScript
.7722 .01203 m
.77337 .01203 L
s
% Start of user PostScript
0.78785714 0. 0.78907527 0. MAarrowhead1
% End of user PostScript
.7722 .04637 m
.77303 .04642 L
s
% Start of user PostScript
0.78785714 0.035714286 0.78872881 0.035763984 MAarrowhead1
% End of user PostScript
.7722 .08071 m
.7727 .0808 L
s
% Start of user PostScript
0.78785714 0.071428571 0.78838235 0.071523248 MAarrowhead1
% End of user PostScript
.7722 .11506 m
.77237 .11519 L
s
% Start of user PostScript
0.78785714 0.10714286 0.78803589 0.10727779 MAarrowhead1
% End of user PostScript
.7722 .1494 m
.77204 .14956 L
s
% Start of user PostScript
0.78785714 0.14285714 0.78768943 0.14302762 MAarrowhead1
% End of user PostScript
.7722 .18374 m
.7717 .18393 L
s
% Start of user PostScript
0.78785714 0.17857143 0.78734297 0.17877272 MAarrowhead1
% End of user PostScript
.7722 .21808 m
.77137 .2183 L
s
% Start of user PostScript
0.78785714 0.21428571 0.78699651 0.21451311 MAarrowhead1
% End of user PostScript
.7722 .25243 m
.77104 .25266 L
s
% Start of user PostScript
0.78785714 0.25 0.78665005 0.25024877 MAarrowhead1
% End of user PostScript
.7722 .28677 m
.7707 .28702 L
s
% Start of user PostScript
0.78785714 0.28571429 0.78630359 0.28597972 MAarrowhead1
% End of user PostScript
.7722 .32111 m
.77037 .32138 L
s
% Start of user PostScript
0.78785714 0.32142857 0.78595713 0.32170595 MAarrowhead1
% End of user PostScript
.7722 .35545 m
.77004 .35573 L
s
% Start of user PostScript
0.78785714 0.35714286 0.78561067 0.35742745 MAarrowhead1
% End of user PostScript
.7722 .3898 m
.7697 .39007 L
s
% Start of user PostScript
0.78785714 0.39285714 0.78526421 0.39314424 MAarrowhead1
% End of user PostScript
.7722 .42414 m
.76937 .42441 L
s
% Start of user PostScript
0.78785714 0.42857143 0.78491775 0.42885631 MAarrowhead1
% End of user PostScript
.7722 .45848 m
.76904 .45875 L
s
% Start of user PostScript
0.78785714 0.46428571 0.78457129 0.46456366 MAarrowhead1
% End of user PostScript
.7722 .49282 m
.7687 .49308 L
s
% Start of user PostScript
0.78785714 0.5 0.78422483 0.50026628 MAarrowhead1
% End of user PostScript
.84019 .01203 m
.84105 .01203 L
s
% Start of user PostScript
0.85857143 0. 0.8594564 0. MAarrowhead1
% End of user PostScript
.84019 .04637 m
.84071 .04642 L
s
% Start of user PostScript
0.85857143 0.035714286 0.8591067 0.035764178 MAarrowhead1
% End of user PostScript
.84019 .08071 m
.84037 .08081 L
s
% Start of user PostScript
0.85857143 0.071428571 0.85875699 0.071524025 MAarrowhead1
% End of user PostScript
.84019 .11506 m
.84004 .11519 L
s
% Start of user PostScript
0.85857143 0.10714286 0.85840729 0.10727954 MAarrowhead1
% End of user PostScript
.84019 .1494 m
.8397 .14957 L
s
% Start of user PostScript
0.85857143 0.14285714 0.85805758 0.14303073 MAarrowhead1
% End of user PostScript
.84019 .18374 m
.83936 .18394 L
s
% Start of user PostScript
0.85857143 0.17857143 0.85770788 0.17877758 MAarrowhead1
% End of user PostScript
.84019 .21808 m
.83903 .21831 L
s
% Start of user PostScript
0.85857143 0.21428571 0.85735818 0.21452011 MAarrowhead1
% End of user PostScript
.84019 .25243 m
.83869 .25267 L
s
% Start of user PostScript
0.85857143 0.25 0.85700847 0.2502583 MAarrowhead1
% End of user PostScript
.84019 .28677 m
.83836 .28704 L
s
% Start of user PostScript
0.85857143 0.28571429 0.85665877 0.28599216 MAarrowhead1
% End of user PostScript
.84019 .32111 m
.83802 .32139 L
s
% Start of user PostScript
0.85857143 0.32142857 0.85630906 0.32172169 MAarrowhead1
% End of user PostScript
.84019 .35545 m
.83768 .35575 L
s
% Start of user PostScript
0.85857143 0.35714286 0.85595936 0.35744689 MAarrowhead1
% End of user PostScript
.84019 .3898 m
.83735 .39009 L
s
% Start of user PostScript
0.85857143 0.39285714 0.85560966 0.39316776 MAarrowhead1
% End of user PostScript
.84019 .42414 m
.83701 .42444 L
s
% Start of user PostScript
0.85857143 0.42857143 0.85525995 0.4288843 MAarrowhead1
% End of user PostScript
.84019 .45848 m
.83667 .45878 L
s
% Start of user PostScript
0.85857143 0.46428571 0.85491025 0.4645965 MAarrowhead1
% End of user PostScript
.84019 .49282 m
.83634 .49312 L
s
% Start of user PostScript
0.85857143 0.5 0.85456055 0.50030438 MAarrowhead1
% End of user PostScript
.90819 .01203 m
.90865 .01203 L
s
% Start of user PostScript
0.92928571 0. 0.92976464 0. MAarrowhead1
% End of user PostScript
.90819 .04637 m
.90831 .04642 L
s
% Start of user PostScript
0.92928571 0.035714286 0.92941214 0.035764343 MAarrowhead1
% End of user PostScript
.90819 .08071 m
.90798 .08081 L
s
% Start of user PostScript
0.92928571 0.071428571 0.92905964 0.071524685 MAarrowhead1
% End of user PostScript
.90819 .11506 m
.90764 .11519 L
s
% Start of user PostScript
0.92928571 0.10714286 0.92870714 0.10728102 MAarrowhead1
% End of user PostScript
.90819 .1494 m
.9073 .14957 L
s
% Start of user PostScript
0.92928571 0.14285714 0.92835464 0.14303336 MAarrowhead1
% End of user PostScript
.90819 .18374 m
.90696 .18394 L
s
% Start of user PostScript
0.92928571 0.17857143 0.92800213 0.1787817 MAarrowhead1
% End of user PostScript
.90819 .21808 m
.90662 .21831 L
s
% Start of user PostScript
0.92928571 0.21428571 0.92764963 0.21452604 MAarrowhead1
% End of user PostScript
.90819 .25243 m
.90628 .25268 L
s
% Start of user PostScript
0.92928571 0.25 0.92729713 0.25026637 MAarrowhead1
% End of user PostScript
.90819 .28677 m
.90594 .28705 L
s
% Start of user PostScript
0.92928571 0.28571429 0.92694463 0.28600271 MAarrowhead1
% End of user PostScript
.90819 .32111 m
.9056 .32141 L
s
% Start of user PostScript
0.92928571 0.32142857 0.92659212 0.32173504 MAarrowhead1
% End of user PostScript
.90819 .35545 m
.90526 .35576 L
s
% Start of user PostScript
0.92928571 0.35714286 0.92623962 0.35746337 MAarrowhead1
% End of user PostScript
.90819 .3898 m
.90492 .39011 L
s
% Start of user PostScript
0.92928571 0.39285714 0.92588712 0.3931877 MAarrowhead1
% End of user PostScript
.90819 .42414 m
.90459 .42446 L
s
% Start of user PostScript
0.92928571 0.42857143 0.92553462 0.42890802 MAarrowhead1
% End of user PostScript
.90819 .45848 m
.90425 .45881 L
s
% Start of user PostScript
0.92928571 0.46428571 0.92518212 0.46462435 MAarrowhead1
% End of user PostScript
.90819 .49282 m
.90391 .49315 L
s
% Start of user PostScript
0.92928571 0.5 0.92482961 0.50033668 MAarrowhead1
% End of user PostScript
.97619 .01203 m
.97619 .01203 L
s
% Start of user PostScript
1. 0. MAarrowzero1
% End of user PostScript
.97619 .04637 m
.97585 .04642 L
s
% Start of user PostScript
1. 0.035714286 0.99964506 0.035764484 MAarrowhead1
% End of user PostScript
.97619 .08071 m
.97551 .08081 L
s
% Start of user PostScript
1. 0.071428571 0.99929012 0.07152525 MAarrowhead1
% End of user PostScript
.97619 .11506 m
.97517 .11519 L
s
% Start of user PostScript
1. 0.10714286 0.99893518 0.1072823 MAarrowhead1
% End of user PostScript
.97619 .1494 m
.97483 .14957 L
s
% Start of user PostScript
1. 0.14285714 0.99858024 0.14303563 MAarrowhead1
% End of user PostScript
.97619 .18374 m
.97448 .18395 L
s
% Start of user PostScript
1. 0.17857143 0.9982253 0.17878524 MAarrowhead1
% End of user PostScript
.97619 .21808 m
.97414 .21832 L
s
% Start of user PostScript
1. 0.21428571 0.99787036 0.21453113 MAarrowhead1
% End of user PostScript
.97619 .25243 m
.9738 .25269 L
s
% Start of user PostScript
1. 0.25 0.99751542 0.2502733 MAarrowhead1
% End of user PostScript
.97619 .28677 m
.97346 .28705 L
s
% Start of user PostScript
1. 0.28571429 0.99716047 0.28601176 MAarrowhead1
% End of user PostScript
.97619 .32111 m
.97312 .32142 L
s
% Start of user PostScript
1. 0.32142857 0.99680553 0.3217465 MAarrowhead1
% End of user PostScript
.97619 .35545 m
.97278 .35577 L
s
% Start of user PostScript
1. 0.35714286 0.99645059 0.35747752 MAarrowhead1
% End of user PostScript
.97619 .3898 m
.97244 .39013 L
s
% Start of user PostScript
1. 0.39285714 0.99609565 0.39320482 MAarrowhead1
% End of user PostScript
.97619 .42414 m
.97209 .42448 L
s
% Start of user PostScript
1. 0.42857143 0.99574071 0.4289284 MAarrowhead1
% End of user PostScript
.97619 .45848 m
.97175 .45883 L
s
% Start of user PostScript
1. 0.46428571 0.99538577 0.46464826 MAarrowhead1
% End of user PostScript
.97619 .49282 m
.97141 .49317 L
s
% Start of user PostScript
1. 0.5 0.99503083 0.50036441 MAarrowhead1
% End of user PostScript
.5 Mabswid
.11076 .10819 m
.11259 .10821 L
.11433 .10827 L
.11645 .10838 L
.11855 .10853 L
.12252 .10889 L
.1272 .10944 L
.15238 .11356 L
.22847 .13017 L
.28017 .1435 L
.30885 .15204 L
.33409 .1608 L
.35463 .16947 L
.37015 .17783 L
.37728 .18275 L
.38277 .18751 L
.38711 .19261 L
.38887 .19552 L
.38949 .19682 L
.39004 .19824 L
.39072 .20078 L
.39092 .20216 L
.39099 .20346 L
.39086 .20578 L
.39034 .20826 L
.38988 .20965 L
.38923 .21116 L
.38765 .21388 L
.38565 .21652 L
.38336 .21893 L
.37815 .22325 L
.37082 .22787 L
.36139 .23247 L
.35092 .23652 L
.33995 .23994 L
.32702 .24317 L
.31487 .24558 L
.30047 .24778 L
.29182 .24879 L
.28365 .24955 L
.27901 .24989 L
.27389 .25021 L
.26436 .25061 L
.25516 .25076 L
.24517 .25068 L
.23646 .25039 L
.22671 .24982 L
.21574 .24886 L
.20545 .24763 L
.19407 .24589 L
Mistroke
.18194 .24355 L
.15969 .23772 L
.14027 .23064 L
.12246 .22195 L
.10506 .21056 L
.0908 .19808 L
.07976 .18545 L
.06941 .16995 L
.06203 .15546 L
.0561 .14034 L
.05179 .12579 L
.05026 .11926 L
.04902 .11281 L
.04819 .10731 L
.04767 .10273 L
.0474 .09899 L
.0473 .09527 L
.04731 .09356 L
.04738 .09181 L
.04762 .08892 L
.04802 .08636 L
.04849 .08428 L
.04919 .08215 L
.04997 .08038 L
.05082 .07892 L
.05169 .07772 L
.05275 .07656 L
.054 .07547 L
.0554 .07453 L
.05684 .07377 L
.0587 .07301 L
.06055 .07244 L
.06265 .07197 L
.06391 .07176 L
.06513 .07159 L
.0675 .07135 L
.06876 .07126 L
.07021 .07119 L
.07156 .07115 L
.07309 .07113 L
.07475 .07114 L
.07636 .07116 L
.0794 .07126 L
.08287 .07143 L
.08726 .07173 L
.09175 .07209 L
.1011 .07297 L
.15061 .0786 L
.31359 .09679 L
.43954 .11175 L
Mistroke
.49867 .12031 L
.54629 .12887 L
.56714 .13345 L
.58717 .13865 L
.60352 .1438 L
.61595 .14864 L
.62763 .15447 L
.63245 .15753 L
.63682 .1609 L
.6401 .16409 L
.64248 .16706 L
.6442 .16994 L
.64545 .17303 L
.64616 .17635 L
.64626 .17942 L
.6461 .18113 L
.64576 .183 L
.6447 .18644 L
.64321 .18969 L
.64112 .19317 L
.63611 .19952 L
.62836 .207 L
.61932 .21412 L
.59272 .23055 L
.52944 .25813 L
.48933 .27097 L
.4638 .27771 L
.439 .2833 L
.41629 .28762 L
.39037 .29164 L
.37554 .2935 L
.36152 .29497 L
.34781 .29612 L
.33299 .29705 L
.32005 .2976 L
.30593 .29788 L
.29239 .29785 L
.27988 .29755 L
.26508 .29682 L
.24882 .29553 L
.23339 .29379 L
.2191 .29168 L
.20228 .28851 L
.18478 .2843 L
.15463 .27429 L
.13883 .26718 L
.12496 .25951 L
.11003 .24926 L
.09734 .2383 L
.08758 .22794 L
Mistroke
.0783 .2159 L
.06528 .19364 L
.05956 .18085 L
.05465 .16759 L
.04827 .14554 L
.04462 .12858 L
.04321 .12044 L
.04221 .11348 L
.04152 .10769 L
.04099 .10203 L
.04069 .09745 L
.04055 .09363 L
.04055 .08925 L
.0407 .08564 L
.04096 .08277 L
.04137 .08003 L
.04195 .07741 L
.0423 .07623 L
.04271 .07502 L
.04355 .07311 L
.04445 .07156 L
.04554 .07011 L
.04684 .06879 L
.04807 .06782 L
.04955 .06692 L
.0513 .06611 L
.05337 .06541 L
.05439 .06515 L
.05551 .0649 L
.05765 .06454 L
.05981 .0643 L
.06229 .06413 L
.06481 .06404 L
.06726 .06403 L
.07034 .06408 L
.07218 .06415 L
.07395 .06423 L
.08126 .06469 L
.09635 .06602 L
.11755 .0682 L
.1798 .07466 L
.28946 .08516 L
.42487 .09828 L
.54374 .11275 L
.59809 .1221 L
.6367 .13153 L
.6517 .13658 L
.66459 .14224 L
.6694 .14491 L
.67375 .14778 L
Mistroke
.67692 .1503 L
.67973 .15305 L
.68191 .15576 L
.68344 .15826 L
.68454 .16081 L
.68519 .16326 L
.68551 .16614 L
.68538 .16884 L
.6848 .17183 L
.68369 .17506 L
.68212 .17827 L
.68029 .18126 L
.67486 .18808 L
.66075 .2008 L
.63923 .21536 L
.61051 .23096 L
.54474 .25835 L
.49962 .2726 L
.45324 .28408 L
.40504 .29284 L
.39101 .29479 L
.37578 .2966 L
.36232 .29793 L
.34755 .29909 L
.33338 .29991 L
.32022 .3004 L
.30678 .30062 L
.29387 .30056 L
.2787 .30012 L
.2645 .29934 L
.24881 .29803 L
.23207 .29606 L
.21697 .29372 L
.20055 .29048 L
.18478 .28659 L
.1683 .28155 L
.15334 .27594 L
.14029 .27003 L
.11674 .25619 L
.10412 .24643 L
.09361 .23648 L
.08358 .2249 L
.07409 .21132 L
.06163 .18748 L
.05648 .1745 L
.05255 .16275 L
.04701 .14192 L
.04365 .12504 L
.04178 .11244 L
.04109 .10633 L
Mistroke
.04065 .10125 L
.04034 .09598 L
.04024 .09161 L
.04028 .08813 L
.04046 .08479 L
.0408 .08159 L
.0413 .07864 L
.04185 .07645 L
.04258 .07434 L
.04348 .0724 L
.04444 .07084 L
.04563 .06937 L
.04704 .06805 L
.0484 .06709 L
.0498 .06632 L
.05146 .06562 L
.05341 .065 L
.05518 .06459 L
.05727 .06423 L
.05963 .06397 L
.06199 .06381 L
.06436 .06373 L
.06666 .06371 L
.06949 .06375 L
.07234 .06385 L
.07564 .06401 L
.07953 .06426 L
.08834 .06498 L
.10777 .06688 L
.17463 .07382 L
.28236 .0841 L
.4174 .097 L
.53806 .11127 L
.594 .12049 L
.63417 .12981 L
.64996 .1348 L
.66366 .1404 L
.66882 .14305 L
.67352 .14589 L
.67698 .14839 L
.6801 .15111 L
.68257 .1538 L
.68434 .15628 L
.68568 .15881 L
.68656 .16123 L
.68712 .16409 L
.68722 .16677 L
.68687 .16974 L
.686 .17294 L
.68466 .17613 L
Mistroke
.68303 .17909 L
.67802 .18588 L
.67182 .19231 L
.66462 .19853 L
.64204 .21415 L
.61589 .22862 L
.55146 .25616 L
.50801 .27036 L
.46156 .28239 L
.43882 .28717 L
.41353 .29165 L
.39065 .29496 L
.36505 .29779 L
.3502 .29901 L
.33638 .29986 L
.32223 .30044 L
.3086 .3007 L
.29252 .30063 L
.27744 .30016 L
.26072 .29917 L
.25222 .29845 L
.24282 .29749 L
.2266 .29536 L
.21156 .29282 L
.1952 .28934 L
.17802 .28474 L
.1605 .27884 L
.14464 .2722 L
.13097 .26519 L
.11742 .25674 L
.10657 .24856 L
.09567 .23866 L
.07935 .2193 L
.07179 .20759 L
.0649 .19467 L
.05537 .17144 L
.04817 .14687 L
.04558 .13539 L
.04354 .12446 L
.04213 .11525 L
.04124 .10793 L
.04066 .10149 L
.04034 .09618 L
.04023 .09162 L
.0403 .08741 L
.04049 .08426 L
.04084 .08121 L
.04136 .07835 L
.04171 .07692 L
.04207 .07571 L
Mistroke
.04287 .0736 L
.04376 .07188 L
.04469 .07046 L
.04582 .06914 L
.047 .06807 L
.04818 .06722 L
.0496 .0664 L
.05129 .06566 L
.05323 .06503 L
.05519 .06457 L
.05625 .06438 L
.05745 .0642 L
.05977 .06394 L
.06221 .06378 L
.06461 .06371 L
.0674 .0637 L
.06907 .06373 L
.0707 .06378 L
.07417 .06392 L
.07819 .06416 L
.08569 .06474 L
.09506 .06559 L
.11586 .06771 L
.17152 .07349 L
.28006 .08388 L
.41604 .09685 L
.53793 .11123 L
.59412 .12049 L
.6149 .12488 L
.6341 .12975 L
.65005 .13479 L
.66191 .13954 L
.67138 .14448 L
.67817 .14929 L
.68113 .15207 L
.68361 .15507 L
.6852 .15767 L
.68643 .16057 L
.68714 .16374 L
.68728 .16554 L
.68725 .16719 L
.68677 .17045 L
.68582 .17358 L
.68434 .17686 L
.68258 .17988 L
.6773 .18675 L
.66344 .1995 L
.64088 .21488 L
.61388 .22965 L
.54729 .25766 L
Mistroke
.50627 .27087 L
.45518 .28381 L
.40632 .29278 L
.39135 .29487 L
.37679 .29661 L
.36326 .29796 L
.34857 .29913 L
.33557 .29991 L
.32096 .30048 L
.30746 .30071 L
.29461 .30067 L
.27935 .30025 L
.26522 .29949 L
.24959 .2982 L
.23307 .29629 L
.21662 .29374 L
.19891 .2902 L
.18354 .28633 L
.16763 .28141 L
.15375 .27619 L
.13912 .26953 L
.11547 .25538 L
.10266 .24523 L
.09214 .235 L
.08214 .2231 L
.07283 .20933 L
.06565 .1962 L
.06011 .18394 L
.05188 .16058 L
.04649 .13964 L
.04329 .12297 L
.04154 .11061 L
.04092 .10466 L
.04054 .09978 L
.0403 .09507 L
.04023 .09117 L
.0403 .08738 L
.04053 .08382 L
.04094 .08057 L
.04146 .0779 L
.04204 .07581 L
.04279 .0738 L
.04396 .07155 L
.04471 .07044 L
.04548 .0695 L
.04722 .0679 L
.0483 .06714 L
.04936 .06653 L
Mfstroke
.11076 .20435 m
.09792 .19466 L
.08602 .18312 L
.07734 .17244 L
.0696 .16052 L
.06256 .14669 L
.05769 .13435 L
.05434 .12344 L
.05224 .11452 L
.05149 .11045 L
.0509 .10639 L
.05051 .10287 L
.0503 .0999 L
.05021 .09672 L
.05024 .09505 L
.0503 .09358 L
.05053 .09109 L
.05091 .08869 L
.05118 .08749 L
.05146 .08645 L
.05223 .08432 L
.05304 .08265 L
.05404 .0811 L
.05507 .07987 L
.05613 .07886 L
.05742 .07788 L
.05894 .07697 L
.06067 .07618 L
.0627 .07549 L
.06459 .07501 L
.06684 .0746 L
.06818 .07442 L
.06947 .07428 L
.07094 .07416 L
.07255 .07407 L
.07403 .07402 L
.07545 .07399 L
.07707 .07399 L
.07887 .07401 L
.08062 .07406 L
.0823 .07412 L
.08632 .07433 L
.09013 .07459 L
.09445 .07495 L
.113 .07686 L
.2461 .09271 L
.34646 .10452 L
.40725 .11224 L
.46385 .12037 L
.51192 .12861 L
Mistroke
.55641 .13837 L
.57283 .14291 L
.58802 .14792 L
.59912 .15236 L
.60925 .15736 L
.61856 .16349 L
.62243 .16692 L
.62529 .17017 L
.62733 .17326 L
.62866 .17612 L
.6296 .17945 L
.62991 .18265 L
.62985 .18431 L
.62962 .18615 L
.62921 .18809 L
.62865 .18992 L
.62726 .19322 L
.62522 .1968 L
.61857 .20507 L
.61016 .21277 L
.59117 .226 L
.56407 .24049 L
.52933 .25517 L
.49048 .26821 L
.4464 .27971 L
.42086 .28495 L
.3921 .28968 L
.36649 .29286 L
.3514 .29428 L
.33696 .29531 L
.32341 .29599 L
.31084 .29637 L
.29609 .29647 L
.28189 .29623 L
.26662 .29556 L
.25785 .29497 L
.24958 .29428 L
.23288 .29243 L
.21486 .2897 L
.19912 .2866 L
.18277 .28256 L
.15457 .27312 L
.13952 .26641 L
.12437 .25807 L
.1002 .23997 L
.08769 .22708 L
.07757 .21389 L
.06983 .20141 L
.0629 .18771 L
.05406 .16495 L
Mistroke
.04845 .14537 L
.04423 .12546 L
.04202 .11075 L
.04132 .10413 L
.04091 .09873 L
.04077 .09591 L
.0407 .09353 L
.04068 .09098 L
.04071 .08875 L
.0409 .08509 L
.04122 .08213 L
.0417 .07929 L
.04199 .078 L
.04236 .07668 L
.0431 .0746 L
.04392 .07287 L
.04475 .07151 L
.04575 .07021 L
.04696 .06899 L
.04838 .06788 L
.04972 .06708 L
.05132 .06634 L
.05294 .06576 L
.05452 .06532 L
.0564 .06493 L
.05852 .06462 L
.06051 .06442 L
.06247 .0643 L
.06477 .06422 L
.06738 .0642 L
.07036 .06425 L
.07215 .06431 L
.07388 .06439 L
.07758 .06459 L
.08188 .06489 L
.09962 .0665 L
.16153 .07298 L
.37933 .09393 L
.51458 .10901 L
.57942 .11894 L
.60523 .12404 L
.6261 .12905 L
.64288 .13403 L
.65759 .13962 L
.66799 .1449 L
.67519 .1499 L
.67829 .15277 L
.6806 .1555 L
.6825 .15854 L
.6833 .16026 L
Mistroke
.68385 .16184 L
.6845 .16506 L
.6846 .16691 L
.68452 .16862 L
.68397 .17181 L
.68349 .17343 L
.68283 .17523 L
.6812 .17858 L
.67926 .18174 L
.67336 .18902 L
.65774 .20269 L
.63859 .21548 L
.61338 .22935 L
.5776 .24567 L
.5379 .26061 L
.4975 .2731 L
.47411 .27921 L
.44746 .28523 L
.41971 .29045 L
.39299 .29447 L
.37967 .29611 L
.36482 .29764 L
.35058 .29882 L
.33695 .29967 L
.32151 .3003 L
.31319 .30049 L
.30413 .30057 L
.29508 .30052 L
.28546 .30031 L
.26809 .29953 L
.25182 .29827 L
.2366 .29661 L
.21991 .29417 L
.20219 .29079 L
.17131 .28251 L
.15462 .27642 L
.13992 .26981 L
.11515 .25503 L
.104 .24628 L
.0929 .2357 L
.07677 .21544 L
.06941 .2033 L
.06368 .192 L
.05502 .17032 L
.04926 .1511 L
.04457 .13016 L
.04305 .12136 L
.042 .11412 L
.0413 .10831 L
.04076 .1026 L
Mistroke
.04042 .09751 L
.04026 .09277 L
.04025 .09036 L
.04029 .08824 L
.04048 .08465 L
.04085 .08128 L
.04112 .07959 L
.04142 .07814 L
.04201 .07597 L
.04278 .07387 L
.04372 .07198 L
.04473 .07046 L
.04571 .06929 L
.04689 .06819 L
.04825 .0672 L
.04963 .06641 L
.051 .0658 L
.05239 .0653 L
.05411 .06483 L
.05578 .06448 L
.05778 .06417 L
.06005 .06394 L
.06213 .06381 L
.06456 .06373 L
.06737 .06372 L
.06903 .06375 L
.07061 .06379 L
.07384 .06392 L
.07712 .06411 L
.08445 .06465 L
.09226 .06534 L
.11404 .06754 L
.18014 .07437 L
.38997 .09426 L
.5211 .10894 L
.5773 .11744 L
.60461 .12266 L
.62599 .12762 L
.6417 .13207 L
.65592 .13707 L
.66784 .14254 L
.6722 .14507 L
.67631 .14791 L
.67929 .15038 L
.68193 .15309 L
.68412 .15599 L
.68562 .15875 L
.68661 .16153 L
.6871 .16421 L
.68719 .16664 L
Mistroke
.68691 .16932 L
.68656 .17096 L
.68604 .17271 L
.68475 .17587 L
.68286 .17932 L
.68021 .18315 L
.67403 .19014 L
.66671 .1968 L
.62569 .22351 L
.59426 .2389 L
.56063 .25276 L
.51849 .26721 L
.4672 .28109 L
.41849 .29084 L
.38848 .29523 L
.37422 .29688 L
.35885 .29834 L
.34547 .29933 L
.33055 .30014 L
.31675 .30058 L
.30372 .30072 L
.28807 .30053 L
.27368 .29998 L
.25691 .29886 L
.24099 .29728 L
.22497 .29511 L
.20743 .29201 L
.18934 .28788 L
.17278 .28311 L
.14455 .27215 L
.12981 .26453 L
.11722 .2566 L
.09263 .23552 L
.08119 .22183 L
.07223 .20832 L
.05961 .18273 L
.05444 .16871 L
.05073 .15661 L
.04587 .13677 L
.04263 .11872 L
.0416 .11108 L
.04117 .10728 L
.04085 .10393 L
.04043 .09804 L
.04025 .09335 L
.04024 .08945 L
.04038 .08581 L
.04061 .08304 L
.04097 .08034 L
.04149 .07778 L
Mistroke
.04218 .07539 L
.04295 .07343 L
.04376 .07186 L
.04482 .07029 L
.0461 .06887 L
.04744 .06772 L
.04879 .06684 L
.05052 .06597 L
.05259 .06522 L
.05361 .06493 L
.05474 .06466 L
.0569 .06427 L
.05907 .06401 L
.06158 .06382 L
.06414 .06372 L
.06663 .0637 L
.06977 .06375 L
.07165 .06381 L
.07346 .06389 L
.07697 .06408 L
.08098 .06436 L
.18923 .07526 L
.4 .09523 L
.52523 .10946 L
.57872 .11765 L
.62537 .12741 L
.6445 .1329 L
.6586 .1381 L
.6651 .14106 L
.67113 .14433 L
.67552 .14722 L
.67949 .15046 L
.6824 .1535 L
.68448 .1564 L
.68604 .15951 L
.68664 .16127 L
.68701 .1629 L
.68729 .16583 L
.68704 .16907 L
.6863 .17217 L
.6852 .17508 L
.68346 .17845 L
.6811 .18204 L
.67561 .18859 L
.65767 .20384 L
.63657 .21743 L
.60793 .23257 L
.57769 .24603 L
.54039 .26008 L
.50348 .27168 L
Mistroke
.45976 .2828 L
.43395 .28811 L
.4038 .29315 L
.39004 .29504 L
.37485 .29682 L
.36026 .29822 L
.34641 .29928 L
.33771 .2998 L
.32973 .30018 L
.32077 .30048 L
.3111 .30068 L
.3017 .30073 L
.29141 .30061 L
.28161 .30034 L
.27253 .29993 L
.25626 .29881 L
.24698 .29794 L
.23829 .29696 L
.22076 .29445 L
.20206 .2909 L
.18454 .28661 L
.16868 .28177 L
.15051 .27483 L
.13493 .26736 L
.10883 .25039 L
.0964 .23939 L
.08606 .22807 L
.07776 .21701 L
.07021 .20484 L
.05955 .18259 L
.05157 .15952 L
.04594 .13712 L
.0427 .11921 L
.04156 .11076 L
.04086 .10396 L
.04047 .09873 L
.04026 .09365 L
.04023 .09135 L
.04025 .08905 L
.04041 .08529 L
.04071 .08213 L
.04119 .07912 L
.04178 .07665 L
.04244 .07465 L
.0432 .07291 L
.04398 .07151 L
.04498 .0701 L
.04602 .06894 L
.04728 .06785 L
.0488 .06684 L
Mistroke
.05055 .06596 L
.05235 .06529 L
.05417 .06479 L
.05597 .06442 L
.0582 .0641 L
.06048 .06389 L
.06314 .06375 L
.06456 .06371 L
.0662 .0637 L
.06926 .06373 L
.07235 .06384 L
.07422 .06393 L
.07626 .06404 L
.08013 .0643 L
.08996 .06511 L
.21626 .07789 L
.44189 .09954 L
.50616 .10697 L
.56805 .11583 L
.59254 .12018 L
.6154 .12499 L
.64813 .13412 L
.6615 .13936 L
.66758 .14232 L
.67254 .1452 L
.67645 .14791 L
.67998 .15092 L
.68256 .15369 L
.68443 .15631 L
.68535 .15796 L
.68614 .15976 L
.6867 .16147 L
.68704 .16305 L
.68729 .1661 L
.687 .16936 L
.68662 .17107 L
.68606 .17292 L
.68463 .17629 L
.68228 .18035 L
.67953 .18411 L
.66695 .19665 L
.64804 .21041 L
.60121 .23575 L
.53327 .26248 L
.48632 .27637 L
.43653 .28762 L
Mfstroke
.11076 .3005 m
.09574 .28538 L
.08388 .27018 L
.07234 .25126 L
.06344 .2325 L
.05185 .19895 L
.04725 .18099 L
.04396 .16558 L
.03931 .13779 L
.03655 .11451 L
.03578 .10536 L
.03549 .10086 L
.0353 .0971 L
.0351 .09069 L
.03511 .08553 L
.03528 .08095 L
.03557 .0774 L
.03605 .07391 L
.03664 .07112 L
.03729 .06891 L
.03798 .06714 L
.03883 .06546 L
.03985 .06394 L
.04099 .06263 L
.04236 .06145 L
.04378 .06053 L
.04519 .05983 L
.04699 .05915 L
.04801 .05886 L
.04914 .05858 L
.05018 .05838 L
.05137 .05818 L
.05362 .05792 L
.05605 .05775 L
.05752 .05769 L
.05895 .05766 L
.06052 .05765 L
.06201 .05767 L
.0638 .05771 L
.06557 .05777 L
.06891 .05792 L
.07221 .05812 L
.08055 .05874 L
.13526 .06393 L
.35195 .08215 L
.48584 .09384 L
.55471 .10127 L
.61068 .10901 L
.63711 .11366 L
.66145 .11898 L
Mistroke
.67952 .12404 L
.69296 .12892 L
.70369 .13418 L
.7108 .1391 L
.71376 .14191 L
.71504 .1434 L
.7162 .14499 L
.71782 .14796 L
.71876 .15073 L
.7192 .15362 L
.71923 .15527 L
.71911 .15681 L
.71856 .15966 L
.71751 .16274 L
.71619 .16552 L
.71464 .16816 L
.71004 .17429 L
.69623 .18739 L
.67559 .20212 L
.62444 .22995 L
.5627 .25548 L
.52302 .26862 L
.47552 .28142 L
.45043 .28695 L
.42554 .29162 L
.40233 .29523 L
.37572 .29848 L
.35998 .29995 L
.34496 .30102 L
.32877 .30182 L
.31955 .3021 L
.31105 .30224 L
.29573 .3022 L
.27882 .30171 L
.26269 .30076 L
.24765 .29942 L
.23038 .29729 L
.21419 .29466 L
.19659 .29098 L
.17797 .286 L
.16008 .27993 L
.1421 .2722 L
.1276 .26442 L
.11303 .25474 L
.10028 .24419 L
.08977 .23347 L
.08106 .2227 L
.07275 .21021 L
.06133 .1878 L
.0528 .16456 L
Mistroke
.04675 .14182 L
.04449 .13084 L
.04288 .12153 L
.04178 .11385 L
.04093 .10647 L
.04043 .10059 L
.04017 .09577 L
.04007 .09143 L
.04014 .08731 L
.04035 .08391 L
.04067 .08115 L
.04105 .07893 L
.04155 .07675 L
.04219 .07474 L
.04287 .07309 L
.04379 .07138 L
.04477 .06998 L
.04574 .06888 L
.0469 .06784 L
.04828 .06687 L
.04989 .066 L
.05139 .06539 L
.05318 .06482 L
.05509 .06438 L
.057 .06406 L
.05926 .0638 L
.0606 .06369 L
.06187 .06362 L
.06458 .06353 L
.0662 .06352 L
.06775 .06353 L
.07077 .06361 L
.0742 .06376 L
.07733 .06394 L
.0809 .06419 L
.08798 .06477 L
.10753 .06668 L
.27248 .08296 L
.40445 .0954 L
.4776 .1032 L
.54889 .11246 L
.57972 .11741 L
.60531 .1223 L
.62683 .12728 L
.64359 .13203 L
.65665 .13663 L
.66818 .14185 L
.67696 .14728 L
.68063 .15032 L
.68336 .15321 L
Mistroke
.6855 .1562 L
.68634 .15773 L
.68709 .15942 L
.68794 .16246 L
.68824 .16534 L
.68819 .1671 L
.68799 .16879 L
.68721 .17198 L
.68656 .17378 L
.68582 .17547 L
.68368 .17933 L
.67859 .18605 L
.67252 .19226 L
.65428 .20658 L
.60483 .23423 L
.54106 .25995 L
.50154 .27232 L
.45271 .28442 L
.42587 .28965 L
.39541 .2944 L
.38002 .29631 L
.36507 .29785 L
.35135 .29899 L
.33612 .29994 L
.32182 .30051 L
.30817 .30076 L
.29298 .30069 L
.27639 .30017 L
.25975 .29914 L
.24212 .29746 L
.22703 .29548 L
.21058 .29268 L
.18146 .28579 L
.16566 .28077 L
.15178 .27541 L
.12652 .26265 L
.10544 .24766 L
.09514 .23817 L
.08526 .22713 L
.07058 .20553 L
.06353 .1918 L
.05804 .1788 L
.05043 .15556 L
.04533 .13418 L
.04249 .11781 L
.04145 .10988 L
.04082 .10357 L
.04057 .1004 L
.04038 .09722 L
.04027 .09445 L
Mistroke
.04023 .09207 L
.04026 .08847 L
.04042 .08504 L
.0407 .08219 L
.04105 .07987 L
.04156 .07745 L
.04225 .07515 L
.04302 .07327 L
.04383 .07174 L
.04476 .07036 L
.04573 .06922 L
.0469 .06813 L
.04829 .06713 L
.0498 .0663 L
.05153 .06556 L
.05314 .06505 L
.05503 .06459 L
.05609 .0644 L
.05726 .06421 L
.05948 .06396 L
.06206 .06378 L
.06362 .06373 L
.06514 .0637 L
.06805 .0637 L
.07089 .06378 L
.07255 .06384 L
.07442 .06393 L
.07801 .06414 L
.09447 .06553 L
.11414 .06752 L
.28968 .08476 L
.40782 .096 L
.53522 .11083 L
.56593 .11547 L
.59481 .12061 L
.61805 .12559 L
.63653 .13043 L
.65219 .13555 L
.66374 .14037 L
.67369 .14592 L
.67793 .14905 L
.68117 .15207 L
.68342 .15475 L
.68525 .15769 L
.68644 .1605 L
.68709 .16311 L
.68733 .16619 L
.68722 .16796 L
.68698 .16961 L
.68617 .17267 L
Mistroke
.68481 .17597 L
.68287 .17947 L
.6802 .18329 L
.6739 .19036 L
.65753 .20396 L
.63678 .21732 L
.60983 .23165 L
.54914 .25701 L
.50798 .27038 L
.46582 .28142 L
.44053 .28684 L
.41141 .292 L
.38236 .29598 L
.36894 .29743 L
.35416 .29872 L
.34024 .29966 L
.32724 .30028 L
.31462 .30063 L
.30114 .30073 L
.28613 .30049 L
.272 .2999 L
.25637 .29882 L
.23958 .29712 L
.22326 .29485 L
.20567 .29166 L
.19034 .28814 L
.17442 .28364 L
.16046 .27883 L
.14567 .27267 L
.12152 .25948 L
.10845 .25008 L
.09744 .24041 L
.08585 .22781 L
.07679 .21557 L
.06348 .19166 L
.05793 .17846 L
.05368 .16638 L
.04811 .14666 L
.04427 .12863 L
.04289 .12046 L
.04177 .11249 L
.0411 .10653 L
.0406 .10077 L
.04041 .09761 L
.04029 .0949 L
.04024 .09248 L
.04023 .0901 L
.04035 .08638 L
.04064 .08279 L
.04087 .08101 L
Mistroke
.04112 .0795 L
.04144 .078 L
.04183 .07649 L
.04265 .07411 L
.04358 .07218 L
.04466 .07051 L
.04576 .06921 L
.04717 .06793 L
.04865 .06692 L
.05016 .06613 L
.05166 .06553 L
.05345 .06497 L
.05549 .06451 L
.05757 .06418 L
.05882 .06403 L
.06002 .06392 L
.06234 .06378 L
.06499 .0637 L
.06753 .0637 L
.07006 .06376 L
.07301 .06387 L
.07642 .06405 L
.08437 .06462 L
.09407 .06549 L
.11543 .06766 L
.26181 .08218 L
.38303 .09356 L
.45495 .10096 L
.51959 .10871 L
.57269 .11661 L
.59691 .12104 L
.6194 .12593 L
.6357 .13021 L
.65087 .13508 L
.66225 .1397 L
.67076 .14411 L
.67867 .14972 L
.68176 .15276 L
.68307 .15433 L
.68427 .15605 L
.68523 .15771 L
.68594 .15925 L
.6869 .16231 L
.68727 .16513 L
.68717 .16815 L
.68665 .17095 L
.68566 .17399 L
.68433 .17689 L
.68279 .17956 L
.67778 .18621 L
Mistroke
.67151 .19264 L
.65288 .2072 L
.63027 .22102 L
.60014 .23625 L
.56142 .25247 L
.52135 .26633 L
.47988 .27802 L
.43581 .28776 L
.41198 .29191 L
.38465 .29571 L
.36833 .29748 L
.35254 .29885 L
.33805 .29978 L
.32205 .30045 L
.31361 .30064 L
.30424 .30073 L
.29437 .30066 L
.28506 .30045 L
.26826 .29968 L
.25876 .29902 L
.25006 .29825 L
.23315 .2963 L
.2175 .2939 L
.20045 .29054 L
.18259 .28607 L
.16597 .28083 L
.15089 .27499 L
.12471 .2615 L
.1126 .25329 L
.10074 .24351 L
.0825 .22358 L
.07339 .21026 L
.06616 .19722 L
.05584 .17279 L
.04867 .14888 L
.0445 .12987 L
.04182 .11291 L
.04103 .10583 L
.04073 .10247 L
.04049 .09907 L
.04027 .09408 L
.04023 .08992 L
.04035 .08635 L
.04057 .08341 L
.04097 .08033 L
.04146 .07789 L
.04216 .07544 L
.04295 .07344 L
.04374 .0719 L
.04468 .07047 L
Mistroke
.04664 .06837 L
.04788 .06741 L
.04914 .06664 L
.05064 .06592 L
.05238 .06528 L
.05421 .06478 L
.05641 .06435 L
.05758 .06418 L
.0589 .06402 L
.06144 .06382 L
.06403 .06372 L
.06696 .0637 L
.06965 .06374 L
.07279 .06386 L
.07482 .06396 L
.07682 .06407 L
.08078 .06434 L
.09079 .06519 L
.11346 .06746 L
.27793 .08368 L
.40472 .0957 L
.47718 .10346 L
.5399 .11151 L
.58601 .11896 L
.62607 .12759 L
.64417 .13279 L
.65821 .13793 L
.66828 .1427 L
.67667 .14808 L
.68021 .15113 L
.6828 .15399 L
.68494 .15718 L
.68575 .1588 L
.68644 .1606 L
.68714 .16367 L
.68728 .16541 L
.68727 .167 L
.68684 .17014 L
.68598 .17314 L
.68474 .17607 L
.683 .17922 L
.67885 .18495 L
.67298 .19124 L
.66493 .19832 L
.64378 .2131 L
.61444 .22937 L
.54495 .25849 L
.47898 .27825 L
Mfstroke
.11076 .39666 m
.08828 .36577 L
.07208 .33394 L
.05809 .29439 L
.04875 .25669 L
.0427 .22378 L
.03873 .19644 L
.03344 .1477 L
.03194 .12911 L
.03101 .11511 L
.03038 .10282 L
.03004 .0924 L
.02997 .08807 L
.02996 .08389 L
.03009 .07749 L
.03038 .07248 L
.03077 .06866 L
.03131 .0653 L
.03166 .06367 L
.03202 .06232 L
.03277 .06015 L
.03366 .05825 L
.03456 .05681 L
.03548 .05568 L
.03659 .05462 L
.0379 .05368 L
.03943 .05286 L
.04029 .0525 L
.04126 .05216 L
.04215 .05191 L
.04318 .05166 L
.04511 .05131 L
.04714 .05107 L
.04952 .0509 L
.05197 .05083 L
.05438 .05082 L
.05735 .05088 L
.06027 .051 L
.06392 .05119 L
.06766 .05144 L
.08446 .05279 L
.14619 .05811 L
.25326 .06602 L
.41929 .07726 L
.56898 .08938 L
.60457 .09313 L
.6387 .09736 L
.66446 .10119 L
.68846 .10556 L
.70776 .11 L
Mistroke
.72227 .11428 L
.73329 .11854 L
.73792 .12078 L
.74221 .12324 L
.74574 .12572 L
.7484 .12804 L
.75045 .1303 L
.75211 .13272 L
.75319 .13492 L
.75386 .13701 L
.75423 .13933 L
.75424 .14186 L
.75381 .14463 L
.75337 .14623 L
.75283 .14774 L
.75141 .15083 L
.74939 .1542 L
.74452 .16046 L
.73881 .16635 L
.69773 .19621 L
.64427 .22471 L
.57092 .25506 L
.52913 .26883 L
.48532 .28078 L
.45912 .28674 L
.42912 .29247 L
.40285 .29653 L
.38844 .29838 L
.37261 .30008 L
.35715 .30142 L
.34275 .30237 L
.32801 .30303 L
.31381 .30336 L
.29769 .30335 L
.28258 .30296 L
.26582 .30205 L
.24787 .30049 L
.23372 .29878 L
.21849 .29642 L
.19123 .29063 L
.17581 .28628 L
.16002 .28083 L
.13347 .26864 L
.11991 .26044 L
.1064 .25037 L
.09564 .24052 L
.08548 .22919 L
.07745 .21833 L
.06982 .20587 L
.05924 .18347 L
Mistroke
.05079 .15846 L
.04515 .13496 L
.04335 .1252 L
.04207 .11694 L
.04116 .10972 L
.04058 .10391 L
.0402 .09867 L
.04 .09429 L
.03996 .09018 L
.04007 .08628 L
.04029 .08326 L
.04064 .08045 L
.04104 .07831 L
.04156 .07621 L
.04229 .07404 L
.04308 .07232 L
.04411 .07059 L
.04522 .06919 L
.04635 .06807 L
.0475 .06718 L
.04887 .06633 L
.05045 .06558 L
.05203 .065 L
.0539 .06448 L
.05601 .06406 L
.05814 .06377 L
.06029 .06357 L
.06237 .06346 L
.06493 .0634 L
.06752 .0634 L
.07055 .06347 L
.07399 .06362 L
.07713 .06381 L
.08082 .06406 L
.09992 .06579 L
.22577 .07845 L
.35547 .09048 L
.4287 .09766 L
.49543 .10507 L
.55473 .11306 L
.60011 .12091 L
.63942 .13034 L
.65583 .13583 L
.66802 .14119 L
.67645 .1462 L
.68021 .1491 L
.68307 .15185 L
.68545 .15481 L
.68706 .15755 L
.68773 .15908 L
Mistroke
.68829 .16075 L
.68886 .16383 L
.68891 .1665 L
.68851 .16948 L
.68761 .17263 L
.68633 .17562 L
.68306 .18105 L
.67821 .18701 L
.6612 .20192 L
.63879 .21658 L
.58183 .24456 L
.50636 .27101 L
.45558 .28385 L
.42935 .28908 L
.40391 .29325 L
.37862 .29651 L
.3653 .29788 L
.35071 .29908 L
.33577 .3 L
.32156 .30056 L
.31276 .30075 L
.30435 .30082 L
.2884 .30064 L
.27426 .30011 L
.2591 .29913 L
.24609 .29793 L
.23169 .29618 L
.2163 .29377 L
.19982 .29048 L
.17071 .28252 L
.15514 .27683 L
.14157 .27081 L
.12772 .26339 L
.11376 .25421 L
.10196 .24467 L
.09211 .23504 L
.07582 .21415 L
.06848 .20174 L
.06267 .18994 L
.05281 .1637 L
.04673 .14078 L
.04445 .12964 L
.04288 .12044 L
.04168 .11187 L
.04095 .10508 L
.04065 .10157 L
.04045 .09851 L
.04031 .09552 L
.04023 .09253 L
.04022 .09026 L
Mistroke
.04027 .08795 L
.04037 .08572 L
.04052 .0838 L
.0409 .08071 L
.04118 .07915 L
.04146 .07784 L
.04215 .07543 L
.04291 .0735 L
.04387 .07166 L
.04504 .07 L
.04618 .06877 L
.04735 .06777 L
.04877 .06684 L
.05044 .06599 L
.05217 .06534 L
.05387 .06485 L
.056 .06441 L
.05817 .06409 L
.06033 .06389 L
.06246 .06376 L
.06496 .06369 L
.0678 .0637 L
.07087 .06377 L
.07269 .06384 L
.07441 .06393 L
.08153 .06439 L
.10173 .06624 L
.25976 .08198 L
.37647 .09291 L
.50895 .1073 L
.56903 .11597 L
.5964 .12091 L
.62186 .1265 L
.64129 .13184 L
.6559 .13695 L
.66706 .14201 L
.67602 .14752 L
.67943 .15033 L
.68241 .15342 L
.68456 .1564 L
.68598 .15918 L
.68683 .16173 L
.68729 .16457 L
.68728 .16757 L
.68683 .17043 L
.68579 .17379 L
.6843 .17703 L
.68027 .18322 L
.67424 .19004 L
.6658 .19764 L
Mistroke
.62324 .22485 L
.56677 .25042 L
.52706 .26452 L
.47792 .27852 L
.45312 .28426 L
.42535 .28968 L
.40004 .2937 L
.38559 .2956 L
.37157 .29716 L
.35784 .29843 L
.3426 .29952 L
.32846 .30023 L
.31516 .30062 L
.3025 .30073 L
.28834 .30055 L
.27339 .29998 L
.25923 .29906 L
.24335 .29755 L
.2266 .29537 L
.21234 .29297 L
.19688 .28974 L
.18044 .28545 L
.16334 .2799 L
.13441 .26709 L
.12096 .25912 L
.10735 .2492 L
.09541 .23841 L
.08415 .22571 L
.07512 .21301 L
.06809 .20096 L
.05741 .1771 L
.04931 .1514 L
.04623 .13845 L
.0441 .12769 L
.04262 .11866 L
.04161 .11115 L
.04118 .10737 L
.04082 .10358 L
.04059 .10062 L
.04041 .09766 L
.04024 .09274 L
.04026 .08872 L
.04034 .0865 L
.04047 .08456 L
.04083 .08129 L
.04107 .07979 L
.04136 .07831 L
.042 .07593 L
.04282 .07372 L
.0439 .07164 L
Mistroke
.04495 .07013 L
.04603 .06894 L
.0474 .06776 L
.04885 .06681 L
.05029 .06607 L
.05175 .06549 L
.05347 .06497 L
.05546 .06452 L
.05757 .06418 L
.05885 .06403 L
.06009 .06392 L
.06145 .06382 L
.06275 .06376 L
.0643 .06372 L
.06584 .0637 L
.06871 .06372 L
.07156 .06381 L
.0749 .06396 L
.07872 .0642 L
.09711 .06579 L
.12458 .06863 L
.30463 .08615 L
.43073 .09836 L
.49954 .10614 L
.55728 .11411 L
.60905 .12356 L
.63105 .12891 L
.65031 .13488 L
.66414 .14059 L
.66967 .14347 L
.67404 .14618 L
.68046 .15138 L
.68295 .15418 L
.68495 .15719 L
.68627 .16009 L
.68709 .16331 L
.68729 .1664 L
.68701 .1693 L
.68629 .17221 L
.68529 .17488 L
.68373 .178 L
.68187 .18096 L
.67639 .18776 L
.66986 .19414 L
.6503 .20893 L
.60344 .23471 L
.5363 .26147 L
.49337 .27449 L
.44953 .28501 L
.42329 .29003 L
Mistroke
.39314 .29464 L
.37877 .29639 L
.36313 .29797 L
.34948 .29907 L
.33411 .29998 L
.31955 .30052 L
.30396 .30073 L
.29047 .30059 L
.27554 .30008 L
.25925 .29906 L
.24174 .29737 L
.22519 .29515 L
.21021 .29257 L
.1815 .28576 L
.16581 .28078 L
.15183 .27539 L
.12774 .26333 L
.10521 .24743 L
.09442 .23739 L
.08401 .22552 L
.07602 .2144 L
.06871 .20212 L
.05797 .17858 L
.05105 .15776 L
.04541 .13457 L
.0436 .12481 L
.04235 .11681 L
.04152 .1104 L
.04087 .10415 L
.04046 .09861 L
.04026 .09348 L
.04025 .08919 L
.04039 .08562 L
.04064 .08279 L
.04102 .08007 L
.04157 .07747 L
.04229 .07507 L
.04301 .0733 L
.04393 .07159 L
.04489 .0702 L
.04587 .06909 L
.04711 .06798 L
.0484 .06708 L
.04959 .06641 L
.05097 .06579 L
.05259 .06522 L
.05422 .06478 L
.05624 .06438 L
.05745 .06419 L
.05864 .06405 L
Mistroke
.05994 .06393 L
.06118 .06384 L
.06267 .06376 L
.06414 .06372 L
.06689 .0637 L
.06961 .06374 L
.07282 .06386 L
.07647 .06405 L
.08493 .06467 L
.09412 .0655 L
.12051 .0682 L
.29528 .08529 L
.42608 .09788 L
.49809 .10596 L
.55834 .11427 L
.6017 .12201 L
.63807 .1309 L
.65405 .13627 L
.66606 .14153 L
.67439 .14642 L
.67813 .14926 L
.68096 .15189 L
.68336 .15472 L
.68509 .15744 L
.68636 .16036 L
.68713 .16359 L
.68729 .16645 L
.68697 .16952 L
.68621 .17247 L
.68516 .17516 L
.68333 .17867 L
.68119 .18193 L
.6748 .18943 L
.65822 .20344 L
.63662 .21741 L
.60712 .23296 L
.52973 .26365 L
.50536 .27114 L
Mfstroke
.11076 .49282 m
.08143 .44033 L
.06234 .38536 L
.04786 .31889 L
.03953 .26027 L
.03479 .2143 L
.03198 .18003 L
.0287 .1273 L
.02792 .10965 L
.02752 .09713 L
.02735 .08661 L
.02738 .07802 L
.02747 .07452 L
.02762 .07118 L
.028 .06615 L
.02849 .06227 L
.02904 .05936 L
.02975 .05681 L
.03019 .05559 L
.03062 .05459 L
.0315 .05299 L
.03253 .05159 L
.03355 .05056 L
.0346 .04976 L
.03584 .04902 L
.0373 .04838 L
.039 .04785 L
.04003 .04761 L
.04104 .04742 L
.04302 .04715 L
.04408 .04705 L
.04531 .04697 L
.04757 .04688 L
.05022 .04687 L
.05294 .04692 L
.05563 .04702 L
.05896 .04718 L
.06223 .04739 L
.07055 .04799 L
.08959 .04957 L
.16043 .05512 L
.29353 .06367 L
.46349 .07405 L
.54363 .07973 L
.611 .08558 L
.66924 .09223 L
.69447 .09599 L
.71718 .10023 L
.73547 .10465 L
.74347 .10706 L
Mistroke
.75082 .1097 L
.75681 .11229 L
.76136 .11469 L
.76521 .11719 L
.76808 .11952 L
.77033 .12186 L
.7721 .12437 L
.77332 .12695 L
.77377 .12843 L
.77404 .12982 L
.77417 .13239 L
.77392 .13476 L
.7732 .13755 L
.77213 .14023 L
.77078 .14281 L
.76899 .14563 L
.7649 .15085 L
.75192 .16329 L
.71244 .19064 L
.66112 .21836 L
.60177 .24448 L
.56435 .25832 L
.51984 .27233 L
.47724 .28336 L
.42648 .29347 L
.4104 .29599 L
.39291 .29835 L
.37627 .30021 L
.36034 .30165 L
.34512 .3027 L
.32846 .30346 L
.31884 .30372 L
.30962 .30383 L
.29212 .30368 L
.27614 .30308 L
.259 .30194 L
.24428 .3005 L
.22801 .29835 L
.21067 .29536 L
.19219 .29125 L
.17503 .2864 L
.15989 .28113 L
.13125 .26774 L
.11694 .25873 L
.10456 .24913 L
.0856 .22964 L
.07672 .21753 L
.06966 .20587 L
.05814 .18094 L
.05332 .16716 L
Mistroke
.04974 .15491 L
.0447 .13298 L
.04287 .12255 L
.04164 .11404 L
.0408 .10676 L
.04049 .10339 L
.04024 .10001 L
.04005 .09658 L
.03994 .09361 L
.03991 .09094 L
.03993 .08867 L
.04011 .08488 L
.04027 .08295 L
.04047 .08128 L
.04072 .07965 L
.04099 .07827 L
.04132 .07687 L
.04172 .0755 L
.04252 .07336 L
.04337 .07164 L
.04442 .07005 L
.04574 .06855 L
.047 .06746 L
.04849 .06647 L
.05005 .06568 L
.05159 .06508 L
.05348 .06452 L
.0554 .06411 L
.05726 .06382 L
.05943 .06359 L
.06196 .06342 L
.06332 .06338 L
.06487 .06335 L
.06777 .06336 L
.07068 .06343 L
.0738 .06357 L
.07697 .06375 L
.08348 .06422 L
.1012 .06587 L
.25491 .08112 L
.37643 .0924 L
.44924 .09974 L
.5149 .10741 L
.56945 .11527 L
.59438 .11967 L
.61752 .12452 L
.63443 .12877 L
.65016 .1336 L
.66202 .13817 L
.67092 .14252 L
Mistroke
.67944 .14816 L
.6828 .15121 L
.68555 .1545 L
.6873 .1574 L
.68841 .16016 L
.68907 .16324 L
.6892 .16499 L
.68916 .1666 L
.68873 .16958 L
.68793 .17238 L
.68661 .1755 L
.68473 .17887 L
.68 .18521 L
.67439 .19107 L
.65632 .20552 L
.63002 .22162 L
.59943 .2369 L
.56582 .25103 L
.52674 .26482 L
.48653 .27648 L
.43654 .28776 L
.40655 .29287 L
.39247 .29485 L
.37652 .29676 L
.36202 .29819 L
.34602 .29942 L
.33705 .29995 L
.32873 .30033 L
.31216 .30077 L
.29763 .30081 L
.28151 .30044 L
.26449 .29954 L
.24852 .2982 L
.23935 .29718 L
.22941 .29587 L
.21141 .29289 L
.19407 .28916 L
.17836 .28493 L
.1444 .27217 L
.12861 .26393 L
.11262 .25338 L
.09021 .23296 L
.07974 .21991 L
.07148 .20712 L
.0597 .18302 L
.0512 .15831 L
.04587 .13685 L
.04281 .12002 L
.04192 .11372 L
.04121 .10771 L
Mistroke
.04067 .10185 L
.04037 .09707 L
.04022 .09208 L
.04026 .0881 L
.04035 .08611 L
.04049 .08411 L
.04088 .08085 L
.04138 .07819 L
.04204 .07575 L
.04272 .07392 L
.04358 .07215 L
.04473 .07038 L
.04593 .069 L
.04741 .06773 L
.04915 .06662 L
.05083 .06583 L
.05253 .06522 L
.05456 .06469 L
.05577 .06444 L
.05693 .06426 L
.05908 .06399 L
.06124 .06382 L
.06378 .06372 L
.06672 .06369 L
.06827 .0637 L
.07004 .06374 L
.07345 .06388 L
.07701 .06407 L
.08055 .06432 L
.11769 .06789 L
.29648 .08538 L
.41549 .09677 L
.4795 .10371 L
.54182 .11176 L
.57134 .11635 L
.60004 .12163 L
.64032 .13154 L
.6553 .13671 L
.66791 .14245 L
.67281 .14531 L
.67675 .14807 L
.67996 .15081 L
.68236 .15335 L
.68435 .15606 L
.68592 .15901 L
.68685 .16179 L
.68729 .16447 L
.68729 .16761 L
.68681 .17057 L
.68577 .17386 L
Mistroke
.68497 .17571 L
.6841 .17741 L
.67955 .18414 L
.67265 .1916 L
.65535 .20552 L
.60653 .23326 L
.54484 .25854 L
.5054 .27113 L
.4578 .28324 L
.43266 .28835 L
.4076 .29259 L
.38405 .29578 L
.37134 .29719 L
.35734 .29847 L
.34177 .29957 L
.32684 .30029 L
.31807 .30056 L
.30874 .30071 L
.29185 .30062 L
.2832 .3004 L
.2739 .3 L
.25702 .29888 L
.24664 .29791 L
.23683 .29678 L
.21847 .29407 L
.2025 .291 L
.18582 .28696 L
.15698 .27749 L
.14181 .27086 L
.12838 .26371 L
.11459 .25475 L
.10124 .24397 L
.08972 .23235 L
.08057 .22099 L
.06623 .19736 L
.06005 .18381 L
.05469 .16946 L
.04783 .14547 L
.04382 .12613 L
.0425 .11783 L
.04145 .1098 L
.04084 .10375 L
.04043 .09805 L
.04025 .09333 L
.04024 .08953 L
.04037 .08596 L
.04065 .08265 L
.04101 .08015 L
.04151 .07771 L
.04217 .07542 L
Mistroke
.04302 .07329 L
.04395 .07155 L
.04492 .07017 L
.04598 .06898 L
.04707 .06801 L
.04838 .06709 L
.0499 .06626 L
.05148 .06559 L
.05308 .06507 L
.05463 .06469 L
.05642 .06435 L
.05861 .06405 L
.06075 .06387 L
.06342 .06374 L
.06614 .0637 L
.06883 .06372 L
.07148 .0638 L
.07458 .06394 L
.0781 .06416 L
.09499 .06558 L
.11978 .06812 L
.30456 .08615 L
.43066 .09835 L
.49947 .10613 L
.55722 .1141 L
.60901 .12355 L
.63101 .1289 L
.65028 .13487 L
.66412 .14058 L
.66965 .14346 L
.67403 .14617 L
.68045 .15136 L
.68294 .15416 L
.68494 .15718 L
.68626 .16008 L
.68709 .1633 L
.68729 .16639 L
.68701 .16929 L
.6863 .1722 L
.6853 .17487 L
.68373 .17798 L
.68188 .18095 L
.6764 .18775 L
.66987 .19413 L
.65032 .20892 L
.60348 .23469 L
.53634 .26145 L
.49342 .27448 L
.44959 .285 L
.42335 .29002 L
Mistroke
.3932 .29463 L
.37883 .29638 L
.36319 .29797 L
.34954 .29906 L
.33417 .29998 L
.31961 .30052 L
.30403 .30073 L
.29054 .30059 L
.27561 .30008 L
.25932 .29906 L
.24181 .29738 L
.22526 .29516 L
.21028 .29258 L
.18157 .28578 L
.16588 .2808 L
.15189 .27541 L
.1278 .26337 L
.10526 .24747 L
.09446 .23744 L
.08405 .22557 L
.07605 .21445 L
.06874 .20217 L
.05799 .17863 L
.05107 .15781 L
.04542 .13461 L
.0436 .12485 L
.04235 .11684 L
.04152 .11043 L
.04088 .10418 L
.04046 .09863 L
.04026 .0935 L
.04025 .08921 L
.04039 .08564 L
.04063 .08281 L
.04102 .08008 L
.04156 .07748 L
.04228 .07508 L
.04301 .0733 L
.04393 .07159 L
.04489 .07021 L
.04586 .0691 L
.0471 .06799 L
.04839 .06708 L
.04959 .06641 L
.05096 .06579 L
.05259 .06522 L
.05421 .06478 L
.05623 .06438 L
.05744 .0642 L
.05863 .06405 L
Mistroke
.05993 .06393 L
.06117 .06384 L
.06266 .06376 L
.06413 .06372 L
.06688 .0637 L
.0696 .06374 L
.0728 .06386 L
.07646 .06405 L
.08491 .06467 L
.0941 .0655 L
.12048 .0682 L
.29522 .08528 L
.42601 .09787 L
.49802 .10595 L
.55829 .11426 L
.60166 .122 L
.63803 .13089 L
.65403 .13626 L
.66604 .14152 L
.67437 .14641 L
.67812 .14925 L
.68095 .15188 L
.68335 .15471 L
.68508 .15743 L
.68636 .16035 L
.68713 .16358 L
.68729 .16643 L
.68697 .16951 L
.68621 .17245 L
.68517 .17515 L
.68334 .17866 L
.6812 .18192 L
.67481 .18942 L
.65824 .20343 L
.63664 .2174 L
.60715 .23295 L
.52977 .26363 L
.52444 .26535 L
Mfstroke
.20692 .10819 m
.26775 .11853 L
.34485 .13281 L
.38417 .14118 L
.4234 .15097 L
.45531 .16091 L
.47908 .1707 L
.4899 .17658 L
.49894 .18299 L
.50262 .18638 L
.50543 .1896 L
.50781 .19317 L
.50883 .19519 L
.50955 .19705 L
.51002 .19866 L
.51036 .20038 L
.51057 .20349 L
.51044 .20541 L
.51014 .20722 L
.50973 .20885 L
.50912 .21061 L
.50757 .21392 L
.50533 .21742 L
.49982 .2237 L
.49279 .22967 L
.48338 .23601 L
.46164 .24712 L
.44543 .25357 L
.42807 .25935 L
.40946 .26452 L
.39039 .26892 L
.37008 .27272 L
.35019 .27564 L
.33916 .27692 L
.32674 .2781 L
.31388 .27902 L
.30672 .2794 L
.29997 .27966 L
.29323 .27985 L
.28583 .27995 L
.27219 .27985 L
.25868 .27939 L
.24605 .27861 L
.23225 .27734 L
.21699 .2754 L
.20104 .2727 L
.18622 .26949 L
.16008 .26182 L
.13665 .25208 L
.11738 .24114 L
Mistroke
.09884 .22684 L
.08213 .2089 L
.06837 .18794 L
.0589 .1678 L
.05278 .15044 L
.04827 .1337 L
.04514 .11811 L
.04412 .11138 L
.04335 .10496 L
.0429 .09962 L
.0427 .0953 L
.04266 .09147 L
.04276 .08831 L
.04301 .08522 L
.04342 .08233 L
.04389 .08012 L
.04443 .07826 L
.04513 .07645 L
.04599 .07473 L
.04706 .07313 L
.04817 .07184 L
.04954 .07063 L
.05116 .06954 L
.05306 .0686 L
.05504 .06789 L
.05698 .06738 L
.05814 .06714 L
.05927 .06695 L
.06142 .06668 L
.06397 .06647 L
.06665 .06637 L
.06824 .06634 L
.06975 .06634 L
.07259 .0664 L
.0759 .06652 L
.07925 .06671 L
.08256 .06693 L
.09858 .06835 L
.12089 .0707 L
.17858 .07693 L
.27281 .08644 L
.40806 .10014 L
.47357 .10772 L
.53786 .11669 L
.5887 .12598 L
.62456 .13513 L
.64081 .14083 L
.65267 .14629 L
.66238 .1525 L
.66602 .15573 L
Mistroke
.6691 .15934 L
.67018 .16098 L
.67104 .16256 L
.67221 .16555 L
.67286 .16881 L
.67295 .17068 L
.67287 .17243 L
.6723 .17565 L
.67134 .17862 L
.66972 .18207 L
.66772 .18537 L
.66256 .19188 L
.65631 .19807 L
.63739 .21248 L
.61314 .22681 L
.58116 .24223 L
.54599 .25627 L
.50782 .2689 L
.46628 .28003 L
.42303 .28896 L
.39894 .29279 L
.37174 .29615 L
.35649 .29758 L
.34803 .29823 L
.34007 .29874 L
.32575 .29942 L
.3098 .29981 L
.30161 .29986 L
.29265 .29978 L
.27623 .29928 L
.26007 .2983 L
.24508 .29694 L
.2288 .29491 L
.21096 .29195 L
.19252 .28795 L
.17562 .28329 L
.16137 .27847 L
.14641 .27233 L
.13384 .26611 L
.12121 .25863 L
.09987 .24209 L
.08344 .2242 L
.07509 .21239 L
.06743 .19915 L
.05683 .17498 L
.04984 .15284 L
.0456 .1349 L
.04385 .12567 L
.04259 .11782 L
.04173 .11142 L
Mistroke
.04107 .10535 L
.04061 .0995 L
.04038 .09475 L
.04032 .09026 L
.04037 .08796 L
.04046 .08597 L
.04074 .08279 L
.04111 .08012 L
.04155 .078 L
.04212 .07593 L
.04285 .07396 L
.04375 .07214 L
.04472 .07065 L
.0457 .06947 L
.047 .06825 L
.04852 .06716 L
.04995 .06638 L
.05166 .06566 L
.05367 .06504 L
.05488 .06476 L
.05603 .06453 L
.05715 .06435 L
.05843 .06419 L
.06089 .06397 L
.06334 .06384 L
.06481 .06381 L
.06625 .0638 L
.06931 .06383 L
.07114 .06389 L
.07288 .06396 L
.07596 .06412 L
.07956 .06435 L
.08762 .06499 L
.22206 .07855 L
.46538 .10229 L
.52563 .10972 L
.58116 .11832 L
.60574 .12311 L
.62892 .12863 L
.64658 .13393 L
.6597 .13896 L
.67015 .14424 L
.67758 .14942 L
.68066 .15232 L
.68293 .15506 L
.6848 .15811 L
.68556 .15983 L
.68609 .16141 L
.68665 .16431 L
.68673 .16702 L
Mistroke
.68636 .17003 L
.68546 .17324 L
.68428 .17608 L
.68285 .17875 L
.67847 .18493 L
.67182 .19201 L
.66415 .19869 L
.64179 .21417 L
.58495 .24291 L
.51577 .26799 L
.47429 .27936 L
.45058 .28475 L
.42317 .29001 L
.39492 .29436 L
.36732 .29755 L
.35151 .29889 L
.33685 .29981 L
.3286 .30019 L
.31957 .30049 L
.30295 .3007 L
.28846 .30052 L
.27234 .29989 L
.25534 .2987 L
.23937 .29706 L
.22441 .295 L
.21081 .29265 L
.18072 .28551 L
.16439 .28025 L
.14769 .27356 L
.12007 .25851 L
.10645 .24844 L
.09492 .23789 L
.08368 .22508 L
.07363 .21062 L
.06681 .19848 L
.06058 .18506 L
.05238 .16222 L
.04623 .13844 L
.04285 .12017 L
.04177 .11247 L
.04098 .1053 L
.04055 .09992 L
.04029 .09469 L
.04024 .09206 L
.04024 .08983 L
.0403 .08743 L
.04041 .08533 L
.04074 .08199 L
.04098 .0803 L
.04125 .07884 L
Mistroke
.04189 .07629 L
.04262 .0742 L
.04338 .07256 L
.04431 .07101 L
.04546 .06954 L
.04681 .06823 L
.0481 .06727 L
.04964 .06639 L
.05128 .06567 L
.05296 .06511 L
.05459 .0647 L
.05648 .06434 L
.05871 .06405 L
.05989 .06394 L
.06126 .06384 L
.06381 .06373 L
.06637 .0637 L
.06897 .06373 L
.07189 .06382 L
.07454 .06395 L
.07761 .06413 L
.09319 .06541 L
.23818 .07997 L
.36067 .09141 L
.48671 .10459 L
.54492 .11224 L
.59713 .12109 L
.63749 .13074 L
.6548 .13657 L
.66742 .14225 L
.67194 .14484 L
.67616 .14771 L
.67928 .15029 L
.68201 .15307 L
.68413 .15586 L
.68556 .15843 L
.68656 .16105 L
.6871 .16355 L
.68727 .16652 L
.68691 .1697 L
.6862 .17245 L
.685 .1755 L
.68322 .17883 L
.6808 .18244 L
.67515 .18906 L
.65774 .20379 L
.63593 .21781 L
.60678 .23312 L
.56807 .2499 L
.53165 .26302 L
Mistroke
.48719 .27614 L
.46026 .28269 L
.43406 .28809 L
.40556 .29289 L
.37833 .29644 L
.36444 .29785 L
.34906 .2991 L
.33423 .29997 L
.32033 .3005 L
.30531 .30072 L
.28856 .30055 L
.28003 .30027 L
.27083 .29983 L
.2541 .29862 L
.23843 .29697 L
.22137 .29455 L
.20534 .29159 L
.19066 .28822 L
.16371 .28003 L
.15067 .27489 L
.13687 .26838 L
.1225 .26012 L
.10858 .25018 L
.08724 .22948 L
.07747 .21659 L
.06974 .204 L
.06228 .189 L
.05662 .17495 L
.04924 .15112 L
.04496 .13227 L
.04217 .11555 L
.04122 .1077 L
.04065 .10138 L
.04034 .09604 L
.04023 .09158 L
.04028 .08805 L
.04046 .08463 L
.04081 .08139 L
.04107 .07976 L
.04135 .0784 L
.04198 .076 L
.04269 .07403 L
.04346 .0724 L
.04438 .07089 L
.04631 .06867 L
.04753 .06766 L
.04878 .06685 L
.05027 .06609 L
.052 .06541 L
.05405 .06482 L
Mistroke
.05612 .0644 L
.05726 .06422 L
.05858 .06406 L
.06002 .06392 L
.06143 .06382 L
.06419 .06372 L
.0669 .0637 L
.0684 .06372 L
.07011 .06376 L
.07196 .06382 L
.07375 .0639 L
.08103 .06436 L
.08857 .06499 L
.1093 .06703 L
.27596 .0835 L
.39445 .09468 L
.46086 .10161 L
.52804 .10984 L
.58428 .11864 L
.62522 .12737 L
.64107 .13181 L
.65547 .13682 L
.66643 .14172 L
.67437 .14641 L
.67811 .14924 L
.68139 .15234 L
.68379 .15533 L
.68543 .15811 L
.68646 .16066 L
.68711 .1635 L
.68729 .1665 L
.687 .16934 L
.68665 .17095 L
.68613 .17272 L
.68479 .17596 L
.68304 .17915 L
.68104 .18214 L
.67519 .18902 L
.66715 .19649 L
.62607 .22333 L
.59476 .2387 L
.56113 .25258 L
.52563 .26497 L
.48198 .27749 L
.43585 .28775 L
.41343 .29168 L
.38865 .29521 L
.374 .29691 L
.35752 .29845 L
.34218 .29954 L
Mistroke
.32757 .30026 L
.31858 .30054 L
.30998 .30069 L
.29366 .30065 L
.28444 .30043 L
.27584 .30009 L
.26635 .29956 L
.25622 .29881 L
.24055 .29723 L
.22365 .29491 L
.20776 .29208 L
.19333 .28889 L
.16089 .27899 L
.14544 .27257 L
.12947 .26434 L
.11615 .25586 L
.10458 .24689 L
.08586 .22782 L
.07712 .21607 L
.07017 .20477 L
.05804 .17874 L
.05135 .15878 L
.04636 .13907 L
.04309 .12171 L
.04202 .11443 L
.04131 .10851 L
.04072 .1023 L
.0405 .09921 L
.04036 .09651 L
.04023 .09213 L
.04028 .08797 L
.04037 .08599 L
.04052 .08398 L
.04073 .08205 L
.04097 .08038 L
.04151 .0777 L
.04187 .07636 L
.04223 .07522 L
.04305 .07321 L
.04392 .0716 L
.04501 .07006 L
.0463 .06867 L
.04755 .06765 L
.04882 .06682 L
.05034 .06605 L
.05212 .06537 L
.05386 .06487 L
.05559 .06449 L
.05763 .06417 L
.05998 .06392 L
Mistroke
.06124 .06384 L
.06265 .06377 L
.06537 .0637 L
.06822 .06371 L
.07103 .06379 L
.07383 .06391 L
.07661 .06406 L
.08352 .06456 L
.10041 .06612 L
.12006 .06815 L
Mfstroke
.20692 .20435 m
.2021 .20429 L
.19758 .20412 L
.19223 .2038 L
.18705 .20336 L
.17758 .20221 L
.16703 .20042 L
.15524 .19771 L
.14277 .19396 L
.12124 .18486 L
.11134 .17921 L
.10153 .17238 L
.08649 .15851 L
.07918 .14951 L
.07353 .14093 L
.0692 .13286 L
.06606 .12567 L
.06356 .11837 L
.06205 .11239 L
.06149 .10933 L
.06115 .10669 L
.06104 .10538 L
.06096 .104 L
.06092 .10261 L
.06094 .10138 L
.06108 .09927 L
.06134 .09743 L
.06168 .0959 L
.06215 .09437 L
.06279 .09284 L
.06361 .09138 L
.06442 .09025 L
.06544 .08913 L
.06671 .08804 L
.06821 .08705 L
.06962 .08632 L
.07132 .08563 L
.07334 .08502 L
.07452 .08473 L
.0757 .0845 L
.07684 .08431 L
.07814 .08414 L
.07936 .08401 L
.08054 .08391 L
.08298 .08378 L
.08435 .08374 L
.08587 .08372 L
.08752 .08372 L
.08915 .08375 L
.09066 .0838 L
Mistroke
.09237 .08387 L
.09561 .08405 L
.09928 .08432 L
.10651 .08498 L
.14718 .09012 L
.21478 .09965 L
.29512 .11111 L
.39722 .12712 L
.44417 .13597 L
.48894 .14632 L
.50771 .15167 L
.5234 .15691 L
.5469 .16722 L
.55649 .17319 L
.56069 .17653 L
.56396 .17971 L
.5664 .18268 L
.56816 .18542 L
.5696 .1885 L
.57054 .19185 L
.57077 .1935 L
.57087 .19526 L
.57062 .19845 L
.57022 .20041 L
.56966 .20228 L
.56902 .20396 L
.56818 .20578 L
.56595 .20956 L
.5629 .21357 L
.55569 .22082 L
.53693 .23413 L
.51389 .2461 L
.48059 .25931 L
.44255 .27069 L
.42354 .27525 L
.40199 .27961 L
.38226 .2829 L
.35985 .28585 L
.34687 .28718 L
.33466 .28818 L
.32274 .28893 L
.30992 .28946 L
.29555 .28972 L
.28193 .28964 L
.26676 .28913 L
.25818 .28865 L
.25034 .28808 L
.23578 .28666 L
.22211 .28488 L
.20713 .28238 L
Mistroke
.19115 .279 L
.17471 .27461 L
.15951 .26957 L
.14617 .2642 L
.1326 .25762 L
.11022 .24338 L
.09241 .22757 L
.08307 .21681 L
.07538 .20612 L
.06379 .18533 L
.05466 .16253 L
.04835 .14063 L
.04495 .12465 L
.04365 .11684 L
.04273 .11022 L
.04235 .10686 L
.04201 .10344 L
.04162 .09803 L
.0415 .09526 L
.04144 .09254 L
.04145 .09038 L
.04151 .08817 L
.04176 .08463 L
.04197 .08284 L
.0422 .08132 L
.04274 .07879 L
.04344 .07647 L
.04424 .07454 L
.04524 .07273 L
.04632 .07126 L
.04744 .07008 L
.04986 .06828 L
.05123 .06755 L
.05288 .06688 L
.05482 .06629 L
.05675 .06586 L
.05787 .06566 L
.05916 .06548 L
.06042 .06534 L
.06164 .06523 L
.06417 .06509 L
.06663 .06504 L
.06967 .06505 L
.07274 .06514 L
.07559 .06526 L
.07891 .06546 L
.08631 .06602 L
.10216 .06752 L
.1539 .07301 L
.37588 .09482 L
Mistroke
.44147 .1017 L
.50836 .10979 L
.5633 .11802 L
.60586 .12639 L
.6391 .13557 L
.6525 .14071 L
.66377 .14644 L
.66831 .14946 L
.67238 .15281 L
.67539 .15604 L
.67749 .15908 L
.67895 .16215 L
.67975 .16497 L
.67998 .16654 L
.68008 .16827 L
.67983 .17142 L
.67912 .17445 L
.67806 .17731 L
.67645 .18048 L
.67425 .18393 L
.66829 .19109 L
.66123 .19775 L
.62233 .22362 L
.59449 .23755 L
.55964 .25217 L
.52512 .26433 L
.48319 .27651 L
.45762 .28267 L
.43276 .28777 L
.40608 .29229 L
.37999 .29576 L
.36563 .29727 L
.34992 .29858 L
.34079 .29917 L
.33207 .29963 L
.31549 .30018 L
.30686 .30029 L
.29764 .30028 L
.28091 .2999 L
.27152 .29947 L
.26268 .29892 L
.25295 .29813 L
.24246 .29706 L
.22468 .2947 L
.20865 .29189 L
.19035 .28779 L
.17349 .28299 L
.14485 .27196 L
.12985 .26423 L
.11698 .25612 L
Mistroke
.09322 .23585 L
.08205 .22269 L
.07317 .20962 L
.05952 .18224 L
.05403 .16721 L
.05014 .15424 L
.04515 .13299 L
.0424 .11682 L
.04148 .1097 L
.0408 .1028 L
.04057 .09968 L
.0404 .09656 L
.04031 .09384 L
.04027 .09152 L
.04033 .08764 L
.04052 .08446 L
.04086 .08139 L
.04137 .07853 L
.04168 .07723 L
.04206 .07593 L
.04285 .07381 L
.04374 .07203 L
.04467 .0706 L
.04581 .06924 L
.04702 .06814 L
.04821 .06728 L
.04961 .06647 L
.05126 .06574 L
.05319 .06511 L
.05497 .06467 L
.0571 .0643 L
.05922 .06405 L
.0613 .06388 L
.06374 .06378 L
.06651 .06375 L
.06909 .06378 L
.07164 .06386 L
.07462 .06399 L
.07801 .0642 L
.0865 .06485 L
.09724 .06585 L
.12161 .06836 L
.18909 .0753 L
.41892 .09722 L
.49087 .10517 L
.56035 .1147 L
.58922 .11967 L
.61323 .12462 L
.63344 .12971 L
.64878 .13451 L
Mistroke
.66172 .13965 L
.67129 .14467 L
.67878 .15013 L
.68189 .15329 L
.68408 .15625 L
.68547 .15885 L
.68636 .1613 L
.68691 .16404 L
.68701 .167 L
.68659 .17015 L
.68573 .17318 L
.68459 .17593 L
.68295 .17895 L
.6782 .1855 L
.67107 .19288 L
.65112 .2083 L
.59872 .23686 L
.56512 .25101 L
.52437 .26535 L
.48454 .27681 L
.43708 .28749 L
.40792 .29252 L
.37998 .29624 L
.36602 .29769 L
.35054 .29898 L
.3356 .29989 L
.32158 .30045 L
.30496 .30071 L
.28916 .30055 L
.28 .30026 L
.27159 .29986 L
.26183 .29924 L
.25253 .29847 L
.23395 .29639 L
.21675 .29375 L
.19802 .28999 L
.17846 .28486 L
.14613 .27288 L
.13104 .26522 L
.11568 .25552 L
.1037 .24613 L
.09217 .23503 L
.07496 .21276 L
.06679 .19845 L
.05962 .18273 L
.0546 .16917 L
.05042 .15549 L
.04502 .13256 L
.04332 .12312 L
.04216 .11541 L
Mistroke
.04136 .10896 L
.04075 .10271 L
.04038 .09693 L
.04024 .09214 L
.04027 .08822 L
.04047 .08456 L
.04079 .08154 L
.0412 .07912 L
.0415 .07775 L
.04186 .07641 L
.0426 .07425 L
.04354 .07226 L
.04475 .0704 L
.04593 .06904 L
.04735 .0678 L
.04883 .06682 L
.05032 .06607 L
.05192 .06544 L
.05354 .06495 L
.05545 .06452 L
.05769 .06417 L
.06009 .06392 L
.06137 .06383 L
.06283 .06376 L
.06557 .0637 L
.0683 .06372 L
.07128 .0638 L
.07427 .06393 L
.07713 .06409 L
.08043 .06432 L
.09716 .0658 L
.24366 .08049 L
.37046 .09234 L
.5005 .10626 L
.55862 .11432 L
.61006 .12379 L
.63339 .12956 L
.65141 .13529 L
.66424 .14064 L
.67017 .14377 L
.67479 .14671 L
.67838 .14948 L
.68158 .15257 L
.68405 .15573 L
.68509 .15748 L
.68588 .15912 L
.68686 .1622 L
.68726 .16504 L
.68727 .16663 L
.68714 .16837 L
Mistroke
.68648 .17157 L
.68546 .17445 L
.6839 .17767 L
.67937 .18431 L
.67364 .19059 L
.66702 .19659 L
.62209 .22544 L
.58739 .24194 L
.54983 .25675 L
.51063 .26959 L
.46339 .28198 L
.43837 .28726 L
.4135 .29166 L
.3903 .29501 L
.36367 .29792 L
.34796 .29917 L
.33295 .30003 L
.31679 .30058 L
.30759 .30071 L
.29912 .30071 L
.28386 .30041 L
.26704 .29961 L
.25102 .29834 L
.23612 .29669 L
.21728 .29386 L
.19971 .29038 L
.16776 .28145 L
.15067 .27489 L
.13575 .2678 L
.11961 .25823 L
.10572 .24785 L
.0951 .23809 L
.08486 .2266 L
.0702 .20483 L
.06364 .192 L
.05792 .17843 L
.05036 .15529 L
.04579 .13639 L
.04303 .12137 L
.04198 .11407 L
.04124 .10787 L
.04066 .10154 L
.04035 .09645 L
.04023 .09155 L
.04029 .08766 L
.04039 .08571 L
.04054 .08375 L
.04094 .08057 L
.04144 .07797 L
.04212 .07557 L
Mistroke
.04279 .07378 L
.04365 .07206 L
.04481 .07032 L
.046 .06896 L
.04755 .06765 L
.04919 .06662 L
.05085 .06583 L
.05253 .06524 L
.05453 .06471 L
.05561 .06449 L
.05685 .06428 L
.05903 .06401 L
.06121 .06384 L
.06378 .06373 L
.0653 .0637 L
.06673 .0637 L
.0698 .06375 L
.07164 .06381 L
.07339 .06389 L
.0768 .06407 L
.08067 .06434 L
.11809 .06794 L
.29799 .08554 L
.42367 .09763 L
.49373 .10543 L
.55399 .1136 L
.60094 .12185 L
.62163 .12647 L
.64037 .1316 L
.6547 .13652 L
.66526 .14113 L
.67364 .14592 L
.67674 .14814 L
.67959 .15055 L
.68197 .15299 L
.68373 .15524 L
.68513 .15753 L
.68613 .15972 L
.6869 .1623 L
.68725 .16472 L
.68724 .1674 L
.68681 .17029 L
.68607 .17288 L
.68491 .17571 L
.68191 .18089 L
.67691 .18719 L
.67104 .19307 L
.64196 .21422 L
.59829 .2371 L
Mfstroke
.20692 .30051 m
.19044 .29656 L
.17575 .29226 L
.1604 .28682 L
.14442 .2799 L
.13043 .27249 L
.11832 .26477 L
.09711 .24711 L
.08697 .23597 L
.0786 .22484 L
.07005 .21096 L
.06351 .19794 L
.05346 .17171 L
.0495 .15811 L
.04656 .1461 L
.04276 .1266 L
.0414 .11753 L
.04047 .11 L
.03987 .1038 L
.03946 .0979 L
.03928 .0932 L
.03926 .08937 L
.03938 .08535 L
.03965 .08208 L
.04008 .07895 L
.04038 .07739 L
.0407 .07607 L
.04144 .07369 L
.0424 .07149 L
.04346 .06973 L
.04457 .06833 L
.04582 .06712 L
.04708 .06618 L
.04859 .0653 L
.05034 .06453 L
.052 .06398 L
.05366 .06357 L
.05562 .0632 L
.05788 .06292 L
.05925 .0628 L
.06056 .06271 L
.06206 .06264 L
.06373 .06261 L
.0667 .06261 L
.06849 .06264 L
.07023 .0627 L
.07367 .06285 L
.07704 .06306 L
.0855 .06371 L
.22422 .07741 L
Mistroke
.34358 .08827 L
.41931 .09545 L
.49025 .10302 L
.55096 .11083 L
.57927 .11522 L
.60587 .12007 L
.62552 .12434 L
.64401 .12921 L
.65712 .13345 L
.66887 .13822 L
.67462 .14111 L
.6792 .14382 L
.68285 .14641 L
.6862 .14931 L
.68847 .15177 L
.69039 .15446 L
.69186 .15733 L
.69274 .16007 L
.69317 .16312 L
.69318 .16487 L
.69303 .1665 L
.69272 .16825 L
.69231 .16984 L
.69167 .1717 L
.69092 .17346 L
.68731 .1796 L
.68168 .1864 L
.66708 .19927 L
.64622 .21331 L
.59616 .23903 L
.52516 .26573 L
.47712 .27921 L
.45218 .28491 L
.42782 .28966 L
.40434 .29347 L
.37719 .29694 L
.36262 .29838 L
.34864 .29948 L
.33359 .30035 L
.31702 .30091 L
.30313 .30105 L
.28771 .30084 L
.27142 .30018 L
.25611 .2991 L
.24166 .29765 L
.2285 .29594 L
.19916 .29053 L
.18362 .28663 L
.16938 .28227 L
.15299 .27613 L
Mistroke
.13868 .26956 L
.11212 .25317 L
.09931 .24241 L
.08848 .23116 L
.07274 .2094 L
.06178 .18809 L
.05322 .16515 L
.04719 .14298 L
.04322 .12276 L
.04184 .1133 L
.04099 .10576 L
.04052 .09997 L
.04035 .09701 L
.04025 .09443 L
.0402 .08975 L
.04026 .0874 L
.04037 .08542 L
.04069 .08206 L
.04111 .07934 L
.04171 .07674 L
.04207 .07557 L
.04251 .07437 L
.04332 .07256 L
.04433 .07088 L
.04541 .06951 L
.0465 .06843 L
.04788 .06735 L
.04931 .0665 L
.0507 .06584 L
.05233 .06525 L
.05426 .06472 L
.05539 .06449 L
.05648 .06429 L
.05853 .06402 L
.06096 .06381 L
.06338 .0637 L
.06584 .06366 L
.06818 .06368 L
.0709 .06375 L
.07404 .06388 L
.07762 .06409 L
.08474 .06462 L
.20911 .07716 L
.31844 .08739 L
.45754 .10118 L
.52726 .10966 L
.56039 .11451 L
.59197 .11998 L
.61709 .12528 L
.63646 .13031 L
Mistroke
.6515 .13518 L
.66481 .14075 L
.67444 .14626 L
.67852 .14935 L
.68161 .15231 L
.68388 .15511 L
.68546 .15771 L
.68671 .16075 L
.68735 .16369 L
.68747 .16689 L
.68729 .1687 L
.68698 .17036 L
.68598 .17361 L
.68458 .17672 L
.6824 .18041 L
.67989 .18384 L
.6726 .19174 L
.65709 .20434 L
.63472 .21856 L
.57387 .24762 L
.5339 .26229 L
.49068 .27524 L
.44726 .2855 L
.42092 .29045 L
.39488 .29442 L
.36574 .29774 L
.34971 .29906 L
.34052 .29965 L
.332 .30009 L
.31558 .30062 L
.30614 .30073 L
.29728 .30071 L
.28781 .30054 L
.27915 .30025 L
.26908 .29974 L
.25953 .29909 L
.24328 .29755 L
.22605 .29529 L
.21138 .2928 L
.19539 .28939 L
.1785 .28489 L
.16089 .279 L
.13114 .2653 L
.11688 .25638 L
.10503 .24728 L
.09351 .23646 L
.0826 .22371 L
.07391 .21111 L
.06712 .19911 L
.05679 .17542 L
Mistroke
.0493 .15134 L
.0443 .1288 L
.0427 .11922 L
.0415 .11027 L
.04108 .10639 L
.04077 .10298 L
.04039 .09722 L
.04024 .09274 L
.04026 .08841 L
.04034 .08645 L
.04047 .08449 L
.04083 .08129 L
.04129 .07866 L
.0419 .07624 L
.04253 .07442 L
.04332 .07267 L
.0444 .07087 L
.04551 .06948 L
.04695 .06811 L
.04846 .06703 L
.05001 .0662 L
.05156 .06556 L
.05341 .06498 L
.05449 .06472 L
.05554 .0645 L
.05762 .06417 L
.06007 .06392 L
.06239 .06377 L
.06504 .0637 L
.06758 .0637 L
.07011 .06376 L
.07306 .06387 L
.07647 .06405 L
.08442 .06463 L
.09413 .0655 L
.1155 .06767 L
.26191 .08219 L
.38303 .09356 L
.45489 .10095 L
.51952 .10869 L
.57259 .11659 L
.59681 .12101 L
.61931 .12591 L
.63562 .13018 L
.65081 .13506 L
.6622 .13967 L
.67072 .14408 L
.67864 .14968 L
.68174 .15272 L
.68304 .15429 L
Mistroke
.68425 .15601 L
.68521 .15767 L
.68593 .1592 L
.6869 .16226 L
.68728 .16508 L
.68718 .16809 L
.68667 .17089 L
.68569 .17392 L
.68437 .17682 L
.68284 .17949 L
.67785 .18614 L
.67159 .19257 L
.65301 .20711 L
.63044 .22093 L
.60034 .23615 L
.56165 .25238 L
.52167 .26623 L
.48027 .27792 L
.43628 .28767 L
.41011 .2922 L
.38518 .29564 L
.37136 .29718 L
.35603 .29858 L
.34745 .29921 L
.33945 .2997 L
.32347 .30041 L
.30951 .3007 L
.29393 .30066 L
.27743 .30017 L
.26184 .29925 L
.25298 .29852 L
.24329 .29754 L
.22566 .29522 L
.20855 .29224 L
.19286 .28877 L
.15853 .27809 L
.14053 .27023 L
.12526 .26184 L
.102 .24464 L
.09064 .23338 L
.08134 .22204 L
.0663 .19749 L
.05989 .18342 L
.05517 .17085 L
.04889 .14976 L
.04451 .12994 L
.04315 .12208 L
.04204 .11458 L
.04129 .10841 L
.04079 .10314 L
Mistroke
.0404 .09743 L
.04024 .09285 L
.04026 .08852 L
.04035 .08632 L
.04048 .08443 L
.04082 .08132 L
.04125 .07884 L
.04188 .07633 L
.04259 .07427 L
.04352 .0723 L
.04465 .07052 L
.04574 .06923 L
.04708 .06801 L
.04868 .06691 L
.05058 .06595 L
.05258 .06522 L
.05457 .0647 L
.05651 .06433 L
.05846 .06407 L
.06076 .06387 L
.06343 .06374 L
.06628 .0637 L
.06781 .06371 L
.06954 .06374 L
.07278 .06386 L
.07602 .06403 L
.08308 .06452 L
.09032 .06514 L
.10998 .0671 L
.27685 .08358 L
.3978 .09501 L
.52872 .10994 L
.5858 .11892 L
.61278 .12439 L
.63413 .12976 L
.65006 .13479 L
.66237 .13975 L
.66801 .14256 L
.67328 .14568 L
.67706 .14839 L
.68037 .15129 L
.68312 .1544 L
.68501 .15731 L
.6864 .16048 L
.6869 .16231 L
.68718 .16403 L
.68726 .16718 L
.68685 .17009 L
.68644 .17171 L
.68585 .17349 L
Mistroke
.6844 .17676 L
.6827 .1797 L
.68041 .18298 L
.6745 .18974 L
.6599 .20221 L
.63716 .2171 L
.60621 .2334 L
.57134 .24861 L
.53383 .26229 L
.49005 .27539 L
.44548 .28585 L
.41977 .29063 L
.3904 .29499 L
.37358 .29695 L
.35767 .29844 L
.3421 .29955 L
.33413 .29998 L
.32527 .30035 L
.31672 .30058 L
.30732 .30072 L
.29835 .30071 L
.28998 .30058 L
.27401 .3 L
.25685 .29886 L
.24705 .29795 L
.23646 .29673 L
.21728 .29386 L
.19877 .29017 L
.18205 .28591 L
.15242 .27563 L
.13665 .26827 L
.12286 .26035 L
.09826 .2412 L
.08665 .22878 L
.0775 .21663 L
.06446 .19375 L
.05876 .18061 L
.0544 .16857 L
.04797 .14609 L
.04566 .13577 L
.04373 .12561 L
.04242 .11728 L
.04152 .11039 L
.04091 .10453 L
.04049 .09898 L
.04027 .09418 L
.04023 .09019 L
.04032 .08699 L
.04052 .08391 L
.04092 .08067 L
Mistroke
.04143 .07804 L
.04177 .07669 L
.04212 .07554 L
.04304 .07325 L
.04406 .07137 L
.04535 .06965 L
.04673 .06829 L
.04816 .06723 L
.04958 .06641 L
.05103 .06576 L
.05275 .06517 L
.05477 .06466 L
.05694 .06427 L
.0581 .06411 L
.05943 .06397 L
.06192 .0638 L
.06441 .06371 L
.0673 .0637 L
.06884 .06372 L
.0706 .06377 L
.07389 .06391 L
.07719 .0641 L
.08546 .06472 L
.0958 .06566 L
.14732 .07101 L
.33265 .08876 L
.47023 .10266 L
.54264 .1119 L
.57308 .11667 L
.59861 .12138 L
.61991 .12606 L
.63947 .13132 L
.65301 .13587 L
.66506 .14104 L
.67501 .14685 L
.67912 .15012 L
.68216 .15322 L
.68435 .15617 L
.6858 .15891 L
.68686 .16211 L
.68727 .16519 L
.68721 .1678 L
.68673 .17065 L
.6859 .17336 L
.68483 .17588 L
.68127 .18182 L
.67597 .1882 L
.66205 .20059 L
.64147 .21452 L
.59217 .23985 L
Mistroke
.53237 .26278 L
Mfstroke
.20692 .39666 m
.1792 .38607 L
.15556 .37435 L
.13059 .35809 L
.10969 .33985 L
.09299 .32048 L
.07991 .30065 L
.06811 .2772 L
.05827 .25128 L
.05079 .22533 L
.0449 .19883 L
.03822 .15781 L
.03583 .13792 L
.03431 .12241 L
.03334 .10996 L
.0328 .10068 L
.0325 .09266 L
.03242 .08639 L
.03252 .08088 L
.03279 .07597 L
.03316 .07238 L
.03368 .06918 L
.03422 .06686 L
.0349 .06467 L
.03584 .0625 L
.03681 .06085 L
.03807 .05927 L
.03942 .05804 L
.04079 .0571 L
.04217 .05639 L
.04383 .05574 L
.04473 .05547 L
.04575 .0552 L
.04773 .05482 L
.04888 .05465 L
.05 .05453 L
.05212 .05436 L
.05457 .05426 L
.05603 .05424 L
.05769 .05424 L
.05934 .05426 L
.06092 .0543 L
.06409 .05443 L
.06772 .05463 L
.08308 .05582 L
.10567 .05788 L
.31573 .07473 L
.46807 .08644 L
.54153 .09319 L
.60169 .10005 L
Mistroke
.65728 .10866 L
.68028 .11353 L
.69999 .11896 L
.71398 .12418 L
.7195 .12683 L
.72382 .1293 L
.73014 .13406 L
.73258 .13663 L
.73453 .13939 L
.73585 .14211 L
.73635 .14367 L
.73667 .14512 L
.73689 .14781 L
.73665 .15072 L
.73603 .15335 L
.73512 .15586 L
.73378 .15864 L
.73194 .16168 L
.72683 .16822 L
.71979 .17529 L
.70336 .1884 L
.66259 .21332 L
.60278 .24152 L
.56265 .25689 L
.51991 .27068 L
.47664 .28211 L
.42603 .29235 L
.39768 .29663 L
.3821 .29853 L
.36494 .30023 L
.34881 .30147 L
.33378 .30228 L
.3184 .30277 L
.30359 .3029 L
.2862 .3026 L
.27732 .30225 L
.26747 .30169 L
.24997 .30025 L
.23348 .2983 L
.21418 .29521 L
.19664 .29154 L
.17776 .28647 L
.15852 .27985 L
.14356 .2734 L
.12823 .26528 L
.11564 .25711 L
.1034 .24744 L
.09341 .23788 L
.08363 .22652 L
.0695 .20497 L
Mistroke
.06274 .1914 L
.05764 .17904 L
.04932 .15277 L
.04459 .13181 L
.04302 .12282 L
.04193 .11552 L
.04118 .10943 L
.0406 .10354 L
.04021 .09804 L
.04003 .09347 L
.04001 .08966 L
.04013 .0861 L
.04033 .08339 L
.04066 .08074 L
.04117 .07798 L
.04175 .07578 L
.04256 .07358 L
.04345 .07177 L
.04439 .07033 L
.04535 .06916 L
.04651 .06804 L
.04786 .06702 L
.04923 .06623 L
.05085 .06549 L
.05269 .06487 L
.05455 .0644 L
.05644 .06406 L
.05827 .06382 L
.06053 .06362 L
.06281 .0635 L
.06548 .06345 L
.06853 .06347 L
.07131 .06356 L
.07458 .06371 L
.07836 .06394 L
.08273 .06426 L
.09155 .06503 L
.20509 .07654 L
.44883 .09987 L
.52007 .10829 L
.55539 .11328 L
.58524 .11823 L
.60983 .12308 L
.6325 .12856 L
.64945 .13372 L
.6623 .13871 L
.67223 .14377 L
.68011 .14938 L
.68339 .15266 L
.6847 .15429 L
Mistroke
.68574 .15582 L
.68724 .1587 L
.68824 .16187 L
.68862 .165 L
.68848 .16798 L
.68778 .17128 L
.68715 .17316 L
.68642 .17489 L
.68457 .17839 L
.68194 .18227 L
.67566 .18947 L
.65994 .20273 L
.63742 .2173 L
.58323 .24392 L
.54649 .25811 L
.50199 .27223 L
.47633 .27902 L
.4462 .28581 L
.41663 .29125 L
.38811 .29537 L
.3737 .29703 L
.35764 .29853 L
.34212 .29963 L
.32746 .30034 L
.31168 .30075 L
.30258 .3008 L
.29396 .30073 L
.28484 .30052 L
.27643 .30019 L
.26713 .29969 L
.2573 .29897 L
.24176 .29744 L
.22513 .29521 L
.2095 .29249 L
.19541 .28945 L
.17912 .28513 L
.16194 .27944 L
.14629 .27302 L
.1327 .26622 L
.10814 .24989 L
.09631 .23935 L
.08633 .22845 L
.07167 .20743 L
.05988 .18344 L
.05482 .16988 L
.05115 .15812 L
.0454 .13456 L
.04371 .12552 L
.04234 .1168 L
.04147 .11003 L
Mistroke
.04082 .1036 L
.04041 .09771 L
.04024 .0929 L
.04022 .09027 L
.04027 .08796 L
.04036 .08604 L
.0405 .0841 L
.04068 .08234 L
.04093 .08055 L
.04124 .07884 L
.04158 .07736 L
.0423 .07499 L
.04324 .07281 L
.04418 .07118 L
.04535 .06964 L
.04672 .06828 L
.04814 .06722 L
.04961 .06638 L
.05106 .06574 L
.05288 .06512 L
.05473 .06465 L
.05665 .0643 L
.05886 .06402 L
.06111 .06383 L
.06331 .06373 L
.06606 .06369 L
.06771 .0637 L
.0693 .06373 L
.07237 .06383 L
.07587 .06401 L
.08355 .06455 L
.09183 .06527 L
.11522 .06764 L
.26288 .08227 L
.38813 .09404 L
.46152 .10167 L
.52602 .10955 L
.57453 .1169 L
.61724 .12539 L
.6369 .13053 L
.65231 .13558 L
.66357 .14028 L
.67315 .14555 L
.68001 .15088 L
.68283 .15395 L
.68479 .15681 L
.68609 .1595 L
.68698 .16247 L
.68733 .16532 L
.68723 .168 L
Mistroke
.68699 .16965 L
.68656 .17145 L
.68539 .17474 L
.68377 .17799 L
.68187 .18101 L
.67619 .18801 L
.66826 .19557 L
.64841 .21019 L
.62453 .22416 L
.59301 .23949 L
.5523 .25587 L
.50743 .27054 L
.46022 .2827 L
.40977 .29225 L
.38229 .29599 L
.36606 .2977 L
.35044 .299 L
.3371 .29983 L
.32225 .30045 L
.30646 .30072 L
.29155 .30062 L
.27736 .30017 L
.26436 .29943 L
.24926 .29817 L
.23495 .29654 L
.21936 .29422 L
.20297 .29109 L
.1742 .28357 L
.15879 .2782 L
.14493 .27233 L
.13042 .26488 L
.11604 .25578 L
.10289 .24544 L
.09222 .23509 L
.07491 .21269 L
.06722 .1993 L
.0604 .18466 L
.05144 .1591 L
.04604 .13756 L
.04403 .12732 L
.04264 .1188 L
.04168 .11177 L
.04105 .10604 L
.04057 .10037 L
.0403 .09504 L
.04023 .09083 L
.04032 .0869 L
.04052 .08394 L
.04086 .08104 L
.04136 .07832 L
Mistroke
.0417 .07695 L
.04204 .07579 L
.04281 .07375 L
.04365 .07207 L
.04452 .0707 L
.04555 .06943 L
.04769 .06755 L
.04917 .06663 L
.0507 .0659 L
.05219 .06535 L
.05392 .06485 L
.05591 .06443 L
.05787 .06414 L
.0603 .0639 L
.06278 .06376 L
.06524 .0637 L
.06767 .06371 L
.07051 .06377 L
.07374 .0639 L
.07719 .0641 L
.0812 .06437 L
.08925 .06505 L
.11207 .06731 L
.2857 .0844 L
.42266 .09752 L
.54764 .11264 L
.59848 .12135 L
.62195 .12655 L
.64001 .13148 L
.65622 .13712 L
.66329 .14018 L
.6697 .14349 L
.67442 .14644 L
.67872 .14976 L
.68182 .15282 L
.68408 .15575 L
.68572 .15873 L
.68638 .16042 L
.68682 .16196 L
.68727 .16499 L
.6872 .16789 L
.68696 .16956 L
.68655 .17133 L
.68544 .17454 L
.68461 .17634 L
.6837 .17804 L
.68119 .18193 L
.67557 .18863 L
.66904 .19487 L
.64984 .20924 L
Mistroke
.59894 .2368 L
.53361 .26237 L
.49373 .2744 L
.44434 .28608 L
.4173 .29105 L
.38651 .29548 L
.37177 .29714 L
.35589 .29859 L
.34203 .29955 L
.32658 .3003 L
.31077 .30068 L
.29562 .30068 L
.28183 .30034 L
.26675 .29959 L
.25017 .29826 L
.23255 .29622 L
.21752 .2939 L
.20112 .29069 L
.17246 .28301 L
.157 .2775 L
.14343 .27163 L
.11905 .25786 L
.09895 .24185 L
.08851 .23097 L
.07869 .21835 L
.07125 .20667 L
.0646 .19404 L
.05497 .17029 L
.04895 .15002 L
.04447 .12973 L
.042 .11427 L
.04113 .10683 L
.04061 .1009 L
.04043 .09794 L
.0403 .09495 L
.04024 .09234 L
.04023 .09009 L
.04033 .08674 L
.04056 .08355 L
.04089 .08088 L
.04128 .0787 L
.04184 .07644 L
.04259 .07428 L
.0434 .07251 L
.04426 .07107 L
.04535 .06966 L
.04648 .06851 L
.04761 .0676 L
.04891 .06677 L
.05045 .066 L
Mistroke
.05199 .06541 L
.05378 .06489 L
.05479 .06465 L
.05591 .06443 L
.05817 .0641 L
.06044 .06389 L
.06306 .06375 L
.06465 .06371 L
.06621 .0637 L
.06916 .06373 L
.07206 .06383 L
.07546 .06399 L
.07932 .06424 L
.09459 .06554 L
.11611 .06774 L
.29391 .08516 L
.42806 .09808 L
.49468 .10554 L
.55064 .11309 L
.60451 .12259 L
.62743 .12794 L
.64742 .13387 L
.66078 .13904 L
.67064 .14404 L
.67867 .14971 L
.68196 .15298 L
.68425 .15603 L
.68586 .15906 L
.68682 .16195 L
.68724 .16458 L
.68724 .16747 L
.68672 .17066 L
.68627 .17229 L
.68562 .17408 L
.68411 .1773 L
.68229 .18032 L
.67763 .18638 L
.67219 .192 L
.65613 .20494 L
.63335 .21929 L
.60261 .2351 L
.53129 .26313 L
Mfstroke
.20692 .49282 m
.1684 .47265 L
.13707 .44972 L
.10625 .41716 L
.08298 .3803 L
.06657 .34184 L
.05533 .30432 L
.04653 .26349 L
.04022 .22357 L
.03605 .18907 L
.03315 .15889 L
.03152 .13816 L
.03035 .12027 L
.02988 .1114 L
.02955 .10427 L
.02918 .09274 L
.02909 .08457 L
.02919 .07766 L
.0293 .0747 L
.02947 .07191 L
.02987 .06768 L
.03015 .06568 L
.03044 .064 L
.03082 .06224 L
.03121 .06076 L
.03202 .05847 L
.03285 .05674 L
.03385 .05519 L
.03507 .05381 L
.03619 .05286 L
.03754 .052 L
.03909 .05128 L
.04069 .05073 L
.04231 .05034 L
.0439 .05005 L
.04579 .04982 L
.04793 .04966 L
.04917 .0496 L
.05057 .04957 L
.05328 .04956 L
.05614 .04962 L
.05899 .04973 L
.06232 .04991 L
.06631 .05017 L
.0755 .05087 L
.12355 .05499 L
.37907 .07266 L
.45779 .078 L
.54148 .08448 L
.61159 .09125 L
Mistroke
.66482 .09811 L
.691 .10257 L
.71065 .1068 L
.72874 .11191 L
.73548 .11433 L
.74162 .11694 L
.74608 .11921 L
.75021 .12175 L
.75334 .12413 L
.75567 .12633 L
.75782 .12899 L
.75873 .13047 L
.75943 .13188 L
.76027 .13444 L
.76065 .13726 L
.76053 .13996 L
.76003 .14247 L
.75909 .14527 L
.75766 .14826 L
.75433 .15343 L
.74944 .15923 L
.73416 .17295 L
.71529 .18641 L
.66452 .21542 L
.59221 .24749 L
.50465 .27607 L
.477 .28299 L
.44592 .28961 L
.41749 .29457 L
.4012 .29694 L
.38534 .29892 L
.3703 .30048 L
.35355 .30185 L
.338 .30278 L
.32333 .30333 L
.30937 .30355 L
.29373 .30343 L
.27718 .30287 L
.2615 .30188 L
.24394 .3002 L
.22541 .2977 L
.20967 .29492 L
.19263 .29112 L
.17461 .28604 L
.15601 .27938 L
.1408 .27257 L
.12506 .26386 L
.09922 .24412 L
.08732 .23153 L
.0777 .21881 L
Mistroke
.06408 .19473 L
.05826 .18107 L
.05393 .16888 L
.04702 .14381 L
.04445 .13148 L
.04271 .12136 L
.04153 .11297 L
.04076 .10603 L
.04045 .10256 L
.04021 .09909 L
.04006 .09617 L
.03997 .09367 L
.03995 .0895 L
.04009 .08559 L
.04037 .08237 L
.04073 .07978 L
.04129 .07712 L
.04167 .07577 L
.04205 .07462 L
.04285 .07272 L
.04383 .07097 L
.04488 .06954 L
.04615 .06822 L
.04747 .06717 L
.04881 .06634 L
.05042 .06556 L
.05235 .06488 L
.05339 .06458 L
.05456 .06431 L
.05569 .06409 L
.0568 .06392 L
.05904 .06366 L
.06029 .06355 L
.06169 .06347 L
.06323 .06341 L
.06475 .06338 L
.06776 .06339 L
.07079 .06347 L
.07379 .0636 L
.07732 .0638 L
.08135 .06409 L
.12965 .06886 L
.31698 .08687 L
.45713 .10065 L
.52779 .10917 L
.56235 .1142 L
.59115 .11914 L
.63393 .12873 L
.65135 .13413 L
.66606 .14015 L
Mistroke
.67128 .14286 L
.67612 .14587 L
.67971 .14857 L
.68284 .15148 L
.68508 .15414 L
.68695 .15711 L
.68812 .15986 L
.68878 .16246 L
.68903 .16554 L
.68894 .16728 L
.68872 .16887 L
.68791 .172 L
.68672 .17498 L
.68481 .17852 L
.68258 .18181 L
.676 .18939 L
.66019 .2027 L
.63778 .21719 L
.58593 .24284 L
.51066 .26976 L
.46165 .28252 L
.43527 .28799 L
.4095 .29241 L
.38504 .29577 L
.35791 .29853 L
.34342 .29957 L
.32955 .30029 L
.31406 .30074 L
.29706 .30079 L
.27988 .30036 L
.26371 .29948 L
.25435 .29874 L
.24583 .29791 L
.22666 .29546 L
.20828 .29227 L
.1886 .28778 L
.17046 .28244 L
.15431 .27649 L
.12757 .2633 L
.11379 .25423 L
.10201 .24472 L
.08189 .22284 L
.07279 .20934 L
.06581 .19659 L
.05538 .17152 L
.04904 .1504 L
.0444 .12937 L
.04298 .12112 L
.04187 .11334 L
.04117 .10736 L
Mistroke
.04065 .10151 L
.04036 .0968 L
.04023 .09287 L
.04024 .08876 L
.04039 .08545 L
.04071 .08209 L
.04114 .07932 L
.0417 .0769 L
.04246 .07458 L
.04339 .0725 L
.04441 .07083 L
.04547 .06949 L
.04655 .06842 L
.04785 .06741 L
.04936 .06651 L
.05103 .06575 L
.053 .06508 L
.05501 .06459 L
.057 .06425 L
.05829 .06408 L
.05953 .06395 L
.06094 .06384 L
.06251 .06376 L
.06532 .06369 L
.06701 .06369 L
.06866 .06371 L
.07182 .06381 L
.0735 .06388 L
.07544 .06398 L
.08266 .06448 L
.10305 .06637 L
.15916 .07222 L
.35483 .09083 L
.48286 .10411 L
.54208 .1118 L
.59695 .12102 L
.62061 .12619 L
.64174 .13198 L
.65774 .13769 L
.66908 .14309 L
.67742 .1486 L
.68094 .15179 L
.68348 .15479 L
.68516 .15745 L
.68645 .16042 L
.68719 .16357 L
.68735 .16656 L
.68699 .1697 L
.68657 .17147 L
.68605 .17309 L
Mistroke
.68469 .17628 L
.68299 .17931 L
.67778 .18625 L
.67012 .19394 L
.65117 .20838 L
.62854 .22199 L
.57261 .24811 L
.53458 .26205 L
.49535 .27396 L
.44822 .28529 L
.42477 .28978 L
.3986 .2939 L
.38487 .29568 L
.36935 .29739 L
.35472 .29868 L
.34103 .29962 L
.32463 .30037 L
.31589 .30061 L
.30659 .30072 L
.29074 .3006 L
.28166 .30034 L
.27316 .29996 L
.25795 .29895 L
.24137 .29733 L
.22569 .29523 L
.21129 .29277 L
.18438 .28657 L
.17117 .2826 L
.15703 .27751 L
.12953 .26438 L
.11551 .2554 L
.10377 .2462 L
.09387 .23683 L
.08424 .22582 L
.06985 .2042 L
.06306 .19075 L
.05792 .17844 L
.04953 .15221 L
.04495 .13222 L
.04336 .12339 L
.0421 .11498 L
.04127 .1082 L
.04075 .10272 L
.04042 .0978 L
.04026 .09365 L
.04024 .08937 L
.04037 .0859 L
.04066 .08255 L
.04113 .07946 L
.04173 .07683 L
Mistroke
.04241 .07473 L
.04334 .07264 L
.04436 .07093 L
.04541 .06958 L
.0465 .06849 L
.04781 .06746 L
.04935 .06653 L
.05121 .06569 L
.05226 .06532 L
.05343 .06498 L
.0545 .06471 L
.05574 .06446 L
.05693 .06427 L
.05806 .06412 L
.06051 .06388 L
.06195 .0638 L
.06336 .06374 L
.06602 .0637 L
.06914 .06373 L
.07222 .06383 L
.07525 .06398 L
.08281 .0645 L
.09947 .06602 L
.15652 .07196 L
.38308 .09356 L
.50641 .107 L
.56687 .11564 L
.61193 .1242 L
.63273 .12937 L
.65124 .13522 L
.66496 .14098 L
.67025 .14381 L
.67451 .1465 L
.68085 .15177 L
.68329 .15463 L
.68525 .15775 L
.68598 .15934 L
.68659 .16108 L
.68721 .16428 L
.68724 .16745 L
.68678 .17043 L
.68576 .17373 L
.68505 .17541 L
.68413 .17726 L
.67986 .1837 L
.67281 .1914 L
.66439 .19875 L
.61853 .22729 L
.55943 .25323 L
.52215 .26607 L
Mistroke
.47747 .27862 L
.45269 .28435 L
.42369 .28996 L
.39578 .29428 L
.36828 .29749 L
.35199 .29889 L
.34294 .2995 L
.33443 .29996 L
.31912 .30053 L
.31092 .30068 L
.30208 .30073 L
.29244 .30063 L
.28191 .30035 L
.27189 .29989 L
.2626 .29931 L
.25419 .29863 L
.24491 .29772 L
.22614 .2953 L
.20824 .29218 L
.19145 .28842 L
.16096 .27902 L
.14482 .27228 L
.13065 .26501 L
.11529 .25525 L
.10218 .24481 L
.0919 .23474 L
.08208 .22303 L
.06817 .20111 L
.06196 .18829 L
.0566 .1749 L
.04955 .15232 L
.04479 .13141 L
.04322 .12257 L
.04213 .11524 L
.0414 .10938 L
.04082 .10359 L
.04045 .09842 L
.04026 .09358 L
.04025 .08898 L
.04041 .08532 L
.04056 .08349 L
.04078 .08165 L
.04102 .08004 L
.04129 .07866 L
.04191 .07621 L
.04259 .07428 L
.0435 .07233 L
.04448 .07075 L
.04543 .06956 L
.04658 .06843 L
Mistroke
.04789 .0674 L
.04924 .06659 L
.05057 .06595 L
.05193 .06543 L
.05361 .06493 L
.05526 .06456 L
.0572 .06423 L
.05942 .06397 L
.06145 .06382 L
.06385 .06373 L
.06659 .0637 L
.06823 .06371 L
.06978 .06375 L
.0728 .06386 L
.07621 .06404 L
.0841 .0646 L
.09267 .06536 L
.11208 .06731 L
.17649 .07399 L
.38326 .09358 L
.51392 .10796 L
.57091 .11631 L
.59895 .12145 L
.62115 .12636 L
.63744 .13072 L
.65239 .13564 L
.66507 .14104 L
.67429 .14635 L
.68054 .15147 L
.68311 .15439 L
.68489 .15708 L
.68609 .15963 L
.68692 .16243 L
.68727 .1651 L
.68723 .16759 L
.68681 .17029 L
.68607 .17287 L
.68514 .17521 L
.68384 .17778 L
.67991 .18363 L
.67508 .18914 L
.66354 .19942 L
.64773 .21061 L
.60364 .23462 L
.53868 .26066 L
Mfstroke
.30308 .10819 m
.39525 .12158 L
.49034 .13926 L
.52884 .14936 L
.54654 .15535 L
.56004 .161 L
.57033 .16644 L
.57486 .16937 L
.579 .17253 L
.58205 .17532 L
.58482 .17843 L
.5868 .1813 L
.58821 .18401 L
.58885 .18567 L
.58936 .18744 L
.58984 .19066 L
.58987 .19265 L
.5897 .19453 L
.5894 .19623 L
.58891 .19807 L
.58756 .20154 L
.58553 .20524 L
.58039 .21192 L
.57366 .21844 L
.56588 .22456 L
.54306 .23844 L
.51059 .25315 L
.47428 .26574 L
.4515 .27214 L
.42453 .27846 L
.39908 .28328 L
.38503 .28549 L
.36974 .28754 L
.35674 .28899 L
.34212 .29031 L
.32851 .29123 L
.31557 .29182 L
.30197 .29215 L
.28941 .29217 L
.2747 .29183 L
.26063 .29113 L
.24499 .28989 L
.23706 .28905 L
.22833 .28797 L
.19853 .28278 L
.18202 .27875 L
.1647 .27342 L
.13521 .2609 L
.12073 .25254 L
.10834 .24375 L
Mistroke
.09509 .23205 L
.08458 .2204 L
.0689 .19694 L
.06228 .18362 L
.0572 .17123 L
.05016 .14926 L
.04596 .13156 L
.04313 .11541 L
.04225 .10856 L
.0419 .10524 L
.04161 .10196 L
.04127 .09656 L
.04116 .09218 L
.04123 .08805 L
.04134 .08594 L
.0415 .0841 L
.04191 .08113 L
.0424 .07874 L
.04307 .07644 L
.04391 .07434 L
.04473 .07279 L
.04572 .07135 L
.04666 .07025 L
.04779 .06921 L
.04924 .06817 L
.05075 .06733 L
.05235 .06665 L
.05394 .06613 L
.05581 .06567 L
.05798 .06529 L
.06019 .06502 L
.06236 .06485 L
.06509 .06475 L
.06672 .06472 L
.0683 .06473 L
.07136 .06479 L
.07299 .06485 L
.07486 .06493 L
.0788 .06516 L
.08269 .06544 L
.09253 .06629 L
.11473 .06854 L
.28231 .08536 L
.41183 .09802 L
.5298 .11214 L
.57932 .12015 L
.60168 .12463 L
.62229 .12957 L
.63765 .13405 L
.65172 .13917 L
Mistroke
.66201 .14398 L
.66955 .14862 L
.67308 .1514 L
.67621 .15449 L
.67849 .15745 L
.68006 .16024 L
.6811 .16304 L
.68162 .16561 L
.68174 .16862 L
.68141 .17149 L
.68055 .17467 L
.67913 .17808 L
.67749 .18102 L
.67528 .18428 L
.66885 .1917 L
.66108 .19876 L
.64129 .21295 L
.61346 .2287 L
.58376 .24262 L
.54699 .25709 L
.50926 .26944 L
.4623 .28176 L
.43993 .28652 L
.41457 .29109 L
.38931 .29475 L
.36537 .29741 L
.35053 .29864 L
.33623 .29953 L
.32084 .30015 L
.31205 .30034 L
.30386 .30041 L
.29004 .30027 L
.27467 .29973 L
.25846 .29869 L
.2432 .29724 L
.22515 .29486 L
.20809 .29187 L
.17672 .28408 L
.15984 .27834 L
.14483 .27203 L
.12937 .26404 L
.11393 .25403 L
.10026 .24284 L
.08913 .23145 L
.07999 .21997 L
.07141 .20672 L
.05981 .18301 L
.05145 .15892 L
.0457 .13577 L
.04361 .12467 L
Mistroke
.04224 .11578 L
.04134 .10849 L
.04099 .10501 L
.0407 .10158 L
.04051 .09879 L
.04036 .09592 L
.04026 .09136 L
.04034 .08717 L
.04057 .08378 L
.04098 .08054 L
.04127 .07892 L
.04158 .07756 L
.04225 .07532 L
.0431 .07322 L
.04404 .0715 L
.04501 .07014 L
.04598 .06905 L
.04712 .06804 L
.04848 .06708 L
.04988 .06632 L
.05158 .06561 L
.05333 .06505 L
.05503 .06465 L
.05701 .0643 L
.05934 .06402 L
.0617 .06385 L
.06312 .06379 L
.06448 .06375 L
.06604 .06373 L
.06774 .06374 L
.06936 .06377 L
.07115 .06383 L
.07458 .06398 L
.07899 .06425 L
.08334 .06458 L
.12672 .06889 L
.31733 .08738 L
.44057 .09946 L
.50494 .10688 L
.56651 .11566 L
.59286 .12034 L
.61488 .12497 L
.63338 .12966 L
.64793 .13417 L
.66024 .13895 L
.66924 .14341 L
.67695 .14852 L
.6802 .15139 L
.68266 .15414 L
.68452 .15686 L
Mistroke
.68597 .15988 L
.68684 .1631 L
.68709 .16614 L
.68686 .16902 L
.68627 .17169 L
.68515 .1748 L
.68368 .17778 L
.67902 .18456 L
.67313 .19097 L
.65467 .20589 L
.63339 .21922 L
.60538 .23376 L
.54173 .25959 L
.49702 .27348 L
.47012 .28039 L
.44348 .28624 L
.41728 .29103 L
.39229 .29473 L
.3632 .29795 L
.3553 .29862 L
.34664 .29925 L
.33067 .30012 L
.31506 .30061 L
.30058 .30071 L
.28362 .30039 L
.26733 .29962 L
.25219 .29844 L
.23812 .29693 L
.22266 .29475 L
.2063 .29178 L
.19018 .28809 L
.17314 .28322 L
.14378 .27179 L
.12804 .2635 L
.11274 .25338 L
.09981 .24264 L
.08932 .23188 L
.07202 .20797 L
.06463 .1941 L
.05891 .18097 L
.05128 .15854 L
.04591 .13695 L
.04245 .11749 L
.04141 .1094 L
.04097 .10524 L
.04067 .10171 L
.04034 .09608 L
.04025 .09329 L
.04023 .09083 L
.04032 .0869 L
Mistroke
.04044 .0849 L
.0406 .08318 L
.04102 .08007 L
.04129 .07866 L
.04163 .07723 L
.04233 .07496 L
.0431 .07311 L
.04416 .07124 L
.04525 .06977 L
.04668 .06834 L
.04819 .06721 L
.04964 .06638 L
.05132 .06565 L
.05287 .06514 L
.05472 .06467 L
.05686 .06428 L
.05814 .06411 L
.05936 .06398 L
.06175 .06381 L
.06446 .06371 L
.0671 .0637 L
.06965 .06375 L
.0728 .06386 L
.07598 .06402 L
.08217 .06445 L
.08973 .06509 L
.13579 .06981 L
.32076 .08765 L
.46066 .10159 L
.53381 .11065 L
.56584 .11547 L
.59244 .12017 L
.63487 .12997 L
.65194 .13548 L
.66615 .14159 L
.67118 .14437 L
.67579 .14743 L
.67917 .15017 L
.68207 .15311 L
.68411 .15582 L
.68575 .15882 L
.68672 .1616 L
.6872 .16422 L
.68725 .16718 L
.68677 .17043 L
.68583 .17354 L
.68454 .17646 L
.68109 .18206 L
.67605 .18812 L
.66141 .20107 L
Mistroke
.63938 .21578 L
.57984 .24514 L
.50687 .2707 L
.45871 .28303 L
.43088 .28868 L
.39934 .29379 L
.38307 .29589 L
.36731 .29758 L
.35283 .29882 L
.33681 .29984 L
.32126 .30047 L
.30452 .30073 L
.29 .30058 L
.27386 .3 L
.25661 .29884 L
.24054 .29723 L
.22288 .29479 L
.20422 .29136 L
.17362 .28338 L
.15688 .27745 L
.14183 .27087 L
.12898 .26406 L
.11629 .25596 L
.09616 .23915 L
.0865 .2286 L
.07855 .21816 L
.06416 .19311 L
.05852 .17999 L
.0536 .16614 L
.04726 .14309 L
.04349 .1242 L
.04148 .11009 L
.04082 .1035 L
.04043 .09807 L
.04031 .09526 L
.04024 .09287 L
.04023 .0903 L
.04027 .08805 L
.04037 .08603 L
.04051 .08404 L
.04089 .08083 L
.0412 .07908 L
.04154 .07756 L
.0423 .07505 L
.04306 .07321 L
.04399 .07149 L
.04499 .07009 L
.04599 .06897 L
.04729 .06784 L
.04886 .0668 L
Mistroke
.05049 .06599 L
.05213 .06537 L
.05396 .06484 L
.05581 .06445 L
.05799 .06413 L
.0593 .06398 L
.06055 .06388 L
.06306 .06375 L
.06456 .06371 L
.06601 .0637 L
.06913 .06373 L
.07098 .06378 L
.07273 .06385 L
.0759 .06402 L
.07948 .06425 L
.08656 .06481 L
.10604 .06669 L
.15742 .07206 L
.36869 .09217 L
.4866 .10457 L
.54353 .11203 L
.59512 .12068 L
.61906 .12585 L
.63747 .13072 L
.65302 .13588 L
.66454 .14078 L
.67371 .14596 L
.67752 .14875 L
.68082 .15174 L
.68311 .15439 L
.68478 .1569 L
.68611 .15968 L
.68698 .16271 L
.68722 .16438 L
.68729 .16618 L
.68698 .16943 L
.68657 .17126 L
.68603 .17298 L
.68429 .17696 L
.68219 .18048 L
.67983 .18373 L
.67303 .19119 L
.65544 .20543 L
.63324 .21935 L
.57498 .24714 L
.5342 .26217 L
.49198 .27487 L
.44776 .28538 L
.42262 .29015 L
.39463 .29444 L
Mistroke
.36891 .29743 L
.35383 .29875 L
.33945 .2997 L
.32598 .30032 L
.31351 .30065 L
.29891 .30071 L
.28489 .30045 L
.2699 .29978 L
.25359 .29858 L
.23812 .29694 L
.22393 .29496 L
.20827 .29218 L
.19132 .28839 L
.17378 .28344 L
.15833 .27802 L
.12841 .26372 L
.1136 .25402 L
.10092 .24367 L
.08182 .22267 L
.07307 .20972 L
.06624 .19739 L
.05675 .17532 L
.05049 .15576 L
.04584 .13663 L
.04273 .11943 L
.04173 .11214 L
.04096 .10512 L
.04051 .09932 L
.04028 .09458 L
.04023 .09043 L
.04031 .08709 L
.04054 .08368 L
.04089 .08087 L
.04137 .0783 L
.04201 .07591 L
.04273 .07394 L
.04348 .07236 L
.04449 .07074 L
.04572 .06924 L
.04703 .06804 L
.04837 .0671 L
.04987 .06627 L
.0514 .06562 L
.05322 .06504 L
.05422 .06478 L
.05535 .06454 L
.05766 .06417 L
.059 .06401 L
.06031 .0639 L
.06278 .06376 L
Mistroke
.06562 .0637 L
.06853 .06372 L
.07141 .0638 L
.07478 .06396 L
.07862 .06419 L
.09469 .06555 L
.13822 .07006 L
.14799 .07108 L
Mfstroke
.30308 .20435 m
.29919 .2073 L
.29394 .2103 L
.28795 .21294 L
.28162 .21515 L
.27313 .21747 L
.2682 .21855 L
.26264 .21958 L
.25751 .22036 L
.25158 .22111 L
.24592 .22166 L
.24041 .22206 L
.23411 .22236 L
.23044 .22246 L
.22697 .22251 L
.22047 .22248 L
.21334 .22226 L
.20616 .22184 L
.19925 .22126 L
.19294 .22057 L
.18604 .21963 L
.16989 .21667 L
.16172 .21472 L
.15281 .21221 L
.13734 .20676 L
.12356 .20048 L
.10948 .19224 L
.09586 .18184 L
.08487 .17092 L
.07644 .16025 L
.06481 .14001 L
.06084 .13044 L
.0577 .12078 L
.0565 .11616 L
.05553 .11163 L
.05493 .10806 L
.05467 .10616 L
.05448 .10445 L
.05432 .10254 L
.05423 .10089 L
.05418 .0992 L
.0542 .09746 L
.05427 .09602 L
.05439 .09458 L
.05454 .09341 L
.05475 .09219 L
.05499 .09104 L
.05527 .09001 L
.05589 .08822 L
.0567 .08649 L
Mistroke
.05775 .08484 L
.05881 .08357 L
.06009 .08238 L
.06144 .08141 L
.06277 .08065 L
.06418 .08 L
.06581 .07941 L
.06774 .07888 L
.06969 .07848 L
.07081 .0783 L
.07207 .07814 L
.07449 .07791 L
.07702 .07777 L
.07953 .07772 L
.082 .07773 L
.08446 .07779 L
.0873 .07791 L
.09056 .0781 L
.09783 .07867 L
.10531 .0794 L
.22402 .09428 L
.41713 .11992 L
.47155 .12897 L
.52237 .13959 L
.54329 .14511 L
.56042 .15052 L
.57447 .15594 L
.58533 .16116 L
.59383 .16642 L
.60066 .17222 L
.60352 .17559 L
.60556 .17883 L
.60684 .18178 L
.60767 .18503 L
.60791 .18821 L
.60781 .19005 L
.60756 .19178 L
.60714 .1936 L
.60661 .19528 L
.60493 .1991 L
.6031 .20221 L
.60062 .20563 L
.59416 .21259 L
.57767 .2254 L
.55372 .23912 L
.52769 .2509 L
.49509 .26284 L
.45083 .27544 L
.40388 .2851 L
.39031 .28725 L
Mistroke
.37527 .28929 L
.3619 .29082 L
.34692 .29221 L
.33765 .29289 L
.32892 .29341 L
.32047 .2938 L
.31136 .29409 L
.3023 .29425 L
.29368 .29426 L
.27736 .29394 L
.26271 .29323 L
.24649 .29195 L
.23827 .29108 L
.22946 .28999 L
.21357 .28753 L
.19783 .28442 L
.18312 .2808 L
.15644 .27208 L
.14197 .26586 L
.12743 .25822 L
.104 .24172 L
.09273 .2311 L
.08338 .22031 L
.07446 .20771 L
.06649 .19374 L
.05651 .17065 L
.05015 .15052 L
.0453 .12969 L
.04272 .11423 L
.04186 .10716 L
.04133 .10142 L
.04115 .09869 L
.04101 .09589 L
.04094 .09317 L
.04092 .09082 L
.04104 .08691 L
.04129 .08377 L
.04148 .0822 L
.04173 .08061 L
.04229 .078 L
.04299 .07575 L
.04376 .0739 L
.04456 .07245 L
.04551 .07106 L
.04668 .06974 L
.04805 .06856 L
.04935 .0677 L
.05089 .0669 L
.05246 .06627 L
.05401 .06579 L
Mistroke
.05592 .06534 L
.05788 .06501 L
.05981 .06478 L
.06172 .06462 L
.06394 .06451 L
.06645 .06447 L
.06926 .06449 L
.07256 .06458 L
.07591 .06474 L
.07924 .06495 L
.09443 .06623 L
.14548 .07157 L
.32299 .08888 L
.46452 .10334 L
.53017 .11168 L
.58224 .12008 L
.62049 .12836 L
.63617 .13276 L
.65061 .13776 L
.66224 .14296 L
.66747 .1459 L
.67169 .14874 L
.67497 .15142 L
.67789 .15438 L
.67995 .15712 L
.6814 .15968 L
.68247 .16254 L
.68306 .1656 L
.68313 .16824 L
.68277 .17117 L
.68189 .17437 L
.68118 .17618 L
.6804 .17784 L
.67639 .1842 L
.67122 .19023 L
.66415 .19688 L
.6477 .20924 L
.62259 .22423 L
.58977 .24022 L
.55334 .25496 L
.51516 .2678 L
.47416 .27908 L
.42423 .28956 L
.39451 .29417 L
.37944 .29604 L
.36546 .29749 L
.35166 .29865 L
.33643 .29961 L
.32001 .30026 L
.30427 .30049 L
Mistroke
.28944 .30034 L
.27545 .29985 L
.25995 .29889 L
.24325 .29732 L
.22568 .29501 L
.20912 .29214 L
.19422 .2889 L
.17866 .28473 L
.15151 .27506 L
.12831 .26348 L
.10614 .24803 L
.09508 .2379 L
.08581 .2276 L
.0775 .21647 L
.06987 .20407 L
.0591 .18131 L
.05045 .15549 L
.04553 .13496 L
.04244 .11728 L
.04138 .109 L
.04102 .10546 L
.04075 .10236 L
.04042 .09726 L
.04026 .09233 L
.0403 .08814 L
.04039 .08603 L
.04052 .08424 L
.04085 .08133 L
.04133 .07861 L
.04184 .07657 L
.04251 .07457 L
.04334 .0727 L
.04438 .07096 L
.04549 .06955 L
.04662 .06844 L
.04896 .06679 L
.05046 .06604 L
.05197 .06546 L
.05369 .06494 L
.05537 .06457 L
.05746 .06423 L
.05959 .06399 L
.06184 .06383 L
.06444 .06374 L
.06707 .06373 L
.06963 .06377 L
.07284 .06389 L
.07476 .06398 L
.0766 .06409 L
.08425 .06464 L
Mistroke
.1297 .06919 L
.29452 .08525 L
.43537 .09889 L
.50449 .10681 L
.56142 .11482 L
.60486 .12274 L
.64055 .13174 L
.65485 .13668 L
.66565 .14145 L
.6748 .14686 L
.67876 .14997 L
.68166 .15286 L
.68382 .15563 L
.68533 .15827 L
.68646 .16121 L
.68707 .16442 L
.68708 .16766 L
.68686 .16931 L
.68647 .17112 L
.68538 .17437 L
.68392 .17743 L
.67984 .18358 L
.67485 .18927 L
.65955 .20241 L
.63717 .21705 L
.6066 .23318 L
.57221 .24824 L
.535 .26189 L
.49208 .27483 L
.44816 .28529 L
.42293 .29008 L
.39392 .29452 L
.37735 .29654 L
.36158 .2981 L
.34616 .29929 L
.33739 .29981 L
.32937 .30018 L
.31263 .30065 L
.3041 .30072 L
.29465 .30066 L
.27775 .30017 L
.26182 .29924 L
.25208 .29843 L
.24284 .29749 L
.22553 .2952 L
.20697 .29192 L
.18709 .28729 L
.17141 .28266 L
.15467 .27656 L
.13912 .26952 L
Mistroke
.12342 .26069 L
.10995 .25126 L
.09873 .24164 L
.08012 .22036 L
.07194 .20783 L
.06541 .1957 L
.05594 .17306 L
.04904 .15033 L
.04438 .12921 L
.04198 .11411 L
.04122 .10768 L
.04065 .10143 L
.04037 .09672 L
.04024 .09224 L
.04026 .0885 L
.0404 .08547 L
.04072 .08206 L
.04095 .08052 L
.04123 .07894 L
.04185 .07643 L
.04255 .07439 L
.04351 .07231 L
.04453 .07069 L
.0458 .06916 L
.04732 .06782 L
.04869 .0669 L
.0503 .06607 L
.05195 .06543 L
.05357 .06494 L
.05564 .06448 L
.05688 .06428 L
.05807 .06412 L
.0604 .06389 L
.06306 .06375 L
.06569 .0637 L
.06878 .06372 L
.07192 .06382 L
.07504 .06397 L
.0815 .0644 L
.08931 .06505 L
.13757 .07 L
.30942 .0866 L
.4481 .10021 L
.51912 .10865 L
.58366 .11853 L
.62779 .12804 L
.64715 .13379 L
.66153 .13938 L
.67175 .14471 L
.67868 .14974 L
Mistroke
.6816 .15258 L
.68405 .15572 L
.68572 .15874 L
.68672 .16157 L
.68722 .16447 L
.68722 .16757 L
.68681 .17025 L
.68595 .17321 L
.68455 .17645 L
.68253 .17996 L
.67762 .18639 L
.66353 .19943 L
.64613 .21163 L
.62035 .22635 L
.5864 .24237 L
.54892 .25708 L
.50885 .27012 L
.46629 .28131 L
.41537 .29136 L
.40054 .29362 L
.38391 .2958 L
.36886 .29743 L
.35244 .29885 L
.3439 .29944 L
.33578 .2999 L
.32039 .3005 L
.30571 .30072 L
.28962 .30057 L
.27228 .29991 L
.25596 .29879 L
.24654 .29789 L
.23796 .29692 L
.21869 .2941 L
.2003 .29051 L
.18067 .28552 L
.16269 .27966 L
.14674 .27316 L
.12068 .25894 L
.10741 .24925 L
.09617 .23916 L
.07728 .2163 L
.06888 .20243 L
.06249 .18949 L
.05319 .16485 L
.0476 .14451 L
.04539 .13443 L
.04356 .1246 L
.04238 .11699 L
.04142 .10957 L
.04081 .10348 L
Mistroke
.04045 .09844 L
.04026 .09373 L
.04024 .0893 L
.04039 .08569 L
.04065 .08268 L
.04098 .08027 L
.04145 .07794 L
.04213 .07554 L
.04288 .07358 L
.04385 .07172 L
.04504 .07002 L
.04639 .06859 L
.04799 .06734 L
.0495 .06645 L
.05131 .06565 L
.05319 .06504 L
.05504 .0646 L
.05612 .0644 L
.05735 .06421 L
.05972 .06395 L
.06211 .06379 L
.06484 .06371 L
.06734 .0637 L
.07028 .06376 L
.07366 .0639 L
.07703 .06409 L
.08555 .06472 L
.10473 .06655 L
.15757 .07207 L
.25558 .0816 L
.38358 .09361 L
.51625 .10827 L
.57977 .11783 L
.60514 .12272 L
.62563 .12748 L
.65405 .13627 L
.66531 .14116 L
.67461 .14658 L
.67827 .14937 L
.6815 .15246 L
.68386 .15543 L
.68548 .15821 L
.68649 .16075 L
.68713 .16359 L
.68728 .1666 L
.68698 .16945 L
.68646 .17164 L
.68567 .17396 L
.68363 .17816 L
Mfstroke
.30308 .30051 m
.28784 .30031 L
.27381 .29978 L
.25747 .2987 L
.24193 .29719 L
.22754 .29531 L
.21428 .29313 L
.18472 .28647 L
.16976 .28194 L
.15615 .27698 L
.14064 .27011 L
.12722 .26286 L
.10275 .24514 L
.09116 .23378 L
.0815 .22209 L
.06701 .19875 L
.06076 .18536 L
.05611 .17339 L
.04936 .15143 L
.04519 .13328 L
.04353 .12426 L
.04223 .11576 L
.04141 .10923 L
.0408 .10302 L
.04056 .09986 L
.04041 .09717 L
.04026 .09241 L
.04026 .09001 L
.04031 .08759 L
.04042 .08549 L
.04057 .08368 L
.04096 .08057 L
.04145 .07808 L
.04211 .07569 L
.04295 .07352 L
.0438 .07187 L
.04468 .07053 L
.04577 .06925 L
.04705 .06807 L
.04861 .06699 L
.05049 .06602 L
.05245 .0653 L
.05442 .06476 L
.05636 .06439 L
.05865 .06408 L
.05987 .06396 L
.06125 .06386 L
.06387 .06375 L
.06541 .06373 L
.06711 .06373 L
Mistroke
.06878 .06375 L
.07036 .06379 L
.0723 .06386 L
.07449 .06396 L
.07871 .06422 L
.08806 .06496 L
.09806 .06591 L
.15406 .07174 L
.37084 .09242 L
.44124 .09952 L
.50573 .10696 L
.562 .11491 L
.6055 .12287 L
.63889 .13123 L
.65221 .13567 L
.6642 .14073 L
.67351 .14597 L
.67761 .14899 L
.68069 .1518 L
.68288 .15432 L
.68474 .15711 L
.6861 .16006 L
.68686 .16285 L
.68715 .1659 L
.68709 .16764 L
.68688 .16925 L
.68616 .17224 L
.68491 .17545 L
.6834 .17836 L
.68166 .18111 L
.67657 .18746 L
.66147 .20097 L
.63905 .21594 L
.57919 .24539 L
.536 .26155 L
.48981 .27544 L
.44449 .28604 L
.41649 .29117 L
.38874 .29519 L
.37402 .2969 L
.35813 .2984 L
.34427 .29941 L
.32878 .30021 L
.31989 .3005 L
.31173 .30066 L
.30222 .30072 L
.29316 .30064 L
.27686 .30013 L
.26759 .29963 L
.25899 .29903 L
Mistroke
.24233 .29743 L
.22648 .29534 L
.21229 .29295 L
.19694 .28974 L
.18058 .28549 L
.1636 .27998 L
.13488 .26733 L
.122 .25979 L
.10911 .25061 L
.09874 .24164 L
.08887 .23137 L
.07329 .21008 L
.06244 .18937 L
.05328 .16514 L
.04695 .14172 L
.04333 .12321 L
.04227 .11621 L
.04142 .10954 L
.04106 .10611 L
.04074 .10259 L
.04038 .09699 L
.04027 .09416 L
.04023 .09135 L
.04025 .0889 L
.04032 .08682 L
.04057 .0834 L
.04078 .08165 L
.04101 .08014 L
.04158 .07741 L
.04197 .07604 L
.04235 .07489 L
.04314 .07303 L
.04399 .0715 L
.04502 .07004 L
.04628 .0687 L
.04774 .06751 L
.04928 .06657 L
.05079 .06586 L
.05257 .06523 L
.05441 .06474 L
.05621 .06438 L
.05844 .06407 L
.0607 .06387 L
.06296 .06375 L
.06516 .0637 L
.06773 .06371 L
.07063 .06377 L
.07405 .06392 L
.0774 .06411 L
.08576 .06474 L
Mistroke
.10431 .06651 L
.16861 .0732 L
.26464 .08245 L
.40221 .09545 L
.52359 .10924 L
.58196 .11823 L
.62535 .12741 L
.64213 .13214 L
.65721 .13752 L
.66843 .14279 L
.6728 .14537 L
.67636 .14785 L
.67933 .15031 L
.68198 .15301 L
.6839 .1555 L
.68528 .15782 L
.68636 .16037 L
.68706 .16321 L
.68729 .16621 L
.68704 .16906 L
.68629 .1722 L
.68565 .17399 L
.68493 .17567 L
.68107 .18209 L
.67611 .18806 L
.66942 .19452 L
.65128 .20828 L
.62508 .22386 L
.59599 .23814 L
.56003 .253 L
.5245 .26533 L
.48181 .27753 L
.45544 .28375 L
.43003 .28883 L
.40278 .2933 L
.37639 .29665 L
.3609 .29817 L
.3441 .29943 L
.33523 .29993 L
.32683 .30029 L
.31753 .30057 L
.30742 .30071 L
.29867 .30071 L
.28905 .30056 L
.27989 .30027 L
.27135 .29986 L
.2551 .29871 L
.23771 .29689 L
.22107 .2945 L
.20294 .29109 L
Mistroke
.18429 .28654 L
.16733 .28131 L
.13862 .26928 L
.1238 .26094 L
.11131 .25231 L
.08722 .22946 L
.0763 .21483 L
.06792 .20063 L
.05638 .1743 L
.05217 .16156 L
.04854 .14838 L
.04411 .12775 L
.04177 .11245 L
.04102 .10573 L
.04071 .10225 L
.04051 .09931 L
.04035 .0964 L
.04026 .09353 L
.04023 .09107 L
.04025 .0889 L
.04041 .08532 L
.04073 .082 L
.04112 .07951 L
.04166 .0771 L
.04237 .07483 L
.04329 .07274 L
.04428 .07104 L
.04531 .0697 L
.04644 .06854 L
.04762 .0676 L
.04903 .06671 L
.05069 .0659 L
.05249 .06525 L
.05456 .0647 L
.05648 .06434 L
.05874 .06404 L
.06103 .06385 L
.06327 .06374 L
.06604 .0637 L
.06884 .06372 L
.07161 .06381 L
.07433 .06393 L
.08108 .06437 L
.09825 .0659 L
.12309 .06847 L
.19895 .07621 L
.3176 .08736 L
.45624 .1011 L
.51462 .10805 L
.5699 .11614 L
Mistroke
.59728 .12111 L
.61893 .12582 L
.63628 .13038 L
.65219 .13557 L
.66446 .14074 L
.66963 .14345 L
.67437 .14641 L
.6781 .14923 L
.68091 .15184 L
.68308 .15435 L
.68488 .15706 L
.68565 .15857 L
.68632 .16025 L
.68708 .16325 L
.68726 .16495 L
.68728 .1668 L
.68712 .16857 L
.68683 .17019 L
.68596 .1732 L
.68451 .17652 L
.68248 .18004 L
.68013 .18335 L
.66732 .19635 L
.65089 .20854 L
.59925 .23666 L
.5662 .25063 L
.52595 .26487 L
.48664 .27629 L
.43954 .28703 L
.41085 .29208 L
.38321 .29588 L
.36944 .29737 L
.35408 .29873 L
.33926 .29971 L
.32525 .30035 L
.31657 .30059 L
.30709 .30072 L
.29807 .30071 L
.2897 .30058 L
.27368 .29999 L
.25661 .29884 L
.24768 .29801 L
.2381 .29693 L
.22084 .29446 L
.20046 .29055 L
.18221 .28596 L
.15346 .27607 L
.13807 .269 L
.12449 .26136 L
.10017 .24299 L
Mistroke
.08856 .23102 L
.07929 .21921 L
.06602 .19695 L
.0557 .17237 L
.04914 .15073 L
.04512 .13309 L
.04342 .12378 L
.04208 .11485 L
.04124 .10792 L
.04065 .10148 L
.04035 .09638 L
.04023 .09148 L
.04029 .08758 L
.04048 .08437 L
.04066 .08262 L
.04089 .08086 L
.04144 .078 L
.04211 .07558 L
.04286 .07364 L
.04379 .07183 L
.04496 .07011 L
.04637 .06861 L
.04785 .06743 L
.04923 .06659 L
.05085 .06584 L
.0525 .06525 L
.05412 .0648 L
.05617 .06439 L
.0574 .0642 L
.05859 .06406 L
.06089 .06386 L
.06352 .06373 L
.06623 .0637 L
.06936 .06374 L
.07254 .06385 L
.07565 .064 L
.08415 .06461 L
.09352 .06544 L
.21141 .07742 L
.329 .08842 L
.46101 .10163 L
.51642 .10829 L
.5686 .11592 L
.59245 .12017 L
.61553 .12502 L
.64793 .13405 L
.66177 .13948 L
.67158 .1446 L
.67592 .14751 L
.67979 .15073 L
Mistroke
.68267 .15383 L
.68469 .15674 L
.68603 .15945 L
.68684 .16203 L
.68726 .1649 L
.68718 .16804 L
.68659 .17119 L
.68543 .17455 L
.68402 .17746 L
.68206 .18068 L
.6761 .18806 L
.66897 .19492 L
.64752 .21074 L
.62306 .22493 L
.59175 .24004 L
.55823 .25367 L
.51596 .26799 L
.47189 .27999 L
.4271 .28936 L
.39785 .294 L
.3686 .29746 L
.35198 .29889 L
.33623 .29988 L
.327 .30028 L
.31856 .30054 L
.30872 .30071 L
.29938 .30072 L
.28339 .3004 L
.26633 .29956 L
.25165 .2984 L
.23549 .29661 L
.21808 .294 L
.19958 .29035 L
.18241 .28602 L
.16715 .28125 L
.13943 .26969 L
.12486 .2616 L
.1122 .25299 L
.09008 .23275 L
.0798 .21992 L
.07176 .20753 L
.0605 .18489 L
.05198 .16092 L
.0467 .1406 L
.04354 .12449 L
.04225 .11611 L
.04127 .10814 L
.04094 .10484 L
.04066 .10159 L
.04035 .09632 L
Mistroke
.04023 .09186 L
.04027 .08818 L
.04046 .08462 L
.04083 .0813 L
.04109 .07965 L
.04138 .07824 L
.04173 .07684 L
.04217 .07542 L
.04302 .07329 L
.04407 .07136 L
.04516 .06987 L
.04648 .06851 L
.04787 .06742 L
.04927 .06657 L
.05092 .06581 L
.05261 .06521 L
.05425 .06477 L
.05615 .06439 L
.0584 .06408 L
.0596 .06396 L
.06097 .06385 L
.06355 .06373 L
.06614 .0637 L
.06892 .06373 L
.07174 .06381 L
.07443 .06394 L
.07754 .06412 L
.09337 .06543 L
.23286 .07947 L
.35525 .09089 L
.48525 .10441 L
.55067 .11309 L
.58074 .11801 L
.60854 .12345 L
.62865 .12826 L
.64707 .13376 L
.66059 .13895 L
.67052 .14397 L
.67469 .14663 L
.67841 .1495 L
.68108 .15201 L
.68339 .15477 L
.68525 .15776 L
.68644 .16061 L
.68689 .16228 L
.68718 .16405 L
.68725 .16725 L
.68686 .17007 L
.68599 .17312 L
.68476 .17603 L
Mistroke
.68332 .17869 L
.67851 .18536 L
.67242 .19178 L
.65754 .20394 L
.63997 .21542 L
.58778 .24177 L
Mfstroke
.30308 .39666 m
.27479 .39291 L
.24948 .38839 L
.22099 .38168 L
.19502 .37367 L
.1721 .36461 L
.15213 .35471 L
.1318 .34197 L
.11238 .32621 L
.09535 .30806 L
.07996 .28613 L
.0682 .26366 L
.05961 .24229 L
.05186 .21734 L
.0457 .19144 L
.03879 .15124 L
.03663 .13409 L
.03523 .12059 L
.03437 .11031 L
.03379 .1012 L
.0336 .09708 L
.03346 .09298 L
.03337 .08672 L
.03341 .08367 L
.03351 .08071 L
.03365 .07819 L
.03382 .07611 L
.03424 .07258 L
.03475 .06982 L
.03542 .06723 L
.03627 .06493 L
.0371 .06324 L
.03798 .06187 L
.03904 .06059 L
.0403 .05943 L
.04172 .05845 L
.04339 .05759 L
.04511 .05695 L
.04682 .05648 L
.04793 .05624 L
.04901 .05606 L
.05024 .05589 L
.05161 .05574 L
.05407 .05557 L
.05556 .05552 L
.05701 .05549 L
.05855 .05548 L
.06031 .05551 L
.06204 .05555 L
.06372 .05561 L
Mistroke
.06708 .05577 L
.07095 .05601 L
.09198 .05776 L
.24754 .07118 L
.39057 .08212 L
.47372 .08901 L
.55627 .09717 L
.61778 .10509 L
.64672 .10992 L
.66954 .11463 L
.68672 .11908 L
.70007 .12344 L
.71213 .12867 L
.71637 .13103 L
.72025 .13362 L
.72347 .13626 L
.72585 .13873 L
.72764 .14112 L
.72904 .14368 L
.73002 .14654 L
.73043 .14924 L
.73037 .15225 L
.7301 .15395 L
.72973 .15551 L
.72858 .15872 L
.72709 .16172 L
.72228 .16865 L
.7165 .17494 L
.70896 .18175 L
.67311 .20627 L
.61757 .23451 L
.58053 .24983 L
.54068 .26388 L
.50023 .27583 L
.45252 .28711 L
.42595 .29209 L
.39501 .29672 L
.38094 .2984 L
.36542 .29995 L
.35044 .30113 L
.33642 .30194 L
.31964 .30253 L
.30373 .30269 L
.29448 .30259 L
.28601 .30238 L
.27617 .30199 L
.26682 .30144 L
.25769 .30076 L
.24798 .29984 L
.23054 .29769 L
Mistroke
.21183 .29458 L
.19148 .29009 L
.17463 .28532 L
.15945 .28003 L
.14217 .27257 L
.12744 .26465 L
.10305 .24699 L
.09154 .23572 L
.082 .22425 L
.06751 .20111 L
.05778 .1793 L
.05037 .15653 L
.04532 .13538 L
.04228 .11787 L
.04123 .10969 L
.04059 .10318 L
.04022 .09784 L
.04004 .09275 L
.04006 .08856 L
.04021 .08516 L
.04055 .08171 L
.041 .07889 L
.04132 .07745 L
.04165 .07622 L
.04251 .07376 L
.04344 .07185 L
.04462 .07007 L
.04602 .06852 L
.04749 .06731 L
.04899 .06639 L
.05073 .06557 L
.05235 .065 L
.05428 .06449 L
.05653 .06407 L
.05788 .06389 L
.05917 .06375 L
.06042 .06365 L
.06184 .06357 L
.06457 .06348 L
.06757 .06348 L
.07049 .06355 L
.0722 .06362 L
.07412 .06371 L
.0778 .06393 L
.094 .06528 L
.21406 .07743 L
.32179 .08745 L
.45943 .10107 L
.5345 .11029 L
.59227 .11959 L
Mistroke
.61539 .12438 L
.63675 .12982 L
.6533 .13517 L
.66554 .14031 L
.6745 .1453 L
.67843 .14813 L
.68153 .15086 L
.68386 .15342 L
.68585 .15626 L
.68716 .15888 L
.68798 .16135 L
.68847 .16459 L
.68839 .16768 L
.68787 .17049 L
.68687 .17358 L
.68526 .17699 L
.68301 .18064 L
.67763 .18731 L
.66196 .20117 L
.64205 .21452 L
.61503 .22932 L
.57959 .24543 L
.5389 .26072 L
.49573 .27396 L
.44931 .28516 L
.42355 .29007 L
.39424 .29457 L
.38094 .29622 L
.36661 .29773 L
.35305 .29888 L
.34019 .29973 L
.3279 .30032 L
.31456 .3007 L
.29953 .30078 L
.28569 .30054 L
.26922 .29981 L
.2539 .29867 L
.23701 .29686 L
.21911 .29423 L
.20368 .2913 L
.1894 .28796 L
.15799 .27794 L
.14301 .27148 L
.12794 .2635 L
.10371 .2462 L
.091 .23381 L
.08062 .22111 L
.07254 .2089 L
.06535 .19562 L
.05518 .17092 L
Mistroke
.0489 .14984 L
.04455 .13018 L
.04292 .12068 L
.0418 .11273 L
.04108 .10646 L
.04057 .10044 L
.04031 .09562 L
.04022 .09166 L
.04027 .08787 L
.04049 .0842 L
.04088 .08088 L
.04139 .07817 L
.04195 .07607 L
.04264 .07412 L
.04332 .07265 L
.04415 .07122 L
.04516 .06986 L
.04635 .06862 L
.04759 .06761 L
.04881 .06681 L
.05031 .06605 L
.05183 .06546 L
.05364 .06491 L
.05573 .06446 L
.05685 .06427 L
.05812 .0641 L
.06059 .06387 L
.06317 .06374 L
.06575 .06369 L
.0683 .06371 L
.07085 .06377 L
.07382 .0639 L
.07724 .06409 L
.08498 .06467 L
.09308 .06539 L
.23322 .07949 L
.34206 .08963 L
.47491 .10319 L
.54533 .11228 L
.59882 .1214 L
.62013 .12609 L
.63977 .13139 L
.65498 .1366 L
.66623 .14159 L
.6712 .14433 L
.67525 .14698 L
.6812 .15208 L
.68361 .15499 L
.68529 .15773 L
.68655 .16079 L
Mistroke
.68699 .16252 L
.68723 .1641 L
.68731 .167 L
.68697 .16971 L
.68616 .17272 L
.68484 .17593 L
.68331 .17877 L
.68157 .18144 L
.67656 .1876 L
.6602 .202 L
.6398 .21554 L
.61207 .23056 L
.57662 .24648 L
.54129 .25977 L
.49687 .27354 L
.45132 .28464 L
.40394 .29313 L
.37482 .29682 L
.35964 .29828 L
.35078 .29898 L
.34263 .29952 L
.32774 .30026 L
.31153 .30068 L
.29626 .30069 L
.28165 .30034 L
.2644 .29944 L
.25564 .29876 L
.24598 .29784 L
.22887 .2957 L
.21291 .29308 L
.19428 .28912 L
.17759 .28461 L
.15883 .27821 L
.142 .27095 L
.12836 .2637 L
.11463 .25478 L
.09365 .23661 L
.08356 .22496 L
.0744 .21188 L
.06159 .18744 L
.05329 .16518 L
.04799 .14614 L
.04417 .12806 L
.04174 .11225 L
.04094 .1049 L
.04048 .09898 L
.04034 .09619 L
.04025 .09334 L
.04023 .0906 L
.04027 .08822 L
Mistroke
.04036 .08616 L
.04049 .08433 L
.04083 .08124 L
.04136 .07834 L
.04172 .07688 L
.0421 .07562 L
.04291 .07352 L
.0438 .0718 L
.0447 .07045 L
.04578 .06918 L
.0471 .06799 L
.04864 .06693 L
.05008 .06617 L
.0518 .06548 L
.05371 .0649 L
.05563 .06448 L
.05791 .06414 L
.05913 .064 L
.06054 .06388 L
.06303 .06375 L
.06452 .06371 L
.06593 .0637 L
.06868 .06372 L
.07178 .06381 L
.07477 .06395 L
.07818 .06416 L
.08492 .06467 L
.10353 .06643 L
.26215 .08221 L
.39301 .09454 L
.46678 .10227 L
.53936 .11143 L
.59292 .12026 L
.61811 .12562 L
.63798 .13087 L
.65279 .13579 L
.66422 .14063 L
.66947 .14336 L
.67436 .1464 L
.67787 .14903 L
.68093 .15186 L
.68355 .15498 L
.68532 .15789 L
.68659 .16108 L
.68702 .16291 L
.68724 .16463 L
.68721 .16779 L
.68671 .17071 L
.68625 .17234 L
.68561 .17412 L
Mistroke
.68406 .17739 L
.67991 .18364 L
.67383 .19041 L
.65896 .2029 L
.63626 .21762 L
.60985 .23164 L
.57567 .24686 L
.53183 .26296 L
.49021 .27534 L
.44025 .2869 L
.41007 .2922 L
.3811 .29613 L
.36659 .29765 L
.35051 .299 L
.33497 .29994 L
.32038 .3005 L
.30676 .30072 L
.29192 .30062 L
.27774 .30018 L
.26467 .29945 L
.24928 .29817 L
.23244 .2962 L
.21657 .29374 L
.20196 .29087 L
.18564 .28691 L
.17064 .28242 L
.1439 .27186 L
.1299 .26459 L
.11785 .25704 L
.10497 .24723 L
.094 .23696 L
.08464 .22632 L
.07579 .21405 L
.06344 .19158 L
.05805 .17878 L
.05343 .1656 L
.04744 .14383 L
.04391 .12664 L
.04187 .11327 L
.04112 .10674 L
.04065 .10143 L
.04033 .09601 L
.04023 .09149 L
.0403 .08724 L
.04053 .08387 L
.04071 .08218 L
.04095 .08049 L
.0415 .07774 L
.04214 .0755 L
.04295 .07343 L
Mistroke
.04374 .0719 L
.04473 .07042 L
.04603 .06893 L
.04737 .06778 L
.04908 .06668 L
.05088 .06582 L
.0527 .06519 L
.05453 .06471 L
.0567 .0643 L
.05787 .06414 L
.05922 .06399 L
.06158 .06382 L
.06394 .06372 L
.06671 .0637 L
.06835 .06372 L
.0699 .06375 L
.07321 .06388 L
.07519 .06398 L
.07708 .06409 L
.08492 .06467 L
.12509 .06868 L
.31449 .08707 L
.4364 .09896 L
.50289 .10656 L
.55965 .11448 L
.58757 .11925 L
.61412 .1247 L
.63477 .12994 L
.65031 .13488 L
.66333 .1402 L
.66882 .143 L
.67388 .14608 L
.67782 .14899 L
.68079 .15172 L
.68309 .15436 L
.68495 .15719 L
.68618 .15986 L
.687 .16281 L
.68729 .16563 L
.68716 .16826 L
.68672 .17066 L
.68591 .17334 L
.6847 .17616 L
.68323 .17884 L
.67881 .185 L
.67348 .19076 L
.65735 .20407 L
.61829 .22742 L
.56253 .25205 L
Mfstroke
.30308 .49282 m
.26202 .48363 L
.22628 .47278 L
.18752 .45675 L
.15403 .43753 L
.12649 .41573 L
.10446 .39189 L
.08438 .36165 L
.06779 .32572 L
.05555 .28746 L
.04638 .24676 L
.04056 .21148 L
.03691 .18332 L
.03404 .15596 L
.03206 .13244 L
.03098 .11641 L
.03028 .10284 L
.03006 .09686 L
.02993 .09201 L
.02986 .08401 L
.02996 .07815 L
.03022 .07311 L
.03064 .06872 L
.03117 .06537 L
.03152 .06372 L
.03187 .06236 L
.03277 .05975 L
.03365 .05793 L
.03456 .05652 L
.03566 .05522 L
.03697 .05408 L
.03821 .05327 L
.03947 .05264 L
.04098 .05207 L
.04274 .05158 L
.04469 .05121 L
.04586 .05105 L
.04697 .05093 L
.04927 .05076 L
.05163 .05069 L
.05305 .05067 L
.05462 .05068 L
.05762 .05075 L
.0594 .05082 L
.06114 .0509 L
.06538 .05115 L
.08429 .05264 L
.11304 .05518 L
.3195 .07029 L
.48135 .08159 L
Mistroke
.56386 .08861 L
.60424 .09279 L
.63802 .09693 L
.66602 .10108 L
.69153 .10579 L
.71051 .11027 L
.72459 .11455 L
.73514 .11877 L
.74387 .12356 L
.74723 .12604 L
.75011 .12875 L
.75219 .13136 L
.75356 .13378 L
.7545 .13633 L
.75494 .13876 L
.75498 .14147 L
.75451 .14444 L
.75356 .14744 L
.75291 .14896 L
.75207 .15064 L
.74824 .15651 L
.74336 .1622 L
.73692 .16844 L
.72239 .18009 L
.67231 .21072 L
.61027 .23988 L
.57367 .25411 L
.53025 .26853 L
.48849 .28003 L
.43904 .29072 L
.40904 .29568 L
.38027 .29932 L
.36595 .30072 L
.35003 .30195 L
.33469 .30279 L
.32023 .30326 L
.30328 .30342 L
.28711 .30313 L
.27778 .30277 L
.26916 .30229 L
.25967 .3016 L
.24963 .30069 L
.23072 .29838 L
.21317 .29548 L
.19411 .29137 L
.17419 .28579 L
.1421 .27311 L
.12718 .26505 L
.11203 .25485 L
.10033 .24506 L
Mistroke
.08909 .2335 L
.07245 .21045 L
.06467 .19589 L
.05787 .17996 L
.05314 .16634 L
.0492 .15263 L
.04623 .14018 L
.04419 .12998 L
.04156 .11313 L
.04079 .1062 L
.04048 .10278 L
.04027 .09981 L
.04003 .09503 L
.03995 .09042 L
.03999 .0881 L
.04008 .08606 L
.04035 .08263 L
.04057 .0809 L
.04081 .07942 L
.04112 .07793 L
.04149 .07644 L
.04216 .07439 L
.04289 .07269 L
.04387 .07094 L
.0449 .06955 L
.04602 .06837 L
.04738 .06726 L
.04894 .06629 L
.05054 .06554 L
.05232 .0649 L
.05439 .06437 L
.05629 .06401 L
.05856 .06372 L
.0599 .0636 L
.06119 .06351 L
.06273 .06344 L
.06426 .0634 L
.06714 .0634 L
.06886 .06342 L
.07053 .06347 L
.07398 .06362 L
.07746 .06383 L
.08464 .06436 L
.10444 .06624 L
.23989 .07977 L
.34795 .08977 L
.47823 .10304 L
.54702 .1119 L
.59945 .12078 L
.62044 .12533 L
Mistroke
.63989 .13048 L
.65497 .1355 L
.6664 .14037 L
.67569 .14566 L
.67955 .14853 L
.68293 .15169 L
.68432 .15328 L
.68562 .15504 L
.68658 .1566 L
.68742 .15828 L
.68806 .15996 L
.68849 .16149 L
.68892 .16452 L
.68882 .16761 L
.68828 .17048 L
.68721 .17368 L
.68556 .17711 L
.68164 .18297 L
.67578 .18955 L
.65809 .20418 L
.63217 .22037 L
.60184 .23575 L
.56872 .24987 L
.5312 .26334 L
.48403 .27711 L
.43024 .28892 L
.39798 .29409 L
.38288 .29603 L
.3659 .29782 L
.35053 .29909 L
.33592 .29999 L
.32019 .3006 L
.31126 .30077 L
.30307 .30082 L
.28822 .30063 L
.27192 .29998 L
.25638 .29891 L
.24197 .29748 L
.22531 .29525 L
.20977 .29256 L
.1929 .28886 L
.17513 .28393 L
.15714 .27763 L
.14085 .27046 L
.1131 .25372 L
.10122 .24401 L
.08975 .23245 L
.08088 .22147 L
.07276 .20927 L
.06067 .18536 L
Mistroke
.05287 .1639 L
.04689 .14152 L
.04343 .12391 L
.04215 .11545 L
.04128 .10838 L
.04093 .10484 L
.04063 .10127 L
.04031 .09566 L
.04022 .09143 L
.04027 .0879 L
.04046 .08447 L
.04082 .08125 L
.04132 .07846 L
.04199 .07592 L
.04267 .07403 L
.04354 .07223 L
.04447 .07075 L
.04541 .06957 L
.0466 .06838 L
.04784 .06742 L
.05033 .06604 L
.05189 .06543 L
.05345 .06496 L
.05543 .06451 L
.05746 .06418 L
.05942 .06396 L
.06169 .0638 L
.06435 .0637 L
.06577 .06369 L
.0674 .06369 L
.07044 .06376 L
.07351 .06388 L
.0766 .06405 L
.08007 .06428 L
.08688 .06483 L
.10543 .06662 L
.26417 .08239 L
.38576 .09381 L
.4576 .10123 L
.522 .10901 L
.57472 .11693 L
.59871 .12137 L
.62095 .12628 L
.63704 .13056 L
.65199 .13546 L
.66317 .14008 L
.6715 .1445 L
.6792 .15012 L
.68219 .15316 L
.68344 .15474 L
Mistroke
.6846 .15646 L
.6855 .15812 L
.68617 .15966 L
.68705 .16273 L
.68735 .16555 L
.68717 .16858 L
.68659 .17138 L
.68554 .17442 L
.68414 .17732 L
.68255 .17999 L
.67743 .18665 L
.67105 .19309 L
.65224 .20766 L
.62946 .22149 L
.59916 .23671 L
.56024 .25293 L
.52005 .26674 L
.47846 .27838 L
.43428 .28805 L
.41039 .29216 L
.38297 .29591 L
.36663 .29765 L
.35081 .29898 L
.3363 .29987 L
.32026 .3005 L
.31182 .30067 L
.30244 .30073 L
.29256 .30064 L
.28324 .3004 L
.26642 .29957 L
.25691 .29887 L
.24819 .29807 L
.2313 .29605 L
.21566 .29358 L
.19863 .29014 L
.18081 .28556 L
.16425 .28023 L
.14924 .27428 L
.12321 .26057 L
.11124 .25226 L
.09953 .24239 L
.08155 .22232 L
.0726 .20896 L
.0655 .1959 L
.0554 .17153 L
.04839 .14778 L
.04433 .12896 L
.04174 .1122 L
.04097 .10521 L
.04067 .10164 L
Mistroke
.04046 .09853 L
.04027 .09396 L
.04024 .08957 L
.04037 .08594 L
.04062 .08296 L
.04097 .08034 L
.04138 .07822 L
.04196 .07605 L
.0426 .07424 L
.04341 .0725 L
.04438 .0709 L
.0453 .06971 L
.04642 .06856 L
.04775 .0675 L
.04932 .06655 L
.05094 .0658 L
.05255 .06523 L
.05433 .06475 L
.05613 .0644 L
.05825 .06409 L
.06072 .06387 L
.06336 .06374 L
.06477 .06371 L
.06638 .0637 L
.06939 .06374 L
.07239 .06384 L
.07565 .064 L
.07894 .06421 L
.08567 .06473 L
.10397 .06648 L
.26155 .08216 L
.38513 .09376 L
.458 .10129 L
.52266 .10911 L
.57502 .11701 L
.61456 .1248 L
.64807 .13409 L
.66184 .13951 L
.67198 .14485 L
.6761 .14765 L
.67979 .15073 L
.68256 .15368 L
.68452 .15645 L
.68583 .15898 L
.68678 .1618 L
.68725 .16478 L
.68723 .16761 L
.68702 .16921 L
.68665 .17097 L
.68558 .17419 L
Mistroke
.68407 .17737 L
.68229 .18034 L
.6769 .1872 L
.66928 .19465 L
.6527 .20733 L
.633 .21949 L
.57419 .24746 L
.49439 .27422 L
.44633 .28568 L
.41664 .29115 L
.38743 .29537 L
.37394 .29692 L
.35899 .29833 L
.34457 .2994 L
.33103 .30012 L
.3186 .30054 L
.30473 .30073 L
.29006 .30058 L
.27617 .30011 L
.2598 .2991 L
.24416 .29764 L
.23009 .29588 L
.2148 .29342 L
.19834 .29007 L
.18111 .28565 L
.15141 .27521 L
.13676 .26833 L
.12171 .25961 L
.10824 .24992 L
.0953 .23829 L
.08465 .22633 L
.07623 .21472 L
.06314 .19091 L
.05723 .17661 L
.05287 .16383 L
.04917 .15086 L
.04608 .13779 L
.04268 .11908 L
.04154 .11058 L
.04113 .10686 L
.04083 .10364 L
.04043 .09804 L
.04031 .09537 L
.04024 .09272 L
.04027 .08831 L
.04045 .08483 L
.04075 .08183 L
.04122 .07899 L
.04179 .07664 L
.04241 .07474 L
Mistroke
.04325 .07281 L
.04415 .07124 L
.04526 .06976 L
.0466 .0684 L
.04818 .06721 L
.04984 .06628 L
.05147 .0656 L
.0534 .06498 L
.05532 .06454 L
.0572 .06423 L
.05943 .06397 L
.06196 .0638 L
.06433 .06372 L
.06668 .0637 L
.06943 .06374 L
.07257 .06385 L
.07446 .06394 L
.07627 .06404 L
.0806 .06433 L
.08942 .06506 L
.10975 .06707 L
.27927 .0838 L
.39698 .09493 L
.52626 .1096 L
.58798 .11932 L
.63159 .12905 L
.64785 .13402 L
.66216 .13965 L
.67251 .14518 L
.67952 .15048 L
.6823 .15337 L
.68454 .15648 L
.68591 .15917 L
.68687 .16217 L
.68716 .16388 L
.68728 .16545 L
.68725 .16728 L
.68705 .16902 L
.68631 .17215 L
.68568 .17393 L
.68497 .17559 L
.68154 .18143 L
.67616 .18801 L
.66055 .20172 L
.64157 .21446 L
.61633 .22842 L
.55861 .25353 L
Mfstroke
.39924 .10819 m
.45482 .11557 L
.50329 .12307 L
.54985 .13199 L
.58956 .14234 L
.60519 .14785 L
.61881 .15407 L
.6239 .157 L
.62852 .16016 L
.63189 .16294 L
.63488 .16596 L
.63716 .16893 L
.63874 .17168 L
.63985 .17448 L
.64048 .17717 L
.6407 .18032 L
.64042 .18328 L
.63962 .18657 L
.63894 .18842 L
.63819 .19011 L
.63371 .19724 L
.63067 .20088 L
.62674 .20491 L
.60893 .21892 L
.5802 .23549 L
.54615 .25078 L
.50835 .26438 L
.46708 .27619 L
.44199 .28203 L
.41281 .28762 L
.38458 .29185 L
.37134 .29343 L
.35706 .29485 L
.34349 .29592 L
.32834 .29679 L
.31428 .29727 L
.30099 .29744 L
.285 .29725 L
.27028 .29668 L
.26207 .29618 L
.25312 .29549 L
.23682 .2938 L
.22264 .29184 L
.20711 .2891 L
.19212 .2858 L
.17629 .28149 L
.14913 .27162 L
.12573 .25963 L
.11181 .25027 L
.10008 .24055 L
Mistroke
.08772 .22778 L
.07808 .21528 L
.064 .19069 L
.05818 .17709 L
.05377 .16465 L
.04775 .14311 L
.04423 .12615 L
.04194 .11093 L
.04125 .10453 L
.04098 .10124 L
.04079 .09839 L
.0406 .09345 L
.04058 .09119 L
.0406 .08888 L
.04078 .08521 L
.04109 .08218 L
.04133 .08062 L
.04161 .07909 L
.04223 .07664 L
.04305 .07437 L
.04411 .07225 L
.04519 .07066 L
.04628 .06941 L
.0477 .06819 L
.04917 .06721 L
.05067 .06645 L
.05216 .06587 L
.05392 .06533 L
.05595 .06488 L
.05793 .06457 L
.05985 .06435 L
.06224 .06419 L
.06466 .0641 L
.06704 .06408 L
.06938 .06411 L
.07211 .0642 L
.0752 .06434 L
.08227 .06481 L
.08982 .06545 L
.1109 .06755 L
.25178 .0817 L
.38276 .0941 L
.4524 .10132 L
.51297 .10858 L
.56687 .1165 L
.61459 .12585 L
.63544 .13133 L
.65122 .13659 L
.6633 .14182 L
.66876 .14479 L
Mistroke
.67301 .14756 L
.67649 .15028 L
.67958 .1533 L
.68097 .15498 L
.68208 .15655 L
.68376 .15969 L
.68475 .16269 L
.68517 .16545 L
.68511 .16867 L
.68455 .17176 L
.68405 .1734 L
.68336 .17522 L
.68151 .17893 L
.67673 .18569 L
.66894 .19378 L
.65967 .2015 L
.6384 .21578 L
.60914 .23158 L
.57825 .24549 L
.54027 .25987 L
.50145 .27205 L
.45328 .28405 L
.43037 .28862 L
.40442 .29291 L
.37873 .29626 L
.36707 .29747 L
.35419 .29859 L
.33853 .29963 L
.32344 .30028 L
.3085 .30059 L
.29452 .30055 L
.2792 .30013 L
.26216 .29916 L
.25353 .29846 L
.24424 .29754 L
.22744 .29539 L
.21185 .29277 L
.19503 .2892 L
.18044 .28535 L
.16528 .28049 L
.13816 .26895 L
.11549 .2553 L
.10198 .24454 L
.09091 .23359 L
.08051 .22083 L
.07091 .20599 L
.05865 .18025 L
.05376 .16656 L
.05015 .15444 L
.04527 .13376 L
Mistroke
.04255 .11812 L
.04157 .11077 L
.04118 .10724 L
.04085 .10375 L
.04044 .09798 L
.04026 .0933 L
.04026 .08913 L
.04044 .08515 L
.04076 .08189 L
.04119 .07924 L
.04172 .07693 L
.0423 .07508 L
.04308 .07319 L
.04392 .07163 L
.04496 .07015 L
.04618 .06881 L
.04734 .06783 L
.04873 .0669 L
.05037 .06606 L
.0523 .06533 L
.0543 .06478 L
.05627 .06439 L
.05826 .06411 L
.06053 .0639 L
.06259 .06378 L
.06503 .06372 L
.06782 .06372 L
.07105 .0638 L
.07434 .06394 L
.07756 .06413 L
.09193 .0653 L
.11123 .06724 L
.27059 .08302 L
.38213 .09349 L
.5093 .10739 L
.57066 .1163 L
.59388 .12048 L
.61644 .12527 L
.64918 .13453 L
.66253 .13988 L
.67222 .14507 L
.67644 .14798 L
.68019 .15121 L
.68297 .15432 L
.6849 .15725 L
.68622 .1602 L
.68694 .16291 L
.68722 .16608 L
.68697 .16911 L
.68614 .17248 L
Mistroke
.68552 .17419 L
.68467 .17608 L
.6806 .18266 L
.67753 .18644 L
.67366 .19053 L
.66522 .19804 L
.61862 .22723 L
.58268 .24394 L
.54345 .25901 L
.50081 .27243 L
.45579 .28367 L
.42916 .28899 L
.40344 .2932 L
.37339 .29697 L
.35701 .29849 L
.34787 .29918 L
.33934 .2997 L
.32386 .30039 L
.3156 .3006 L
.30678 .30072 L
.29177 .30062 L
.27506 .30005 L
.26003 .29911 L
.2438 .2976 L
.22845 .29564 L
.21447 .29336 L
.18157 .28577 L
.16362 .27999 L
.14764 .27357 L
.12063 .2589 L
.10839 .25004 L
.09615 .23914 L
.08677 .22893 L
.07807 .21746 L
.06546 .19582 L
.05569 .17236 L
.04858 .14855 L
.04466 .13071 L
.04316 .12216 L
.04209 .11491 L
.04134 .10885 L
.04077 .10297 L
.04044 .09821 L
.04028 .09427 L
.04024 .08983 L
.04036 .08613 L
.04059 .0832 L
.04097 .08036 L
.04151 .07768 L
.04187 .07634 L
Mistroke
.04224 .07521 L
.04304 .07323 L
.04391 .07161 L
.04484 .07028 L
.04592 .06905 L
.04813 .06725 L
.04952 .06644 L
.05093 .0658 L
.0526 .06522 L
.05453 .06471 L
.05562 .06449 L
.05682 .06429 L
.05911 .064 L
.06046 .06389 L
.06178 .06381 L
.06329 .06374 L
.06499 .06371 L
.06643 .0637 L
.06806 .06371 L
.06984 .06375 L
.07156 .06381 L
.07482 .06396 L
.07855 .06419 L
.09637 .06572 L
.11751 .06788 L
.29601 .08536 L
.41734 .09698 L
.48306 .10415 L
.54772 .11265 L
.60021 .1217 L
.63726 .13066 L
.65122 .13521 L
.66364 .14035 L
.67279 .14536 L
.67916 .15016 L
.68201 .15304 L
.68325 .15458 L
.68437 .15621 L
.68594 .15926 L
.68685 .16209 L
.68725 .16487 L
.68723 .16748 L
.68679 .17039 L
.68583 .17354 L
.68429 .17695 L
.68204 .1807 L
.67648 .18765 L
.6614 .20108 L
.64078 .21494 L
.61684 .22816 L
Mistroke
.58279 .24391 L
.54636 .25799 L
.5059 .27098 L
.45589 .28365 L
.42581 .28959 L
.39615 .29423 L
.36627 .29768 L
.34893 .29911 L
.33282 .30004 L
.31772 .30056 L
.30338 .30073 L
.28741 .30052 L
.27007 .29979 L
.2613 .29921 L
.25171 .29841 L
.23423 .29644 L
.21723 .29385 L
.20159 .2908 L
.17405 .28352 L
.15893 .27825 L
.14526 .27249 L
.11981 .25836 L
.10698 .2489 L
.0963 .23929 L
.08649 .22859 L
.07733 .21637 L
.06417 .19314 L
.05806 .17882 L
.05345 .16567 L
.04726 .14309 L
.04507 .13286 L
.04331 .12311 L
.04218 .1156 L
.0413 .10843 L
.04093 .10479 L
.04067 .10169 L
.04034 .09619 L
.04025 .09344 L
.04023 .09066 L
.04027 .08825 L
.04036 .08617 L
.04065 .08266 L
.04086 .08107 L
.04113 .07945 L
.04172 .07689 L
.04239 .0748 L
.04332 .07267 L
.04431 .071 L
.04561 .06937 L
.047 .06807 L
Mistroke
.04834 .06711 L
.04989 .06626 L
.05134 .06564 L
.05306 .06508 L
.05506 .0646 L
.05626 .06437 L
.05741 .0642 L
.05965 .06395 L
.06219 .06378 L
.06467 .06371 L
.06708 .0637 L
.07004 .06375 L
.07303 .06387 L
.07599 .06402 L
.07887 .06421 L
.086 .06476 L
.12951 .06915 L
.31846 .08744 L
.45315 .10076 L
.51507 .10811 L
.56625 .11554 L
.61006 .12378 L
.62914 .12839 L
.64627 .13349 L
.65964 .13854 L
.66963 .14346 L
.67657 .14801 L
.67947 .15043 L
.68203 .15306 L
.68421 .15596 L
.6857 .1587 L
.68637 .16039 L
.68683 .16201 L
.68727 .16507 L
.68715 .16834 L
.68653 .17141 L
.68602 .17302 L
.68532 .17482 L
.68344 .17849 L
.67906 .18469 L
.6727 .19151 L
.65721 .20418 L
.63353 .21919 L
.60636 .23332 L
.56777 .25002 L
.52683 .26459 L
.48544 .2766 L
.43522 .28787 L
.40511 .29296 L
.39134 .29487 L
Mistroke
.37584 .29671 L
.36185 .29809 L
.34651 .29927 L
.33789 .29979 L
.32995 .30017 L
.31418 .30063 L
.29904 .30071 L
.28463 .30044 L
.26864 .29971 L
.25125 .29836 L
.23393 .2964 L
.21571 .29358 L
.20027 .2905 L
.18362 .28636 L
.15477 .2766 L
.13954 .26974 L
.12647 .26257 L
.11503 .25506 L
.10358 .24604 L
.08559 .2275 L
.07658 .21526 L
.06936 .20332 L
.06221 .18886 L
.05691 .17575 L
.04911 .15062 L
.04619 .13827 L
.04411 .12773 L
.04277 .11966 L
.04171 .11201 L
.04106 .10612 L
.04058 .10046 L
.04039 .09732 L
.04029 .09463 L
.04023 .0899 L
.04036 .08615 L
.04065 .08269 L
.04107 .07978 L
.04137 .0783 L
.04168 .07704 L
.04234 .07493 L
.04316 .07299 L
.044 .07148 L
.04488 .07022 L
.04594 .06902 L
.04721 .0679 L
.04861 .06695 L
.05029 .06608 L
.05222 .06534 L
.05418 .06479 L
.05618 .06439 L
Mistroke
.05814 .06411 L
.06057 .06388 L
.06304 .06375 L
.06534 .0637 L
.06804 .06371 L
.07105 .06379 L
.07407 .06392 L
.07707 .06409 L
.07997 .06429 L
.0871 .06486 L
.1303 .06923 L
.16119 .07244 L
Mfstroke
.39924 .20435 m
.39906 .20672 L
.39859 .20888 L
.39768 .21136 L
.39646 .2137 L
.3934 .21782 L
.3888 .22223 L
.38219 .22696 L
.37342 .23178 L
.35317 .23974 L
.34098 .24324 L
.32633 .24657 L
.31108 .24922 L
.29599 .25114 L
.28633 .25203 L
.27704 .25265 L
.27155 .25291 L
.2665 .25308 L
.26057 .2532 L
.2549 .25322 L
.24438 .25306 L
.23449 .25264 L
.22345 .25186 L
.21782 .25133 L
.21161 .25064 L
.19965 .24898 L
.18658 .24664 L
.1751 .24407 L
.16303 .24078 L
.14094 .23289 L
.12187 .22351 L
.10235 .21028 L
.08686 .19571 L
.07332 .17807 L
.06261 .15847 L
.05652 .14337 L
.05193 .12839 L
.05028 .12161 L
.04894 .115 L
.04808 .10979 L
.04772 .10725 L
.04742 .10469 L
.0472 .10244 L
.04702 .1001 L
.04685 .09631 L
.04686 .09285 L
.04702 .08995 L
.04731 .08741 L
.04769 .08531 L
.04825 .08314 L
Mistroke
.04889 .0813 L
.04971 .07956 L
.05074 .07791 L
.05185 .07655 L
.05299 .07546 L
.05546 .07377 L
.05687 .07308 L
.05854 .07244 L
.06052 .07187 L
.06248 .07145 L
.06363 .07126 L
.06493 .07109 L
.06609 .07096 L
.06743 .07085 L
.06996 .07072 L
.07284 .07067 L
.0757 .07069 L
.07856 .07078 L
.08142 .07091 L
.08473 .07111 L
.09206 .07169 L
.10761 .07323 L
.15723 .07891 L
.36344 .10172 L
.42391 .10894 L
.48576 .11739 L
.5371 .12598 L
.57726 .13468 L
.6093 .14429 L
.62231 .14965 L
.63325 .15561 L
.63769 .15875 L
.64164 .16223 L
.64456 .16557 L
.64658 .16871 L
.64785 .17158 L
.64868 .17478 L
.64887 .17641 L
.64892 .17817 L
.64858 .1814 L
.64777 .18452 L
.64659 .18746 L
.64486 .19072 L
.6425 .19423 L
.63614 .20152 L
.62866 .20826 L
.60992 .22147 L
.58737 .23407 L
.5221 .26112 L
.48111 .2736 L
Mistroke
.45503 .28011 L
.42956 .28547 L
.40661 .2895 L
.38029 .29319 L
.3653 .29484 L
.35105 .29611 L
.33714 .29705 L
.32201 .29775 L
.30762 .29808 L
.2918 .29806 L
.27665 .29763 L
.26258 .29685 L
.24975 .29581 L
.23563 .29427 L
.22087 .29216 L
.20716 .2897 L
.19085 .28606 L
.17387 .28131 L
.14481 .27022 L
.1298 .26253 L
.11667 .25428 L
.10333 .24393 L
.09086 .23179 L
.08198 .22113 L
.07357 .20883 L
.06187 .18644 L
.05247 .16093 L
.04686 .13969 L
.04347 .1222 L
.04237 .11486 L
.04161 .1088 L
.04113 .10391 L
.04076 .09908 L
.04056 .09474 L
.0405 .09065 L
.04061 .08673 L
.04085 .08358 L
.04128 .0804 L
.04183 .07779 L
.04245 .07568 L
.04312 .07395 L
.04397 .07228 L
.04499 .07074 L
.04614 .06941 L
.04754 .06816 L
.04918 .06708 L
.05087 .06625 L
.05259 .06561 L
.0543 .06514 L
.05642 .0647 L
Mistroke
.05859 .06439 L
.05978 .06427 L
.06115 .06417 L
.06264 .06408 L
.06409 .06403 L
.06684 .064 L
.06848 .06402 L
.07003 .06405 L
.0719 .06411 L
.07371 .06419 L
.07809 .06444 L
.0871 .06514 L
.20983 .0776 L
.44055 .0999 L
.50849 .10784 L
.57164 .11712 L
.61521 .12577 L
.63514 .13099 L
.65057 .13606 L
.66433 .14199 L
.66976 .145 L
.67402 .14784 L
.67721 .15039 L
.6801 .15326 L
.68238 .15619 L
.68412 .15936 L
.68477 .16105 L
.68526 .16285 L
.68565 .1661 L
.6856 .16794 L
.6854 .16966 L
.68499 .17156 L
.68437 .17361 L
.68366 .1754 L
.68273 .17736 L
.68061 .18095 L
.67522 .18779 L
.66851 .19443 L
.65943 .20187 L
.6361 .21727 L
.57883 .24532 L
.54003 .26001 L
.49789 .2731 L
.45549 .28361 L
.42972 .28877 L
.40416 .29298 L
.38919 .29504 L
.37257 .29695 L
.3584 .29828 L
.34252 .29942 L
Mistroke
.33344 .29991 L
.32487 .30026 L
.31573 .30051 L
.30584 .30063 L
.29655 .3006 L
.28768 .30044 L
.27091 .29975 L
.2548 .2986 L
.23761 .29679 L
.22293 .29472 L
.20681 .29181 L
.18974 .28791 L
.17176 .28271 L
.15528 .27673 L
.14096 .27037 L
.11482 .25484 L
.10213 .24469 L
.0914 .23414 L
.07542 .21341 L
.06814 .201 L
.06248 .1894 L
.0534 .16547 L
.04697 .14174 L
.04478 .13127 L
.04302 .12124 L
.04191 .11349 L
.04108 .10622 L
.04078 .10295 L
.04053 .0996 L
.04028 .09427 L
.04024 .0916 L
.04026 .08893 L
.04034 .08662 L
.04047 .08466 L
.04082 .08145 L
.04108 .07981 L
.04136 .0784 L
.04204 .07585 L
.04248 .07458 L
.04293 .07351 L
.04388 .0717 L
.04487 .07025 L
.0461 .06888 L
.04755 .06766 L
.04894 .06677 L
.05036 .06606 L
.05205 .06541 L
.05402 .06484 L
.05511 .0646 L
.05618 .0644 L
Mistroke
.05829 .0641 L
.06074 .06388 L
.06221 .0638 L
.06362 .06374 L
.06611 .06371 L
.06904 .06374 L
.07232 .06385 L
.07562 .06401 L
.08412 .06461 L
.09311 .06541 L
.11844 .06799 L
.28946 .08476 L
.41161 .09641 L
.54037 .1116 L
.59505 .1207 L
.62057 .12624 L
.64058 .1317 L
.65553 .13689 L
.66652 .14182 L
.67571 .14742 L
.67926 .15031 L
.68235 .15353 L
.68457 .15664 L
.686 .15957 L
.68653 .16111 L
.68694 .16282 L
.68718 .16462 L
.68723 .16632 L
.68692 .16949 L
.68618 .17241 L
.68559 .17405 L
.6848 .17584 L
.68301 .17913 L
.67845 .18537 L
.67197 .19217 L
.65644 .2047 L
.63035 .22096 L
.59966 .23646 L
.56742 .25015 L
.52675 .2646 L
.48481 .27676 L
.4344 .28802 L
.40402 .29311 L
.37482 .29682 L
.36023 .29822 L
.35241 .29885 L
.34401 .29943 L
.32837 .30023 L
.31364 .30064 L
.29897 .30071 L
Mistroke
.28536 .30046 L
.26948 .29975 L
.25424 .29863 L
.24017 .29718 L
.22709 .29544 L
.19762 .2899 L
.18116 .28566 L
.16601 .28085 L
.13916 .26955 L
.12522 .26181 L
.11326 .25377 L
.10059 .24337 L
.08987 .23251 L
.08108 .22168 L
.07279 .20927 L
.06131 .1868 L
.05208 .16125 L
.04659 .1401 L
.04355 .12451 L
.04151 .11033 L
.04089 .10433 L
.04046 .09862 L
.04026 .09387 L
.04023 .09002 L
.04035 .08625 L
.04064 .08274 L
.04106 .07985 L
.04155 .07754 L
.04226 .07516 L
.04318 .07295 L
.0442 .07117 L
.04526 .06976 L
.04649 .0685 L
.04776 .0675 L
.04929 .06656 L
.0511 .06574 L
.05318 .06505 L
.05429 .06477 L
.05536 .06454 L
.05747 .06419 L
.05866 .06405 L
.05998 .06393 L
.06246 .06377 L
.06395 .06372 L
.0654 .0637 L
.06699 .0637 L
.06849 .06372 L
.0703 .06376 L
.07208 .06383 L
.07542 .06399 L
Mistroke
.07871 .0642 L
.08699 .06485 L
.13969 .07022 L
.33795 .08926 L
.46042 .10156 L
.52176 .109 L
.57821 .11756 L
.60382 .12245 L
.62779 .12804 L
.64605 .13341 L
.65952 .13849 L
.67044 .14392 L
.6752 .14699 L
.67892 .14994 L
.68156 .15253 L
.68378 .15531 L
.68557 .15842 L
.68665 .16132 L
.68721 .1643 L
.68722 .16759 L
.6867 .17075 L
.68577 .17371 L
.68443 .17668 L
.68288 .17941 L
.6783 .1856 L
.67172 .19244 L
.66284 .19997 L
.64241 .21395 L
.58805 .24165 L
.52167 .26622 L
.47917 .2782 L
.45369 .28413 L
.42819 .28917 L
.4032 .29324 L
.38955 .2951 L
.37472 .29683 L
.36198 .29807 L
.34765 .29919 L
.33438 .29997 L
.32173 .30046 L
.30545 .30073 L
.29612 .30069 L
.28739 .30052 L
.27124 .29986 L
.25387 .2986 L
.23671 .29676 L
.22054 .29441 L
.20609 .29175 L
.19063 .28822 L
.15626 .2772 L
Mistroke
.14001 .26998 L
.12333 .26064 L
.11023 .25148 L
.09753 .24049 L
.07843 .21798 L
.07089 .20603 L
.06388 .19252 L
.05342 .16559 L
.04725 .14303 L
.04364 .12508 L
.04228 .11633 L
.04128 .10827 L
.04071 .10224 L
.0405 .09915 L
.04035 .09647 L
.04026 .09356 L
.04023 .09103 L
.04033 .08677 L
.04046 .08465 L
.04063 .08283 L
.04087 .08099 L
.04118 .07921 L
.04177 .0767 L
.04243 .0747 L
.04331 .07268 L
.04429 .07104 L
.04529 .06972 L
.04632 .06866 L
.04756 .06764 L
.049 .06672 L
.05074 .06588 L
.05282 .06515 L
.05385 .06487 L
.05498 .06461 L
.05713 .06424 L
.05937 .06398 L
.06162 .06381 L
.06427 .06372 L
.06584 .0637 L
.06733 .0637 L
.07021 .06376 L
.0731 .06387 L
.07647 .06405 L
.08038 .06431 L
.09864 .06594 L
.14703 .07098 L
.36113 .09145 L
.4752 .10323 L
.56961 .11609 L
.60781 .12329 L
Mistroke
.64008 .13151 L
.65451 .13645 L
.66553 .14127 L
.67336 .14573 L
.67976 .1507 L
Mfstroke
.39924 .30051 m
.38484 .30217 L
.37149 .30348 L
.35579 .30471 L
.34065 .30558 L
.32643 .30611 L
.31311 .30633 L
.29832 .30625 L
.28245 .30578 L
.26638 .30485 L
.24899 .3033 L
.23254 .30125 L
.21753 .29884 L
.20015 .29529 L
.18152 .29045 L
.14916 .27869 L
.13306 .27068 L
.11893 .26197 L
.09575 .2427 L
.08479 .23034 L
.07607 .21819 L
.06748 .20338 L
.0609 .18933 L
.05266 .16656 L
.04666 .14392 L
.04303 .1253 L
.0418 .1172 L
.04082 .10931 L
.04015 .10226 L
.03992 .09882 L
.03977 .09582 L
.03966 .09102 L
.03968 .0886 L
.03975 .08654 L
.03988 .08444 L
.04004 .08264 L
.04026 .0808 L
.04055 .079 L
.04091 .07727 L
.04131 .07578 L
.04217 .07331 L
.0431 .07141 L
.04423 .0697 L
.04532 .06844 L
.04664 .06726 L
.04822 .0662 L
.0501 .06526 L
.05207 .06456 L
.05403 .06405 L
.05608 .06367 L
Mistroke
.05843 .06337 L
.06084 .06319 L
.06318 .06309 L
.0647 .06307 L
.06615 .06306 L
.0678 .06308 L
.06962 .06313 L
.07287 .06326 L
.0767 .06347 L
.08435 .06404 L
.09379 .06489 L
.11463 .06699 L
.27947 .08304 L
.41794 .09604 L
.49597 .10454 L
.5616 .11341 L
.60946 .122 L
.63141 .12714 L
.6483 .13204 L
.66258 .13731 L
.67459 .1433 L
.6793 .14642 L
.68337 .14981 L
.68635 .15308 L
.68836 .15609 L
.68967 .15896 L
.69047 .16204 L
.6907 .16471 L
.69048 .16768 L
.68974 .17092 L
.68909 .17276 L
.68837 .17445 L
.68447 .18094 L
.67936 .18706 L
.67227 .19387 L
.65557 .20657 L
.60684 .23372 L
.53218 .26321 L
.48621 .2767 L
.45968 .28309 L
.42989 .28911 L
.40216 .29362 L
.38689 .29566 L
.37012 .29752 L
.35427 .29892 L
.33953 .2999 L
.32443 .30057 L
.30991 .30089 L
.29504 .30086 L
.27885 .30041 L
Mistroke
.2634 .29954 L
.24917 .29834 L
.23249 .29638 L
.21432 .2935 L
.19731 .29 L
.18178 .286 L
.1647 .28054 L
.14921 .27441 L
.12243 .26021 L
.10895 .25062 L
.0977 .24079 L
.0868 .22909 L
.07673 .21561 L
.0643 .19352 L
.05583 .17286 L
.04891 .14996 L
.04484 .13181 L
.04223 .11609 L
.0413 .10862 L
.04072 .10254 L
.0404 .09783 L
.04023 .09321 L
.04023 .08897 L
.04038 .08548 L
.04067 .08233 L
.04112 .07939 L
.04167 .07697 L
.04228 .07503 L
.04311 .07303 L
.04416 .07118 L
.04529 .06968 L
.04645 .0685 L
.04778 .06745 L
.04914 .06661 L
.05076 .06584 L
.05268 .06516 L
.0537 .06488 L
.05487 .06461 L
.05595 .0644 L
.05714 .06421 L
.05954 .06394 L
.06195 .06377 L
.0646 .06369 L
.06721 .06368 L
.07029 .06374 L
.07193 .0638 L
.07379 .06388 L
.08089 .06433 L
.08845 .06495 L
.12827 .069 L
Mistroke
.29461 .0852 L
.42563 .0978 L
.49808 .10592 L
.55907 .11434 L
.61114 .12396 L
.63317 .12943 L
.65243 .13558 L
.66602 .14142 L
.6714 .14438 L
.67565 .14719 L
.67913 .14998 L
.68173 .15255 L
.68401 .15544 L
.68579 .15858 L
.68687 .16164 L
.68719 .1632 L
.68738 .16492 L
.6873 .168 L
.68677 .17092 L
.68623 .17271 L
.68559 .17441 L
.68402 .17764 L
.68182 .18116 L
.67886 .18503 L
.6642 .19895 L
.64518 .21227 L
.5915 .24017 L
.52381 .26556 L
.4773 .27867 L
.42941 .28895 L
.40225 .29338 L
.37092 .29723 L
.35449 .2987 L
.34528 .29936 L
.33648 .29987 L
.32819 .30024 L
.3191 .30054 L
.303 .30074 L
.28701 .30052 L
.27222 .29992 L
.25499 .29871 L
.23854 .29699 L
.22338 .29488 L
.20938 .29241 L
.17822 .28481 L
.16107 .27906 L
.14558 .27264 L
.11894 .25778 L
.10563 .24778 L
.09461 .23759 L
Mistroke
.08399 .2255 L
.07427 .21167 L
.0668 .19849 L
.06111 .18634 L
.05268 .16324 L
.04637 .13913 L
.04287 .12033 L
.04176 .11242 L
.04096 .10507 L
.04052 .09957 L
.04027 .09424 L
.04023 .09158 L
.04024 .08931 L
.04031 .08701 L
.04045 .08477 L
.04081 .08141 L
.04108 .07971 L
.04138 .07826 L
.04204 .07581 L
.04288 .07358 L
.04372 .07194 L
.04477 .07037 L
.04604 .06893 L
.04757 .06763 L
.04918 .06662 L
.0508 .06585 L
.05258 .06522 L
.05436 .06475 L
.05647 .06434 L
.0576 .06417 L
.05891 .06402 L
.06122 .06384 L
.0639 .06372 L
.06663 .0637 L
.06931 .06373 L
.07206 .06382 L
.07519 .06398 L
.08137 .06439 L
.09838 .06591 L
.14902 .07119 L
.35312 .09069 L
.49517 .1056 L
.55911 .11439 L
.59074 .11984 L
.61578 .12507 L
.63475 .12993 L
.65189 .13545 L
.66606 .14153 L
.67168 .14466 L
.67597 .14755 L
Mistroke
.67934 .15031 L
.68228 .15335 L
.6836 .15505 L
.68462 .15662 L
.68614 .15975 L
.68694 .16248 L
.68729 .16552 L
.6871 .16874 L
.68643 .17178 L
.68531 .17485 L
.6836 .17822 L
.67925 .18447 L
.67356 .19068 L
.66711 .19652 L
.64869 .20999 L
.62324 .22484 L
.56092 .25266 L
.52679 .2646 L
.48492 .27673 L
.43269 .28834 L
.40157 .29348 L
.38601 .29554 L
.37095 .29722 L
.35663 .29853 L
.34076 .29963 L
.32604 .30032 L
.31224 .30066 L
.29708 .3007 L
.28016 .30028 L
.27157 .29988 L
.26229 .29929 L
.24544 .29778 L
.22758 .29551 L
.21146 .2928 L
.19304 .28882 L
.17605 .28414 L
.14713 .27334 L
.13194 .26574 L
.11889 .25774 L
.09469 .23768 L
.08328 .22459 L
.07419 .21155 L
.06017 .18408 L
.05452 .16894 L
.05051 .15583 L
.04535 .13425 L
.04249 .11781 L
.04154 .11055 L
.04082 .10352 L
.04057 .10034 L
Mistroke
.04039 .09717 L
.04028 .0944 L
.04023 .09203 L
.04028 .0879 L
.04047 .08452 L
.04083 .08128 L
.04109 .07966 L
.04137 .07829 L
.04197 .07603 L
.04275 .07389 L
.0436 .07214 L
.04449 .07074 L
.04563 .06935 L
.04682 .06822 L
.04799 .06734 L
.04938 .06652 L
.05102 .06577 L
.05293 .06512 L
.0547 .06467 L
.0568 .06429 L
.05891 .06402 L
.06097 .06385 L
.0634 .06374 L
.06614 .0637 L
.0687 .06372 L
.07124 .06379 L
.07419 .06392 L
.07756 .06412 L
.086 .06476 L
.09667 .06575 L
.12087 .06824 L
.18796 .07513 L
.41746 .09699 L
.4896 .10493 L
.55935 .11443 L
.58839 .1194 L
.61255 .12434 L
.63291 .12942 L
.64838 .1342 L
.66147 .13934 L
.67116 .14435 L
.67878 .14981 L
.68195 .15297 L
.68419 .15592 L
.68562 .15852 L
.68656 .16097 L
.68714 .1637 L
.68728 .16667 L
.68691 .16982 L
.68608 .17284 L
Mistroke
.68497 .17559 L
.68337 .17861 L
.67868 .18515 L
.67162 .19253 L
.65179 .20794 L
.5996 .23649 L
.56608 .25068 L
.52541 .26504 L
.48565 .27654 L
.43829 .28728 L
.40917 .29234 L
.38127 .29611 L
.36732 .29758 L
.35187 .2989 L
.33696 .29984 L
.32295 .30042 L
.30634 .30072 L
.29055 .30059 L
.28141 .30033 L
.273 .29995 L
.26324 .29935 L
.25395 .29861 L
.23537 .29659 L
.21817 .29401 L
.19942 .29032 L
.17984 .28528 L
.14736 .27344 L
.13217 .26586 L
.11671 .25625 L
.10462 .24692 L
.09297 .23589 L
.07557 .21371 L
.06728 .19941 L
.06 .18368 L
.0549 .17007 L
.05065 .15632 L
.04515 .13325 L
.04342 .12373 L
.04223 .11595 L
.04141 .10944 L
.04078 .10313 L
.04039 .09729 L
.04024 .09245 L
.04026 .08849 L
.04045 .0848 L
.04076 .08175 L
.04116 .0793 L
.04146 .07792 L
.04181 .07656 L
.04254 .07439 L
Mistroke
.04348 .07237 L
.04467 .07049 L
.04585 .06912 L
.04726 .06787 L
.04873 .06687 L
.0502 .06611 L
.0518 .06548 L
.05341 .06498 L
.05532 .06454 L
.05754 .06418 L
.05993 .06393 L
.06121 .06384 L
.06266 .06376 L
.06539 .0637 L
.06812 .06371 L
.07108 .06379 L
.07407 .06392 L
.07692 .06408 L
.0802 .0643 L
.09688 .06577 L
.24295 .08042 L
.3697 .09227 L
.49985 .10618 L
.5581 .11423 L
.60967 .1237 L
.63307 .12946 L
.65116 .13519 L
.66405 .14054 L
.67465 .1466 L
.67973 .15068 L
.68185 .15286 L
.68369 .15519 L
.68498 .15725 L
.68606 .15955 L
.68674 .16166 L
.68713 .16364 L
.68729 .16575 L
.68721 .16776 L
.68696 .16958 L
.68648 .17157 L
.68575 .17376 L
.68472 .17611 L
.68227 .18037 L
.67882 .18498 L
.67421 .19003 L
.66362 .19936 L
.62975 .22131 L
Mfstroke
.39924 .39666 m
.37082 .3963 L
.3451 .39528 L
.3156 .39318 L
.28799 .39017 L
.26279 .38638 L
.23992 .38192 L
.21541 .37581 L
.19034 .3678 L
.16642 .35796 L
.14245 .34513 L
.12188 .33071 L
.10509 .31547 L
.08818 .29527 L
.07314 .2707 L
.06205 .24594 L
.05415 .22262 L
.04802 .19935 L
.04319 .17609 L
.04011 .15782 L
.03776 .14101 L
.03624 .128 L
.03507 .11589 L
.03436 .10669 L
.03393 .09927 L
.03376 .09534 L
.03365 .09147 L
.03361 .08557 L
.03367 .08266 L
.03379 .07987 L
.03413 .07553 L
.03458 .07218 L
.03512 .06951 L
.03582 .06701 L
.03672 .06476 L
.0377 .06295 L
.03888 .06134 L
.04013 .06008 L
.04139 .05912 L
.04301 .05819 L
.04394 .05777 L
.04497 .05739 L
.04591 .05709 L
.047 .0568 L
.04906 .05639 L
.05033 .05621 L
.05159 .05607 L
.05277 .05597 L
.05412 .05588 L
.05564 .05582 L
Mistroke
.05735 .05579 L
.05904 .05579 L
.06064 .05581 L
.06235 .05585 L
.06398 .05591 L
.0679 .0561 L
.07595 .05665 L
.19999 .06773 L
.31964 .07708 L
.47851 .08995 L
.55225 .09731 L
.6123 .10496 L
.65556 .11243 L
.67522 .11689 L
.69037 .12118 L
.70229 .12545 L
.71241 .1302 L
.71618 .13245 L
.71957 .13485 L
.72223 .13713 L
.72424 .13924 L
.72615 .1418 L
.72762 .14458 L
.72848 .1472 L
.72887 .1497 L
.72883 .15267 L
.72835 .15545 L
.72736 .15854 L
.72668 .16012 L
.7258 .16187 L
.72151 .1683 L
.71618 .17433 L
.69976 .1884 L
.65652 .21528 L
.59402 .24437 L
.51999 .27018 L
.47466 .28217 L
.4188 .2932 L
.38838 .29748 L
.37057 .29941 L
.35381 .30083 L
.33874 .30176 L
.32193 .30241 L
.31332 .30258 L
.30404 .30263 L
.28711 .30237 L
.27068 .30163 L
.26127 .30099 L
.25243 .30023 L
.23457 .2982 L
Mistroke
.2154 .2952 L
.19779 .29157 L
.18133 .2873 L
.15171 .27685 L
.13594 .26937 L
.12026 .26009 L
.09566 .24 L
.08318 .22575 L
.07329 .21134 L
.06595 .19801 L
.05936 .18328 L
.05113 .15918 L
.04561 .13674 L
.04254 .11954 L
.04163 .11298 L
.04091 .1066 L
.04059 .1031 L
.04036 .10008 L
.04009 .09471 L
.04003 .09043 L
.04014 .08646 L
.04026 .08461 L
.04043 .08276 L
.04085 .07976 L
.04115 .0782 L
.04152 .07669 L
.04231 .07429 L
.04315 .07241 L
.0442 .07066 L
.04533 .06924 L
.04648 .06812 L
.04772 .06717 L
.04898 .0664 L
.0504 .06572 L
.05209 .06509 L
.05407 .06455 L
.05611 .06415 L
.05808 .06387 L
.06039 .06366 L
.06178 .06358 L
.06309 .06352 L
.06467 .06349 L
.06621 .06348 L
.06912 .06352 L
.0725 .06364 L
.07566 .0638 L
.0788 .064 L
.08667 .06462 L
.10614 .0665 L
.15652 .07175 L
Mistroke
.35243 .09032 L
.48676 .1042 L
.54854 .11232 L
.60506 .12215 L
.62795 .12744 L
.64824 .13341 L
.66332 .1393 L
.66915 .14217 L
.67381 .1449 L
.67803 .14785 L
.68119 .15057 L
.68401 .15365 L
.68526 .15538 L
.68623 .15699 L
.68753 .15996 L
.68799 .16153 L
.6883 .16321 L
.68846 .16607 L
.68812 .16925 L
.68774 .17089 L
.68717 .17269 L
.68575 .176 L
.6839 .17926 L
.68179 .18231 L
.67567 .18935 L
.66724 .19699 L
.64717 .21134 L
.62383 .22478 L
.5634 .25187 L
.52447 .26546 L
.47789 .27862 L
.43235 .28849 L
.40891 .29247 L
.38578 .29565 L
.37224 .29717 L
.35721 .29855 L
.34326 .29955 L
.33015 .30023 L
.31574 .30067 L
.29961 .30078 L
.28251 .30043 L
.26632 .29962 L
.24968 .29827 L
.24035 .29727 L
.23189 .29619 L
.20007 .29052 L
.18255 .28611 L
.16413 .28023 L
.14882 .27414 L
.1329 .26632 L
Mistroke
.10688 .24887 L
.09461 .23763 L
.08451 .2262 L
.06974 .20404 L
.06323 .19115 L
.05829 .17944 L
.05074 .15668 L
.04611 .13795 L
.04291 .12064 L
.04186 .11322 L
.04104 .10599 L
.04057 .10044 L
.04032 .09592 L
.04022 .09153 L
.04029 .08747 L
.04048 .08434 L
.04076 .08175 L
.04117 .07922 L
.04172 .07684 L
.04243 .07466 L
.04335 .07259 L
.04447 .07075 L
.04567 .06929 L
.04692 .06812 L
.04817 .06721 L
.04975 .06632 L
.05139 .06562 L
.05332 .065 L
.05445 .06472 L
.05556 .06449 L
.05764 .06416 L
.05882 .06402 L
.06013 .0639 L
.06152 .06381 L
.0631 .06374 L
.06483 .0637 L
.06651 .06369 L
.06816 .0637 L
.06972 .06374 L
.07159 .0638 L
.07344 .06388 L
.07668 .06406 L
.0805 .06432 L
.08911 .06503 L
.10798 .06688 L
.17197 .07353 L
.27804 .08368 L
.41225 .09645 L
.5335 .11058 L
.59031 .11974 L
Mistroke
.63148 .129 L
.6477 .13394 L
.66188 .1395 L
.67219 .14494 L
.67609 .1476 L
.67918 .15012 L
.68169 .15262 L
.68357 .15494 L
.68519 .15754 L
.68641 .16037 L
.6871 .16313 L
.68733 .16617 L
.68708 .16908 L
.68645 .1718 L
.68538 .17475 L
.68378 .17796 L
.67975 .18388 L
.67318 .19107 L
.66559 .1978 L
.64572 .2119 L
.61853 .2273 L
.58674 .24223 L
.5532 .25554 L
.51444 .26846 L
.47442 .27938 L
.42224 .29022 L
.39236 .29474 L
.37648 .29665 L
.35895 .29834 L
.34321 .29948 L
.32853 .30023 L
.31351 .30065 L
.29902 .30072 L
.28196 .30035 L
.26597 .29954 L
.25669 .29885 L
.24827 .29807 L
.22936 .29577 L
.21326 .29314 L
.19837 .29008 L
.18095 .2856 L
.16548 .28066 L
.13568 .26776 L
.1207 .25895 L
.10768 .24947 L
.09748 .24044 L
.08774 .23007 L
.07312 .20982 L
.06134 .18685 L
.05235 .16216 L
Mistroke
.04626 .1386 L
.04293 .12072 L
.04176 .11242 L
.0413 .10846 L
.04091 .10455 L
.04062 .10107 L
.04044 .09814 L
.04025 .09298 L
.04026 .08855 L
.04043 .08498 L
.04079 .08157 L
.04103 .08003 L
.04133 .07846 L
.04195 .0761 L
.04274 .0739 L
.04362 .07211 L
.04453 .07068 L
.04559 .06939 L
.04669 .06833 L
.04801 .06733 L
.04957 .06642 L
.05127 .06567 L
.05323 .06503 L
.05505 .0646 L
.05719 .06423 L
.05937 .06398 L
.0615 .06382 L
.06413 .06372 L
.0668 .0637 L
.06944 .06374 L
.07203 .06382 L
.07505 .06397 L
.07846 .06418 L
.09605 .06569 L
.11758 .06789 L
.19143 .07547 L
.41049 .09628 L
.47966 .10375 L
.54722 .11258 L
.6004 .12174 L
.63755 .13075 L
.65431 .13637 L
.66647 .14174 L
.6764 .14787 L
.68011 .15104 L
.68326 .15459 L
.68438 .15622 L
.68526 .15777 L
.68648 .16072 L
.68717 .16394 L
Mistroke
.68729 .16579 L
.68724 .1675 L
.68679 .17039 L
.68581 .17361 L
.68426 .17702 L
.68233 .18027 L
.67722 .18684 L
.67011 .19391 L
.65334 .20688 L
.6274 .2226 L
.59845 .23702 L
.52847 .26406 L
.48183 .27753 L
.45842 .2831 L
.43222 .28843 L
.40854 .29244 L
.38124 .29611 L
.36886 .29743 L
.3553 .29863 L
.34225 .29954 L
.33013 .30016 L
.31474 .30062 L
.30025 .30072 L
.28411 .30042 L
.26674 .29959 L
.25 .29824 L
.2342 .29644 L
.22001 .29432 L
.20479 .29148 L
.17378 .28343 L
.1571 .27754 L
.14256 .27122 L
.12968 .26446 L
.11659 .25617 L
.09558 .23857 L
.08552 .22741 L
.07593 .21426 L
.06805 .20089 L
.06109 .18628 L
.052 .16097 L
.04652 .13979 L
.04286 .12024 L
.0416 .1111 L
.04116 .10719 L
.04084 .10376 L
.0406 .10072 L
.04041 .09765 L
.04024 .09283 L
.04023 .09037 L
.04028 .08796 L
Mistroke
.04036 .08605 L
.04051 .0841 L
.0409 .0808 L
.04139 .07818 L
.04172 .07688 L
.04212 .07557 L
.04295 .07344 L
.04385 .07172 L
.04494 .07015 L
.04598 .06898 L
.04724 .06788 L
.04862 .06694 L
.05002 .0662 L
.05168 .06552 L
.05362 .06493 L
.05466 .06468 L
.05585 .06445 L
.05813 .06411 L
.06054 .06388 L
.06293 .06375 L
.06533 .0637 L
.06771 .06371 L
.07049 .06377 L
.07369 .0639 L
.07728 .0641 L
.08093 .06436 L
.08849 .06498 L
.22097 .07834 L
.34207 .08964 L
.47444 .10315 L
.52877 .10994 L
.57915 .11772 L
.60188 .12204 L
.62365 .12697 L
.64041 .13161 L
.65373 .13615 L
.66606 .14154 L
.67468 .14662 L
.67846 .14953 L
.68132 .15227 L
.68379 .15533 L
.68486 .15704 L
.68567 .15862 L
.68664 .16128 L
.6872 .16419 L
.68728 .16678 L
.68696 .16954 L
.68616 .17262 L
.685 .17552 L
.68329 .17873 L
Mistroke
.68099 .18221 L
.67487 .18936 L
.66619 .19729 L
.64546 .21205 L
.59104 .24035 L
Mfstroke
.39924 .49282 m
.35699 .48905 L
.31946 .48405 L
.27738 .47612 L
.23914 .46612 L
.2055 .45429 L
.17633 .44082 L
.1469 .42279 L
.11931 .39955 L
.09592 .37169 L
.07589 .33701 L
.06167 .30104 L
.05212 .26721 L
.04429 .22917 L
.03868 .19227 L
.0332 .14138 L
.03171 .12215 L
.03086 .10801 L
.03042 .0979 L
.03021 .08911 L
.03018 .08525 L
.03021 .08149 L
.0303 .07802 L
.03044 .07514 L
.03079 .07075 L
.0313 .0669 L
.03191 .06395 L
.0323 .06251 L
.03269 .06131 L
.03349 .05938 L
.03444 .05767 L
.0354 .05639 L
.03637 .05537 L
.03755 .05442 L
.03893 .05357 L
.0405 .05286 L
.04142 .05253 L
.04234 .05226 L
.04424 .05183 L
.04612 .05154 L
.04728 .05141 L
.04856 .0513 L
.05101 .05118 L
.05246 .05115 L
.05388 .05114 L
.05552 .05116 L
.05736 .0512 L
.05919 .05126 L
.06098 .05134 L
.06532 .05158 L
Mistroke
.07441 .05225 L
.09649 .05416 L
.27372 .06782 L
.43561 .07893 L
.51875 .08542 L
.58831 .09201 L
.642 .09857 L
.68651 .10607 L
.70463 .11021 L
.71856 .11421 L
.73076 .11878 L
.73582 .12118 L
.74053 .12387 L
.74406 .12636 L
.74713 .12909 L
.74851 .13061 L
.74959 .13203 L
.75121 .13484 L
.75211 .13731 L
.75258 .14006 L
.75255 .14297 L
.75206 .14573 L
.75159 .14734 L
.75093 .14909 L
.74934 .15231 L
.74514 .15849 L
.73834 .16594 L
.73045 .17302 L
.69115 .19985 L
.63238 .23007 L
.56294 .25778 L
.51766 .27213 L
.46965 .28439 L
.42033 .29387 L
.39039 .29809 L
.37556 .29974 L
.36133 .30105 L
.34926 .30193 L
.33603 .30266 L
.3211 .30318 L
.30718 .30336 L
.29331 .30323 L
.27796 .30272 L
.26178 .30171 L
.24662 .30032 L
.22929 .29812 L
.211 .29501 L
.19554 .29166 L
.17882 .28717 L
.16139 .28131 L
Mistroke
.14348 .27372 L
.11416 .25638 L
.10179 .24635 L
.08979 .23425 L
.08053 .22271 L
.07205 .20975 L
.05966 .1845 L
.05177 .16181 L
.04627 .14032 L
.04427 .13039 L
.04268 .121 L
.04164 .11367 L
.04083 .10656 L
.04034 .10086 L
.04007 .09614 L
.03996 .09176 L
.04 .08809 L
.04014 .08514 L
.0404 .08229 L
.0408 .07954 L
.04135 .07698 L
.04192 .07507 L
.04266 .0732 L
.04355 .07148 L
.04449 .07008 L
.04563 .06876 L
.047 .06755 L
.04859 .06649 L
.05026 .06566 L
.05188 .06505 L
.0538 .06451 L
.05559 .06414 L
.05771 .06382 L
.06011 .06359 L
.06252 .06346 L
.06493 .0634 L
.06728 .0634 L
.07017 .06347 L
.07309 .06358 L
.07678 .06379 L
.08036 .06403 L
.08931 .06478 L
.10909 .06673 L
.17727 .07376 L
.27922 .08343 L
.42086 .09686 L
.54107 .11106 L
.59673 .12026 L
.63678 .12959 L
.6522 .1345 L
Mistroke
.66565 .14004 L
.67071 .14265 L
.67535 .14547 L
.67876 .14794 L
.68185 .15064 L
.68428 .15329 L
.68603 .15575 L
.68736 .15826 L
.68824 .16067 L
.6888 .1635 L
.6889 .16616 L
.68856 .16912 L
.6877 .17231 L
.68705 .174 L
.68622 .1758 L
.68439 .17904 L
.67864 .18652 L
.672 .19312 L
.66305 .20052 L
.61822 .22779 L
.58549 .24301 L
.54934 .25713 L
.51205 .26933 L
.46761 .28114 L
.44268 .28654 L
.41354 .29177 L
.38555 .2957 L
.37254 .29716 L
.358 .29852 L
.34174 .29967 L
.33271 .30014 L
.32422 .30047 L
.30878 .3008 L
.29202 .30071 L
.28245 .30045 L
.272 .29999 L
.26208 .29935 L
.25289 .2986 L
.23542 .29668 L
.21693 .29388 L
.20091 .29072 L
.18369 .28645 L
.16886 .2819 L
.15357 .27619 L
.13908 .26958 L
.12665 .26275 L
.10472 .24708 L
.09319 .23618 L
.0838 .22532 L
.07502 .21293 L
Mistroke
.06693 .19879 L
.05654 .17481 L
.04923 .15113 L
.04483 .13164 L
.04235 .11688 L
.04145 .10992 L
.04079 .10324 L
.0404 .09772 L
.04024 .09322 L
.04023 .08955 L
.04033 .08646 L
.04056 .08344 L
.04092 .08057 L
.04141 .07806 L
.04204 .07576 L
.04268 .07402 L
.04348 .07235 L
.04454 .07066 L
.04564 .06932 L
.04698 .06806 L
.04857 .06695 L
.05009 .06615 L
.05164 .06552 L
.05348 .06495 L
.05457 .06469 L
.05562 .06447 L
.05768 .06415 L
.06011 .0639 L
.06241 .06376 L
.06503 .06369 L
.06753 .06369 L
.07003 .06374 L
.07294 .06385 L
.0763 .06403 L
.08411 .06459 L
.09402 .06548 L
.11918 .06805 L
.18688 .07501 L
.30169 .08587 L
.43981 .0993 L
.4998 .10615 L
.55731 .11409 L
.5837 .11851 L
.60937 .1236 L
.64536 .13315 L
.65986 .13859 L
.6706 .14396 L
.67784 .14894 L
.68098 .15183 L
.6833 .15455 L
Mistroke
.68437 .1561 L
.68534 .15779 L
.68659 .1609 L
.68723 .16397 L
.68733 .16683 L
.68693 .16997 L
.68648 .17178 L
.68591 .17347 L
.68435 .17694 L
.68209 .1807 L
.67694 .18719 L
.66958 .19442 L
.65188 .2079 L
.60515 .23391 L
.53852 .26072 L
.49234 .27478 L
.44325 .28631 L
.41592 .29128 L
.38552 .29561 L
.37249 .29707 L
.35826 .2984 L
.3423 .29954 L
.32715 .30028 L
.31788 .30056 L
.30925 .3007 L
.29969 .30072 L
.28947 .30057 L
.27212 .29991 L
.26218 .29928 L
.25284 .29851 L
.23539 .29659 L
.21945 .29423 L
.20117 .29071 L
.18409 .28649 L
.16815 .28159 L
.15154 .27527 L
.13756 .26874 L
.12367 .26086 L
.11198 .25282 L
.10024 .24305 L
.08259 .2237 L
.07371 .21078 L
.06686 .19861 L
.0607 .18537 L
.0553 .17124 L
.0484 .14784 L
.04431 .12885 L
.04202 .11443 L
.04119 .10748 L
.04067 .10172 L
Mistroke
.04035 .09639 L
.04023 .09209 L
.04029 .08773 L
.0405 .08413 L
.04081 .08143 L
.04124 .07888 L
.04176 .07675 L
.0423 .07503 L
.04305 .07322 L
.04397 .07152 L
.04495 .07013 L
.04596 .069 L
.04725 .06787 L
.04861 .06695 L
.04993 .06624 L
.05148 .06559 L
.05331 .06501 L
.05543 .06452 L
.05738 .0642 L
.05971 .06395 L
.06202 .06379 L
.0643 .06372 L
.06696 .0637 L
.06997 .06375 L
.07278 .06386 L
.07555 .064 L
.08247 .06447 L
.1019 .06627 L
.125 .06867 L
.2021 .07652 L
.31314 .08694 L
.45741 .10123 L
.51499 .1081 L
.57 .11616 L
.59716 .12109 L
.61884 .1258 L
.63787 .13084 L
.65225 .13559 L
.66423 .14063 L
.66932 .14328 L
.67406 .14619 L
.67776 .14895 L
.6806 .15152 L
.68281 .154 L
.68467 .15669 L
.68611 .15965 L
.68693 .16246 L
.6872 .16419 L
.68729 .16584 L
.68706 .16897 L
Mistroke
.68626 .17232 L
.68503 .17546 L
.68317 .17894 L
.68063 .1827 L
.66867 .19519 L
.65274 .2073 L
.60131 .2357 L
.52985 .26361 L
.48624 .27639 L
.45883 .28301 L
.43236 .28841 L
.40823 .29249 L
.38082 .29616 L
.36519 .29778 L
.35045 .299 L
.33607 .29988 L
.32056 .30049 L
.30705 .30072 L
.29234 .30063 L
.27828 .3002 L
.26533 .2995 L
.25007 .29825 L
.23339 .29633 L
.21764 .29392 L
.20314 .29113 L
.1862 .28706 L
.16876 .28179 L
.13925 .26959 L
.12412 .26114 L
.1111 .25215 L
.09738 .24035 L
.08601 .22801 L
.07747 .21658 L
.06953 .20362 L
.05873 .18053 L
.05025 .15489 L
.04534 .13422 L
.04263 .11876 L
.04176 .11238 L
.04114 .1069 L
.04063 .10114 L
.04035 .09647 L
.04023 .09201 L
.04029 .08775 L
.04051 .0841 L
.04084 .0812 L
.04137 .07828 L
.04201 .0759 L
.04272 .07397 L
.04346 .0724 L
Mistroke
.04438 .07089 L
.04548 .06951 L
.04668 .06833 L
.04813 .06725 L
.04964 .06638 L
.05116 .06571 L
.05263 .06521 L
.05437 .06475 L
.05633 .06436 L
.05832 .06409 L
.06066 .06387 L
.06333 .06374 L
.06577 .0637 L
.06863 .06372 L
.07196 .06382 L
.07393 .06391 L
.0758 .06401 L
.08353 .06456 L
.12376 .06854 L
.18462 .0748 L
.39614 .09485 L
.46485 .10206 L
.53389 .11065 L
.58944 .11959 L
.62944 .12847 L
.64658 .13359 L
.65958 .13851 L
.67077 .14412 L
.67568 .14733 L
.67933 .15031 L
.68198 .15301 L
.68418 .1559 L
.68508 .15744 L
.68589 .15913 L
.68686 .16215 L
.68727 .16504 L
.68717 .16818 L
.68659 .17118 L
.68568 .17395 L
.68409 .17734 L
.68185 .18099 L
.67648 .18766 L
.66889 .195 L
.65849 .20325 L
.60758 .23274 L
.57831 .24578 L
Mfstroke
.4954 .10819 m
.55059 .11603 L
.59416 .12394 L
.6316 .13331 L
.64763 .13887 L
.65921 .14411 L
.66405 .14686 L
.66843 .14982 L
.6716 .15242 L
.6744 .15526 L
.67673 .15835 L
.67831 .1613 L
.67899 .16311 L
.67944 .16486 L
.6797 .16643 L
.67981 .16817 L
.67959 .17137 L
.67892 .17431 L
.67837 .17596 L
.67763 .17776 L
.67592 .18104 L
.67132 .1875 L
.66567 .19355 L
.64819 .20768 L
.62653 .22121 L
.59456 .23747 L
.55968 .25212 L
.52025 .26586 L
.47118 .2795 L
.44143 .28607 L
.41208 .29134 L
.38238 .29546 L
.36679 .29714 L
.34912 .29862 L
.33419 .29951 L
.32003 .30005 L
.30422 .30029 L
.29526 .30024 L
.28706 .30008 L
.27031 .29939 L
.26079 .29876 L
.25197 .29802 L
.23573 .29624 L
.21853 .29369 L
.20401 .29093 L
.1886 .28732 L
.1616 .2789 L
.14592 .27244 L
.13179 .26532 L
.10782 .24926 L
Mistroke
.09591 .23859 L
.08631 .22807 L
.07727 .21599 L
.06898 .20234 L
.0577 .17758 L
.05048 .15546 L
.04508 .13261 L
.04331 .1228 L
.04193 .11336 L
.04112 .10632 L
.04081 .10283 L
.04058 .09975 L
.04032 .09438 L
.04028 .0901 L
.04039 .0865 L
.04065 .0831 L
.04104 .08028 L
.04149 .078 L
.04211 .07577 L
.04292 .07366 L
.0439 .07175 L
.04495 .07024 L
.04621 .06885 L
.04754 .06774 L
.04884 .06689 L
.05038 .06611 L
.05222 .0654 L
.05435 .06481 L
.05632 .06442 L
.05751 .06424 L
.05867 .0641 L
.06084 .06392 L
.06338 .06379 L
.06596 .06375 L
.06851 .06377 L
.07093 .06383 L
.07378 .06395 L
.07694 .06413 L
.0801 .06434 L
.09614 .06574 L
.11857 .06804 L
.28398 .0843 L
.42077 .09741 L
.49753 .10599 L
.56226 .115 L
.6125 .12446 L
.63501 .13017 L
.65196 .13566 L
.66344 .14047 L
.67327 .14594 L
Mistroke
.67715 .14876 L
.68057 .15185 L
.68309 .15482 L
.68484 .15758 L
.68607 .16041 L
.68682 .16347 L
.68702 .16641 L
.68678 .1691 L
.68601 .17232 L
.68536 .17415 L
.68462 .17584 L
.68067 .18236 L
.67583 .18816 L
.66912 .19464 L
.65146 .20806 L
.59703 .23762 L
.52874 .26394 L
.48313 .27717 L
.45672 .28345 L
.42685 .28939 L
.39925 .29378 L
.38401 .29577 L
.36713 .29758 L
.3513 .29892 L
.33647 .29985 L
.32202 .30043 L
.30655 .3007 L
.29054 .30058 L
.28141 .30031 L
.27295 .29994 L
.25728 .29888 L
.24061 .29722 L
.22567 .29521 L
.21173 .29284 L
.18055 .28547 L
.16386 .28007 L
.1486 .27398 L
.12211 .25985 L
.10882 .25037 L
.09765 .2406 L
.08681 .22897 L
.07672 .21546 L
.06339 .19144 L
.05453 .16895 L
.04862 .14869 L
.04497 .13233 L
.04243 .11734 L
.04149 .1101 L
.04087 .10412 L
.04046 .09853 L
Mistroke
.04027 .09403 L
.04024 .08948 L
.04039 .08572 L
.04066 .08262 L
.04109 .0797 L
.04161 .07729 L
.0422 .07534 L
.04299 .07334 L
.04401 .07146 L
.0451 .06995 L
.04624 .06873 L
.04766 .06757 L
.04914 .06665 L
.05058 .06595 L
.05228 .06532 L
.0543 .06476 L
.05538 .06453 L
.05663 .06432 L
.05897 .06402 L
.06134 .06383 L
.06371 .06373 L
.06647 .0637 L
.06927 .06374 L
.07203 .06383 L
.07467 .06395 L
.07775 .06413 L
.08459 .06464 L
.12614 .06879 L
.31829 .08742 L
.44236 .09959 L
.50681 .10705 L
.56799 .11583 L
.59461 .12059 L
.61666 .12529 L
.63511 .13005 L
.64949 .1346 L
.66062 .13897 L
.67046 .14394 L
.67793 .1491 L
.68104 .15199 L
.68336 .15474 L
.68518 .15765 L
.68596 .15932 L
.68652 .16088 L
.68714 .16376 L
.68726 .16688 L
.68686 .17 L
.68603 .17296 L
.68493 .17566 L
.68336 .1786 L
Mistroke
.67836 .18553 L
.67109 .19301 L
.65347 .2068 L
.60441 .23425 L
.5695 .24933 L
.5313 .26313 L
.49111 .2751 L
.44214 .28652 L
.41874 .29081 L
.39268 .2947 L
.36946 .29737 L
.35585 .29859 L
.34283 .2995 L
.32816 .30024 L
.3122 .30066 L
.29689 .30069 L
.28281 .30038 L
.26604 .29954 L
.25652 .29883 L
.24772 .29802 L
.23151 .29607 L
.2144 .29335 L
.19813 .29002 L
.18095 .2856 L
.15119 .27512 L
.13423 .26699 L
.11926 .258 L
.10701 .24892 L
.0948 .23778 L
.07798 .21733 L
.07048 .20531 L
.06447 .19376 L
.05601 .17327 L
.04961 .15251 L
.04498 .1324 L
.04328 .12293 L
.04211 .11508 L
.04131 .10859 L
.0408 .10331 L
.04043 .09808 L
.04025 .09316 L
.04025 .08905 L
.04039 .08566 L
.04068 .08238 L
.04116 .07931 L
.04145 .07794 L
.04181 .07656 L
.04258 .0743 L
.04346 .07241 L
.04439 .07088 L
Mistroke
.04546 .06953 L
.04657 .06843 L
.04893 .06676 L
.05043 .06601 L
.05192 .06544 L
.05368 .06491 L
.0557 .06447 L
.05793 .06413 L
.06013 .06391 L
.06141 .06383 L
.06286 .06376 L
.06566 .0637 L
.06848 .06372 L
.07168 .06381 L
.07462 .06395 L
.07807 .06415 L
.08669 .06482 L
.09754 .06583 L
.12209 .06837 L
.2926 .08504 L
.43082 .09837 L
.50698 .10707 L
.57028 .1162 L
.61884 .1258 L
.64031 .13158 L
.65628 .13714 L
.66697 .142 L
.67595 .14753 L
.67942 .15039 L
.68241 .15351 L
.68455 .15651 L
.68596 .15929 L
.68686 .16216 L
.68728 .16525 L
.68716 .16821 L
.68666 .17093 L
.68559 .17417 L
.68476 .17602 L
.68387 .17773 L
.67939 .18429 L
.67411 .19013 L
.66695 .19665 L
.64847 .21013 L
.59232 .23978 L
.52249 .26597 L
.47595 .279 L
.44905 .28511 L
.41867 .29082 L
.39059 .29497 L
.37511 .29679 L
Mistroke
.358 .29841 L
.34195 .29956 L
.32694 .30029 L
.31157 .30067 L
.29673 .30069 L
.28052 .30029 L
.2713 .29986 L
.26276 .29932 L
.24699 .29794 L
.23027 .2959 L
.21531 .29351 L
.20143 .29076 L
.1706 .28241 L
.15421 .27638 L
.13938 .26966 L
.11397 .25429 L
.10142 .24412 L
.09099 .23376 L
.08101 .22159 L
.07184 .20767 L
.06085 .18573 L
.05341 .16555 L
.0474 .14368 L
.04389 .12652 L
.04178 .11257 L
.04103 .10588 L
.04058 .10037 L
.04031 .09524 L
.04023 .09112 L
.04032 .08694 L
.04056 .08351 L
.04092 .08066 L
.04144 .07799 L
.04205 .07578 L
.0427 .074 L
.04359 .07217 L
.04469 .07047 L
.04587 .06909 L
.04709 .068 L
.04861 .06695 L
.05018 .06613 L
.05171 .06551 L
.05351 .06496 L
.05564 .06448 L
.05678 .06429 L
.05809 .06411 L
.06056 .06388 L
.06305 .06375 L
.06554 .0637 L
.06845 .06372 L
Mistroke
.07139 .0638 L
.07429 .06393 L
.08029 .06431 L
.08746 .06489 L
.13092 .0693 L
.31312 .08694 L
.42924 .09821 L
.4907 .10506 L
.5506 .11308 L
.60108 .12188 L
.63748 .13073 L
.65398 .13624 L
.66629 .14165 L
.67476 .14668 L
.67851 .14958 L
.68135 .1523 L
.68365 .15512 L
.68547 .1582 L
.68661 .16115 L
.68716 .16388 L
.68726 .16713 L
.68706 .16898 L
.68671 .17071 L
.68569 .17392 L
.6849 .17573 L
.68406 .17738 L
.67928 .18442 L
.67196 .19221 L
.65354 .20675 L
.60423 .23434 L
.56793 .24995 L
.5287 .26398 L
.48223 .27742 L
.4327 .28834 L
.40292 .29328 L
.38655 .29548 L
.36867 .29745 L
.35325 .29879 L
.34493 .29937 L
.33586 .29989 L
.3197 .30051 L
.30429 .30073 L
.29543 .30068 L
.28703 .30051 L
.27116 .29985 L
.25392 .29861 L
.24416 .29764 L
.23517 .29656 L
.2037 .29125 L
.18809 .28756 L
Mistroke
.17132 .28264 L
.13802 .26897 L
.12104 .25917 L
.10694 .24887 L
.09515 .23814 L
.08389 .22537 L
.07484 .21257 L
.06763 .20008 L
.05698 .17595 L
.04921 .15101 L
.04455 .13014 L
.04284 .12016 L
.04172 .11211 L
.04107 .10629 L
.0406 .10075 L
.04031 .0954 L
.04023 .09103 L
.04025 .08889 L
.04033 .08674 L
.04059 .08322 L
.04099 .08024 L
.04148 .07783 L
.04214 .07549 L
.04289 .07356 L
.04367 .07203 L
.04461 .07057 L
.04576 .06921 L
.04713 .06797 L
.04855 .06698 L
.04997 .06622 L
.05153 .06557 L
.05308 .06508 L
.0549 .06463 L
.05699 .06426 L
.05894 .06402 L
.06087 .06386 L
.06314 .06375 L
.06573 .0637 L
.06728 .0637 L
.06898 .06373 L
.07222 .06383 L
.07413 .06392 L
.07598 .06402 L
.08048 .06432 L
.09933 .06601 L
.15259 .07156 L
.16876 .07321 L
Mfstroke
.4954 .20435 m
.49518 .2072 L
.4946 .20981 L
.49348 .21283 L
.49199 .21569 L
.4883 .22078 L
.48282 .2263 L
.47502 .23232 L
.4648 .23861 L
.44151 .24944 L
.41102 .25964 L
.37667 .26774 L
.35457 .27151 L
.33287 .27422 L
.32032 .27537 L
.31353 .27586 L
.30618 .2763 L
.29901 .27662 L
.29243 .27683 L
.27934 .277 L
.26604 .27681 L
.25838 .27654 L
.25117 .27617 L
.24351 .27564 L
.23648 .27505 L
.22057 .27325 L
.20699 .27119 L
.19225 .26834 L
.16594 .26136 L
.15183 .25637 L
.13688 .24987 L
.12315 .2425 L
.10946 .23339 L
.09791 .22386 L
.08843 .21433 L
.07304 .19392 L
.06229 .17384 L
.0551 .15564 L
.04967 .1374 L
.04602 .12073 L
.04483 .11352 L
.04392 .10659 L
.04362 .1037 L
.04338 .10083 L
.04311 .09614 L
.04305 .09215 L
.04314 .08883 L
.04339 .0856 L
.0436 .08396 L
.04383 .08256 L
Mistroke
.04441 .08003 L
.04507 .07794 L
.04578 .07628 L
.04665 .0747 L
.04773 .07319 L
.04902 .07182 L
.05024 .07082 L
.05171 .06987 L
.05322 .06912 L
.05471 .06855 L
.05657 .068 L
.05847 .06758 L
.06035 .06728 L
.0622 .06706 L
.06437 .0669 L
.06683 .06679 L
.06969 .06676 L
.07249 .0668 L
.07578 .06692 L
.07753 .06701 L
.07951 .06712 L
.08708 .06767 L
.09508 .06839 L
.14907 .07419 L
.32923 .09258 L
.45761 .1065 L
.52374 .11538 L
.57659 .12451 L
.61974 .13498 L
.63705 .14089 L
.64445 .14402 L
.65139 .14751 L
.6567 .15074 L
.66081 .15379 L
.66398 .15669 L
.66673 .15995 L
.66855 .16291 L
.66974 .16573 L
.67045 .16874 L
.67063 .17204 L
.67024 .17528 L
.6694 .17833 L
.66797 .18172 L
.66587 .18539 L
.65986 .19303 L
.6525 .20013 L
.63361 .21414 L
.61052 .22763 L
.54757 .25536 L
.50816 .26853 L
Mistroke
.45862 .28158 L
.41119 .29075 L
.38242 .29478 L
.36824 .29634 L
.35479 .29755 L
.34199 .29846 L
.3281 .29917 L
.3124 .29962 L
.29793 .29969 L
.28403 .29943 L
.26884 .29875 L
.25438 .2977 L
.24101 .29635 L
.22425 .2941 L
.20844 .29133 L
.17934 .28428 L
.16358 .27915 L
.14952 .27358 L
.13389 .26602 L
.12017 .25783 L
.09993 .24203 L
.09055 .23256 L
.08155 .22163 L
.06678 .1978 L
.05706 .17552 L
.04969 .1522 L
.04528 .13324 L
.04236 .11606 L
.04137 .10808 L
.04078 .10175 L
.04058 .09883 L
.04044 .09595 L
.04034 .0913 L
.04036 .08897 L
.04043 .08695 L
.04055 .08489 L
.04075 .08285 L
.04096 .08123 L
.04123 .07959 L
.04184 .07694 L
.04257 .0747 L
.04337 .07289 L
.04437 .07118 L
.04558 .06964 L
.04672 .06851 L
.04811 .06745 L
.04976 .0665 L
.05171 .06567 L
.05374 .06504 L
.05576 .0646 L
Mistroke
.05796 .06426 L
.06015 .06404 L
.06273 .06389 L
.06412 .06384 L
.0657 .06382 L
.06851 .06384 L
.07176 .06393 L
.07505 .06408 L
.07827 .06428 L
.09367 .06556 L
.11547 .06778 L
.17301 .07376 L
.28155 .08416 L
.41723 .09715 L
.53847 .11154 L
.59434 .12082 L
.61501 .12522 L
.63413 .13012 L
.64986 .13514 L
.66158 .13988 L
.67093 .1448 L
.67766 .1496 L
.68059 .15237 L
.68303 .15537 L
.68461 .15796 L
.68582 .16086 L
.68652 .16402 L
.68665 .16581 L
.68661 .16747 L
.68616 .17056 L
.68515 .17386 L
.68367 .17713 L
.68192 .18013 L
.67664 .187 L
.66278 .19973 L
.64022 .21509 L
.61316 .22988 L
.54683 .25775 L
.50595 .2709 L
.45493 .28381 L
.40625 .29274 L
.39134 .29483 L
.3768 .29657 L
.3633 .29792 L
.3486 .29909 L
.33427 .29993 L
.32106 .30044 L
.30758 .30068 L
.29472 .30063 L
.27949 .30022 L
Mistroke
.26534 .29946 L
.2497 .29818 L
.23314 .29626 L
.21682 .29375 L
.19922 .29024 L
.18393 .28641 L
.16807 .28153 L
.15426 .27637 L
.13966 .26977 L
.116 .25572 L
.10321 .24568 L
.09267 .23554 L
.08264 .22373 L
.07326 .21002 L
.06095 .18594 L
.0559 .17294 L
.0521 .1613 L
.04665 .14035 L
.0434 .1236 L
.04161 .11116 L
.04097 .10516 L
.04057 .10022 L
.04032 .09548 L
.04023 .09154 L
.04029 .08771 L
.04051 .0841 L
.0409 .08082 L
.04141 .07812 L
.04198 .076 L
.04272 .07397 L
.04358 .0722 L
.04447 .07078 L
.04557 .06942 L
.04685 .0682 L
.04808 .06728 L
.04933 .06655 L
.05081 .06586 L
.05252 .06525 L
.05455 .06471 L
.05578 .06446 L
.05696 .06427 L
.05927 .06399 L
.06051 .06389 L
.06192 .0638 L
.06452 .06372 L
.06752 .06371 L
.07057 .06378 L
.07356 .0639 L
.07719 .0641 L
.08135 .06439 L
Mistroke
.0897 .06509 L
.11338 .06745 L
.17895 .07424 L
.40962 .0962 L
.48397 .10427 L
.5551 .11378 L
.60508 .12272 L
.62812 .12814 L
.64601 .13341 L
.65983 .13864 L
.66589 .14147 L
.67144 .14454 L
.67554 .14726 L
.67931 .15032 L
.6821 .15318 L
.68411 .15584 L
.68559 .1585 L
.68664 .16135 L
.68718 .16424 L
.68722 .16746 L
.68679 .17028 L
.68589 .17334 L
.68463 .17626 L
.68315 .17894 L
.67792 .18603 L
.67141 .19272 L
.65129 .20827 L
.62785 .22235 L
.59761 .2374 L
.52836 .26409 L
.48125 .27767 L
.45675 .28346 L
.43276 .28833 L
.40719 .29264 L
.38293 .29591 L
.36956 .29736 L
.35479 .29867 L
.33884 .29974 L
.32353 .3004 L
.3098 .30069 L
.29453 .30066 L
.27837 .30021 L
.26315 .29935 L
.24877 .29812 L
.23565 .29662 L
.2205 .2944 L
.20625 .29178 L
.1912 .28836 L
.1753 .28391 L
.14779 .27363 L
Mistroke
.13213 .26584 L
.11824 .2573 L
.09533 .23832 L
.08548 .22736 L
.07634 .21489 L
.06331 .19129 L
.0573 .17679 L
.05279 .16357 L
.0468 .14104 L
.04351 .12429 L
.04229 .11641 L
.04145 .10984 L
.0409 .10439 L
.04054 .09992 L
.04031 .09545 L
.04023 .0912 L
.04031 .08722 L
.04052 .08399 L
.04089 .08087 L
.04144 .07799 L
.04203 .07583 L
.04269 .07403 L
.04352 .0723 L
.04453 .07068 L
.04566 .06931 L
.0468 .06823 L
.04825 .06717 L
.04976 .06632 L
.05128 .06567 L
.05279 .06516 L
.05457 .0647 L
.0566 .06432 L
.05881 .06403 L
.06012 .06391 L
.06137 .06383 L
.06394 .06372 L
.06655 .0637 L
.0681 .06371 L
.06982 .06375 L
.07308 .06387 L
.07519 .06398 L
.07727 .0641 L
.08139 .06439 L
.12397 .06856 L
.20298 .0766 L
.44217 .09957 L
.51301 .10785 L
.57896 .11769 L
.60566 .12283 L
.62737 .12793 L
Mistroke
.64372 .13265 L
.65851 .13806 L
.66952 .14339 L
.67729 .14857 L
.68057 .15149 L
.68297 .15421 L
.68498 .15724 L
.68574 .15879 L
.6864 .16049 L
.6871 .16341 L
.68729 .1661 L
.68701 .16925 L
.68628 .17225 L
.6852 .17508 L
.68389 .1777 L
.67983 .18373 L
.67384 .19039 L
.66685 .19674 L
.64627 .21154 L
.62068 .22618 L
.58677 .24221 L
.5475 .25759 L
.50566 .27105 L
.46056 .28262 L
.43549 .28782 L
.40689 .29269 L
.39255 .29471 L
.37703 .29658 L
.36231 .29805 L
.34828 .29915 L
.33486 .29994 L
.32025 .3005 L
.30375 .30073 L
.2885 .30055 L
.27367 .29999 L
.25985 .2991 L
.24461 .29769 L
.2284 .29563 L
.21439 .29335 L
.20134 .29074 L
.17228 .28296 L
.15678 .27741 L
.14097 .27045 L
.11497 .25502 L
.10097 .24372 L
.08931 .23189 L
.08006 .22028 L
.07166 .20736 L
.05954 .18255 L
.05185 .1605 L
Mistroke
.0464 .13925 L
.0443 .12877 L
.04281 .11991 L
.04182 .11289 L
.04106 .1061 L
.04059 .10065 L
.04034 .09615 L
.04023 .09185 L
.04029 .08767 L
.04053 .08388 L
.0409 .08079 L
.04135 .07839 L
.04193 .07616 L
.04251 .07447 L
.04324 .07283 L
.04413 .07127 L
.0452 .06983 L
.04633 .06865 L
.04745 .06772 L
.04872 .06688 L
.05021 .06611 L
.05199 .06541 L
.05381 .06488 L
.05484 .06464 L
.05602 .06442 L
.0583 .06409 L
.0607 .06387 L
.0631 .06375 L
.06573 .0637 L
.06837 .06372 L
.0709 .06378 L
.0738 .0639 L
.07718 .0641 L
.08101 .06436 L
.08858 .06499 L
.22065 .07831 L
.45101 .10052 L
.52017 .10878 L
.57724 .11739 L
.61877 .12578 L
.63772 .1308 L
.65232 .13562 L
.66205 .13961 L
Mfstroke
.4954 .30051 m
.46666 .30566 L
.43497 .31045 L
.4041 .31414 L
.39016 .31547 L
.37518 .31665 L
.35713 .31771 L
.34022 .31834 L
.32178 .31859 L
.3112 .31852 L
.30122 .3183 L
.28313 .31751 L
.26648 .3163 L
.24723 .31425 L
.22897 .3116 L
.21025 .30806 L
.19354 .30407 L
.17596 .29886 L
.15762 .29207 L
.14142 .2846 L
.12739 .27669 L
.10277 .25814 L
.09094 .24608 L
.08125 .2339 L
.07144 .21853 L
.06403 .20402 L
.0529 .17462 L
.04864 .15948 L
.04556 .14627 L
.04179 .12572 L
.04042 .11596 L
.03953 .108 L
.0392 .10434 L
.03893 .10077 L
.03863 .09505 L
.03855 .0922 L
.03854 .08975 L
.03857 .08725 L
.03867 .08481 L
.03896 .0812 L
.03919 .07939 L
.03944 .07784 L
.03999 .07529 L
.04071 .07295 L
.04147 .07114 L
.04227 .06966 L
.04324 .06823 L
.04442 .06692 L
.04595 .06563 L
.04753 .06464 L
Mistroke
.04945 .06376 L
.05061 .06335 L
.05172 .06303 L
.0539 .06254 L
.05522 .06233 L
.05649 .06216 L
.05897 .06194 L
.0603 .06187 L
.06182 .06181 L
.06335 .06178 L
.06486 .06178 L
.06786 .06183 L
.06963 .06189 L
.07133 .06196 L
.07543 .06219 L
.08312 .06275 L
.09253 .06359 L
.22613 .07666 L
.46064 .09833 L
.52626 .10585 L
.57996 .11349 L
.62566 .12214 L
.64509 .127 L
.6622 .13239 L
.67577 .13807 L
.68186 .14137 L
.68652 .14448 L
.69014 .14749 L
.69284 .15034 L
.69497 .15338 L
.69584 .155 L
.69656 .15677 L
.69734 .15985 L
.69753 .16161 L
.69754 .16325 L
.69717 .1663 L
.69625 .16959 L
.69499 .17256 L
.69344 .17538 L
.68866 .18194 L
.68243 .18849 L
.67532 .1947 L
.6549 .20919 L
.59718 .23925 L
.53013 .26457 L
.48535 .27749 L
.43985 .28772 L
.41504 .29211 L
.38633 .29615 L
.37134 .29781 L
Mistroke
.35482 .29928 L
.33886 .30032 L
.32398 .30096 L
.30902 .30126 L
.29493 .30122 L
.27928 .30078 L
.26242 .29981 L
.24623 .29837 L
.23094 .29649 L
.21723 .29434 L
.20251 .29147 L
.1699 .28263 L
.15225 .276 L
.13659 .26867 L
.1082 .25029 L
.09457 .23794 L
.08374 .22556 L
.06822 .20156 L
.06148 .18754 L
.05641 .17472 L
.04952 .15253 L
.04484 .13202 L
.04216 .11591 L
.04131 .10908 L
.04068 .10249 L
.04035 .09752 L
.04019 .09283 L
.04019 .08893 L
.04032 .08578 L
.04063 .08228 L
.04106 .07947 L
.04167 .07679 L
.04204 .07558 L
.04248 .07435 L
.04332 .07251 L
.04435 .0708 L
.04545 .06941 L
.04657 .06832 L
.04779 .06737 L
.0492 .06651 L
.05066 .06583 L
.05207 .0653 L
.05388 .06478 L
.05599 .06435 L
.05814 .06404 L
.06027 .06383 L
.06242 .06371 L
.06454 .06365 L
.06702 .06364 L
.06985 .06369 L
Mistroke
.07303 .06381 L
.07625 .06398 L
.08288 .06445 L
.18257 .07453 L
.28913 .08464 L
.41801 .09695 L
.48444 .1042 L
.54266 .11177 L
.57132 .11623 L
.59922 .12134 L
.63868 .13088 L
.6555 .13659 L
.66747 .14198 L
.67282 .14505 L
.67761 .14844 L
.68123 .15171 L
.68381 .15477 L
.6856 .15765 L
.68675 .16038 L
.68746 .16342 L
.68762 .16515 L
.68762 .16673 L
.6872 .16995 L
.68673 .1718 L
.68614 .17351 L
.68471 .17669 L
.6827 .18012 L
.67779 .18647 L
.671 .19331 L
.65503 .20584 L
.6029 .23502 L
.54096 .25992 L
.49881 .27303 L
.45477 .28392 L
.42938 .28898 L
.40098 .29358 L
.38554 .29562 L
.36808 .29753 L
.35177 .29892 L
.33616 .2999 L
.32006 .30052 L
.30449 .30075 L
.2903 .30061 L
.27465 .30006 L
.25752 .29893 L
.24789 .29805 L
.23915 .29708 L
.22212 .29469 L
.20617 .29178 L
.17667 .28435 L
Mistroke
.16232 .27954 L
.14715 .27336 L
.12224 .25996 L
.10188 .24455 L
.09111 .2339 L
.08209 .22305 L
.06826 .2013 L
.05747 .17726 L
.04964 .15266 L
.04517 .13336 L
.04355 .12452 L
.04226 .11621 L
.04144 .1097 L
.0408 .10338 L
.04044 .0983 L
.04027 .09409 L
.04023 .09171 L
.04024 .08932 L
.0404 .08542 L
.04071 .08211 L
.04113 .07944 L
.04171 .07691 L
.04209 .07563 L
.04249 .07451 L
.0434 .07251 L
.04454 .07067 L
.04581 .06915 L
.04714 .06796 L
.04875 .06686 L
.05066 .06591 L
.05248 .06525 L
.05435 .06475 L
.05656 .06432 L
.05789 .06414 L
.05917 .06399 L
.06151 .06382 L
.06385 .06372 L
.0666 .0637 L
.06976 .06374 L
.07145 .0638 L
.07335 .06388 L
.07701 .06408 L
.08463 .06464 L
.19721 .07604 L
.3092 .08657 L
.45874 .10137 L
.52905 .10998 L
.5863 .11901 L
.627 .12782 L
.64517 .13311 L
Mistroke
.65891 .13822 L
.66993 .14362 L
.67428 .14634 L
.67769 .14888 L
.68027 .15118 L
.68262 .15375 L
.68448 .15636 L
.68592 .15916 L
.68691 .16228 L
.68729 .16516 L
.68729 .16678 L
.68713 .16854 L
.68643 .17179 L
.68531 .17486 L
.68364 .17817 L
.67946 .18421 L
.67358 .19066 L
.66584 .19758 L
.64829 .21025 L
.59291 .23952 L
.52818 .26415 L
.48436 .27688 L
.43873 .28719 L
.4105 .29214 L
.38308 .29589 L
.36822 .2975 L
.35147 .29893 L
.34288 .2995 L
.33354 .30001 L
.32463 .30037 L
.3164 .30059 L
.30016 .30072 L
.28488 .30045 L
.26791 .29966 L
.25835 .29898 L
.24968 .29821 L
.23367 .29637 L
.2164 .29371 L
.20021 .29049 L
.18554 .28688 L
.15735 .27763 L
.13289 .26627 L
.10899 .25051 L
.09724 .24021 L
.08767 .22999 L
.07175 .20751 L
.06467 .19419 L
.05925 .18185 L
.05171 .16003 L
.04641 .1393 L
Mistroke
.04454 .13009 L
.04298 .12103 L
.04195 .1139 L
.04116 .10712 L
.04063 .10121 L
.04035 .09646 L
.04023 .09222 L
.04026 .08866 L
.04043 .08498 L
.04078 .0816 L
.0412 .07907 L
.04179 .07663 L
.04256 .07436 L
.04354 .07226 L
.04461 .07058 L
.04571 .06926 L
.04684 .0682 L
.04817 .06722 L
.0494 .06651 L
.05086 .06583 L
.05256 .06523 L
.05455 .0647 L
.05659 .06432 L
.0586 .06406 L
.06064 .06387 L
.06265 .06377 L
.065 .0637 L
.06768 .06371 L
.07071 .06378 L
.07376 .0639 L
.07668 .06407 L
.08005 .06429 L
.09726 .0658 L
.11808 .06794 L
.18822 .07516 L
.30215 .08592 L
.43947 .09928 L
.50204 .10645 L
.56187 .11483 L
.59161 .12001 L
.6151 .12492 L
.63544 .13013 L
.65097 .13512 L
.66259 .13985 L
.67225 .14501 L
.6794 .15037 L
.68239 .15348 L
.68451 .15644 L
.68594 .15923 L
.68681 .16191 L
Mistroke
.68722 .16435 L
.68727 .16703 L
.68687 .16999 L
.68597 .17316 L
.68482 .17591 L
.68315 .17897 L
.67861 .18523 L
.67195 .19222 L
.65359 .20672 L
.60604 .23348 L
.57138 .24859 L
.52819 .26415 L
.48497 .27672 L
.43348 .2882 L
.4059 .29284 L
.39068 .29496 L
.37389 .29692 L
.35806 .29841 L
.34327 .29948 L
.32811 .30024 L
.31346 .30065 L
.30446 .30073 L
.29624 .30069 L
.28669 .3005 L
.27763 .30018 L
.26136 .29922 L
.25215 .29845 L
.24367 .29758 L
.22569 .29523 L
.20609 .29175 L
.18592 .28699 L
.16762 .28141 L
.15216 .27552 L
.13617 .26802 L
.12293 .26039 L
.10993 .25125 L
.09925 .24213 L
.08869 .23117 L
.07325 .21003 L
.06579 .19649 L
.06014 .18401 L
.05086 .15707 L
.04555 .13523 L
.04254 .11811 L
.04157 .11081 L
.04118 .10731 L
.04085 .10386 L
.04044 .09813 L
.04026 .0935 L
.04024 .08956 L
Mistroke
.04035 .08629 L
.0406 .08312 L
.04101 .08013 L
.04159 .07737 L
.04198 .07598 L
.04239 .07479 L
.04323 .07285 L
.04427 .07106 L
.04531 .0697 L
.0464 .06858 L
.04771 .06753 L
.04927 .06657 L
.05075 .06588 L
.05224 .06533 L
.054 .06483 L
.05604 .06441 L
.05713 .06424 L
.05836 .06408 L
.06072 .06387 L
.06321 .06374 L
.06566 .0637 L
.0681 .06371 L
.07052 .06377 L
.07334 .06388 L
.07657 .06406 L
.08383 .06458 L
.09136 .06524 L
.22665 .07888 L
.34559 .08998 L
.46948 .10258 L
.52834 .10989 L
.58356 .11851 L
.60518 .12273 L
.62517 .12736 L
.6536 .13609 L
.66523 .14112 L
.6705 .14395 L
.67477 .14668 L
.67815 .14927 L
.68118 .15212 L
.68338 .15475 L
.68496 .15722 L
.68629 .16017 L
.68703 .16298 L
.68729 .16611 L
.6872 .16789 L
.68696 .16953 L
.68614 .17269 L
.68546 .17449 L
.68469 .17618 L
Mistroke
.68012 .18336 L
.67516 .18906 L
.66941 .19453 L
.65609 .20498 L
Mfstroke
.4954 .39666 m
.46587 .39831 L
.43921 .39932 L
.40865 .39984 L
.37992 .39964 L
.35351 .39876 L
.32926 .39729 L
.30286 .39486 L
.27519 .39124 L
.2479 .38638 L
.21929 .37958 L
.19327 .37146 L
.17057 .36239 L
.14578 .34957 L
.12134 .3326 L
.10124 .31358 L
.08543 .29343 L
.07208 .27061 L
.06079 .24445 L
.05276 .21953 L
.04721 .19748 L
.04029 .16049 L
.03806 .14489 L
.0363 .13017 L
.035 .11698 L
.0342 .10661 L
.0339 .10166 L
.03367 .09682 L
.03347 .08953 L
.0335 .08378 L
.0337 .07871 L
.03402 .07507 L
.0345 .07167 L
.03511 .06875 L
.03552 .06731 L
.03593 .06609 L
.03687 .06394 L
.03803 .06204 L
.03926 .06057 L
.04055 .05942 L
.04182 .05856 L
.04332 .05778 L
.04513 .05709 L
.04623 .05676 L
.04732 .0565 L
.04849 .05627 L
.04967 .05609 L
.05109 .05591 L
.05245 .05579 L
.05369 .05571 L
Mistroke
.05507 .05565 L
.05771 .0556 L
.05942 .0556 L
.06111 .05563 L
.0627 .05568 L
.06448 .05575 L
.06795 .05593 L
.07144 .05615 L
.08034 .05683 L
.1033 .05893 L
.16709 .06475 L
.39686 .08278 L
.47522 .08933 L
.55354 .09708 L
.61113 .10436 L
.66134 .11312 L
.68229 .11818 L
.69777 .12302 L
.71091 .12856 L
.71609 .13143 L
.72072 .13463 L
.72399 .13754 L
.72629 .14023 L
.72731 .14174 L
.72822 .14339 L
.72889 .14497 L
.72935 .14643 L
.72982 .14908 L
.72983 .15204 L
.7293 .15518 L
.72833 .15817 L
.7269 .16124 L
.72486 .16463 L
.71995 .17093 L
.70691 .1832 L
.68606 .19817 L
.66186 .21255 L
.60294 .24078 L
.53219 .26654 L
.48444 .27987 L
.43557 .29037 L
.40796 .29491 L
.37614 .2989 L
.35947 .30043 L
.35013 .30112 L
.34121 .30167 L
.3328 .30208 L
.32358 .3024 L
.30724 .30267 L
.29107 .3025 L
Mistroke
.27609 .30196 L
.25864 .30082 L
.24197 .29916 L
.22661 .2971 L
.21241 .29468 L
.18077 .28717 L
.16335 .28147 L
.14758 .27508 L
.12043 .26023 L
.10685 .2502 L
.09558 .23994 L
.08473 .22775 L
.07477 .21375 L
.06714 .20039 L
.06133 .18806 L
.05273 .16455 L
.0463 .14 L
.04273 .12084 L
.0416 .1128 L
.04078 .10533 L
.04034 .09974 L
.04008 .09434 L
.04003 .09164 L
.04004 .08934 L
.04011 .08701 L
.04024 .08475 L
.04059 .08135 L
.04086 .07963 L
.04116 .07816 L
.04181 .07569 L
.04265 .07345 L
.04348 .07179 L
.04452 .07021 L
.04578 .06876 L
.04731 .06745 L
.04892 .06643 L
.05053 .06566 L
.05229 .06502 L
.05406 .06454 L
.05617 .06413 L
.05742 .06395 L
.0586 .06381 L
.0609 .06362 L
.06357 .06351 L
.06629 .06347 L
.06896 .06351 L
.07169 .0636 L
.07481 .06375 L
.08098 .06415 L
.09794 .06567 L
Mistroke
.14849 .07092 L
.35261 .09033 L
.49506 .10518 L
.55928 .11394 L
.59109 .11937 L
.61628 .12459 L
.63535 .12943 L
.6526 .13493 L
.66689 .14098 L
.67256 .1441 L
.6769 .14698 L
.68031 .14973 L
.6833 .15276 L
.68464 .15445 L
.68569 .15601 L
.68725 .15913 L
.68808 .16186 L
.68847 .16489 L
.68832 .1681 L
.68769 .17114 L
.68661 .17419 L
.68494 .17756 L
.68066 .18379 L
.67505 .18998 L
.66866 .19582 L
.65039 .20927 L
.6251 .22412 L
.56321 .25194 L
.48767 .27612 L
.43576 .28785 L
.4073 .29271 L
.39027 .29509 L
.37434 .29695 L
.36026 .2983 L
.34465 .29946 L
.33592 .29996 L
.32779 .30032 L
.31154 .30074 L
.29739 .30077 L
.2816 .3004 L
.26492 .29953 L
.2492 .29823 L
.23249 .29627 L
.21473 .29347 L
.19811 .29008 L
.18328 .28632 L
.16619 .28097 L
.14844 .27398 L
.1339 .26686 L
.119 .25787 L
Mistroke
.09529 .23833 L
.08443 .2261 L
.07568 .21392 L
.0632 .19108 L
.05381 .16684 L
.04776 .14523 L
.04368 .12531 L
.04245 .11754 L
.04149 .1102 L
.04091 .10462 L
.04049 .09915 L
.04027 .09448 L
.04022 .09068 L
.04031 .08698 L
.04055 .08356 L
.04087 .08092 L
.04127 .07873 L
.04179 .07659 L
.04246 .07458 L
.0433 .07269 L
.04436 .07091 L
.04563 .06933 L
.04696 .06808 L
.04834 .0671 L
.04972 .06633 L
.05145 .06559 L
.05324 .06502 L
.05534 .06453 L
.05647 .06433 L
.05777 .06414 L
.06022 .0639 L
.06271 .06375 L
.06422 .06371 L
.06587 .06369 L
.06734 .06369 L
.06901 .06372 L
.07089 .06377 L
.073 .06386 L
.07704 .06408 L
.08517 .06468 L
.09543 .06562 L
.11858 .06799 L
.18232 .07456 L
.40804 .09602 L
.48056 .10384 L
.55163 .11322 L
.58152 .11813 L
.60659 .12301 L
.62786 .12803 L
.64417 .13277 L
Mistroke
.65724 .1375 L
.66852 .1428 L
.67352 .14579 L
.67739 .1486 L
.68063 .1515 L
.68306 .15425 L
.68469 .15665 L
.68599 .15926 L
.68692 .16219 L
.6873 .1649 L
.68725 .16776 L
.6867 .17091 L
.68572 .17392 L
.68443 .17675 L
.68028 .18319 L
.67488 .18938 L
.65763 .20389 L
.63481 .21847 L
.60408 .23441 L
.53573 .26166 L
.48848 .27581 L
.43869 .28721 L
.40911 .29236 L
.39395 .29453 L
.3796 .2963 L
.36653 .29766 L
.35183 .2989 L
.33675 .29985 L
.32045 .3005 L
.31118 .30068 L
.3023 .30073 L
.28545 .30047 L
.27593 .3001 L
.26706 .29961 L
.25727 .2989 L
.24682 .29793 L
.22779 .29555 L
.20995 .29252 L
.19409 .28908 L
.17727 .28452 L
.14779 .27364 L
.13239 .26599 L
.11927 .258 L
.10794 .24968 L
.09672 .23971 L
.07945 .21944 L
.07155 .20718 L
.06425 .1933 L
.05843 .17977 L
.05343 .16562 L
Mistroke
.04712 .14248 L
.0435 .12421 L
.04214 .1153 L
.04125 .10803 L
.04089 .10432 L
.04062 .10108 L
.04041 .09762 L
.04029 .09472 L
.04024 .09229 L
.04023 .08991 L
.04036 .08606 L
.0405 .08413 L
.04067 .08245 L
.04091 .08075 L
.04121 .07906 L
.04183 .07648 L
.04225 .07518 L
.04267 .07407 L
.04354 .07225 L
.04461 .07058 L
.04568 .06929 L
.04678 .06824 L
.04812 .06726 L
.04969 .06636 L
.05135 .06564 L
.05298 .0651 L
.05501 .06461 L
.0571 .06424 L
.05918 .064 L
.06123 .06384 L
.06363 .06373 L
.06636 .0637 L
.06931 .06374 L
.07106 .06379 L
.07272 .06385 L
.07612 .06403 L
.07958 .06426 L
.09908 .06598 L
.25247 .08131 L
.37255 .09254 L
.44486 .09986 L
.51044 .10751 L
.56512 .11535 L
.59023 .11974 L
.61362 .12458 L
.63075 .12882 L
.64677 .13365 L
.65889 .13821 L
.66803 .14256 L
.6768 .14818 L
Mistroke
.6803 .15122 L
.6832 .1545 L
.68506 .1574 L
.68629 .16015 L
.68707 .16322 L
.68726 .16496 L
.68729 .16657 L
.68699 .1694 L
.68634 .17205 L
.68523 .17501 L
.68361 .1782 L
.67894 .18484 L
.67323 .191 L
.65548 .20541 L
.62943 .22149 L
.59905 .23675 L
.56557 .25088 L
.52673 .26462 L
.48671 .27627 L
.43693 .28754 L
.40705 .29267 L
.39152 .29485 L
.37709 .29658 L
.36266 .29801 L
.34672 .29926 L
.33779 .29979 L
.3295 .30019 L
.31297 .30065 L
.29849 .30071 L
.28241 .30036 L
.26542 .2995 L
.24946 .29819 L
.24032 .2972 L
.2304 .29592 L
.21242 .29298 L
.19509 .28931 L
.17936 .28514 L
.14534 .27252 L
.12949 .26435 L
.1134 .25387 L
.09091 .23367 L
.08038 .22073 L
.07204 .20801 L
.06012 .18398 L
.05149 .15925 L
.04607 .1377 L
.04294 .12074 L
.04128 .10832 L
.04073 .10239 L
.04041 .09755 L
Mistroke
.04024 .09284 L
.04026 .08843 L
.04045 .0848 L
.04074 .08189 L
.04124 .07891 L
.04158 .07741 L
.04194 .07612 L
.0427 .07401 L
.04364 .07207 L
.04468 .07049 L
.04593 .06903 L
.04726 .06787 L
.04859 .06696 L
.05022 .06611 L
.05217 .06535 L
.05323 .06503 L
.05442 .06473 L
.05558 .06449 L
.05672 .0643 L
.05892 .06402 L
.06015 .06391 L
.06154 .06382 L
.06305 .06375 L
.06454 .06371 L
.06752 .0637 L
.0705 .06377 L
.07346 .06389 L
.07693 .06408 L
.0809 .06435 L
.10233 .06631 L
.12847 .06904 L
.31325 .08695 L
.43969 .09931 L
.50772 .10717 L
.5643 .11522 L
.61439 .12476 L
.63548 .13014 L
.65381 .13618 L
.66682 .14193 L
.67196 .14483 L
.676 .14757 L
.67904 .15004 L
.68181 .15281 L
.684 .15563 L
.68569 .15867 L
.68643 .16059 L
.68691 .16238 L
.68722 .16436 L
.68729 .1665 L
.68709 .16877 L
Mistroke
.68666 .17093 L
.68607 .17289 L
.68522 .17503 L
.68314 .17899 L
.68021 .18324 L
.67322 .19101 L
.65017 .20902 L
.6143 .22944 L
Mfstroke
.49539 .49282 m
.45143 .49225 L
.4123 .49063 L
.3681 .48727 L
.32732 .48238 L
.29058 .47613 L
.25767 .46865 L
.22296 .45822 L
.18823 .44423 L
.15612 .42663 L
.12545 .40315 L
.10085 .3763 L
.0824 .34784 L
.06571 .31084 L
.05839 .28886 L
.0528 .26835 L
.04506 .23201 L
.03951 .19707 L
.03353 .14387 L
.03186 .12287 L
.03095 .10799 L
.0305 .09768 L
.03028 .08865 L
.03026 .08483 L
.0303 .08119 L
.0305 .07561 L
.03083 .0712 L
.03134 .06729 L
.03194 .06426 L
.03261 .06193 L
.03328 .06014 L
.03412 .05847 L
.0351 .05699 L
.03611 .05583 L
.03738 .05472 L
.03868 .05388 L
.04025 .05312 L
.04208 .05248 L
.04308 .05222 L
.04422 .05198 L
.04527 .05179 L
.04643 .05163 L
.04753 .05152 L
.04879 .05141 L
.05116 .0513 L
.05378 .05126 L
.05636 .05129 L
.05787 .05133 L
.05958 .05139 L
.06291 .05155 L
Mistroke
.0701 .05202 L
.07781 .05263 L
.23838 .06551 L
.368 .07436 L
.5228 .08598 L
.5955 .09303 L
.6289 .09705 L
.66006 .10158 L
.68435 .10596 L
.70284 .11012 L
.71806 .11447 L
.72956 .11875 L
.73943 .12379 L
.74323 .12642 L
.74657 .12937 L
.74875 .13193 L
.75045 .13474 L
.75148 .13745 L
.75195 .13996 L
.75204 .14142 L
.75198 .14298 L
.7515 .14584 L
.75098 .14762 L
.75035 .1493 L
.74878 .1525 L
.7442 .15917 L
.73729 .16664 L
.72125 .18003 L
.69916 .1949 L
.64754 .22292 L
.5821 .25082 L
.53925 .2656 L
.49372 .27859 L
.44684 .28914 L
.4183 .29418 L
.39053 .29806 L
.36626 .30061 L
.35205 .30173 L
.33845 .30253 L
.32394 .30309 L
.31043 .30333 L
.29539 .30326 L
.27934 .30276 L
.26272 .30177 L
.25329 .30097 L
.24457 .30008 L
.22853 .29799 L
.21161 .29512 L
.18279 .28831 L
.16691 .2833 L
Mistroke
.15253 .27777 L
.13684 .2704 L
.12286 .26232 L
.09956 .24429 L
.08845 .23271 L
.07943 .22115 L
.071 .20792 L
.06344 .19323 L
.05397 .16887 L
.048 .14779 L
.0442 .13001 L
.04199 .11631 L
.04121 .11012 L
.04061 .10419 L
.04019 .09844 L
.04 .09372 L
.03998 .08909 L
.04013 .08527 L
.0404 .08227 L
.04083 .0794 L
.04138 .07687 L
.042 .07484 L
.0428 .07289 L
.04377 .07111 L
.04473 .06977 L
.04571 .06868 L
.0469 .06763 L
.04828 .06668 L
.04995 .0658 L
.05193 .06504 L
.05399 .06447 L
.05606 .06406 L
.05807 .06378 L
.06045 .06357 L
.06313 .06344 L
.06583 .0634 L
.06891 .06343 L
.07075 .06349 L
.07253 .06356 L
.07598 .06374 L
.07993 .064 L
.09703 .06551 L
.15624 .07164 L
.37029 .09189 L
.4459 .09948 L
.52209 .10845 L
.57858 .11693 L
.60557 .12204 L
.62752 .1271 L
.64521 .13214 L
Mistroke
.66076 .13785 L
.67172 .14323 L
.6793 .14838 L
.68251 .15132 L
.68491 .15412 L
.68686 .15724 L
.68767 .15901 L
.68823 .16065 L
.68863 .16237 L
.68884 .16397 L
.6889 .16575 L
.68877 .16766 L
.68847 .1695 L
.68803 .17124 L
.68681 .17453 L
.68533 .17745 L
.68328 .1807 L
.67786 .18736 L
.66417 .19965 L
.64235 .21445 L
.61674 .22854 L
.58533 .24307 L
.54538 .25853 L
.50505 .27138 L
.45669 .28361 L
.40825 .2926 L
.39414 .29461 L
.37853 .29652 L
.3647 .29793 L
.34924 .29918 L
.33476 .30004 L
.32103 .30057 L
.3063 .30081 L
.29032 .30068 L
.27523 .30015 L
.26084 .29926 L
.24785 .29811 L
.23372 .29646 L
.2173 .29394 L
.20238 .29104 L
.18653 .28722 L
.16963 .28216 L
.15456 .27659 L
.14115 .27061 L
.11676 .25635 L
.10349 .24602 L
.0923 .23524 L
.07497 .21285 L
.06727 .19945 L
.06137 .18699 L
Mistroke
.05163 .15978 L
.04611 .13797 L
.04296 .12097 L
.04179 .11271 L
.04104 .10609 L
.04075 .10276 L
.0405 .0994 L
.04034 .09647 L
.04026 .09394 L
.04023 .08941 L
.04038 .0857 L
.04052 .08379 L
.0407 .08216 L
.04094 .0805 L
.04123 .07889 L
.04154 .07753 L
.04191 .07618 L
.04268 .07401 L
.04377 .07182 L
.04493 .07014 L
.04605 .06889 L
.04721 .06789 L
.0486 .06694 L
.05023 .06609 L
.05211 .06536 L
.05406 .0648 L
.05596 .06441 L
.05819 .06409 L
.06025 .06389 L
.06269 .06375 L
.06544 .06369 L
.06821 .0637 L
.07096 .06377 L
.07365 .06389 L
.07678 .06406 L
.08031 .0643 L
.09866 .06593 L
.12102 .06824 L
.19728 .07604 L
.42169 .09741 L
.49088 .10506 L
.5571 .11406 L
.60401 .12246 L
.62598 .12753 L
.64333 .13249 L
.65902 .13823 L
.6705 .14391 L
.67812 .14918 L
.68137 .15224 L
.68372 .15513 L
Mistroke
.68478 .15678 L
.68571 .15857 L
.6864 .16028 L
.68686 .16187 L
.68732 .16491 L
.68722 .16818 L
.68695 .16989 L
.68649 .17174 L
.68523 .17512 L
.68421 .1772 L
.68306 .17919 L
.68047 .18296 L
.67475 .18952 L
.66702 .19662 L
.64915 .2097 L
.59163 .2401 L
.52111 .2664 L
.47328 .27966 L
.44839 .28525 L
.42396 .28992 L
.39941 .29378 L
.37613 .29668 L
.36334 .29796 L
.3492 .29909 L
.33395 .29999 L
.31928 .30053 L
.30485 .30073 L
.28875 .30056 L
.27171 .29989 L
.25562 .29876 L
.24051 .29723 L
.22668 .29538 L
.21077 .29267 L
.19581 .28949 L
.17958 .2852 L
.16253 .2796 L
.14806 .27376 L
.13353 .26662 L
.12117 .25926 L
.10861 .25021 L
.08938 .23197 L
.07952 .21953 L
.07181 .20762 L
.06479 .19444 L
.05856 .18011 L
.0505 .1558 L
.04562 .13556 L
.04281 .11995 L
.04175 .11229 L
.04105 .10606 L
Mistroke
.04057 .10026 L
.04029 .0948 L
.04023 .09038 L
.04033 .08669 L
.04054 .0837 L
.04089 .08088 L
.04132 .07853 L
.04179 .07662 L
.04245 .07463 L
.04329 .07274 L
.04418 .07119 L
.04511 .06994 L
.04631 .06866 L
.04758 .06763 L
.04881 .06683 L
.05027 .06608 L
.05199 .06541 L
.05399 .06483 L
.05584 .06445 L
.05804 .06412 L
.06024 .0639 L
.06239 .06378 L
.06492 .06371 L
.06778 .06371 L
.07044 .06377 L
.07308 .06387 L
.07615 .06403 L
.07966 .06426 L
.09952 .06603 L
.12465 .06864 L
.19404 .07573 L
.41105 .09634 L
.47926 .1037 L
.54657 .11248 L
.59966 .12159 L
.63714 .13063 L
.65287 .13582 L
.66462 .14082 L
.67451 .1465 L
.67873 .14976 L
.68178 .15278 L
.68405 .15571 L
.68559 .15845 L
.68671 .1615 L
.68704 .16305 L
.68725 .16477 L
.68722 .16769 L
.68667 .17087 L
.6857 .1739 L
.68442 .1767 L
Mistroke
.68242 .18013 L
.67977 .18381 L
.6737 .19054 L
.65428 .20624 L
.63172 .22021 L
.60108 .23581 L
.56779 .25001 L
.52737 .26441 L
.48784 .27597 L
.44074 .2868 L
.41176 .29194 L
.384 .29579 L
.37011 .29731 L
.35472 .29868 L
.33987 .29968 L
.32592 .30032 L
.30936 .3007 L
.29362 .30065 L
.28449 .30043 L
.2761 .30011 L
.26636 .29956 L
.25708 .29888 L
.23851 .29698 L
.2213 .29454 L
.20252 .291 L
.18286 .28614 L
.15016 .27467 L
.1348 .2673 L
.11913 .25791 L
.10683 .24877 L
.09494 .23793 L
.07708 .216 L
.06852 .20177 L
.06098 .18603 L
.05569 .17236 L
.05126 .15848 L
.04551 .13504 L
.04369 .12533 L
.04243 .11738 L
.04156 .11072 L
.04088 .10425 L
.04044 .09827 L
.04025 .09331 L
.04024 .08925 L
.0404 .08546 L
.04069 .08233 L
.04106 .07981 L
.04135 .07839 L
.04169 .077 L
.0424 .07477 L
Mistroke
.04331 .0727 L
.04447 .07077 L
.04562 .06935 L
.047 .06806 L
.04845 .06704 L
.0499 .06625 L
.05147 .0656 L
.05306 .06508 L
.05494 .06462 L
.05713 .06424 L
.05949 .06397 L
.06074 .06387 L
.06218 .06379 L
.06487 .06371 L
.06756 .0637 L
.07048 .06377 L
.07343 .06389 L
.07625 .06404 L
.07948 .06425 L
.09594 .06567 L
.24044 .08018 L
.36652 .09196 L
.49682 .10581 L
.55547 .11383 L
.60762 .12325 L
.63138 .129 L
.6498 .1347 L
.66298 .14004 L
.6691 .14315 L
.67388 .14608 L
.68008 .15101 L
.68254 .15366 L
.68455 .1565 L
.68584 .15901 L
.68667 .16138 L
.68718 .16401 L
.68727 .16687 L
.68698 .16944 L
.68627 .17227 L
.68525 .17497 L
.684 .17749 L
.6809 .18233 L
.67658 .18756 L
.66335 .19957 L
.64687 .21116 L
.59595 .23816 L
Mfstroke
0 0 m
1 0 L
1 .5052 L
0 .5052 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{508.688, 257},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;k0001PB000`400?l00000o`00003oo`3ooooo
0?ooood0oooo003o0?ooool0ooooo@3oool00?l0ooooo`3oooom0?ooo`00o`3ooon;0?ooo`030?oo
g`2LB00000000080000000<0M;oo0?ooo`3oool04@3oool0103OW4P000000018W03Ooooo0?oooeD0
oooo003o0?ooohd0oooo00<0okmd0000M02oool0503oool01@3o_g@004RL0=oOW018B9`0gooo0?l0
ooooE03oool00?l0ooooS@3oool00`3ookl0M00007Boo`0G0?ooo`030?oOW018M;l0oooo0?l0oooo
D`3oool00?l0ooooS@3oool00`3ooml0W4P004RLg`0H0?ooo`030?noM01d_ol0oooo0?l0ooooDP3o
ool00?l0ooooSP3oool00`3OW4P00000000000020000000607Boo`3oool0oooo0?ooo`2oM00007Bo
1P3oool01@3OW4P00000000000000000M;oo00@0oooo00<0okmd0000001d_ol0o`3ooomB0?ooo`00
o`3ooon>0?ooo`070?noM00004P0W=oo0?ooo`3ooml0W4P0001d_`020?ooo`030?noM00007@0_ooo
00@0oooo00<0omnL04P0001d_ol00P3oool00`2oM00007Bo0?ooo`020?ooo`040=nLB00007@0M7A8
09cOool0ooooD@3oool00?l0ooooSP3oool00`3ookl0M00007Boo`020?ooo`070?oog`2LB000B9cO
0?ooo`3ogi`0B00007Boo`040?ooo`030=nLB000B9`0gooo00<0oooo00T0gibL0;ooo`3oool0oooo
0=nLB000B9`0gooO09adW03Oool0o`3ooom@0?ooo`00o`3ooon>0?ooo`030?oog`2LB000B9cO00<0
oooo00L0omnL04P0B02Lgol0oooO09a80000B9`0gooo00<0oooo00D0okmd000000000000000004RL
g`050?ooo`050;md0000B9`0gooo0?oOW01dW=l0o`3ooom@0?ooo`00o`3ooon?0?ooo`030=nLB000
07@0_ooo0080oooo00L0oooO09a80018W=l0oooo0;md0018M7@0M9cO00<0oooo00L0oono07@0B02L
gol0oooo0=nLB0000000B9cO0080oooo00<0oooO09a80000M;l00P3oool00`3OW9`0_ooo0?ooo`3o
0?ooodh0oooo003o0?ooohl0oooo00@0okmd00000000B9`0gooo0P3oool01`3OW4P007Bo0?ooo`3o
_g@004RL0;nLB01d_ol00`3oool02`3o_g@004RL0=ooo`3oool0oono07@00018W=l0oooo0?oog`2L
B00007Bo0080oooo00<0oono07Ad_`3oool0o`3ooom>0?ooo`00o`3ooon?0?ooo`0K0?oo_`1d0000
M9bL04P0M02oool0oooO09a80000M;l0oooo0?oo_`1d04P0W=oo0;md001dM7@004RL0=ooo`3oool0
gia80000M02oool0oooo0=nLB000B9`0gooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0M02oool0
o`3ooom>0?ooo`00o`3ooon>0?ooo`0A0?oOW0180000000004RLg`3ookl0M0000000000007@0_ooo
0?oOW0180000000007Boo`3oool0_g@00000M02oool00P3oool02@3ogi`0B000000000000000M;oo
0;md00000000001809cOo`020?ooo`030=nLB000B9`0gooo0?l0ooooCP3oool00?l0ooooo`3oooom
0?ooo`00o`3ooooo0?ooood0oooo003o0?ooool0ooooo@3oool00?l0ooooo`3oooom0?ooo`00o`3o
oooo0?ooood0oooo003o0?ooool0ooooo@3oool00?l0ooooo`3oooom0?ooo`00o`3ooooo0?ooood0
oooo003o0?ooool0ooooo@3oool00?l0ooooo`3oooom0?ooo`00o`3ooooo0?ooood0oooo003o0?oo
ool0ooooo@3oool00?l0ooooo`3oooom0?ooo`00o`3ooooo0?ooood0oooo003o0?ooool0ooooo@3o
ool007X0oooo00@0_g@0000000000000M;ooI`3oool0102oM00000000000001d_ol30?ooo`030?oO
W0180000M;oo0080oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`1M0?ooo`040;md
00000000000007Boo`<0oooo00<0omnL04P0001d_ol01@3oool00`3ooml0W4P004RLg`1P0?ooo`04
0;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00`3oool01@3ooml0W4P0000000000000
07Bo0600oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`030?ooo`060?oo_`1d
0000000000000000B9`0goooH`3oool00`3ookl0M000000000020000000304RLg`3oool0oooo0480
oooo001i0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cOI@3oool01P3OW4P007Bo0?ooo`3ogi`0
B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02o
ool0oooo05`0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00H0
oooo00<0gia80018W03Oool0GP3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL
04P0001d_ol00`3oool01`3OW4P007Bo0?ooo`3ookl0M0000018W03Oool0G@3oool01P3OW4P007Bo
0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool00`3ookl0M00004RLg`020?oo
o`030=nLB00007@0_ooo06@0oooo00<0okmd0000001d_ol0A@3oool007P0oooo00<0oooO09a80018
W=l00P3oool00`3o_g@0001809cOo`1S0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02L
gol0203oool00`3o_g@007Bo0?ooo`1O0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02L
gol02P3oool00`3ogi`0B01809cOo`1M0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02L
gol01P3oool00`3ooml0W4P007Boo`020?ooo`030?oOW0180000B9cO05`0oooo00<0oooO09a80018
W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?noM000B9`0gooo00<0oooo00<0_g@004RLg`3o
ool0H`3oool00`3ooml0W4P0001d_`150?ooo`00N03oool00`3ooml0W4P004RLg`020?ooo`040?oo
g`2LB00004RL0=ooof80oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?oo
o`030?noM000M;l0oooo05h0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool5
0?ooo`030?noM0000000000000@0000000<004RL0=ooo`3oool0FP3oool00`3ooml0W4P004RLg`02
0?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0oono07@0001d_ol00`3oool00`2oM000001d0;oo
o`1K0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3o_g@004RL
0=ooo`030?ooo`030;md0000M;l0oooo06@0oooo00<0gia80018W03Oool0A03oool007P0oooo00<0
oooO09a80000M;l00`3oool00`3OW4P0001809cOo`1R0?ooo`030?oog`2LB00007Bo00<0oooo00<0
gia80000B02Lgol02@3oool00`3o_g@0B9cO0?ooo`1M0?ooo`030?oog`2LB00007Bo00<0oooo00<0
gia80000B02Lgol01@3oool00`3ooml0W4Q809cOo`020?ooo`030;md0000M;l0oooo05`0oooo00<0
oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0
gia80000B02Lgol0F`3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0
oooO09a8001d_ol00P3oool00`3ookl0M00004RLg`1U0?ooo`030?oOW01804P0W=oo04@0oooo001i
0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0H`3oool00`2oM00004RL0=ooo`02
0?ooo`030?oOW0180000B9cO00X0oooo00<0gia804RLg`3oool0G@3oool00`2oM00004RL0=ooo`02
0?ooo`030?oOW0180000B9cO00H0oooo00L0oono07@0M02oool0oooo0?noM000B9`0gooo05d0oooo
00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`030;md000007@0_ooo0080oooo
00<0gia80000B02Lgol0G03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00L0oooo
00H0_g@00000B02Lgml0W4P00000M02ooomU0?ooo`030?oo_`1d0000M;oo04@0oooo001i0?ooo`03
0=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0H`3oool00`3OW4P0001809cOo`020?ooo`03
0?oog`2LB00007Bo00/0oooo00<0_g@007Boo`3oool0G03oool00`3OW4P0001809cOo`020?ooo`03
0?oog`2LB00007Bo00L0oooo00H0omnL04Q8W03Oool0omnL04P0B02LgomM0?ooo`030=nLB00004P0
W=oo0080oooo00<0oooO09a80000M;l01P3oool0203o_g@0000004RLg`3oool0oooO09a80000B9`0
goooG03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00P0oooo00D0oooO09a80000
000004RL0=ooo`1V0?ooo`030;md0000M;l0oooo04<0oooo001i0?ooo`030?oOW0180000B9cO00<0
oooo00<0_g@00018W03Oool0HP3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00X0
oooo00<0omnL04P0M02oool0G03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00L0
oooo00D0okmd001d_`3ooml0W4P004RLg`1M0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018
W03Oool01@3oool00`3ooml0W4P000000002000000030000M02oool0oooo05`0oooo00<0omnL04P0
0018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`060;md000004P0W=oo0?oOW018B9`0goooI@3o
ool00`3OW4P004RL0=ooo`130?ooo`00N@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000
B9`0gooo0680oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030?oo
g`2LB000M;oo05`0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`04
0=nLB018W=l0_g@0001d_ed0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`06
0?ooo`030?oo_`1d000007Bo0600oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=oo
o`060?ooo`030?oOW0180000M;oo0080oooo00<0okmd04RLg`3oool0I03oool00`3ogi`0B01809cO
o`130?ooo`00NP3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo06<0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo_`1d0000B9cO05d0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`090?ooo`040=nLB01dM7@0001d0;oooed0oooo00<0
omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030?oOW0180000B9cO0600oooo00<0
omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`060?ooo`030?oOW01804P0W=oo0080oooo00<0
okmd0018W03Oool0I03oool00`3ookl0M00007Boo`130?ooo`00N`3oool01P3OW4P0001d0;ooo`3o
oml0W4P004RLgfD0oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`070?noM000B9`0gooo
0?ooo`3OW4P0001809cOo`1N0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO2`3oool00`2oM000
001809cOo`1N0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO2@3oool0103ooml0W4P00000M02o
oomO0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool00`3ooml0W4P004RLg`020?ooo`03
0;md0000M;l0oooo06D0oooo00<0_g@0001d_`3oool0@P3oool007`0oooo00@0gia8000000000000
07BoI`3oool0103OW4P0000000000000M;l90?ooo`050?oOW018000000000000001d_ol0H03oool0
103OW4P0000000000000M;l<0?ooo`030?oog`2LB000B9cO05l0oooo00@0gia800000000000007Bo
303oool0103ookl0M00000000018W=mN0?ooo`040=nLB00000000000001d_`T0oooo00D0oooO09a8
000000000000001d_`1U0?ooo`050?oo_`1d000000000000M02oool0@P3oool00?l0ooooo`3oooom
0?ooo`00o`3ooooo0?ooood0oooo003o0?ooool0ooooo@3oool00?l0ooooo`3oooom0?ooo`00o`3o
oooo0?ooood0oooo003o0?ooool0ooooo@3oool00?l0ooooo`3oooom0?ooo`00o`3ooooo0?ooood0
oooo003o0?ooool0ooooo@3oool00?l0ooooo`3oooom0?ooo`00o`3ooooo0?ooood0oooo003o0?oo
ool0ooooo@3oool007@0ooooo`00003o000005<00000=P3oool007@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`040;md00000000000007Boo`d0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0d0?ooo`00HP3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg``0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo06l0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0d0?ooo`00H@3oool00`3ooml0W4P004RL
g`020?ooo`030?noM00004P0W=oo00/0oooo00@000000?ooo`00000000009`3oool2000002H0oooo
0P00000W0?ooo`8000009P3oool2000002L0oooo0P00000V0?ooo`8000009P3oool2000002H0oooo
0P00000W0?ooo`8000009P3oool2000002H0oooo0P00000V0?ooo`8000009P3oool200000400oooo
00<000000?ooo`3oool0=03oool00640oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018
W03Oool:0?ooo`030000003oool0000000D000008`3oool600000280oooo1P00000S0?ooo`H00000
8P3oool6000002<0oooo1P00000R0?ooo`H000008P3oool600000280oooo1P00000S0?ooo`H00000
8P3oool600000280oooo1P00000R0?ooo`H000008P3oool6000003`0oooo00<000000?ooo`3oool0
=03oool00640oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`0:0?ooo`030000003o
ool0000000T000007`3oool:000001h0oooo2P00000O0?ooo`X000007P3oool:000001l0oooo2P00
000N0?ooo`X000007P3oool:000001h0oooo2P00000O0?ooo`X000007P3oool:000001h0oooo2P00
000N0?ooo`X000007P3oool:000003P0oooo00<000000?ooo`3oool0=03oool00680oooo00<0_g@0
0018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`l00000703oool=000001/0oooo3@00000L
0?ooo`d000006`3oool=000001`0oooo3@00000K0?ooo`d000006`3oool=000001/0oooo3@00000L
0?ooo`d000006`3oool=000001/0oooo3@00000K0?ooo`d000006`3oool=000002L0oooo00<00000
0?ooo`3oool01`3oool5000003H0oooo001R0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8
0000M;l02P3oool00`000000oooo0000000:000001h0oooo2`00000M0?ooo`/000007P3oool;0000
01d0oooo2`00000N0?ooo`/000007@3oool;000001d0oooo2`00000M0?ooo`/000007P3oool;0000
01d0oooo2`00000M0?ooo`/000007@3oool;000001d0oooo2`00000g0?ooo`030000003oool0oooo
03@0oooo001R0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool02@3oool00`000000
oooo0000000600000280oooo1`00000Q0?ooo`L000008P3oool700000240oooo1`00000R0?ooo`L0
00008@3oool700000240oooo1`00000Q0?ooo`L000008P3oool700000240oooo1`00000Q0?ooo`L0
00008@3oool700000240oooo1`00000k0?ooo`030000003oool0oooo03@0oooo001R0?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool02@3oool00`000000oooo00000002000002H0
oooo0`00000U0?ooo`<000009P3oool3000002D0oooo0`00000V0?ooo`<000009@3oool3000002D0
oooo0`00000U0?ooo`<000009P3oool3000002D0oooo0`00000U0?ooo`<000009@3oool3000002D0
oooo0`00000o0?ooo`030000003oool0oooo03@0oooo001S0?ooo`030?oOW0180000M;oo0080oooo
00<0gia8001d_`3oool02@3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo
0?ooo`0d0?ooo`00I03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`X0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodl0oooo00<000000?ooo`3oool0=03oool006D0oooo00@0gia8000000000000
07Bo2`3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0d0?ooo`00
M03oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0d0?ooo`00M03o
ool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0d0?ooo`00M03oool0
0`000000oooo0?ooo`3o0?ooool0ooooC`3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`00
0000oooo0?ooo`3o0?ooool0oooo4P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
03@0oooo001d0?ooo`<00000o`3ooooo0?oooa40oooo0`00000i0?ooo`<00000=P3oool007@0oooo
00<000000?ooo`3oool0o`3ooooo0?oooa00oooo1000000k0?ooo`030000003oool0oooo03@0oooo
001d0?ooo`030000003oool0oooo0?l0ooooo`3oool?0?ooo`H00000=P3oool01@000000oooo0?oo
o`3oool0000003H0oooo001d0?ooo`030000003oool0oooo0?l0ooooo`3oool>0?ooo`P00000<`3o
ool3000000<0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool0D@3oool2
00000?l0ooooJ@3oool2000002L0oooo0P00000W0?ooo`L00000<P3oool500000080oooo00<00000
0?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool0D@3oool4000002@0oooo0P00000V0?oo
o`8000009`3oool2000002H0oooo0P00000V0?ooo`8000009`3oool2000002H0oooo0P00000V0?oo
o`8000009P3oool4000002D0oooo1000000W0?ooo`H00000<03oool600000080oooo00<000000?oo
o`3oool0=03oool007@0oooo00<000000?ooo`3oool0:03oool2000002L0oooo1P00000R0?ooo`D0
00008`3oool5000002@0oooo1@00000S0?ooo`D000008`3oool5000002@0oooo1@00000S0?ooo`D0
00008`3oool5000002<0oooo1P00000R0?ooo`L000009`3oool5000002d0oooo200000020?ooo`03
0000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo02P0oooo1P00000R0?ooo`T00000
803oool800000200oooo2000000Q0?ooo`L000008@3oool800000200oooo2000000Q0?ooo`L00000
8@3oool700000240oooo2000000O0?ooo`X000007`3oool9000002L0oooo1000000[0?ooo`X00000
00<0oooo0000003oool0=@3oool007@0oooo00<000000?ooo`3oool0:03oool:000001h0oooo2`00
000N0?ooo`/000007@3oool;000001d0oooo2`00000N0?ooo`/000007@3oool;000001d0oooo2`00
000M0?ooo`/000007@3oool<000001`0oooo3000000M0?ooo`/000009`3oool2000002T0oooo3000
00000`3oool000000?ooo`0e0?ooo`00M03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00P0oooo2`0000070?ooo`d000006`3oool=000001`0oooo3@00000K0?ooo`d000006`3oool=
000001`0oooo3@00000K0?ooo`d000006`3oool=000001/0oooo3@00000K0?ooo`h000006P3oool>
000001X0oooo3P00000W0?ooo`030000003oool0oooo02D0oooo1`0000070?ooo`030000003oool0
oooo03@0oooo001d0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool40000
00/0oooo4P00000M0?ooo`L000008P3oool:000001h0oooo2P00000N0?ooo`X000007`3oool:0000
01h0oooo2P00000N0?ooo`X000007P3oool:000001h0oooo2P00000N0?ooo`L000008@3oool70000
06@0oooo00<000000?ooo`3oool0=03oool007@0oooo0`00000:0?ooo`8000001@3oool010000000
oooo0?ooo`3ooolB000000030?ooo`000000000000l00000@03oool4000002@0oooo1000000T0?oo
o`@000009@3oool4000002@0oooo1000000T0?ooo`@00000903oool4000002@0oooo1000002e0?oo
o`<00000=P3oool007@0oooo00<000000?ooo`3oool02P3oool3000000<0oooo00<000000?ooo`3o
ool07P0000080?ooo`h00000o`3ooooo0?ooo`P0oooo00<000000?ooo`3oool0=03oool007@0oooo
00<000000?ooo`3oool02P3oool3000000<0oooo00<000000?ooo`0000001000000B0?oooaH00000
203oool>00000?l0oooon@3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?oo
o`0:0?ooo`<000000P3oool00`000000oooo00000002000000<0oooo4`0000080?oooa`000001`3o
ool?00000?l0oooojP3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`09
0?ooo`@000000P3oool400000080oooo0P0000000`3oool000000000000500000080oooo50000008
0?ooob0000001`3oool@00000?l0oooofP3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`00
0000oooo0?ooo`090?ooo`H0000000<0oooo0000000000000P3oool4000000030?ooo`0000000000
02P000001`3ooolR000000P0oooo4000003o0?ooolX0oooo00<000000?ooo`3oool0=03oool007@0
oooo00<000000?ooo`3oool02@3oool9000000050?ooo`00000000000000003oool00P00000J0?oo
oa`00000203ooolT000000T0oooo4000003o0?oookX0oooo00<000000?ooo`3oool0=03oool007@0
oooo00<000000?ooo`3oool02@3oool8000000060?ooo`00000000000000003oool000001P3oool?
00000140oooo7P0000090?ooobH000002P3oool@00000?l0ooooZP3oool00`000000oooo0?ooo`0d
0?ooo`00M03oool00`000000oooo0?ooo`080?ooo`T0000000D0oooo000000000000oooo00000004
0?oooal000003`3ooolP000000X0oooo:000000:0?oooa000000o`3ooole0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool0203oool90000
00040?ooo`0000000000000000<0oooo:`00000@0?ooob4000002`3ooolJ000000030?ooo`000000
000000d000002`3oool@00000?l0oooo903oool3000006<0oooo00<000000?ooo`3oool0=03oool0
07@0oooo00<000000?ooo`3oool0203oool<000000<0oooo=P00000B0?ooob8000002`3ooolJ0000
00<0oooo3`00000<0?oooa400000o`3ooolB0?ooo`@00000=P3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00h0oooo1P0000030?ooo`@0
000000<0oooo0000000000000P00000:0?ooo`8000000`3ooolX000001@0oooo8P00000<0?oooa/0
0000103oool?000000h0oooo4@00003o0?ooo`H00000=03oool2000002`0oooo00<000000?ooo`3o
ool0=03oool007@0oooo0`00000=0?ooo`<0000000@0oooo00000000000000000P3oool7000000L0
oooo2P00000=0?ooobH000005@3ooolS000000h0oooo6P0000060?ooo`l00000403oool@00000>h0
oooo1`00000c0?ooo`@00000:@3oool3000003H0oooo001d0?ooo`030000003oool0oooo00d0oooo
0`000000103oool000000?ooo`0000020?ooo`D000001@3ooolH000000d0oooo9P00000>0?ooo`80
00001`3ooolT00000140oooo6@0000060?ooo`d000004`3ooolA00000;D0oooo00<000000?ooo`3o
ool09P3oool700000340oooo1@00000[0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000
003oool0oooo00d0oooo1P0000020?ooo`D00000103oool3000000D0oooo2`0000050?ooo``00000
3P3ooolU000000@0oooo1000000@0?ooobD000005@3ooolG000000D0oooo300000030?ooo`800000
4`3oool>000000D0oooo0P00000V0?ooo`8000009`3oool2000002H0oooo0P00000W0?ooo`<00000
:03oool6000002h0oooo1`00000W0?ooo`8000000P3oool00`000000oooo0?ooo`0d0?ooo`00M03o
ool00`000000oooo0?ooo`0=0?ooo`H000000P3oool500000080oooo0`0000030?ooo`@000000P3o
oolC000000<0oooo3P0000050?ooo`H000000`3ooolU000001X0oooo9P00000;0?ooo`D00000203o
oolF00000080oooo3000000J0?ooo``000008@3oool5000002@0oooo1@00000S0?ooo`D000008`3o
ool6000002P0oooo1000000]0?ooo`T000008`3oool500000080oooo00<000000?ooo`3oool0=03o
ool007@0oooo00<000000?ooo`3oool03@3oool6000000030?ooo`000000000000<000000`3oool0
10000000oooo0?ooo`3oool2000000H0oooo2`0000080?ooo`X000000`3ooolA000000X0oooo9P00
000H0?ooo`l000000`3ooolN000001H0oooo8000000C0?oooa<000005@3oool800000240oooo1`00
000Q0?ooo`L000008@3oool8000002L0oooo1000000[0?ooo`X00000803oool800000080oooo00<0
00000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool03@3oool6000000030?ooo`000000
000000<000000P3oool00`000000oooo0?ooo`02000000@0oooo6`0000060?ooo`T000000P3oool?
000000d0oooo:000000=0?ooo`/00000103oool<000000@0oooo6@00000H0?ooob@000001@3oool;
000000P0oooo300000090?ooo`/000007@3oool;000001d0oooo2`00000M0?ooo`/000009`3oool2
000002X0oooo2000000P0?ooo`/000000P3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0000000D0000000<0oooo0000000000000P0000020?oo
o`80000000<0oooo0000000000000`3oool2000000d0oooo1000000:0?ooo`P000001`3ooolJ0000
00d0oooo:@0000030?ooo`d000003P3oool<000000030?ooo`000000000001X00000303oool=0000
00L0oooo8P00000B0?oooaH000006`3oool=000001/0oooo3@00000K0?ooo`d000009`3oool00`00
0000oooo0?ooo`0V0?ooo`<00000903oool>000000030?ooo`000000oooo03D0oooo001d0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`0000001@0000000`3oool000000000000200000080
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0S0?ooo`P0000000<0oooo00000000
00003@0000050?ooo``00000203ooolc000001d0oooo2`0000050?ooob<000005`3ooolB00000003
0?ooo`000000000000l00000303ooolA000001L0oooo2P00000N0?ooo`X00000YP3oool:00000003
0?ooo`000000oooo03D0oooo001d0?ooo`030000003oool0oooo00X0oooo0P0000000`3oool00000
00000004000000030?ooo`0000000000008000000P3oool00`000000oooo000000030?ooo`030000
003oool0oooo00L0oooo4000000E0?ooo`P00000203oool9000000D0oooo3000000?0?ooob`00000
5@3oool4000000H0oooo300000050?oooa/000006`3ooolE000000L0oooo4000000=0?ooo`h00000
2@3oool4000002@0oooo1000002b0?ooo`@0000000<0oooo0000003oool0=@3oool007@0oooo00<0
00000?ooo`3oool02P3oool9000000030?ooo`00000000000080000000@0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`050?ooo`<00000403oool6000001L0oooo200000090?ooo`T00000
103oool=000000l0oooo;@00000Q0?ooo`/000001@3ooolM000001h0oooo4@0000090?ooo`X00000
4`3oool;00000>40oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02P3o
ool9000000040?ooo`000000000000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`030?ooo`8000006@3oool8000001L0oooo2000000:0?ooo`T00000103oool<00000100oooo
;`00000Q0?ooo`/000001P3ooolM000001h0oooo4P0000060?ooo`X00000503oool800000=T0oooo
00<000000?ooo`3oool0=03oool007@0oooo0`00000:0?ooo`T0000000@0oooo0000000000000000
0P3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
8@3oool8000001L0oooo2000000;0?ooo`P000001@3oool<00000140oooo<000000Q0?ooo``00000
1P3ooolL000001d0oooo4P0000060?ooo`X000004P3oool900000<h0oooo0`00000f0?ooo`00M03o
ool00`000000oooo0?ooo`090?ooo`X0000000@0oooo00000000000000000P3oool00`000000oooo
000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:P3oool8000001L0oooo
2000000;0?ooo`T000001@3oool<00000180oooo<000000S0?ooo`/000001`3ooolK000001X0oooo
5@0000050?ooo`T000004P3oool800000<P0oooo00<000000?ooo`3oool0=03oool007@0oooo00<0
00000?ooo`3oool02@3oool:000000040?ooo`000000000000000080oooo00D000000?ooo`000000
oooo000000040?ooo`800000=03oool8000001L0oooo2000000<0?ooo`T000001@3oool<000001<0
oooo<@00000S0?ooo``000001P3ooolK000001P0oooo5P0000040?ooo`H00000503oool800000<00
oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02@3oool:000000040?oo
o`000000000000000080oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo
03/0oooo2000000G0?ooo`L000003P3oool8000000D0oooo3000000E0?oooc800000903oool:0000
00L0oooo3`0000000`3oool0000000000008000001L0oooo4`0000040?ooo`H000005P3oool80000
0;P0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02@3oool:00000004
0?ooo`000000000000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo04@0oooo2000000F0?ooo`P000003P3oool9000000D0oooo3000000F0?oooc800000903oool:
000000P0oooo3P0000000`3oool0000000000007000001L0oooo4@0000030?ooo`L000005`3oool6
00000;80oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool0203oool;0000
00040?ooo`000000000000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo04`0oooo2000000F0?ooo`L00000403oool8000000H0oooo3000000G0?oooc<000008`3o
ool:000000T0oooo2`0000020?ooo`P000006@3oool>000000<0oooo1P00000G0?ooo`@000008@3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0
oooo00P0oooo2`0000000`3oool0000000000002000000060?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`1D0?ooo`P000005@3oool800000100oooo200000070?ooo`/00000
5`3ooole000002<0oooo2P0000080?ooo`X000000P3oool9000001P0oooo3P0000000`3oool00000
00000005000001@0oooo1@00000K0?ooo`<00000R`3oool00`000000oooo0?ooo`0d0?ooo`00E@3o
ool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono07@000000000
0P0000000`18W=l0oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo2`0000000`3oool00000
00000002000000060?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`1L0?oo
o`L000005P3oool800000100oooo2@0000060?ooo``000005P3ooolg000002<0oooo2@0000060?oo
o``000000P3oool8000001H0oooo3`0000000`3oool000000000000600000140oooo1@00000E0?oo
o`@00000R`3oool00`000000oooo0?ooo`0d0?ooo`00E03oool01P3OW4P007Bo0?ooo`3ogi`0B000
04RLg`80oooo00<0omnL04P0001d_ol0103oool00`3o_g@0000007Boo`0>0?ooo`030000003oool0
oooo00d0oooo1P0000000`3oool0000000000002000000060?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`1S0?ooo`L000005`3oool700000180oooo200000060?ooo`d00000
5P3ooolh00000280oooo1`0000060?ooo`d000000P3oool6000001H0oooo3P0000040?ooo`D00000
4@3oool5000000l0oooo1P00000e0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
=03oool005<0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?oog`2L
B00007Bo00h0oooo00<000000?ooo`3oool03@3oool6000000030?ooo`00000000000080000000H0
oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo06X0oooo1P00000H0?ooo`P0
00004P3oool8000000H0oooo3P00000E0?ooocX000007`3oool6000000L0oooo3@0000000`3oool0
000000000005000001H0oooo300000040?ooo`@000004P3oool4000000X0oooo1`00000d0?ooo`80
0000E03oool00`000000oooo0?ooo`0d0?ooo`00D`3oool00`3ooml0W4P004RLg`020?ooo`040?oo
g`2LB00004RL0=ooo`P0oooo00<0gia80018W03Oool03@3oool00`000000oooo0?ooo`0=0?ooo`H0
000000<0oooo0000000000000P0000001P3oool000000?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`L000001`3oool00`000000oooo0?ooo`0?
0?ooo`L000004`3oool7000000L0oooo3`00000E0?ooocT000007@3oool7000000L0oooo30000002
0?ooo`L000005P3oool9000000@0oooo1000000B0?ooo`8000002@3oool700000340oooo1@00000W
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0=03oool005<0oooo00<0oooO09a8
0000M;l00`3oool00`3OW4P0001809cOo`080?ooo`030?oOW01804P0W=oo00d0oooo00<000000?oo
o`3oool03@3oool3000000040?ooo`00000000000?ooo`@0000000H0oooo0000003oool000000?oo
o`0000030?ooo`030000003oool0oooo05H0oooo0`00000N0?ooo`X000005P3oool8000000L0oooo
0P0000090?ooo`L000002@3oool?000001@0oooo200000000`3oool0000000000006000000030?oo
o`000000000002<000000`3oool2000001T0oooo1`0000070?ooo`/000000`3oool6000001@0oooo
2@0000040?ooo`@00000403oool3000000P0oooo1@00000`0?ooo`H000009@3oool3000002/0oooo
00<000000?ooo`3oool0=03oool005@0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RL
g`080?ooo`030?oo_`1d0000M;oo00d0oooo1@00000;0?ooo`040000003oool000000?ooo`800000
00<0oooo0000000000000P0000001P3oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool06`3oool<000002`0oooo2000000R0?ooo`P000001`3oool4000000l0oooo2`00000>0?oo
o`P000001@3ooolC000001@0oooo200000000`3oool0000000000004000000<0oooo9000000N0?oo
o`H0000000<0oooo0000000000000P0000020?ooo`/000000`3oool6000000h0oooo3@0000040?oo
o`<00000403oool3000000H0oooo1@00000^0?ooo`P000008P3oool6000002H0oooo1@00000f0?oo
o`00E03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00T0oooo00<0_g@0001d_`3o
ool0303oool00`000000oooo0?ooo`0=0?ooo`060000003oool000000?ooo`000000oooo1@000000
103oool000000000000000020?ooo`040000003oool0oooo000002T0oooo1`00000W0?ooo`L00000
8@3oool>000000D0oooo2000000>0?ooo`P000004P3oool7000000<0oooo5P00000D0?ooo`d00000
0P3ooolT000001l0oooo1`0000070?ooo`X000000`3oool4000000T0oooo200000020?ooo`P00000
0`3oool4000000l0oooo0P0000050?ooo`@00000;@3oool900000200oooo2000000S0?ooo`D00000
0P3oool00`000000oooo0?ooo`0d0?ooo`00E03oool00`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo00P0oooo00<0gia80018W03Oool0303oool00`000000oooo0?ooo`0=0?ooo`040000003o
ool000000?ooo`<0000000D0oooo00000000000000000?ooo`0300000080oooo00D000000?ooo`3o
ool0oooo0000000]0?ooo`H000008`3oool=000001/0oooo2P0000040?ooo`H000001`3oool80000
00D0oooo4@00000A0?ooob0000003P3ooolC000000<0oooo8P00000I0?ooo`X000002P3oool90000
0080oooo1@0000040?ooo`X00000103oool8000000<0oooo0`00000>0?ooo`<00000103oool30000
02X0oooo2@00000P0?ooo`X00000803oool800000080oooo00<000000?ooo`3oool0=03oool005@0
oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`030?oOW01804P0W=oo
00`0oooo00<000000?ooo`3oool02`3oool01P000000oooo0000003oool000000?ooo`<0000000@0
oooo00000000000000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0:`3oool:000001h0oooo300000020?ooo`H00000503oool=000000P0oooo1P0000090?oooa00
00001P3oool700000100oooo2`0000020?oooa@000001`3oool<000000<0oooo2P0000050?ooob00
00004`3oool?000000X0oooo200000030?oooa0000001P3oool7000000<0oooo0`00000>0?ooo`80
00000`3oool2000002T0oooo1P00000R0?ooo`d00000703oool;00000080oooo00<000000?ooo`3o
ool0=03oool005D0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`080?ooo`030?oo
_`1d0000M;oo00`0oooo00<000000?ooo`3oool02`3oool010000000oooo0000003oool500000003
0?ooo`00000000000080000000H0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool06@3oool>000001X0oooo3@0000070?ooo`H000003P3oool>
000000d0oooo1P0000080?ooo`d000002`3oool8000000P0oooo3P0000070?ooob4000002@3oool8
000000L0oooo7P00000=0?ooo`d000000P3oool5000000T0oooo200000030?ooo`d000002@3oool5
000000@0oooo0P00000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool3
000002D0oooo3P00000J0?ooo`d000000P3oool00`000000oooo0?ooo`0d0?ooo`00EP3oool01P3O
W4P0001d0;ooo`3ooml0W4P004RLg`X0oooo00<0_g@0001d_`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`80000000<0oooo0000003oool01@0000000`3oool0000000000002000000060?ooo`00
000000000000003oool00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0
oooo2`0000030?ooo`D00000;`3oool6000002T0oooo1P0000020?ooo`L00000103oool8000000d0
oooo3`0000070?ooo`L00000203ooolB000001L0oooo1`0000040?oooaX0000000<0oooo00000000
00000`0000080?ooo`L000003@3oool5000000P0oooo200000030?ooo`@00000403oool5000000@0
oooo0`00000<0?ooo`030000003oool0oooo07l0oooo1`0000020?ooo`030000003oool0oooo03@0
oooo001G0?ooo`040=nLB00000000000001d_`T0oooo00D0oono07@000000000001d0;ooo`0;0?oo
o`030000003oool0oooo00X0oooo0`0000000`3oool0000000000004000000030?ooo`0000000000
008000000P3oool200000080oooo00D000000?ooo`3oool0oooo0000000?0?ooo`8000006`3oool7
000000`0oooo1000000a0?ooo`H00000:@3oool6000000l0oooo2000000=0?ooo`H000003`3oool7
000000P0oooo4@00000G0?ooo`L000001`3ooolL000001`0oooo100000090?ooo`H00000103oool3
000000l0oooo1@0000050?ooo`8000002`3oool2000008P0oooo00<000000?ooo`3oool0=03oool0
07@0oooo00<000000?ooo`3oool02P3oool3000000030?ooo`000000000000@0000000<0oooo0000
000000000P0000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`0=
0?ooo`<000006P3oool3000001@0oooo1@00000b0?ooo`H00000:@3oool600000140oooo1P00000=
0?ooo`D000004@3oool6000000X0oooo3`00000G0?ooo`L000001P3ooolM000001X0oooo0`00000:
0?ooo`D00000103oool3000000h0oooo1@0000050?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0:0?oo
o`<0000000<0oooo000000000000100000020?ooo`@0000000H0oooo0000003oool000000?ooo`00
00030?ooo`030000003oool0oooo00d0oooo0`00000f0?ooo`@00000=03oool6000002T0oooo1P00
000A0?ooo`D000003@3oool600000140oooo1P00000;0?ooo`h000005`3oool7000000H0oooo6`00
000I0?ooo`@000002P3oool3000000D0oooo0`00000=0?ooo`D00000103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0=03oool007@0oooo00<00000
0?ooo`3oool02@3oool4000000030?ooo`000000000000@000000P3oool4000000040?ooo`000000
000000000080oooo00D000000?ooo`3oool0oooo0000000>0?ooo`<00000>P3oool5000003D0oooo
1P00000Y0?ooo`H00000403oool5000000h0oooo1@00000B0?ooo`D00000303oool>000001L0oooo
1`0000050?oooaX000006@3oool3000000T0oooo0`0000060?ooo`8000003@3oool2000000030?oo
o`000000oooo00<0oooo0P00000:0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0
=03oool007@0oooo00<000000?ooo`3oool02@3oool;00000080oooo100000020?ooo`8000000P3o
ool01@000000oooo0?ooo`3oool0000000d0oooo1000000o0?ooo`@00000=`3oool5000002X0oooo
1P00000?0?ooo`D000003P3oool500000180oooo1P00000:0?oooa0000005`3oool7000000@0oooo
6@00000H0?ooo`8000002@3oool3000000H0oooo0P00000=0?ooo`@00000103oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0=03oool007@0oooo0`00
00090?ooo`X0000000<0oooo0000003oool0100000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`0;0?ooo`@00000@`3oool5000003L0oooo1P00000Z0?ooo`H00000
3P3oool5000000h0oooo1P00000B0?ooo`H000002@3oool4000000030?ooo`000000000000T00000
5P3oool7000000@0oooo6@00000F0?ooo`<00000203oool4000000D0oooo00<000000?ooo`3oool0
303oool3000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`210?ooo`<00000
=P3oool007@0oooo00<000000?ooo`3oool02@3oool<000000030?ooo`0000000000008000000P3o
ool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000303oool4000004P0oooo
1000000i0?ooo`H00000:P3oool6000000d0oooo1@00000?0?ooo`D000004`3oool5000000P0oooo
1@0000020?ooo`T000005P3oool7000000@0oooo400000001@3oool00000000000000000oooo00<0
00005P3oool300000080oooo00<000000?ooo`3oool00P3oool4000000@0oooo0P00000=0?ooo`<0
0000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3o
ool0=03oool007@0oooo00<000000?ooo`3oool0203oool7000000030?ooo`000000oooo00<00000
00<0oooo0000000000000`000000103oool000000000000000020?ooo`050000003oool0oooo0?oo
o`000000303oool5000004/0oooo1@00000j0?ooo`H00000:P3oool5000000d0oooo1P00000>0?oo
o`D000004`3oool5000000P0oooo100000040?ooo`P000005P3oool7000000<0oooo6000000E0?oo
o`<000001P3oool4000000@0oooo00<000000?ooo`3oool02P3oool4000000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo03@0oooo001d0?ooo`03
0000003oool0oooo00P0oooo1`0000000`3oool000000000000300000080oooo100000020?ooo`05
0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`080?ooo`H00000A`3oool00`00
0000oooo0?ooo`060?ooo`@00000?03oool5000002X0oooo1P00000=0?ooo`D000003P3oool50000
01<0oooo1@0000070?ooo`@000001P3oool7000001D0oooo1`0000030?ooo`l0000000<0oooo0000
000000001@00000@0?ooo`H000001`3oool4000000<0oooo0P00000;0?ooo`<00000103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`080?ooo`L0000000<0oooo00000000
00000`0000020?ooo`@000000P3oool00`000000oooo000000020?ooo`050000003oool0oooo0?oo
o`0000002P3oool6000004H0oooo0`00000;0?ooo`D00000?03oool4000002`0oooo1P00000<0?oo
o`D000003P3oool5000001<0oooo1P0000050?ooo`@000001`3oool6000001D0oooo1`0000020?oo
o`h000000`3oool2000000030?ooo`000000000000d0oooo2@0000070?ooo`<00000103oool00`00
0000oooo0?ooo`090?ooo`<000000`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo
0?ooo`<00000O`3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0000000@000000P3oool400000080oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0580oooo1000000@0?ooo`@00000?03oool50000
02d0oooo1@00000<0?ooo`D000003P3oool5000001@0oooo1P0000030?ooo`@000001P3oool60000
01D0oooo0`0000000`3oool00000000000030?ooo`h000000P3oool2000000040?ooo`0000000000
000000/0oooo1P0000020?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`8000002@3oool4
00000080oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool4000007h0oooo00<0
00000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool03P3oool00`000000oooo00000004
00000080oooo100000020?ooo`80000000D0oooo0000003oool0oooo000000030?ooo`030000003o
ool0oooo0540oooo1P00000C0?ooo`@000002P3oool00`000000oooo0?ooo`0`0?ooo`D00000;@3o
ool4000000d0oooo1@00000>0?ooo`D00000503oool4000000@0oooo100000050?ooo`H000004@3o
ool9000000@0oooo3P0000000`3oool00000000000020?ooo`8000002P3oool5000000<0oooo0P00
00070?ooo`800000103oool00`000000oooo0?ooo`080?ooo`<000000P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H00000:03oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo03@0oooo001d0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`00000010000002
0?ooo`D000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0C`3oool7000001L0oooo1@0000050?ooo`<000009@3oool00`000000oooo0?ooo`0=
0?ooo`@00000;@3oool4000000h0oooo1000000?0?ooo`D000003P3oool8000000D0oooo10000004
0?ooo`L000003@3oool6000000030?ooo`000000000000800000103oool>000000030?ooo`000000
00000080oooo0P0000090?ooo`@000001@3oool00`000000oooo0?ooo`050?ooo`800000103oool0
0`000000oooo0?ooo`070?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo0?ooo`L000009@3oool3000005@0oooo00<000000?ooo`3oool0=03oool007@0oooo00<00000
0?ooo`3oool03`3oool600000080oooo1@0000020?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo0000001B0?ooo`L000006`3oool9000002@0oooo0`00000A0?ooo`@00000
403oool2000001/0oooo1@0000060?ooo`8000001@3oool400000100oooo1000000:0?ooo`H00000
0P3oool4000000D0oooo100000030?ooo`<0000000@0oooo00000000000000002@3oool800000080
oooo1@0000040?ooo`d0000000<0oooo0000003oool00P3oool2000000P0oooo100000050?ooo`80
00001P3oool2000000<0oooo00<000000?ooo`3oool01`3oool300000080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`3oool7000002D0oooo1@00000V0?ooo`8000009P3oool20000
00<0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool03`3oool500000004
0?ooo`000000oooo0?ooo`@000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0D@3oool6000001h0oooo1`00000R0?ooo`D000004`3oool4
000000`0oooo1000000N0?ooo`@000000P3oool4000000L0oooo1000000@0?ooo`@000001@3oool8
000000D0oooo0`0000060?ooo`@000000P3oool3000000040?ooo`0000000000000000D0oooo2@00
00040?ooo`80000000<0oooo000000000000103oool?000000<0oooo00<000000?ooo`3oool01@3o
ool4000000H0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3oool01P3o
ool300000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06000002H0oooo1P00
000T0?ooo`@00000903oool4000000<0oooo00<000000?ooo`3oool0=03oool007@0oooo00<00000
0?ooo`3oool03`3oool3000000040?ooo`000000000000000080oooo100000020?ooo`8000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0580oooo1000000N0?ooo`T00000
7`3oool8000001D0oooo100000080?ooo`H00000803oool8000000T0oooo1000000@0?ooo`@00000
00<0oooo0000000000001`0000070?ooo`<000001`3oool300000080oooo0`000000103oool00000
0000000000040?ooo`P000001@3oool5000000@0oooo3P0000030?ooo`030000003oool0oooo00D0
oooo0`0000070?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo00H0
oooo0`0000000`3oool000000?ooo`040?ooo`040000003oool0oooo0?ooo`@000009P3oool90000
0240oooo1P00000R0?ooo`H000000`3oool00`000000oooo0?ooo`0d0?ooo`00M03oool3000000/0
oooo00@000000?ooo`3oool0oooo0`000000103oool000000000000000020?ooo`D000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0D`3o
ool4000001`0oooo3000000M0?ooo`X000005`3oool4000000<0oooo2@00000O0?ooo`T000002`3o
ool400000100oooo0P0000000`3oool0000000000007000000P0oooo0`0000070?ooo`<000000P3o
ool6000000D0oooo1P0000070?ooo`@000001@3oool=00000080oooo0P0000060?ooo`8000001`3o
ool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`8000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@000009P3oool:000001l0oooo2@00
000O0?ooo`P0000000@0oooo0000000000000000=P3oool007@0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`3oool3000000040?ooo`000000000000000080oooo1@0000020?ooo`80
000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05@0
oooo0P00000L0?ooo`l000006P3oool<000001T0oooo3P00000M0?ooo`/000003@3oool4000000h0
oooo0`0000020?ooo`H000002P3oool3000000L0oooo0P0000040?ooo`@000001P3oool4000000P0
oooo100000050?ooo``000000`3oool00`000000oooo0?ooo`040?ooo`8000001`3oool00`000000
oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`8000000P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000009P3oool900000200oooo2`00000M0?oo
o`/000000P3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0;0?ooo`80
00000P3oool010000000oooo0000003oool300000080oooo1P0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`8000009`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0200oooo1`0000000`3oool0000000000002
000001H0oooo3@00000K0?ooo`d000006`3oool?000000d0oooo0`00000>0?ooo`800000103oool3
000000`0oooo0P0000070?ooo`8000001@3oool3000000L0oooo0P0000090?ooo`<000001P3oool8
000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`030000003oool0oooo00D0oooo0`000000
0`3oool000000?ooo`040?ooo`040000003oool0oooo000002L0oooo1000000T0?ooo`d000006`3o
ool=00000080oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02P3oool3
00000080oooo00<000000?ooo`000000100000030?ooo`D000000P3oool2000000030?ooo`000000
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`800000O@3oool3
000003/0oooo2@00000O0?ooo`L00000203oool4000000`0oooo1000000<0?ooo`<000004P3oool2
000000L0oooo0P0000050?ooo`<000004P3oool3000000D0oooo2@0000001@3oool000000000003o
ool0000000h0oooo00<000000?ooo`3oool00`3oool2000000<0oooo00<000000?ooo`3oool0103o
ool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1o0?ooo`L000000P3o
ool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0:0?ooo`<000000P3oool0
0`000000oooo00000003000000040?ooo`000000oooo0?ooo`D000000`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool4000007h0oooo
0P0000120?ooo`<00000;`3oool3000000d0oooo1000000;0?ooo`8000004P3oool2000000L0oooo
0P0000050?ooo`<000004@3oool00`000000oooo000000050?ooo`<0000000<0oooo000000000000
0`0000001@3oool000000?ooo`3oool0000000h0oooo00<000000?ooo`3oool00P3oool2000000<0
oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00X0oooo
100000000`3oool000000?ooo`02000000040?ooo`000000000000000080oooo1P0000020?ooo`80
000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo1@00001n0?ooo`<00000@P3oool3000002l0oooo0`00000>0?ooo`8000002`3oool300000140
oooo0P0000070?ooo`<00000103oool300000100oooo00<000000?ooo`0000001@3oool800000080
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`00
0000oooo0?ooo`040?ooo`<0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00X0oooo100000000`3oool0
00000?ooo`02000000040?ooo`000000000000000080oooo1P0000030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`H00000O`3oool2
000004<0oooo1000000^0?ooo`<000003@3oool2000000`0oooo0P00000A0?ooo`800000203oool2
000000<0oooo00<000000?ooo`000000403oool3000000D0oooo200000001@3oool000000?ooo`3o
ool0000000d0oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool0103o
ool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`0d0?ooo`00M03oool00`000000oooo0?ooo`0:0?ooo`@0000000<0oooo0000003oool00P000000
103oool000000000000000030?ooo`D000000`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool8000007l0oooo0`0000140?ooo`<00000
;P3oool2000000d0oooo0P00000<0?ooo`8000004@3oool2000000P0oooo0P0000020?ooo`040000
003oool0000000000100oooo0P0000040?ooo`P000000P3oool00`000000oooo0000000<0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool200000080oooo00<000000?oo
o`3oool00P00002>0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00X0
oooo1P000000103oool000000000003oool3000000<0oooo1P0000020?ooo`8000000P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool800000840oooo0P000015
0?ooo`<00000;@3oool2000000d0oooo0P00000<0?ooo`8000004@3oool2000000P0oooo00<00000
0?ooo`3oool00P0000000`3oool000000?ooo`0?0?ooo`800000103oool00`000000oooo00000005
000000050?ooo`000000oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000H0oooo0P0000020?ooo`040000003oool0oooo00000900oooo00<000000?ooo`3o
ool0=03oool007@0oooo00<000000?ooo`3oool02@3oool7000000040?ooo`00000000000?ooo`80
000000@0oooo0000003oool0oooo1P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo1P0000240?ooo`<00000A@3oool3
000002`0oooo0`00000<0?ooo`800000303oool200000140oooo0P0000070?ooo`070000003oool0
oooo0?ooo`000000oooo0000000?0?ooo`030000003oool0000000@0oooo0P0000000`3oool00000
0000000400000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000D0oooo0P0000020?ooo`040000003oool0oooo00000940oooo00<000000?oo
o`3oool0=03oool007@0oooo00<000000?ooo`3oool02@3oool7000000040?ooo`00000000000?oo
o`@000000P3oool4000000030?ooo`00000000000080oooo0P0000020?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`030?ooo`@00000K03oool7000001D0oooo0P00000;
0?ooo`030000003oool0oooo03P0oooo0P00000]0?ooo`800000303oool2000000`0oooo0P00000A
0?ooo`030000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool0000000l0oooo
0P0000040?ooo`T000000P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`8000000P3oool010000000oooo0?ooo`00002B0?oo
o`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00T0oooo1`0000000`3oool0
0000000000020?ooo`<000000`3oool6000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool3000006d0oooo1`00000G0?oo
o`8000001`3oool3000003`0oooo0P00000]0?ooo`8000002@3oool5000000`0oooo0P00000@0?oo
o`030000003oool0oooo00@0oooo2@00000=0?ooo`030000003oool0000000<0oooo2@0000020?oo
o`030000003oool0oooo00P0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`04
0?ooo`8000000P3oool010000000oooo00000000002C0?ooo`030000003oool0oooo03@0oooo001d
0?ooo`<000002@3oool7000000030?ooo`00000000000080oooo0`0000030?ooo`@0000000<0oooo
0000003oool00P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0L
0?ooo`H000006P3oool300000080oooo1@00000T0?ooo`030000003oool0oooo01L0oooo0`00000;
0?ooo`030000003oool0oooo01h0oooo0P0000050?ooo`D000000P3oool2000000`0oooo0P00000?
0?ooo`030000003oool0oooo00<0oooo1`0000000`3oool000000?ooo`0<0?ooo`030000003oool0
000000<0oooo2@0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`80000000D0oooo000000000000oooo0000002C0?ooo`<00000
=P3oool007@0oooo00<000000?ooo`3oool0403oool4000000040?ooo`0000000000000000<0oooo
100000000`3oool00000000000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0500oooo0`00000N0?ooo`D000007@3oool800000280
oooo0`00000K0?ooo`800000203oool300000240oooo00<000000?ooo`3oool01`0000040?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`H0
00000P3oool00`000000oooo0?ooo`0;0?ooo`8000000`3oool9000000030?ooo`000000oooo00P0
oooo0`0000020?ooo`80000000<0oooo0000003oool00`3oool2000000030?ooo`000000oooo0080
0000UP3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0@0?ooo`@00000
00D0oooo000000000000oooo000000020?ooo`030000003oool0000000@000000`3oool2000000<0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo04l0oooo1000000M0?oo
o`D000007`3oool600000200oooo1@00000M0?ooo`8000001@3oool400000280oooo0P0000000`3o
ool0000000000005000000@0oooo00<000000?ooo`3oool02`3oool2000000h0oooo00<000000?oo
o`3oool00P3oool5000000040?ooo`000000oooo000000d0oooo0P0000030?ooo`L0000000@0oooo
0000003oool000002@3oool6000000030?ooo`000000oooo00<0oooo0P000000103oool000000?oo
o`00002H0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo0100oooo1000
00001@3oool000000000003oool0000000<0oooo100000000`3oool00000000000030?ooo`800000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
C@3oool6000001`0oooo1@00000P0?ooo`D000007`3oool7000001h0oooo0P0000020?ooo`H00000
8`3oool00`000000oooo00000005000000D0oooo0P00000=0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool5000000050?ooo`000000oooo0?ooo`000000303oool2000000<0
oooo200000000`3oool000000?ooo`080?ooo`H0000000<0oooo0000003oool00`3oool200000004
0?ooo`000000oooo000001`0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0d0?oo
o`00M03oool00`000000oooo0?ooo`0@0?ooo`@0000000<0oooo0000000000000P0000030?ooo`L0
00000`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo04`0oooo1`00000K0?ooo`@000008P3oool4000001h0oooo2000000P0?ooo`P0
0000903oool00`000000oooo00000004000000L0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0<0?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo0000000<0?oo
o`8000000`3oool8000000030?ooo`000000oooo00P0oooo1`0000030?ooo`<0000000@0oooo0000
0000000000006`3oool3000007`0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?oo
o`3oool0403oool010000000oooo0000000000020?ooo`<000000`3oool00`000000oooo00000002
000000030?ooo`000000oooo00<0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool2000004/0oooo1`00000M0?ooo`<000008`3oool5000001d0oooo2000000Q
0?ooo`L00000903oool6000000P0oooo0P00000;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00P3oool400000080oooo00<000000?ooo`000000303oool2000000<0oooo1`000000
0`3oool000000?ooo`080?ooo`L000000`3oool6000001`0oooo1@00000V0?ooo`800000D`3oool0
0`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0@0?ooo`040000003oool00000
00000080oooo0`0000030?ooo`030000003oool0000000D000000`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo0P0000080?ooo`030000003oool0oooo04L0oooo1P00000O
0?ooo`<000008`3oool4000000030?ooo`000000000001d0oooo1`00000R0?ooo`H000009@3oool4
000000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo0?ooo`@000000`3oool2000000/0oooo0P0000030?ooo`H0000000<0oooo0000000000002@3o
ool7000000<0oooo0P000000103oool0000000000000000L0?ooo`H00000903oool4000002H0oooo
0P00000V0?ooo`8000000`3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?oo
o`0@0?ooo`040000003oool0000000000080oooo0P0000000`3oool000000?ooo`020?ooo`L00000
103oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`800000
9`3oool2000001h0oooo1000000Q0?ooo`<00000903oool3000000<0oooo00<000000?ooo`3oool0
703oool5000002@0oooo1000000V0?ooo`<000002P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00/0oooo00@000000?ooo`3oool0oooo100000030?ooo`8000002`3oool200000080
oooo200000000`3oool000000?ooo`070?ooo`L000000P3oool6000001`0oooo2000000R0?ooo`H0
00008`3oool5000002<0oooo1@0000030?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000020?ooo`80
000000<0oooo0000003oool00P3oool00`000000oooo00000005000000@0oooo0P0000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`H0
00007@3oool400000280oooo0P00000V0?ooo`800000103oool00`000000oooo0?ooo`0M0?ooo`@0
0000903oool4000002H0oooo0`0000090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`04000000<0oooo0P00000:0?ooo`8000000`3oool600000003
0?ooo`000000000000P0oooo1P0000030?ooo`H00000703oool:000001l0oooo2@00000P0?ooo`L0
00008@3oool7000000<0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`040000003oool0000000000080oooo0P0000000`3oool0
00000?ooo`030?ooo`L000001@3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`070?ooo`800000703oool:000001d0oooo0P00000U0?ooo`030000003oool0oooo02D0
oooo0P0000040?ooo`8000007`3oool2000002H0oooo0P00000V0?ooo`<000002P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00<000000?ooo`0000002P3oool200000080oooo200000000`3oool000000?ooo`05
0?ooo`80000000<0oooo0000000000000P0000030?ooo`D00000703oool<000001d0oooo2`00000M
0?ooo`/000007@3oool:000000<0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`020?ooo`040000003oool0000000000080oooo10000004
0?ooo`P00000103oool2000000@0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0
oooo00P0oooo0P00000H0?ooo``00000703oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo02@0oooo0P00000V0?ooo`8000002`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00/0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo0P00000:0?ooo`800000
0`3oool7000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0100000020?ooo`@00000
00<0oooo0000003oool06`3oool700000240oooo3@00000K0?ooo`d000006`3oool=00000080oooo
00<000000?ooo`3oool0=03oool007@0oooo0`00000:0?ooo`<000000`3oool00`000000oooo0000
000200000080oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0000000D000001@3o
ool2000000@0oooo00<000000?ooo`3oool01P00000:0?ooo`<000005`3oool:000007D0oooo0P00
00160?ooo`8000009P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo008000002P3o
ool200000080oooo00<000000?ooo`0000000`0000000`3oool00000000000060?ooo`030000003o
ool0oooo00@000000P3oool6000007<0oooo1`00000N0?ooo`d00000=P3oool007@0oooo00<00000
0?ooo`3oool02P3oool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`80000000<0oooo
0000003oool00`3oool8000000D0oooo0P0000040?ooo`030000003oool0oooo00H00000303oool2
000001T0oooo1P00001g0?ooo`800000AP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P0000090?ooo`8000000P3oool6000000030?ooo`000000
000000H0oooo00<000000?ooo`3oool00`0000020?ooo`@0000000<0oooo0000003oool0W`3oool4
00000080oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02P3oool30000
00<0oooo00<000000?ooo`0000000P0000020?ooo`80000000<0oooo0000003oool00`3oool00`00
0000oooo00000005000000H0oooo0P0000040?ooo`030000003oool0oooo00P000002`3oool20000
01/0oooo0P00001i0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo008000002P3oool00`000000oooo0?ooo`060000
00030?ooo`000000000000H0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`H00000Y`3o
ool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0:0?ooo`<00000103oool4
00000080oooo0P0000000`3oool000000?ooo`040?ooo`P000001P3oool2000000@0oooo00<00000
0?ooo`3oool02@00000;0?ooo`<00000T`3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000T0oooo0P000000
0`3oool000000?ooo`07000000D0oooo0P0000000`3oool0000000000002000000030?ooo`000000
00000080000000<0oooo0000003oool0Z03oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`00
0000oooo0?ooo`0:0?ooo`@000000`3oool2000000040?ooo`000000oooo0?ooo`8000000P3oool0
0`000000oooo0?ooo`020?ooo`P000001P3oool2000000D0oooo00<000000?ooo`3oool01`00000?
0?ooo`800000TP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`02000000X0oooo00<000000?ooo`3oool01P000000
0`3oool000000?ooo`040?ooo`030000003oool0oooo00<000000P3oool3000000030?ooo`000000
00000:X0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02P3oool40000
00<0oooo0P000000103oool000000?ooo`3oool3000000030?ooo`000000oooo00@0oooo20000006
0?ooo`8000001@3oool00`000000oooo0?ooo`08000000l0oooo0`00002?0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`06000000030?ooo`000000oooo00@0oooo00<0
00000?ooo`0000000`0000001@3oool00000000000000000oooo00800000[03oool00`000000oooo
0?ooo`0d0?ooo`00E@3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo
00<0gia80000000000000`0000000`18W=l0oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
1@0000030?ooo`040000003oool00000000000<0oooo0P0000000`3oool000000?ooo`040?ooo`H0
000000<0oooo0000000000001P3oool2000000D0oooo00<000000?ooo`3oool0100000030?ooo`03
0000003oool0oooo00l0oooo0P00002>0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool01P0000000`3oool000000?ooo`030?ooo`H000000P3oool500000:h0oooo00<000000?oo
o`3oool0=03oool005@0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo1@0000030?ooo`040000003oool00000000000<0oooo0P0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`000000100000000`3oool000000?ooo`060?ooo`8000001@3o
ool2000000040?ooo`0000000000000000@0oooo0P00000A0?ooo`<00000S03oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`02000000P0oooo2@0000000`3oool00000000000040?ooo`030000003oool0000000800000
0P3oool500000;00oooo00<000000?ooo`3oool0=03oool005<0oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo00h0oooo00<000000?ooo`3oool02@3o
ool600000080oooo00<000000?ooo`0000000P0000020?ooo`8000000P3oool00`000000oooo0?oo
o`030?ooo`T000001`3oool2000000H0oooo00<000000?ooo`0000001`3oool200000180oooo1@00
00270?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo00000006000000030?oo
o`000000oooo00@0oooo1@0000000`3oool000000000000300000;80oooo00<000000?ooo`3oool0
=03oool004X0oooo00<0_ibL0=ooo`3oool01P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2L
B00004RL0=ooo`P0oooo00<0okmd001d_`3oool03@3oool00`000000oooo0?ooo`090?ooo`H00000
0P3oool00`000000oooo0000000200000080oooo0P0000020?ooo`030000003oool0oooo00<0oooo
1`0000000`3oool00000000000070?ooo`8000001P3oool2000000T0oooo00<000000?ooo`3oool0
503oool600000840oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo0240oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?oo
o`8000001`3oool;000000@0oooo1@0000020?ooo`@00000]03oool00`000000oooo0?ooo`0d0?oo
o`00B03oool0103ookl0M0000018W03Oool70?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000
B02Lgol02@3oool00`3o_g@0B9cO0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`0000000P0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool70000
00030?ooo`000000000000L0oooo0P0000070?ooo`800000203oool2000001X0oooo1P00001k0?oo
o`030000003oool0oooo01/0oooo0`00000U0?ooo`<000008@3oool010000000oooo0?ooo`3oool3
000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`050000003oool0
oooo0?ooo`0000000`3oool2000000H0oooo0`0000000`3oool0000000000005000000D0oooo1@00
00000`3oool000000000000300000;D0oooo00<000000?ooo`3oool0=03oool004@0oooo00<0oono
07@0000000000`0000000`00B9`0gooo0?ooo`070?ooo`030;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`0;0?ooo`D000003`3oool00`000000oooo00000002
000000<0oooo0P0000020?ooo`030000003oool0oooo00<0oooo1`0000020?ooo`030000003oool0
oooo00H0oooo0P0000080?ooo`030000003oool0oooo00L0oooo0P00000N0?ooo`l00000>03oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool4
000001`0oooo00<000000?ooo`3oool01@3oool400000200oooo00@000000?ooo`3oool0oooo1@00
00000`3oool000000?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo00000002000000H0oooo2`0000040?ooo`D0000000<0oooo0000000000000`00
002c0?ooo`D00000=P3oool003h0oooo00@0oono09bLg`3ookl0M000100000001P00M;l0oooo0?oo
o`3oool0_ibL0=ooo`P0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`03
0;md001d_ol0oooo00X0oooo00<000000?ooo`3oool04@3oool01@000000oooo0000003oool00000
00<0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001@0000000`3o
ool00000000000090?ooo`8000004P3oool200000680oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool60000
01/0oooo00<000000?ooo`3oool0103oool6000001h0oooo00@000000?ooo`3oool0oooo20000008
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000002
000000H0oooo2P0000040?ooo`D0000000<0oooo0000000000000`00002i0?ooo`030000003oool0
oooo03@0oooo000n0?ooo`050?oOW0180000000000000000M;l00`3oool00`2oM7@0_ooo0?ooo`0;
0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool02P3oool00`3ogi`0B01d0;ooo`0:
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`00000000000`3oool2000000<0oooo00<0
00000?ooo`3oool00`3oool8000000030?ooo`000000000000T0oooo0P00000C0?ooo`<00000GP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05@3oool7000001X0oooo00<000000?ooo`3oool0103o
ool7000001d0oooo00@000000?ooo`3oool0oooo200000070?ooo`030000003oool0oooo00L0oooo
00@000000?ooo`3oool0oooo0P0000000`3oool00000000000060?ooo`/000000`3oool200000003
0?ooo`000000000000H000005@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo03@0
oooo000o0?ooo`030?oo_`1dB9`0gooo00@0oooo00<0gibL0;ooo`3oool02`3oool0103ooml0W4P0
0018W03Oool20?ooo`030=nLB000B9`0gooo00X0oooo00<0oooO09a8001d_ol02P3oool00`000000
oooo0?ooo`0B0?ooo`040000003oool00000000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000D000000P3oool2000000T0oooo0P00000E0?oo
o`<00000F@3oool2000000H0oooo0`00000T0?ooo`D00000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01@0oooo1`00000K0?ooo`030000003oool0oooo00<0oooo1`00000M0?oo
o`040000003oool0oooo0?ooo`P000001`3oool00`000000oooo0?ooo`060?ooo`8000000`3oool0
0`000000oooo0?ooo`02000000H0oooo0P0000000`3oool0000000000005000000@0oooo00<00000
0?ooo`0000001@0000000`3oool000000?ooo`0E0?ooo`<000009`3oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo03@0oooo000n0?ooo`030?oog`2LB7@0_ooo00@0oooo00<0oono07Ad
_`3oool03@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00X0oooo00<0oono07@0
0018W=l02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool00000008000000P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00@0oooo200000020?ooo`030000003oool0oooo
00P0oooo0P00000G0?ooo`<00000E@3oool00`000000oooo0?ooo`050?ooo`D000008P3oool60000
00<0oooo0P0000030?ooo`030000003oool0oooo01D0oooo1@00000M0?ooo`030000003oool0oooo
00<0oooo1@00000O0?ooo`040000003oool0oooo0?ooo`L000001`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P0000060?ooo`X000000`3oool;
000001D0oooo1@00000U0?ooo`<000009`3oool2000002H0oooo0P00000[0?ooo`030000003oool0
oooo03@0oooo000n0?ooo`030?oOW01dW=l0oooo00<0oooo00<0oono07@0M02oool03`3oool01P3O
W4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool000000080
00000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00001@0000030?ooo`030000003oool0oooo00P0oooo0`00000H0?ooo`<00000D03oool2000000L0
oooo1P00000Q0?ooo`P0000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0D0?ooo`D0
00007@3oool00`000000oooo0?ooo`030?ooo`D000007`3oool010000000oooo0?ooo`3oool70000
00L0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000
000000H0oooo6000000F0?ooo`L000008P3oool6000002@0oooo1000000T0?ooo`@000009P3oool2
000000<0oooo00<000000?ooo`3oool0=03oool003h0oooo00P0okmd001d_`3oool0oooo0?oog`2L
B000001d0;oooa40oooo00@0gia800000000000007Bo2@3oool01@3ogi`0B000000000000000M;oo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool00000
008000000`3oool300000080oooo00<000000?ooo`3oool0103oool800000080oooo0P00000;0?oo
o`8000006P3oool3000003<0oooo0P00000E0?ooo`<000001`3oool800000200oooo2@0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo01@0oooo1000000M0?ooo`030000003oool0oooo
00@0oooo1000000O0?ooo`030000003oool0oooo0080oooo100000000`3oool000000?ooo`060?oo
o`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo008000001P3ooolG0000
01L0oooo2000000Q0?ooo`L000008P3oool600000280oooo1P00000S0?ooo`D000000`3oool00`00
0000oooo0?ooo`0d0?ooo`00?`3oool01@2oM00000000000000004P0W=oo0300oooo00<000000?oo
o`3oool02P3oool2000000H0oooo00<000000?ooo`0000000P0000030?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool0103oool00`000000oooo00000005000000<0oooo0P00000;0?oo
o`800000703oool4000002/0oooo1P00000A0?ooo`@000002@3oool:000001d0oooo2@0000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool3000001l0oooo00<000000?oo
o`3oool00`3oool300000200oooo00<000000?ooo`3oool00P3oool300000080oooo00<000000?oo
o`3oool0103oool2000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000020000
00D0oooo2`0000020?ooo`X000005`3oool;000001h0oooo2@00000P0?ooo`P00000803oool80000
0240oooo1`0000030?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00X0
oooo0`0000050?ooo`030000003oool00000008000000`3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00@0oooo200000030?ooo`8000002`3oool3000001h0oooo1`00000P0?ooo`X0
00003@3oool4000000/0oooo3000000L0?ooo`H000001P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01D0oooo0P00000O0?ooo`030000003oool0oooo00@0oooo0`00000O0?ooo`03
0000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000000000D0oooo2P0000030?oo
o`X00000603oool9000001l0oooo3000000M0?ooo`/000007@3oool;000001d0oooo2`0000020?oo
o`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00X0oooo0`0000050?ooo`03
0000003oool0oooo008000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000001P0000030?ooo`800000303oool2000001T0oooo4@00000G0?ooo`d0
00001P3oool7000000h0oooo1`00000Q0?ooo`<000002@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000001l0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`0000000P0000040?oo
o`X000000`3oool:000001T0oooo1000000T0?ooo`d000006`3oool=000001/0oooo3@00000K0?oo
o`d000000P3oool00`000000oooo0?ooo`0d0?ooo`00A03oool0103ookl0M0000000M02oool/0?oo
o`030000003oool0oooo00X0oooo0`0000050?ooo`030000003oool0oooo00<000000P3oool01000
0000oooo0000000000030?ooo`030000003oool0oooo00@0oooo0P0000000`3oool0000000000004
000000<0oooo0`00000;0?ooo`<00000603oool<000000@0oooo2000000A0?oooa400000B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool0oooo1P0000040?ooo`T000000`3oool:00000740oooo1`00
000Q0?ooo`L000008@3oool700000080oooo00<000000?ooo`3oool0=03oool003h0oooo00@0oono
09bLg`3ookl0M000100000000`1d_ol0oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo1000
00050?ooo`030000003oool0oooo00<000000`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`0000001`0000020?ooo`@000002`3oool4000001P0oooo2@00
000=0?oooa`00000C@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`8000001`3oool2000000H0oooo0P00
00070?ooo`030000003oool0oooo0080000000@0oooo0000003oool00000103oool9000000<0oooo
2P00003<0?ooo`030000003oool0oooo03@0oooo000n0?ooo`060?oOW018000000000000000004P0
W=oo<03oool3000000T0oooo1@0000040?ooo`030000003oool0oooo00<000000`3oool00`000000
oooo000000030?ooo`030000003oool0oooo00D0oooo0P0000000`3oool000000000000500000080
oooo1000000<0?ooo`@00000603oool7000002H0oooo0`00001;0?ooo`800000103oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool200000080
oooo00<000000?ooo`0000000`0000030?ooo`T00000103oool900000<`0oooo0`00000f0?ooo`00
?`3oool00`3ookl0M00007Boo`0b0?ooo`030000003oool0oooo00T0oooo1@0000040?ooo`030000
003oool0oooo00<000000`3oool010000000oooo0000000000030?ooo`030000003oool0oooo00D0
oooo0P0000000`3oool0000000000005000000030?ooo`000000000000<000003@3oool4000001P0
oooo1000001c0?ooo`800000103oool2000003T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0P0000070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P000000103oool000000000000000030?ooo`T00000103oool80000
0=40oooo00<000000?ooo`3oool0=03oool003l0oooo00<0_gAd0;ooo`3oool0<P3oool00`000000
oooo0?ooo`090?ooo`D000001@3oool00`000000oooo00000002000000<0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`050?ooo`040000003oool000000?ooo`D0000000<0oooo
0000003oool01P00000=0?ooo`@00000603oool200000740oooo0P0000050?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool01@3oool2000001`0oooo0P0000070?ooo`030000003oool0
oooo00D0oooo0P0000060?ooo`80000000@0oooo000000000000oooo0`0000030?ooo`T00000103o
ool800000=<0oooo00<000000?ooo`3oool0=03oool003h0oooo00@0okmd00000000B9`0gooo<P3o
ool00`000000oooo0?ooo`080?ooo`H000001@3oool00`000000oooo00000003000000<0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000H0000000<0
oooo0000000000001P00000>0?ooo`@00000Q`3oool2000000D0oooo0P00000i0?ooo`8000001`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0P0000060?ooo`8000001P3o
ool2000000040?ooo`00000000000?ooo`<000000`3oool9000000@0oooo2000003E0?ooo`030000
003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00P0oooo1`0000040?ooo`030000003o
ool0oooo00<000000`3oool010000000oooo0000000000030?ooo`030000003oool0oooo00H0oooo
0P0000000`3oool0000000000004000000030?ooo`000000000000H000003`3oool500000880oooo
0P0000050?ooo`800000>P3oool00`000000oooo0?ooo`050?ooo`8000007@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`8000000P3oool00`000000oooo
00000002000000<0oooo2@0000040?ooo`L00000f03oool00`000000oooo0?ooo`0d0?ooo`00@@3o
ool01P3OW4P00000000000000000001809cOobd0oooo00<000000?ooo`3oool0203oool7000000@0
oooo00<000000?ooo`3oool00`0000030?ooo`040000003oool00000000000<0oooo00<000000?oo
o`3oool01P3oool010000000oooo0000003oool6000000030?ooo`000000000000D000004@3oool6
000007d0oooo0P0000050?ooo`800000>`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01/0oooo0P0000060?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D000000`3oool9000000@0oooo1`00003J0?ooo`030000003oool0oooo03@0oooo000o0?oo
o`090?oo_`1d0000B9cO0?oOW02L_ol0oooo0=nLB000B9`0gooo02`0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`03000000<0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`070?ooo`040000003oool000000?ooo`@0000000<0oooo0000003oool00`000000103o
ool0000000000000000C0?ooo`80000000<0oooo000000000000N03oool3000000@0oooo0`00000k
0?ooo`8000001P3oool2000001d0oooo00<000000?ooo`3oool0103oool2000000H0oooo0P000006
0?ooo`80000000<0oooo0000000000000`0000030?ooo`T000000`3oool800000=`0oooo00<00000
0?ooo`3oool0=03oool003l0oooo00T0_gAd0;ooo`3oool0oknL09cOo`3oool0oono07@0M02oool0
;03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<00000103oool010000000oooo
0000000000030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`000000oooo10000000103o
ool000000000000000040?ooo`<000004`3oool600000780oooo0`0000040?ooo`<00000?@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01/0oooo0P0000060?ooo`030000003oool0
oooo00@0oooo0P0000060?ooo`80000000<0oooo0000000000000`0000030?ooo`T000000`3oool7
00000=l0oooo00<000000?ooo`3oool0=03oool003h0oooo00T0omnL09boo`3oool0oooO09adW03O
ool0oooo0?oOW018M;l0;@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@00000
0`3oool010000000oooo0000000000030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`00
0000oooo10000000103oool000000?ooo`0000040?ooo`030000003oool0000001D0oooo1P00001]
0?ooo`800000103oool3000003h0oooo0P0000060?ooo`800000703oool2000000H0oooo0P000005
0?ooo`8000001P3oool2000000030?ooo`000000000000<000000P3oool:00000080oooo2000003Q
0?ooo`030000003oool0oooo03@0oooo000n0?ooo`090?noW02Lgol0oooo0;md001d_ol0oooo0=nL
B00007@0_ooo02d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04000000<0oooo
00<000000?ooo`0000000P0000030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`000000
oooo10000000103oool000000000000000040?ooo`@000005P3oool2000000030?ooo`0000000000
00800000I`3oool2000000<0oooo0`00000o0?ooo`8000001P3oool2000001D0oooo00<000000?oo
o`3oool0103oool2000000H0oooo0P0000050?ooo`8000001P3oool2000000030?ooo`0000000000
008000000`3oool2000000030?ooo`000000000000D000000P3oool800000><0oooo00<000000?oo
o`3oool0=03oool003h0oooo00@0oono07@000000000M;oo<P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00@000000`3oool00`000000oooo0?ooo`02000000<0oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`000000oooo00@0000000@0oooo00000000000000001@3o
ool010000000oooo00000000000F0?ooo`<000000P3oool3000005l0oooo1@0000000`3oool00000
0000000200000400oooo0P0000060?ooo`8000005P3oool3000000<0oooo0P0000060?ooo`800000
1@3oool2000000H0oooo0P0000000`3oool0000000000002000000<0oooo0P0000000`3oool00000
00000005000000030?ooo`000000000000H00000iP3oool00`000000oooo0?ooo`0d0?ooo`00M03o
ool3000001<0oooo00D000000?ooo`3oool000000?ooo`02000000@0oooo00@000000?ooo`000000
0000103oool00`000000oooo0?ooo`080?ooo`030000003oool000000080oooo200000050?ooo`80
000000<0oooo0000003oool05`3oool4000000030?ooo`000000000000800000EP3oool500000080
oooo1000000F0?ooo`030000003oool0oooo02D0oooo00@000000?ooo`3oool0oooo0P0000060?oo
o`8000005`3oool4000000030?ooo`000000000000H0oooo0P0000050?ooo`8000001P3oool20000
00030?ooo`0000000000008000000`3oool:000000030?ooo`000000000000H000006P3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0:00oooo0`00000f0?ooo`00@P3oool01@3OW4P0
0000000000000000M;oo02d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo0?ooo`<00000103oool00`000000oooo00000002000000<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo000000020?ooo`P000001P3oool4000001X0oooo2P000019
0?ooo`8000000P3oool4000000<0oooo1000000H0?ooo`<000009@3oool6000000H0oooo0P00000H
0?ooo`H000001@3oool3000000D0oooo0P0000060?ooo`H00000103oool900000080oooo2000000J
0?ooo`<000009P3oool3000002L0oooo0P00001k0?ooo`030000003oool0oooo03@0oooo00100?oo
o`030?oOW0180000B9cO0080oooo00<0omnL04P0M02oool0;03oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo100000030?ooo`030000003oool0
oooo00800000103oool00`000000oooo0?ooo`090?ooo`030000003oool000000080oooo2@000006
0?ooo`040000003oool00000000001d0oooo300000100?ooo`H000000P3oool5000001X0oooo1P00
000R0?ooo`H000001P3oool2000001P0oooo200000030?ooo`8000001@3oool3000000D0oooo1`00
00030?oooa<000006`3oool6000002<0oooo1P00000T0?ooo`@000009P3oool2000002H0oooo0P00
000V0?ooo`8000000`3oool00`000000oooo0?ooo`0d0?ooo`00?`3oool00`3ogi`0B4RL0=ooo`03
0?ooo`030?oo_`1dB9`0gooo02`0oooo00<000000?ooo`3oool02P3oool2000000L0oooo00@00000
0?ooo`3oool0oooo100000030?ooo`030000003oool0oooo00800000103oool00`000000oooo0?oo
o`0:0?ooo`030000003oool000000080oooo2P0000050?ooo`80000000<0oooo000000000000803o
ool4000000<0oooo1P00000E0?ooo`800000703oool?000001d0oooo2000000Q0?ooo`L00000103o
ool2000001T0oooo300000050?ooo`8000001P3oool2000000040?ooo`0000000000000000@0oooo
4`00000L0?ooo`L000008@3oool800000280oooo1P00000S0?ooo`D000008`3oool5000002<0oooo
1@0000030?ooo`030000003oool0oooo03@0oooo000n0?ooo`030?oog`2LM9`0gooo00@0oooo00<0
_g@007Boo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`<000001P3oool010000000oooo0?oo
o`3oool4000000@0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`0000000P3oool8000000030?ooo`000000oooo00D0oooo0P000000103oool00000
00000000000Q0?ooo`H000000`3oool<000000D0oooo1P00000@0?ooo``000000`3oool8000001l0
oooo2P00000O0?ooo`T000000P3oool2000001X0oooo2P0000060?ooo`8000001P3oool6000000@0
oooo4P00000M0?ooo`X000007P3oool:000001l0oooo2@00000P0?ooo`P000008@3oool700000200
oooo200000030?ooo`030000003oool0oooo03@0oooo000n0?ooo`030?oO_`2ogol0oooo0080oooo
00<0oooO09a8001d_ol0;P3oool00`000000oooo0?ooo`0:0?ooo`<000001`3oool00`000000oooo
0?ooo`04000000@0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo00P0oooo
00D000000?ooo`3oool000000?ooo`02000000030?ooo`000000000000T000001P3oool200000080
oooo0P00000U0?ooo`T000001P3ooolK000000T0oooo3`00000L0?ooo`d00000703oool=000001X0
oooo1`0000000`3oool00000000000050?ooo`<000001@3oool6000000D0oooo4@00000N0?ooo``0
0000703oool=000001`0oooo3000000L0?ooo``000007@3oool:000001d0oooo2`0000030?ooo`03
0000003oool0oooo03@0oooo000n0?ooo`0:0?noM01d_ol0oooo0?ooo`3ogi`0B01809cO_`1d0000
04RL0=ooob`0oooo00<000000?ooo`3oool02P3oool3000000L0oooo00D000000?ooo`3oool00000
0?ooo`02000000@0oooo00<000000?ooo`3oool00`0000040?ooo`030000003oool0oooo00P0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo00000008000000030?ooo`000000oooo00H0
oooo0P0000020?ooo`8000001`3oool7000001h0oooo:P0000020?ooo`d000006`3oool>000001T0
oooo3`00000H0?ooo`H000000P3oool3000000@0oooo0`0000060?ooo`H00000103ooolA00000200
oooo1`00000Q0?ooo`h000006P3oool>000001X0oooo3P00000K0?ooo`d000006P3oool>00000080
oooo00<000000?ooo`3oool0=03oool003h0oooo00<0oooO09a8000000001@0000000`00B9`0gooo
0?ooo`0[0?ooo`030000003oool0oooo00T0oooo100000070?ooo`050000003oool0oooo0000003o
ool00P0000050?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`080?ooo`<0
000000D0oooo0000003oool0oooo000000020?ooo`/000001`3oool3000000030?ooo`0000000000
00H0oooo3@00000M0?ooo`/000008@3oool7000003l0oooo0`0000090?ooo`<000006@3oool20000
00H0oooo0P0000050?ooo`8000001`3oool5000000D0oooo4@00001i0?ooo`L000008@3oool70000
01h0oooo2P00000N0?ooo`X000000P3oool00`000000oooo0?ooo`0d0?ooo`00>P3oool0102oW9`0
gooo0?oo_`1d00040000000507Boo`3oool0oooo0;mdM02oool0;@3oool00`000000oooo0?ooo`09
0?ooo`D000001P3oool01@000000oooo0?ooo`000000oooo00<00000103oool00`000000oooo0?oo
o`02000000D0oooo00<000000?ooo`3oool0203oool3000000040?ooo`000000oooo0?ooo`800000
00<0oooo0000000000002P0000080?ooo`80000000@0oooo00000000000000001@3oool;00000240
oooo1`00001T0?ooo`<00000203oool4000001T0oooo0`0000050?ooo`<00000103oool3000000H0
oooo1P0000040?ooo`P0000000<0oooo0000000000001P00003?0?ooo`@00000903oool400000080
oooo00<000000?ooo`3oool0=03oool003T0oooo00<0oooO09a8000000000P0000000`1d_ol0oooo
0?ooo`0c0?ooo`030000003oool0oooo00T0oooo1@0000060?ooo`040000003oool0oooo0?ooo`@0
0000103oool00`000000oooo0?ooo`03000000D0oooo00<000000?ooo`3oool01`3oool400000003
0?ooo`000000oooo0080oooo00<000000?ooo`0000002`0000090?ooo`<0000000<0oooo00000000
00001@3oool8000002H0oooo0`00001Q0?ooo`<000001`3oool4000001/0oooo0P0000050?ooo`<0
0000103oool3000000H0oooo1`0000030?ooo`P0000000<0oooo0000000000001P00003o0?ooo`40
oooo00<000000?ooo`3oool0=03oool003T0oooo00<0oono09bLg`3oool0>03oool00`000000oooo
0?ooo`090?ooo`D000001P3oool01P000000oooo0?ooo`3oool000000?ooo`8000001@3oool00`00
0000oooo0?ooo`02000000D0oooo00<000000?ooo`3oool0203oool4000000030?ooo`000000oooo
0080oooo00<000000?ooo`0000003000000:0?ooo`H00000103oool6000008L0oooo0`0000070?oo
o`<00000703oool3000000D0oooo0P0000050?ooo`8000001@3oool8000000<0oooo4@00003o0?oo
o`@0oooo00<000000?ooo`3oool0=03oool00480oooo00D0_g@0000000000000000004RLg`0]0?oo
o`030000003oool0oooo00P0oooo1P0000060?ooo`060000003oool0oooo0?ooo`000000oooo0P00
00050?ooo`030000003oool0oooo00<000001@3oool00`000000oooo0?ooo`070?ooo`P000000P3o
ool@000000/0oooo1P0000030?ooo`<00000Q03oool4000000H0oooo1000000L0?ooo`<000001@3o
ool3000000@0oooo0`0000040?ooo`<0000000<0oooo0000000000000`0000020?oooa400000o`3o
ool70?ooo`030000003oool0oooo03@0oooo00100?ooo`030=nLB0000000M;oo0080oooo00<0omnL
04P0M02oool0;03oool3000000P0oooo1`0000050?ooo`060000003oool0oooo0?ooo`000000oooo
0P0000060?ooo`030000003oool0oooo008000001@3oool00`000000oooo0?ooo`080?ooo`H00000
00<0oooo0000003oool00P3oool2000000030?ooo`000000000000/00000303oool7000000030?oo
o`000000oooo07l0oooo100000060?ooo`@000007@3oool3000000D0oooo0`0000040?ooo`<00000
103oool3000000030?ooo`000000000000<000000P3ooolA00000?l0oooo203oool3000003H0oooo
000o0?ooo`030=nLB018W=l0oooo00<0oooo00<0omnL04Qd_`3oool0;03oool00`000000oooo0?oo
o`080?ooo`L000001@3oool01P000000oooo0?ooo`3oool000000?ooo`<000001@3oool00`000000
oooo0?ooo`02000000H0oooo00<000000?ooo`3oool01`3oool7000000030?ooo`000000oooo0080
oooo0`0000000`3oool000000000000<000000`0oooo0`0000000`3oool0000000000002000007X0
oooo100000070?ooo`<000007P3oool3000000H0oooo0P0000040?ooo`<000000`3oool400000003
0?ooo`0000000000008000000P3ooolB00000?l0oooo3@3oool00`000000oooo0?ooo`0d0?ooo`00
?P3oool00`3ogi`0M9cO0?ooo`030?ooo`030?noW018M9`0gooo02d0oooo00<000000?ooo`3oool0
503oool01@000000oooo0?ooo`3oool000000080oooo0P0000050?ooo`040000003oool0oooo0?oo
o`8000001P3oool00`000000oooo0?ooo`070?ooo`D000000`3oool010000000oooo0?ooo`3oool?
000000040?ooo`0000000000000000d0oooo0`0000020?ooo`@00000LP3oool4000000L0oooo1000
000M0?ooo`@000001P3oool300000080oooo100000030?ooo`<0000000<0oooo0000000000000`00
00020?oooa<00000o`3oool?0?ooo`030000003oool0oooo03@0oooo000n0?ooo`030?noM000M;l0
oooo0080oooo00D0omnL04QdM01d000004RL0=ooo`0/0?ooo`030000003oool0oooo01D0oooo00H0
00000?ooo`3oool0oooo0000003oool2000000H0oooo00<000000?ooo`3oool00P0000060?ooo`03
0000003oool0oooo00L0oooo100000050?ooo`8000000`3oool00`000000oooo0000000<00000003
0?ooo`0000000000008000003@3oool3000000<0oooo1000001X0?ooo`H000001`3oool4000001h0
oooo0`0000060?ooo`@000000P3oool3000000@0oooo0`0000000`3oool000000000000300000080
oooo4`00003o0?oooa80oooo00<000000?ooo`3oool0=03oool003l0oooo00<0okmd000000000000
100000000`00B9`0gooo0?ooo`0[0?ooo`030000003oool0oooo01D0oooo00H000000?ooo`3oool0
oooo0000003oool2000000H0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool000000080oooo3@00
00000`3oool0000000000003000000d0oooo100000030?ooo`@00000GP3oool6000000T0oooo1000
000O0?ooo`<000001P3oool3000000<0oooo0`0000030?ooo`X0000000<0oooo0000000000004P00
003o0?oooaD0oooo00<000000?ooo`3oool0=03oool003h0oooo00D0omnL04P000000000000004RL
g`020?ooo`030;mdB02Lgol0oooo02`0oooo00<000000?ooo`3oool05@3oool01P000000oooo0?oo
o`3oool000000?ooo`<000001@3oool010000000oooo0?ooo`3oool2000000L0oooo00<000000?oo
o`3oool04@3oool010000000oooo0?ooo`3oool200000080oooo3@0000020?ooo`D000003P3oool4
000000<0oooo1`00001@0?ooo`L000002@3oool6000001l0oooo100000050?ooo`@000000`3oool3
00000080oooo8000003o0?oooaP0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?oo
o`3oool05@3oool01@000000oooo0?ooo`3oool000000080oooo0P0000060?ooo`040000003oool0
oooo0?ooo`8000001`3oool00`000000oooo0?ooo`0A0?ooo`8000000`3oool010000000oooo0?oo
o`3oool>000000030?ooo`000000000000@000003`3oool5000000D0oooo2@0000110?ooo`H00000
2P3oool6000001l0oooo1P0000050?ooo`@000000`3oool400000080oooo0`0000000`3oool00000
0000000J00000?l0oooo6`3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000001P3oool010000000oooo
0?ooo`3oool2000000L0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`3oool20000
00<0oooo3`0000000`3oool000000000000400000140oooo1000000:0?ooo`H00000;`3oool<0000
00X0oooo1P00000P0?ooo`D000001P3oool5000000@0oooo0`0000020?ooob000000o`3ooolO0?oo
o`030000003oool0oooo03@0oooo000n0?ooo`050?oO_`2ogol0oooo0?ooo`2oM0000`0000000`00
07@0_ooo0?ooo`0[0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool00000008000001P3oool010000000oooo0?ooo`3oool2
000000L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool@
00000080oooo1@00000B0?ooo`L000002@3oool_000000T0oooo3@00000R0?ooo`@000001@3oool6
000000D0oooo100000000`3oool000000000000N000000@0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0=03oool0
03h0oooo00<0_g@00000000000000P0000001@0007@0_ooo0?ooo`2oW9`0gooo02`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000P0000060?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?oo
o`0C0?ooo`800000103oool2000000<0oooo4@0000030?ooo`D000005@3ooolA000002P0oooo2000
000[0?ooo`@00000103oool5000000D0oooo9`0000060?ooo`<000009`3oool2000002@0oooo0`00
000V0?ooo`<000009P3oool2000007`0oooo00<000000?ooo`3oool0=03oool003`0oooo00D0_g@0
00000000000004RL0=ooo`030?ooo`030?oog`2LB000M;oo02d0oooo00<000000?ooo`3oool02P3o
ool2000000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000001`3oool010000000oooo
0?ooo`3oool2000000P0oooo00<000000?ooo`3oool0503oool2000000@0oooo0`0000030?oooa40
00000`3oool600000280oooo:000000S0?ooo`8000002@3oool5000000<0oooo1@0000050?ooo`D0
00000`3ooolO000000T0oooo1P00000T0?ooo`@000008P3oool6000002<0oooo1@00000T0?ooo`@0
00009P3oool2000002L0oooo0P00000V0?ooo`8000000`3oool00`000000oooo0?ooo`0d0?ooo`00
?P3oool00`3o_i`0W=oo0?ooo`0c0?ooo`<000002P3oool3000000T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo00000002000000H0oooo00L000000?ooo`3oool0oooo0000003oool00000
00L0oooo00<000000?ooo`3oool05P3oool2000000D0oooo0P0000040?oooa8000000P3oool80000
0440oooo0P00000R0?ooo`D000000`3oool6000000<0oooo1@0000040?ooo`H000000`3oool;0000
00030?ooo`000000000001800000303oool700000280oooo1P00000Q0?ooo`L000008@3oool70000
0280oooo1P00000S0?ooo`D00000903oool5000002<0oooo1@000000103oool0000000000000000f
0?ooo`00M03oool00`000000oooo0?ooo`0:0?ooo`<000002@3oool00`000000oooo0?ooo`020?oo
o`030000003oool00000008000001`3oool010000000oooo0?ooo`3oool2000000P0oooo00<00000
0?ooo`3oool05`3oool2000000D0oooo0`0000030?oooa@0000000<0oooo0000000000000P000000
0`3oool0000000000004000003L0oooo1P00000P0?ooo`X000000`3oool6000000<0oooo1P000004
0?ooob4000003P3oool900000200oooo2@00000N0?ooo`X000007P3oool:000001l0oooo2000000Q
0?ooo`L000008@3oool800000200oooo200000030?ooo`030000003oool0oooo03@0oooo00110?oo
o`060?oOW018000000000000000004P0W=oo;@3oool00`000000oooo0?ooo`0:0?ooo`<000002@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool00000008000001`3oool01`000000oooo0?oo
o`3oool000000?ooo`000000203oool00`000000oooo0?ooo`0H0?ooo`8000001P3oool2000000@0
oooo700000000`3oool0000000000007000000H0oooo1P00000N0?ooo`X000007@3oool@000000D0
oooo100000050?ooob800000403oool<000001d0oooo2`00000L0?ooo``00000703oool<000001d0
oooo2`00000M0?ooo`/000007@3oool;000001d0oooo2`0000030?ooo`030000003oool0oooo03@0
oooo00100?ooo`030;md00000000M;oo0080oooo00<0oooO09adW03Oool0;03oool00`000000oooo
0?ooo`090?ooo`@000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<00000
1`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool200000080oooo00<000000?oo
o`3oool06@3oool2000000H0oooo1P0000000`3oool000000000000E00000080oooo1P0000030?oo
o`d000006`3oool=000000h0oooo6P0000060?ooo`@000000`3oool=000000030?ooo`0000000000
01<00000503oool=000001/0oooo3@00000K0?ooo`L000008@3oool=000001/0oooo3@00000K0?oo
o`d000006`3oool=000001/0oooo3@0000030?ooo`030000003oool0oooo03@0oooo000o0?ooo`03
0=nLB018W=l0oooo00@0oooo00<0gibL0;ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`D0
0000203oool00`000000oooo0?ooo`030?ooo`030000003oool00000008000001`3oool00`000000
oooo0?ooo`020?ooo`8000001@3oool200000080oooo00<000000?ooo`3oool06P3oool2000000D0
oooo900000000`3oool000000000000F000001D0oooo2`0000070?ooo`L000003P3ooolB00000003
0?ooo`000000000000`000000P3ooolD00000;l0oooo1`00000Q0?ooo`L000007P3oool:000001h0
oooo2P0000030?ooo`030000003oool0oooo03@0oooo000n0?ooo`030?oOW01dW=l0oooo00@0oooo
00<0oooO09adW03Oool0;03oool00`000000oooo0?ooo`090?ooo`D00000203oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000800000203oool01`000000oooo0?ooo`3oool000000?oo
o`000000103oool300000080oooo00<000000?ooo`3oool06`3oool2000000D0oooo8@0000000`3o
ool000000000000A000000H0oooo9`0000040?oooa4000000`3oool9000000030?ooo`0000000000
00d000000P3ooolE00000?l0oooo5`3oool4000002@0oooo100000030?ooo`030000003oool0oooo
03@0oooo000n0?ooo`030?noW02Lgol0oooo00<0oooo00<0oooO09a8001d_ol03P3oool0102oM000
00000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0000000000P0000000`1d
_ol0oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo1@0000090?ooo`030000003oool0oooo
0080oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`030000003oool0oooo0080oooo0`00
00040?ooo`<000000P3oool00`000000oooo0?ooo`0L0?ooo`<000000`3oool8000000<0oooo6`00
00030?oooc`00000103oool@00000080oooo4@0000000`3oool000000000000F00000?l0ooooBP3o
ool00`000000oooo0?ooo`0d0?ooo`00?P3oool00`3ogi`0B7Bo0?ooo`020?ooo`030=nLB0000000
B9cO00h0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo
00<0okmd00000000M;l00P3oool00`2oM4P0W=oo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo
1P0000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`0000080?ooo`030000
003oool0oooo0080oooo0P0000040?ooo`D0000000<0oooo0000003oool07`3oool3000000030?oo
o`000000000000P00000103ooolR000000@0oooo4P00000C0?ooo`l000002P3ooolA000000030?oo
o`000000000001T00000o`3ooom?0?ooo`030000003oool0oooo03@0oooo000o0?ooo`060?noM000
0000000000000000B9`0gooo3P3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00/0
oooo00<0omnL04Q8W03Oool02`3oool00`000000oooo0?ooo`080?ooo`L00000203oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000800000203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000@0oooo1@0000000`3oool000000?ooo`0Q0?ooo`80000000<0oooo00000000
00000`0000030?ooo`<000001@3oool^000000H0oooo4`0000080?oooaT0000000<0oooo00000000
00007000003o0?oooeD0oooo00<000000?ooo`3oool0=03oool005<0oooo00<0oooO09a80018W=l0
0P3oool0103ooml0W4P00018W03Oool:0?ooo`030?oo_`1d0000M;oo00/0oooo00<000000?ooo`3o
ool0203oool7000000P0oooo00<000000?ooo`3oool00`3oool01P000000oooo000000000000oooo
000000P0oooo00<000000?ooo`3oool00P3oool3000000<0oooo2000000S0?ooo`D000001`3oool4
000000D0ooooO@00003o0?oooe/0oooo00<000000?ooo`3oool0=03oool005<0oooo00<0oooO09a8
0000M;l00`3oool00`3OW4P0001809cOo`0:0?ooo`030?oOW0180000M;oo00/0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool00000203o
ool00`000000oooo0?ooo`030?ooo`<000000`3oool8000002D0oooo0`00000:0?ooo`@000001`3o
oom500000080oooo:@00003o0?ooof80oooo00<000000?ooo`3oool0=03oool004@0oooo00@0oono
07@0000007@0_ooo303oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00T0oooo00@0
omnL04P0000004P0W=oo2`3oool5000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`03000000T0oooo00<000000?ooo`3oool00`3oool2000000<0oooo1P0000020?ooo`030000
003oool0oooo02D0oooo1000000:0?ooo`<000002@3oool4000000<0ooooF`0000030?ooo`@00000
=P3oool300000?l0oooo9`3oool5000003H0oooo000n0?ooo`040?oo_`2LW=l0oono07@000@00000
00<0M;oo0?ooo`3oool02`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00L0oooo
00D0omnL04P000000000000007Boo`0<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`02000000X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`@00000;`3oool4000001H0oooo1`0000050?ooodX000000`3oool8000003@0
oooo1P00003o0?ooobh0oooo00<000000?ooo`3oool0=03oool003h0oooo00H0omnL04P000000000
00000000B02Lgol@0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0203oool00`3o
okl0M000001d_`0<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool01P00
0000oooo0?ooo`000000oooo000000T0oooo00<000000?ooo`3oool00`3oool300000080oooo0`00
000d0?ooo`<000006P3oool:000000D0oooo<`0000070?ooo`T00000=P3oool600000?l0oooo=03o
ool00`000000oooo0?ooo`0d0?ooo`00?`3oool00`3ookl0M00007Boo`0B0?ooo`040?oog`2LB000
04RL0=ooo`80oooo00<0gia80018W03Oool02P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03000000X0oooo00<0
00000?ooo`3oool00`3oool300000080oooo00<000000?ooo`3oool0=P3oool300000240oooo4`00
000J0?oooa800000>@3oool600000?l0oooo>P3oool00`000000oooo0?ooo`0d0?ooo`00?`3oool0
0`2oM7@0_ooo0?ooo`0C0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02P3oool0
0`3ogi`0B01809cOo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<000002`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool00000000003d0oooo0`00000a0?oooaX00000A@3oool600000?l0oooo@03o
ool00`000000oooo0?ooo`0d0?ooo`00?P3oool0103o_g@000000018W03OoolD0?ooo`060=nLB000
07@0_ooo0?oog`2LB000B9cO203oool01P2oM000M;oo0?ooo`3OW4P0001809cOo`X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`00000:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0000000000?`3o
ool4000008H0oooo1P00003o0?ooodH0oooo00<000000?ooo`3oool0=03oool005L0oooo00@0gia8
00000000000007Bo2P3oool0102oM000000000000018W=l;0?ooo`030000003oool0oooo00X0oooo
0P00000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`00000;0?ooo`030000
003oool0oooo00<0oooo0`0000130?ooo`H00000N03oool800000?l0ooooC03oool00`000000oooo
0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0:0?ooo`<000002`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<00000303oool00`000000oooo0?ooo`030?ooo`<00000B03o
ool6000006T0oooo2@00003o0?oooe@0oooo00<000000?ooo`3oool0=03oool007@0oooo00<00000
0?ooo`3oool02P3oool3000000`0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3o
ool3000000/0oooo00<000000?ooo`3oool0103oool3000004d0oooo1@00001L0?ooo`P00000IP3o
ool2000002H0oooo0P00000V0?ooo`8000009P3oool2000007`0oooo00<000000?ooo`3oool0=03o
ool007@0oooo00<000000?ooo`3oool02P3oool3000000`0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`03000000`0oooo00<000000?ooo`3oool0103oool300000540oooo2000001;
0?ooo`T000007P3oool2000002H0oooo0P00000T0?ooo`@00000903oool4000002@0oooo1000000T
0?ooo`@000009`3oool2000002H0oooo0P00000V0?ooo`8000000`3oool00`000000oooo0?ooo`0d
0?ooo`00M03oool00`000000oooo0?ooo`090?ooo`@00000303oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@00000303oool00`000000oooo0?ooo`040?ooo`<00000F03ooolE0000
02`0oooo2`00000S0?ooo`D000008`3oool500000280oooo1P00000R0?ooo`H000008P3oool60000
0280oooo1P00000T0?ooo`D000008`3oool5000002<0oooo1@0000030?ooo`030000003oool0oooo
03@0oooo001d0?ooo`030000003oool0oooo00T0oooo1@00000;0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool0oooo0`00000<0?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`0000000000K03oool/000000D0oooo1P00000P0?ooo`P00000803oool800000200oooo2000000P
0?ooo`P00000803oool800000200oooo2000000Q0?ooo`P00000803oool800000200oooo20000003
0?ooo`030000003oool0oooo03@0oooo001d0?ooo`<000002@3oool5000000/0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`3oool4000000/0oooo0P0000060?ooo`040000003oool0
0000000001`0oooo0P00000V0?ooo`h000007`3oool9000001h0oooo2P00000M0?ooo`/000007@3o
ool<000001d0oooo2`00000M0?ooo`/000007@3oool;000001d0oooo2`00000M0?ooo`/000007@3o
ool;000001d0oooo2`000000103oool0000000000000000f0?ooo`00M03oool00`000000oooo0?oo
o`090?ooo`D000002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@000002`3o
ool3000000H0oooo00@000000?ooo`0000000000703oool5000002<0oooo3@00000K0?ooo`d00000
6`3oool=000001/0oooo3@00000K0?ooo`h000006`3oool=000001/0oooo3@00000K0?ooo`d00000
6`3oool=000001/0oooo3@00000K0?ooo`d000006`3oool=000000<0oooo00<000000?ooo`3oool0
=03oool007@0oooo00<000000?ooo`3oool0203oool6000000`0oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`3oool4000000/0oooo0`0000060?ooo`030000003oool0000000800000
6`3oool800000240oooo2P00000N0?ooo`X000007P3oool;00000240oooo1`00000R0?ooo`L00000
8@3oool700000240oooo1`00000Q0?ooo`L000008@3oool7000001h0oooo2P00000N0?ooo`X00000
7P3oool:000000<0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool0203o
ool7000000/0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool4000000/0oooo
0`0000070?ooo`030000003oool0oooo008000006`3oool:00000200oooo2000000Q0?ooo`L00000
8P3oool700000?l0oooo5P3oool4000002@0oooo1000000T0?ooo`@000000`3oool00`000000oooo
0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`080?ooo`L000002`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0000000<0oooo0000003oool02@3oool5000000H0oooo00<0
00000?ooo`3oool00P00000K0?ooo`P000008`3oool6000002<0oooo1@00000V0?ooo`<00000o`3o
oom]0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`3oool4000000/0oooo1@0000060?ooo`030000003o
ool0oooo00800000703oool6000002D0oooo0`00000W0?ooo`800000o`3ooonF0?ooo`030000003o
ool0oooo03@0oooo001d0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`3oool4000000/0oooo1P0000060?ooo`80000000<0oooo000000000000703o
ool4000002P0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo03@0oooo001d
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`@000002`3oool6000000L0oooo00@000000?ooo`0000000000703oool300000?l0ooooj03o
ool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool0oooo1000000;0?ooo`L000001`3oool00`000000oooo0000
0002000001/0oooo00<000000?ooo`3oool0o`3ooooW0?ooo`030000003oool0oooo03@0oooo001d
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`040000003oool00000000000X0oooo1P0000090?ooo`80000000<0oooo000000000000o`3o
oooo0?ooo`D0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo1000000;0?ooo`<000000P3oool0
0`000000oooo0?ooo`080?ooo`040000003oool0000000000?l0ooooo`3oool40?ooo`030000003o
ool0oooo03@0oooo001d0?ooo`<000002`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo00000000000:0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000200000?l0ooooo`3o
ool3000003H0oooo001d0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo1000000A0?ooo`030000003oool0
oooo00P0oooo0P0000000`3oool000000000003o0?ooool0oooo0@3oool00`000000oooo0?ooo`0d
0?ooo`00M03oool00`000000oooo0?ooo`0:0?ooo`<000003`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`00000000004@3oool00`000000oooo0?ooo`09
0?ooo`040000003oool0000000000?l0ooooo`3oool00`000000oooo0?ooo`0d0?ooo`00M03oool0
0`000000oooo0?ooo`0:0?ooo`<000003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo1000000B0?ooo`030000003oool0oooo00T0oooo0P0000000`3oool000000000003o
0?ooood0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02P3oool30000
0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000
000000004P3oool2000000/0oooo1000003o0?oooo`0oooo00<000000?ooo`3oool0=03oool007@0
oooo00<000000?ooo`3oool02P3oool300000100oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`@00000503oool00`000000oooo0?ooo`0:0?ooo`@00000o`3oool40?ooo`80
0000m03oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`090?ooo`D00000
3`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0P0000000`3oool00000
0000000D0?ooo`030000003oool0oooo00X0oooo1@00002a0?ooo`8000009P3oool2000002@0oooo
1000000V0?ooo`8000009P3oool2000002H0oooo0P00000V0?ooo`8000009P3oool2000002H0oooo
0P0000040?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00T0oooo1@00
000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool2000000030?ooo`00
0000oooo01@0oooo00<000000?ooo`3oool02`3oool5000008L0oooo0P00000S0?ooo`D000008`3o
ool500000280oooo1P00000S0?ooo`D000008`3oool5000002<0oooo1@00000S0?ooo`D000008`3o
ool5000002<0oooo1@0000040?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0
oooo00T0oooo1@00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool2
000000030?ooo`000000000001D0oooo00<000000?ooo`3oool0303oool5000005`0oooo0`00000R
0?ooo`H00000803oool800000200oooo2000000O0?ooo`T000008@3oool700000240oooo1`00000Q
0?ooo`L000008@3oool700000240oooo1`00000Q0?ooo`L00000103oool00`000000oooo0?ooo`0d
0?ooo`00M03oool00`000000oooo0?ooo`090?ooo`D00000403oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00<0oooo0P0000001@3oool000000000003oool0000001<0oooo0P00000>
0?ooo`D00000;P3oool600000200oooo2@00000N0?ooo`X000007@3oool;000001d0oooo2`00000M
0?ooo``000007@3oool;000001d0oooo2P00000N0?ooo`/000007@3oool:000001h0oooo2P00000N
0?ooo`X00000103oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`080?oo
o`L000003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo0P000000103o
ool000000000003oool2000001@0oooo00<000000?ooo`3oool0303oool6000002D0oooo3@00000L
0?ooo`d000006`3oool=000001/0oooo3@00000K0?ooo`d000006`3oool>000001/0oooo3@00000K
0?ooo`d000006`3oool=000001/0oooo3@00000K0?ooo`d000006`3oool=000000<0oooo00<00000
0?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool0203oool7000000l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`80000000@0oooo000000000000oooo0P00000D
0?ooo`030000003oool0oooo00d0oooo2P00000Q0?ooo`/000007P3oool:000001h0oooo2`00000N
0?ooo`X000007P3oool:00000280oooo1`00000Q0?ooo`L000007P3oool:00000240oooo1`00000N
0?ooo`X000007P3oool:000001h0oooo2P0000030?ooo`030000003oool0oooo03@0oooo001d0?oo
o`<000007P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo0P0000000`3o
ool000000?ooo`04000001@0oooo0P00000?0?ooo``000007`3oool800000280oooo1`00000R0?oo
o`L00000903oool4000002@0oooo1000001e0?ooo`@00000C03oool4000002@0oooo1000000T0?oo
o`@0000000@0oooo0000000000000000=P3oool007@0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo0P0000000`3oool00000000000050000
01@0oooo00<000000?ooo`3oool03P3oool900000280oooo1P00000T0?ooo`D000009P3oool30000
0?l0ooooK@3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool200000080oooo1`00000D0?ooo`80
0000403oool8000002<0oooo1000000W0?ooo`800000o`3ooonF0?ooo`030000003oool0oooo03@0
oooo001d0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`80000000<0oooo0000000000001P00000E0?ooo`030000003oool0oooo00h0oooo
1@0000020?ooo`<000008P3oool200000?l0oooo_`3oool00`000000oooo0?ooo`0d0?ooo`00M03o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool200000080oooo2000000E0?ooo`800000403oool600000080oooo0P00003o0?ooon40oooo00<0
00000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00<0oooo0P0000000`3oool000000?ooo`07000001H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`05000000040?ooo`000000000000000?l0oooogP3o
ool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`80000000<0oooo
0000000000001@00000H0?ooo`8000004`3oool2000000030?ooo`00000000000080oooo0`00003o
0?ooom/0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0000003oool3000001`0oooo00<000000?ooo`3oool04P3oool2000000040?ooo`000000
000000000080oooo0P00003o0?ooomT0oooo00<000000?ooo`3oool0=03oool007@0oooo00<00000
0?ooo`3oool02P3oool2000001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`04
0?ooo`80000000@0oooo00000000000000007P3oool2000001@0oooo0P0000020?ooo`<0000000@0
oooo0000000000000000o`3ooooF0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003o
ool0oooo00X0oooo0`00000C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3o
ool2000000030?ooo`00000000000200oooo00<000000?ooo`3oool04`3oool300000080oooo0`00
0000103oool0000000000000003o0?ooom<0oooo00<000000?ooo`3oool0=03oool007@0oooo00<0
00000?ooo`3oool02P3oool3000001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`050?ooo`80000000<0oooo000000000000803oool2000001H0oooo100000000`3oool000000000
000500000?l0ooood03oool00`000000oooo0?ooo`0d0?ooo`00M03oool3000000X0oooo0`00000D
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool200000080oooo0P00000Q
0?ooo`800000603oool4000000030?ooo`000000000000D00000o`3oooo:0?ooo`<00000=P3oool0
07@0oooo00<000000?ooo`3oool02@3oool4000001@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`050?ooo`80000000@0oooo0000003oool000008P3oool2000001X0oooo3000003o
0?ooolP0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02@3oool50000
01<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`80000000@0oooo0000
003oool000008`3oool2000001`0oooo3000003o0?oool@0oooo00<000000?ooo`3oool0=03oool0
07@0oooo00<000000?ooo`3oool02@3oool5000001@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`050?ooo`040000003oool000000?ooo`8000009@3oool2000001l0oooo30000038
0?ooo`8000009P3oool2000002H0oooo0P00000V0?ooo`8000009P3oool2000002H0oooo0P00000V
0?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`090?oo
o`D00000503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00@000000?oo
o`000000oooo0P00000V0?ooo`8000008@3oool7000000030?ooo`000000000000D00000B03oool2
000002H0oooo0P00000W0?ooo`8000008`3oool5000002<0oooo1@00000S0?ooo`D000008`3oool5
000002<0oooo1@00000S0?ooo`D000008`3oool5000000@0oooo00<000000?ooo`3oool0=03oool0
07@0oooo00<000000?ooo`3oool0203oool6000001@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`060?ooo`8000000P3oool2000002L0oooo0`00000R0?ooo`P000000`3oool70000
01P0oooo0`00000R0?ooo`H000008P3oool6000002<0oooo1P00000P0?ooo`P00000803oool80000
0240oooo1`00000Q0?ooo`L000008@3oool700000240oooo1`00000Q0?ooo`L00000103oool00`00
0000oooo0?ooo`0d0?ooo`00E@3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo
00D0oooo00<0oooO09a80018W=l03@3oool00`000000oooo0?ooo`080?ooo`L000004`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0000000H0oooo0P0000020?ooo`800000:@3oool20000
02@0oooo2@0000050?ooo`L000002`3oool9000001h0oooo2P00000N0?ooo`X000007`3oool:0000
01d0oooo2`00000M0?ooo`/000007P3oool:000001h0oooo2P00000N0?ooo`X000007P3oool:0000
01h0oooo2P0000040?ooo`030000003oool0oooo03@0oooo001D0?ooo`060=nLB000M;l0oooo0?oO
W0180000B9cO0P3oool00`3ogi`0B00007Boo`060?ooo`030=nLB000B9`0gooo00`0oooo00<00000
0?ooo`3oool0203oool7000001@0oooo00<000000?ooo`3oool02`3oool010000000oooo00000000
00050?ooo`030000003oool000000080oooo0P00000J0?ooo`8000003P3oool3000001D0oooo3@00
00040?ooo`X000001P3ooolD000001`0oooo3000000L0?ooo``00000703oool=000001/0oooo3@00
000K0?ooo`h000006`3oool=000001/0oooo3@00000K0?ooo`d000006`3oool=000001/0oooo3@00
00030?ooo`030000003oool0oooo03@0oooo001C0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd
0000B02Lgol02P3oool00`3ogi`0B01809cOo`0<0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0303oool4000000D0oooo00<000000?ooo`0000000P3oool2000001X0oooo1@00000=
0?ooo`<000004`3oool<000000T0oooo2`0000080?ooo``000007P3oool:000001h0oooo2`00000M
0?ooo`/000007P3oool:000001l0oooo2P00000N0?ooo`X000007P3oool:000001h0oooo2P00000N
0?ooo`X000007P3oool:000000<0oooo00<000000?ooo`3oool0=03oool005<0oooo00<0oooO09a8
0018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?noM0000000000000@0000000<004RL
0=ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo10000005
0?ooo`8000000P3oool00`000000oooo0000000J0?ooo`P00000303oool2000001<0oooo2P00000>
0?ooo`h00000103ooolA000001T0oooo1P00000R0?ooo`L000008@3oool7000002@0oooo1000000U
0?ooo`@00000903oool4000002@0oooo1000000T0?ooo`@00000903oool4000002@0oooo10000003
0?ooo`030000003oool0oooo03@0oooo001C0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000
B02Lgol01@3oool00`3ooml0W4Q809cOo`020?ooo`030;md0000M;l0oooo00/0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0<0?ooo`D000001@3oool200000080oooo00<000000?oo
o`0000006P3oool:000000/0oooo0`00000B0?ooo`L000005@3ooolD000000T0oooo4000000=0?oo
o`8000009P3oool3000002D0oooo0`00003o0?oooad0oooo00<000000?ooo`3oool0=03oool005@0
oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`070?oo_`1d07@0_ooo0?oo
o`3o_g@004RL0=ooo`0;0?ooo`D000008P3oool00`000000oooo0?ooo`0=0?ooo`@000001P3oool2
00000080oooo0P00000K0?ooo`P000003`3oool200000180oooo1@00000M0?ooo`D000000`3oool8
000001D0oooo6@00000`0?ooo`T00000o`3ooolW0?ooo`D00000=P3oool005@0oooo00<0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`060?oOW018B9`0gooo0?oOW01804P0W=oo2`3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00d0oooo1@0000050?ooo`030000003o
ool0oooo0080oooo0P00000L0?ooo`H000009@3oool3000002d0oooo2`0000130?oooa000000o`3o
oold0?ooo`030000003oool0oooo03@0oooo001D0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@0
0018W03Oool01`3oool01@3o_g@007Bo0?oog`2LB000B9cO00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo1@0000050?ooo`030000003o
ool0oooo0080oooo0P00000L0?ooo`@00000:03oool00`000000oooo0?ooo`0f0?oood<00000o`3o
oom40?ooo`030000003oool0oooo03@0oooo001D0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool0203oool0103OW4P0B9cO0;md0000M;l;0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`H000001@3oool00`000000oooo
0?ooo`020?ooo`800000703oool300000?l0ooooj03oool00`000000oooo0?ooo`0d0?ooo`00E@3o
ool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00T0oooo00@0gia807AdM00007@0_ooo
2P3oool00`000000oooo0?ooo`0:0?ooo`<00000603oool00`000000oooo0?ooo`0=0?ooo`L00000
1@3oool00`000000oooo0?ooo`020?ooo`800000703oool00`000000oooo0?ooo`3o0?ooonL0oooo
00<000000?ooo`3oool0=03oool005H0oooo00H0gia80000M02oool0oooO09a80018W=l;0?ooo`03
0;md000004P0W=oo00X0oooo00<000000?ooo`3oool02P3oool3000001T0oooo00<000000?ooo`3o
ool0303oool6000000L0oooo00<000000?ooo`3oool00P3oool200000?l0ooooo`3oool60?ooo`03
0000003oool0oooo03@0oooo001G0?ooo`040=nLB00000000000001d_``0oooo00<0oooO09a80018
W=l02P3oool00`000000oooo0?ooo`0:0?ooo`<000006@3oool00`000000oooo0?ooo`0=0?ooo`<0
00002P3oool00`000000oooo0?ooo`020?ooo`<00000o`3ooooo0?ooo`@0oooo00<000000?ooo`3o
ool0=03oool007@0oooo00<000000?ooo`3oool02P3oool3000001T0oooo00<000000?ooo`3oool0
3@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo0P00003o0?ooool0
oooo0`3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`090?ooo`D00000
6@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0`3oool200000?l0ooooo`3oool20?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003o
ool0oooo00T0oooo1@00000I0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`<00000o`3ooooo0?ooo`030000003oool0oooo03@0oooo001d
0?ooo`030000003oool0oooo00T0oooo1@00000I0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool000000?l0oooooP3oool0
0`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`090?ooo`D000006P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0000003o0?ooood0oooo00<000000?ooo`3oool0=03oool007@0oooo0`0000080?ooo`L0
00006@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0000003o0?ooooX0oooo0`00000f0?ooo`00M03oool00`000000oooo
0?ooo`080?ooo`L000006P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool400000=/0oooo0P00000V0?ooo`8000009P3oool2000002H0oooo
0P00000V0?ooo`8000009P3oool2000002H0oooo0P00000V0?ooo`800000103oool00`000000oooo
0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`080?ooo`@000007@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00T0oooo0P0000060?ooo`030000003oool0000008T0oooo0P00
000W0?ooo`8000008`3oool5000002<0oooo1@00000S0?ooo`D000008`3oool5000002<0oooo1@00
000S0?ooo`D000008`3oool5000002<0oooo1@0000040?ooo`030000003oool0oooo03@0oooo001d
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0000005`0oooo1P00000R0?ooo`H000008`3oool600000200oooo2000000P
0?ooo`P00000803oool800000200oooo2000000P0?ooo`P00000803oool800000240oooo1`00000P
0?ooo`P00000103oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool2000000/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`040?ooo`040000003oool00000000000<0oooo0P00000V
0?ooo`H000008P3oool=000001h0oooo2P00000O0?ooo`X000007@3oool;000001d0oooo2`00000M
0?ooo`/000007@3oool;000001d0oooo2`00000M0?ooo`/000007P3oool:000001d0oooo2`000004
0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`060?ooo`<000002P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00@0oooo0P0000000`3oool000000?ooo`020?ooo`@00000903oool<0000
01`0oooo3000000K0?ooo`d00000703oool=000001/0oooo3@00000K0?ooo`d000006`3oool=0000
01/0oooo3@00000K0?ooo`d000006`3oool>000001/0oooo3@00000J0?ooo`d00000103oool00`00
0000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00L0
oooo0`00000:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool3000000<0
oooo1@00000T0?ooo`X000007`3oool8000001h0oooo2`00000N0?ooo`/000007P3oool:000001h0
oooo2P00000N0?ooo`X000007P3oool:000001h0oooo2P00000O0?ooo`X000007P3oool:000001d0
oooo2P0000040?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`@000002P3oool00`000000oooo
0?ooo`0;0?ooo`8000001`3oool300000080oooo1`00000R0?ooo`P000008P3oool600000280oooo
1`00000R0?ooo`L00000903oool4000002@0oooo1000000T0?ooo`@00000903oool4000002@0oooo
1000000U0?ooo`@00000903oool4000002<0oooo100000040?ooo`030000003oool0oooo03@0oooo
001d0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`060?ooo`@000002`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo1000
00000`3oool000000000000600000240oooo1`00000T0?ooo`@000009P3oool3000002H0oooo0`00
003o0?ooodD0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02P3oool2
000001l0oooo00<000000?ooo`3oool01P3oool5000000/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`060?ooo`X00000903oool5000002H0oooo0P00003o0?oooiL0oooo00<00000
0?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02P3oool3000001l0oooo00<000000?oo
o`3oool01P3oool5000000/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?oo
o`P000009@3oool300000?l0oooo`03oool00`000000oooo0?ooo`0d0?ooo`00M03oool3000000X0
oooo0`00000O0?ooo`030000003oool0oooo00H0oooo1P00000;0?ooo`030000003oool0oooo00`0
oooo0P0000090?ooo`D00000:03oool00`000000oooo0?ooo`3o0?oook`0oooo0`00000f0?ooo`00
M03oool00`000000oooo0?ooo`0:0?ooo`<000007`3oool00`000000oooo0?ooo`060?ooo`L00000
2`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo1@00003o0?ooonP0oooo
00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02@3oool400000200oooo00<0
00000?ooo`3oool01@3oool6000000d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`080?ooo`80000000<0oooo000000000000o`3ooooV0?ooo`030000003oool0oooo03@0oooo001d
0?ooo`030000003oool0oooo00T0oooo1@00000O0?ooo`030000003oool0oooo00H0oooo0`00000@
0?ooo`030000003oool0oooo00d0oooo0P00000:0?ooo`80000000<0oooo000000000000o`3ooooT
0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00T0oooo1@00000P0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?oo
o`8000002P3oool2000000030?ooo`00000000000?l0oooohP3oool00`000000oooo0?ooo`0d0?oo
o`00M03oool00`000000oooo0?ooo`090?ooo`D00000803oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0100oooo0P00000:0?ooo`80000000<0oooo000000000000o`3ooooP0?ooo`03
0000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00P0oooo1P00000Q0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool2000000X0oooo0P0000000`3oool00000
0000003o0?ooomh0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool0203o
ool700000200oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00T0oooo1@00003o0?ooom`0oooo00<000000?ooo`3oool0=03oool007@0oooo00<00000
0?ooo`3oool0203oool700000240oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B
0?ooo`800000303oool500000?l0oooof@3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0C0?ooo`800000303oool2000000030?ooo`00000000000?l0ooooe`3oool00`00
0000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06`3oool2000001D0oooo0P00000<0?ooo`80000000<0oooo00000000
0000o`3oool70?ooo`8000009P3oool2000002H0oooo0P00000V0?ooo`8000009P3oool2000002H0
oooo0P0000040?ooo`030000003oool0oooo03@0oooo001d0?ooo`<000002`3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0503oool2000000`0oooo
1P00002:0?ooo`8000009`3oool2000002H0oooo0P00000S0?ooo`D000008`3oool5000002<0oooo
1@00000S0?ooo`D000008`3oool5000002<0oooo1@0000020?ooo`<00000=P3oool007@0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0T0?ooo`8000007P3oool2000001H0oooo0P00
000=0?ooo`D00000G`3oool300000280oooo1P00000S0?ooo`H000008P3oool600000200oooo2000
000P0?ooo`P00000803oool800000200oooo2000000P0?ooo`P00000803oool8000000@0oooo00<0
00000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U
0?ooo`8000007`3oool00`000000oooo0?ooo`040?ooo`8000003`3oool2000000h0oooo10000003
0?ooo`H00000:@3oool6000001l0oooo2@00000N0?ooo`X000007`3oool:000001h0oooo2P00000M
0?ooo`/000007@3oool;000001d0oooo2`00000M0?ooo`/000007@3oool;000001d0oooo2`000004
0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool09@3oool3000001l0oooo0P0000050?ooo`@000003P3oool2000000l0oooo100000000`3o
ool000000000000:000001/0oooo3@00000K0?ooo`d00000703oool<000001`0oooo3@00000K0?oo
o`d000006`3oool=000001/0oooo3@00000K0?ooo`d000006`3oool=000001/0oooo3@00000K0?oo
o`d00000103oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02D0oooo1000000P0?ooo`030000003oool0oooo00<0oooo1@00000>0?ooo`<0
00003P3oool?000001d0oooo2`00000M0?ooo`/000007P3oool:000001h0oooo2`00000N0?ooo`X0
00007P3oool:000001h0oooo2P00000N0?ooo`X000007P3oool:000001h0oooo2P00000N0?ooo`X0
0000103oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0:0?ooo`800000
:03oool400000200oooo00<000000?ooo`3oool00`3oool7000000h0oooo0P00000?0?ooo`/00000
803oool800000240oooo2000000R0?ooo`H000008P3oool7000002@0oooo1000000T0?ooo`@00000
903oool4000002@0oooo1000000T0?ooo`@00000903oool4000002@0oooo100000040?ooo`030000
003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00X0oooo0`00000W0?ooo`@000008@3o
ool2000000@0oooo2000000>0?ooo`<000003`3oool800000280oooo1P00000T0?ooo`D000009P3o
ool2000002H0oooo0`00003o0?oooad0oooo00<000000?ooo`3oool0=03oool007@0oooo00<00000
0?ooo`3oool02P3oool3000002L0oooo1@00000R0?ooo`040000003oool0oooo0?ooo`L000004P3o
ool3000000l0oooo1`00000R0?ooo`@000009`3oool200000?l0ooooKP3oool00`000000oooo0?oo
o`0d0?ooo`00M03oool00`000000oooo0?ooo`0:0?ooo`<000009`3oool600000280oooo0P000002
0?ooo`H000005@3oool2000000h0oooo2P00000P0?ooo`800000o`3ooonG0?ooo`030000003oool0
oooo03@0oooo001d0?ooo`030000003oool0oooo00T0oooo1000000W0?ooo`L000008`3oool00`00
0000oooo0?ooo`04000001P0oooo0`00000=0?ooo`040000003oool0oooo0?ooo`P00000o`3ooone
0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00T0oooo1@00000V0?oo
o`P000008`3oool2000000040?ooo`0000000000000001/0oooo0P00000C0?ooo`<0000000<0oooo
0000000000000`00003o0?oook00oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?oo
o`3oool02@3oool5000002L0oooo1P00000V0?ooo`030000003oool0000001h0oooo0`00000C0?oo
o`@000000P3oool400000?l0oooo[03oool00`000000oooo0?ooo`0d0?ooo`00M03oool3000000T0
oooo1@00000W0?ooo`D00000:03oool200000240oooo0`00000D0?ooo`@000000P3oool500000?l0
ooooY@3oool3000003H0oooo001d0?ooo`030000003oool0oooo00P0oooo1P00000W0?ooo`800000
0P3oool00`000000oooo0?ooo`0X0?ooo`8000008P3oool3000001D0oooo100000030?ooo`D00000
o`3ooonR0?ooo`030000003oool0oooo03@0oooo001d0?ooo`030000003oool0oooo00P0oooo1`00
000[0?ooo`030000003oool0oooo02T0oooo0P00000S0?ooo`<000005P3oool5000000<0oooo1P00
003o0?oooi`0oooo00<000000?ooo`3oool0=03oool007@0oooo00<000000?ooo`3oool0203oool7
000002/0oooo00<000000?ooo`3oool0:`3oool2000002@0oooo0`00000H0?ooo`D00000103oool5
00000?l0ooooU`3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool2000002D0oooo0`00000J0?oo
o`D00000103oool600000?l0ooooT@3oool00`000000oooo0?ooo`0d0?ooo`00M03oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0U0?ooo`<00000703oool5000000D0oooo1P00003o0?oooh/0oooo00<000000?ooo`3o
ool0=03oool005D0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`06
0?oOW0180000000000000000B9`0gooo3@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0;P3oool2000002P0oooo1000000M0?ooo`H000001@3oool8
00000?l0ooooP`3oool00`000000oooo0?ooo`0d0?ooo`00E03oool01P3OW4P007Bo0?ooo`3ogi`0
B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3oool0omnL04Qd_`d0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02l0
oooo0P00000Z0?ooo`D000007P3oool7000000H0oooo2000003l0?ooo`800000O03oool00`000000
oooo0?ooo`0d0?ooo`00D`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00/0oooo
00<0okmd04RLg`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0<@3oool2000002d0oooo1000000Q0?ooo`P000001P3oool;00000500oooo
0P00000V0?ooo`8000009P3oool2000002L0oooo0P00000S0?ooo`D000009P3oool2000002H0oooo
0P00000V0?ooo`800000103oool00`000000oooo0?ooo`0d0?ooo`00D`3oool00`3ooml0W4P004RL
g`020?ooo`040?oog`2LB00004RL0=ooo`X0oooo00<0oono07@0M02oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0b0?ooo`800000;`3oool5000002@0oooo2P0000060?ooo`h000006P3oool300000280oooo
1P00000R0?ooo`H000008P3oool6000002<0oooo1P00000P0?ooo`P000008P3oool600000280oooo
1P00000R0?ooo`H00000103oool00`000000oooo0?ooo`0d0?ooo`00D`3oool00`3ooml0W4P0001d
_`030?ooo`030=nLB00004P0W=oo00X0oooo00<0oooO09a8001d_ol02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo02@0oooo0P00000:0?ooo`030000003oool0oooo01T0oooo0P00
000I0?ooo`800000<P3oool5000000@0oooo1P00000O0?ooo``00000203ooolB00000080oooo2@00
000N0?ooo`X000007P3oool:000001h0oooo2P00000O0?ooo`X000007@3oool;000001h0oooo2P00
000N0?ooo`X000007P3oool:000000@0oooo00<000000?ooo`3oool0=03oool005@0oooo00<0_g@0
0018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030?oo_`1d0000B9cO00/0oooo1@000009
0?ooo`030000003oool0oooo02@0oooo0`00000:0?ooo`030000003oool0oooo01T0oooo0`00000I
0?ooo`030000003oool0oooo00T0oooo1P00000R0?ooo`d000006`3oool=000000<0oooo1`00000A
0?ooobP0000000<0oooo0000000000002P00000L0?ooo``00000703oool=000001/0oooo3@00000K
0?ooo`d000006`3oool=000001/0oooo3@00000K0?oooa800000=P3oool005@0oooo00<0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`0:0?ooo`030?noM0000000M;oo00/0oooo00<000000?oo
o`3oool0<`3oool3000002H0oooo1000000T0?ooo``000007@3oool;000001d0oooo2`00000M0?oo
o`/000007P3oool:000001h0oooo2`00000N0?ooo`X000007@3oool;000001h0oooo2P00000N0?oo
o`X000007@3oool;000001h0oooo2P0000040?ooo`030000003oool0oooo03@0oooo001D0?ooo`03
0?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01P3oool01P3ogml0gooo0?noM0000000001d
0;ooo`/0oooo00<000000?ooo`3oool0<`3oool4000002D0oooo1`00000S0?ooo`X000007`3oool8
00000240oooo2000000P0?ooo`P000008P3oool600000280oooo1`00000T0?ooo`@000008@3oool7
000002@0oooo1000000T0?ooo`@000008@3oool7000002@0oooo100000040?ooo`030000003oool0
oooo03@0oooo001D0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool0
1@3ookl0M0000000000004P0W=oo00`0oooo00<000000?ooo`3oool0<`3oool4000002H0oooo2000
000S0?ooo`L000008P3oool6000002@0oooo1@00000S0?ooo`D000009P3oool2000002H0oooo0`00
001=0?ooo`<00000M@3oool3000002`0oooo00<000000?ooo`3oool0=03oool005D0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030=nLW02oool0oooo00d0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`D000009P3oool900000100oooo00<00000
0?ooo`3oool03`3oool6000002@0oooo1000000W0?ooo`8000002@3oool00`000000oooo0?ooo`0J
0?ooo`800000D`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0d0?ooo`00EP3oool01P3OW4P0001d0;ooo`3ooml0
W4P004RLg`P0oooo00<0omnL07BLg`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool03`3oool5000000H0oooo00<000000?ooo`3oool06@3o
ool010000000oooo0?ooo`3oool700000140oooo00<000000?ooo`3oool04@3oool3000000H0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`8000005P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0=03oool005L0oooo00@0
gia800000000000007Bo2P3oool01@2oM0000000000000000000B9cO00X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo1P0000050?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool500000180oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0=03oool007@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00l0oooo1`0000040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0P3oool500000180oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo03@0oooo001d0?ooool00000o`00001C000003H0oooo002/0?ooo`<00000:P3oool0
0`000000oooo0?ooo`3o0?ooool0oooo8@3oool00:`0oooo00<000000?ooo`3oool0o`3ooooo0?oo
odh0oooo003o0?ooool0ooooo@3oool00?l0ooooo`3oooom0?ooo`00o`3ooooo0?ooood0oooo003o
0?ooool0ooooo@3oool00?l0ooooo`3oooom0?ooo`00o`3ooooo0?ooood0oooo003o0?ooool0oooo
o@3oool00?P0oooo00<0oooO09a8000000000P0000000`1d_ol0oooo0?ooo`150?ooo`030?oog`2L
B00000000080000000<0M;oo0?ooo`3oool04@3oool0103OW4P000000018W03Ooom20?ooo`030;md
000004P0W=oo02@0oooo00@0omnL04P00000B9`0gooo4@3oool00`2oM000001809cOo`1F0?ooo`04
0?oOW018000004RL0=oookh0oooo003j0?ooo`030?noM00007@0_ooo04X0oooo00<0okmd0000M02o
ool0503oool01@3o_g@004RL0=oOW018B9`0gooo0400oooo00<0gia80000M02oool09P3oool00`3o
okl0M000001d_`0@0?ooo`030=nLB00007@0_ooo05P0oooo00<0oono07@00000M;l0_P3oool00?X0
oooo00<0oono07@0001d_ol0BP3oool00`3ookl0M00007Boo`0G0?ooo`030?oOW018M;l0oooo03<0
oooo00<0oono07@0M02oool0203oool00`3ooml0W4P004RLg`0;0?ooo`030?oo_`1d07@0_ooo00X0
oooo00<0oono07@0M02oool03@3oool00`3OW4P004RL0=ooo`0>0?ooo`030?oog`2LB000B9cO01P0
oooo00<0oono07@0M02oool07@3oool00`3ookl0M01d0;ooo`0O0?ooo`030=nLB000B9`0gooo0;d0
oooo003j0?ooo`030?oog`2LB000B9cO04X0oooo00<0oooO09a80018W=l0603oool00`3o_g@0M;oo
0?ooo`0c0?ooo`030?oOW01807@0_ooo00L0oooo00<0oooO09a80018W=l0303oool00`3ogi`0B01d
0;ooo`0:0?ooo`030?oOW01807@0_ooo00`0oooo00<0gia80018W03Oool03P3oool00`3ooml0W4P0
04RLg`0I0?ooo`030?oOW01807@0_ooo01d0oooo00<0omnL04P0M02oool07P3oool00`3OW4P004RL
0=ooo`2m0?ooo`00n`3oool00`3OW4P00000000000020000000607Boo`3oool0oooo0?ooo`2oM000
07Bo1P3oool01@3OW4P00000000000000000M;oo0080oooo00/0oono07@000000000001d0;ooo`3O
W4P0000004RLg`3oool0omnL04P000020000000907Boo`3OW4P000000018W03Oool0okmd00000000
04P0W=oo0080oooo00D0okmd000000000000001809cOo`030?ooo`030;md0000M;l0oooo0180oooo
00<0gia80000000000000P0000001P1d_ol0oooo0?ooo`3oool0_g@0001d_`H0oooo00D0gia80000
00000000000007Boo`040?ooo`030?noM0000000M;oo00L0oooo00`0gia80018W03Oool0oooo0?no
M00007@0_ooo0?ooo`3ooml0W4P00000001d_ol20?ooo`050?noM000000000000000B02Lgol00`3o
ool0203ookl0M0000000000007@0_ooo0=nLB0000000B9cO0P3oool01@3OW4P00000000000000000
M;oo0080oooo00@0okmd0000000007@0_ooo0P3oool00`2oM000M;oo0?ooo`060?ooo`030?oog`2L
B000B9cO0080oooo00T0omnL04P000000000000007Boo`3OW4P000000018W03Oool00P3oool01@2o
M000M;oo0?ooo`3oool0gia80080000000<0001809cOo`3oool00`3oool00`2oM000M;oo0?ooo`02
0?ooo`050=nLB000000000000000B02Lgol0103oool00`3OW4P004RL0=ooo`0>0?ooo`030?oog`2L
B000B9cO0080oooo00<0oono07@0000000000P0000001`18W=l0oooo0?ooo`3oool0omnL04P0001d
_ol00P3oool01P3ogi`0B00000000000000004RL0=ooo`@0oooo00<0_g@007Boo`3oool01`3oool0
102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0000000000P00
00000`18W=l0oooo0?ooo`020?ooo`030;md001d_ol0oooo00L0oooo00@0_g@0000000000000M;oo
0`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB0000000000000<0000000L0B9cO0?ooo`3oool0
oooo0=nLB000B9`0gooo0;d0oooo003k0?ooo`070?noM00004P0W=oo0?ooo`3ooml0W4P0001d_`02
0?ooo`030?noM00007@0_ooo00@0oooo00<0omnL04P0001d_ol00P3oool08@2oM00007Bo0?ooo`3O
W4P004RL0=ooo`3ookl0M01d0;noM00007@0W9ad09cOo`2oM00004RL0=ooo`3oool0_g@007AdM000
07@0_mnL09boo`3o_g@0001809cOg`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`02
0?ooo`030?noM00007@0_ooo0180oooo00L0okmd0000B02Lgol0oooo0?oog`2LB00007Bo0080oooo
00<0okmd0000M02oool0103oool00`3ogi`0B00007Boo`020?ooo`030;md0000M;l0oooo0080oooo
00@0gia80000M01dM4P0W=oo1P3oool01`3o_g@0001809cOo`3oool0oono07@0001d_ol00P3oool0
2`2oM00007Bo0;mdM02oool0omnL04P0B02Lgol0oooo0?oOW018000007Bo0080oooo00`0gia80018
W03Oool0oono07@0M02o_g@0001d09bLM02Lgol0omnL04P0001d_ol20?ooo`0;0;md0000M;l0oooo
0?oOW01807@0_ono09bLg`3oool0omnL04P0001d_ol01`3oool00`3ooml0W4P004RLg`020?ooo`0E
0;md0000B9`0gooo0?ooo`2oM000M7Ad0000M02ogi`0W;oo0?ooo`3ogi`0B00007Boo`3oool0omnL
04P0M02oool0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0001d_ol00P3oool01`3o_g@00000
07Boo`3oool0oooO09a80018W=l00`3oool00`3OW4P004RL0=ooo`0>0?ooo`030?oog`2LB000B9cO
00@0oooo00<0okmd0000001d_ol0103oool00`3ogi`0B00007Boo`020?ooo`060?noM0000000M;oo
0?ooo`3ogi`0B7Bo0`3oool00`3ogi`0B00007Boo`070?ooo`060=nLB000M;l0oooo0?oOW0180000
B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030?noM0000000M;oo00@0oooo00<0omnL04P0001d
_ol01`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@007Bo0?ooo`020?ooo`070;mdM02oool0oooo0?ooo`3OW4P004RL0=ooo`2m0?ooo`00n`3o
ool00`3ookl0M00007Boo`020?ooo`070?oog`2LB000B9cO0?ooo`3ogi`0B00007Boo`040?ooo`03
0=nLB000B9`0gooo00<0oooo00@0gibL0;ooo`2oM00007Bo0P3oool01`3ookl0M4Q804P0B02Lgol0
oooo0;md0000M;l00`3oool01`2oM000000007Boo`3oool0oono07@0001d_ol00P3oool00`3OW4P0
04RL0=ooo`020?ooo`070?oOW0180000B9cO0?ooo`3ogi`0B00007Boo`0B0?ooo`030?oo_`1d0000
M;oo0080oooo00L0oooO09a80018W=l0oooo0?oOW0180000M;oo00@0oooo00<0gia80018W03Oool0
0`3oool02@3OW9`0_ooo0?ooo`3oool0gia80018W03Ooml0W7BL0=ooo`050?ooo`070?oo_`1d0000
B9cO0?ooo`3ooml0W4P0001d_`020?ooo`070=nLB000B9`0gooo0?ooo`3OW4P004RL0=ooo`020?oo
o`060?oOW0180000B9cO0?ooo`2oM00007Bo0P3oool0203ookl0M4Q804P0B02Lgol0oooo0=nLB000
B9`0gooo0`3oool01`3OW9`0_ooo0?oo_`1d0000M;oo0=nLW02oool02P3oool00`3ooml0W4P004RL
g`020?ooo`030;md0000M;l0oooo0080oooo00<0_g@00000001d_ol01P3oool00`3ookl0M00007Bo
o`020?ooo`030?oo_`1d0000M;oo00H0oooo00<0gia80018W03Oool00`3oool02P3Ogml0oooo0?oo
o`3oool0gia80018W03Oool0oooo0?oog`2LB0080000000604RLg`3oool0oooo0?oog`2LB000B9cO
103oool00`3ooml0W4P0001d_`0>0?ooo`030?noM018W=l0oooo00X0oooo00<0oooO09a80018W=l0
0P3oool00`3o_g@0001809cOo`080?ooo`030?oog`2LB00007Bo00d0oooo00<0oooO09a80018W=l0
0P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo00D0oooo00<0gia80018W03Oool0
_@3oool00?/0oooo00<0oooO09a80018W=l00`3oool01`3ogi`0B01809cOo`3ooml0W4P00018W03O
ool00`3oool01@3o_g@00000000000000000B9cO00<0oooo00<0okmd0018W03Oool00P3oool01`3o
_g@0000004RLg`3oool0okmd0000M02oool00P3oool00`3ookl0M00004RLg`020?ooo`070;md0000
M;l0oooo0?ooo`3o_g@0001d0;ooo`030?ooo`070=nLB00007@0_ooo0?oog`2LB00004RL0=ooo`0A
0?ooo`030?oog`2LB000B9cO00<0oooo00L0omnL04P0B02Lgol0oooO09a80000B9`0gooo00<0oooo
00D0okmd000000000000000004RLg`050?ooo`050;md0000B9`0gooo0?oOW01dW=l01@3oool0403o
oml0W4P00018W03Oool0oooo0=nLB0000000M;oo0?ooo`3ogi`0B01809cOo`3oool0okmd0000M02o
ool30?ooo`060=nLB00007@0_ooo0?noM000B9`0gooo0P3oool01@3o_g@0000004RLg`3oool0okmd
00<0000000<0B9cO0?ooo`3oool00P3oool00`2oM000B9cO0?ooo`0;0?ooo`030?oo_`1d0000M;oo
0080oooo00<0okmd0000M02oool00P3oool00`3ookl0M00004RLg`070?ooo`030;md0018W=l0oooo
0080oooo00<0gia80018W03Oool01@3oool00`3o_g@0001d0;ooo`070?ooo`030?noM00007@0_ooo
00h0oooo00<0oono07@0001d_ol01@3oool00`3OW4P004RL0=ooo`0=0?ooo`030?oo_`1d07@0_ooo
00X0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030=nLB000B9`0
gooo00`0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030?noM000
M;l0oooo00@0oooo00<0okmd0000M02oool0_@3oool00?`0oooo00<0gia80000M02oool00P3oool0
1`3ooml0W4P004RLg`3oool0_g@004QdM01dW=l00`3oool02`3ookl0M01809cOo`3oool0gia80000
0018W=l0oooo0?oo_`1d0000M;oo0080oooo00L0oooO09a80000M;l0oooo0?oo_`1d0000M;oo00<0
oooo00/0_g@00018W03Oool0oooo0=nLB000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oO
W01804P0W=oo0?ooo`2oM000B7Ad07BLg`030?ooo`030?oog`2LB000000000L0000000<0B9cO0?oo
o`3oool00P3oool00`3OW4P0001d0;ooo`020?ooo`070?oog`2LB000B9cO0?ooo`2oM000B7Ad07BL
g`030?ooo`070?oo_`1d04P0W=oo0?ooo`3OW4P0000004RLg`020?ooo`030?oog`2LB00007Bo0080
oooo00<0gibL0;ooo`3oool0103oool03`3OW4P004Q807BLg`3oool0okmd0000M01dM7@0_ooo0?oo
g`2LB000B9cO0?ooo`3ookl0M00007Boo`030?ooo`060?oOW01804P0W=oo0?oo_`1d0000M;oo0P3o
ool02`3ooml0W4P0001d_`3oool0oono07@0B02Lgol0oooo0=nLB0000000B9cO0080oooo00<0gia8
0018W03Oool02P3oool00`3ogi`0B01809cOo`030?ooo`030?oo_`1d0000M;oo00<0oooo00<0_g@0
0018W03Oool01P3oool00`3OW4P004RL0=ooo`020?ooo`030?oOW01804P0W=oo00D0oooo00<0oono
07@0001d_ol0203oool00`3ogi`0B01809cOo`0<0?ooo`030?oOW01804P0W=oo00H0oooo00<0omnL
04P0B02Lgol03@3oool00`3ooml0W4P007Boo`0:0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia8
0000B02Lgol0203oool00`3ogi`0B01809cOo`0<0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia8
0000B02Lgol02@3oool00`3o_g@0B9cO0?ooo`040?ooo`030?oOW01804P0W=oo0;`0oooo003l0?oo
o`040?noM000000004RL0=ooo`80oooo00L0gia8001d_`3oool0okmd0018W02oW4P0M;oo00<0oooo
00/0okmd0018W03Oool0oooo0?oo_`1d0000B9cO0?ooo`3o_g@0001d0;ooo`020?ooo`070=nLB000
07@0_ooo0?ooo`3o_g@0001d0;ooo`020?ooo`070=nLB00007@0_ooo0?ooo`3ogi`0B01809cOo`02
0?ooo`030=nLB00007@0_ooo0080oooo00P0oono07@0001d_ol0oooo0?noM000B9`0_ia807Booa40
oooo00@0okmd00000000B9`0gooo0P3oool01`3OW4P007Bo0?ooo`3o_g@004RL0;nLB01d_ol00`3o
ool02`3o_g@004RL0=ooo`3oool0oono07@00018W=l0oooo0?oog`2LB00007Bo0080oooo00<0oono
07Ad_`3oool0103oool0403o_g@0001d09bLM02Lgol0oono07@0001d_kl0M7Bo0?ooo`2oM00004RL
0=ooo`3oool0gia80000M02oool20?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?oo
o`0?0=nLB00007@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@00018W=l0oooo0?oOW01807@0
_ooo00/0oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001d0;ooo`020?ooo`030=nLB00007@0
_ooo00H0oooo00<0omnL04P0B01d_ml00P3oool00`3ookl0M00007Boo`060?ooo`070=nLB00007@0
_ooo0?ooo`3ookl0M00007Boo`020?ooo`030?noM00007@0_ooo00h0oooo00<0oono07@0001d_ol0
1@3oool00`3ookl0M00007Boo`0=0?ooo`030?oo_`1d0000B9cO00/0oooo00<0_g@00018W03Oool0
0P3oool00`3ogi`0B00004RLg`080?ooo`030?oo_`1d0000M;oo00d0oooo00<0_g@00018W03Oool0
0P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd0000M02oool0
_@3oool00?`0oooo0200oono07@0001dW9`0B01d0;ooo`3ooml0W4P0001d_`3oool0oono07@0B02L
gol0_g@007AdM000B9`0gooo0?ooo`3OW4P0001d0;ooo`3oool0gia80018W03Oool0oooo0=nLB000
07@0_ooo0?ooo`2oM000001809cOo`80oooo00/0gia80000M02oool0oooo0;md000004P0W=oo0?oo
o`3ooml0W4P004RLg`030?ooo`0?0;md000007@0_ooo0?ooo`3o_g@0001d0;ooo`3oool0oono07@0
B02Lgol0_g@007AdM000B9`0gooo00h0oooo01/0oono07@0001dW9`0B01d0;ooo`3ooml0W4P0001d
_`3oool0oono07@0B02Lgol0_g@007AdM000B9`0gooo0?ooo`3OW4P0001d0;ooo`3oool0gia80018
W03Oool0oono07@00018W=l00P3oool00`3ogi`0B01d0;ooo`040?ooo`0<0?oo_`1d04P0W=oO09a8
B02Lgml0W4P004RLg`3o_g@007Bo0?noM00007@0_ooo0P3oool01`2oM000001d0;ooo`3oool0okmd
0000M02oool00P3oool01`3OW4P0001d0;ooo`3oool0_g@00000B02Lgol00P3oool02P3OW4P0001d
0;ooo`3oool0gia80018W03Oool0oono07@0001d_ol;0?ooo`030?oog`2LB000B9cO00@0oooo00L0
gia80000M02oool0oooo0;md000004P0W=oo00H0oooo00P0oono07@00018B4P0B9cO0?ooo`3o_g@0
001809cOo`L0oooo00H0_g@00000M02oool0oooo0=nLB018W=l20?ooo`060=nLB000B9`0gooo0?oo
o`3ooml0W4P0200000001P18W=l0oooo0?ooo`3ooml0W4P004RLg`H0oooo00<0_g@0001d_`3oool0
303oool00`3o_g@0000007Boo`0;0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0
2@3oool00`2oM00007Bo0?ooo`0<0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0
2`3oool01`2oM000M;oo0?ooo`3oool0gia80018W03Oool0_@3oool00?/0oooo0140omnL04P00000
0000B9cO0?oo_`1d000000000000M02oool0omnL04P000000000M;oo0?ooo`2oM000001d0;ooo`02
0?ooo`050?oOW018000000000000001d_ol00`3oool01P3ogi`0B00000000018W;l0W4P004RLg`<0
oooo00P0omnL04P000000000B9bL07@00018W=l0oono07@000<0000000@0M;oo0?ooo`3oool0okmd
0`0000002P1d_ol0oooo0?oOW0180000000007Boo`3oool0_g@00000M02oool=0?ooo`0A0?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo0?oOW0180000000007Boo`3oool0_g@00000M02o
ool00P3oool02@3ogi`0B000000000000000M;oo0;md00000000001809cOo`020?ooo`030=nLB000
B9`0gooo00<0oooo00d0oono07@000000000B9cO0?oog`2LB000000004RLg`3oool0okmd00000000
B9`0gooo00<0oooo00D0okmd000000000000000007Boo`040?ooo`060?oOW0180000000004RL_`2L
B000B9cO0`3oool01@3ogi`0B000000000000000M;oo0080oooo00<0_g@004RLg`3oool02P3oool0
0`3ooml0W4P004RLg`050?ooo`060?oOW0180000000004RLW01d0000B9cO1`3oool00`2oM00007Bo
0=nLB0020000000304RLg`3oool0oooo00L0oooo00D0omnL04P000000000001809cOo`020?ooo`03
0=nLB000B9`0gooo00h0oooo00<0oooO09a80018W=l01P3oool00`3OW4P004RL0=ooo`090?ooo`06
0?oOg`3Oool0okmd0000000007@0_ooo2`3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0
gooo00P0oooo00<0gia80018W03Oool0303oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0
gooo00X0oooo00L0omnL04P0M02oool0oooo0=nLB000B9`0gooo0;d0oooo003o0?oooa/0oooo00<0
_g@0001d_`3oool02P3oool00`3o_g@0001d0;ooo`1O0?ooo`030;md0000M;l0oooo00T0oooo00<0
gia80018W03Oool02P3oool00`3ooml0W4P004RLg`0B0?ooo`030=nLB000B9`0gooo01<0oooo00<0
gia80018W03Oool03P3oool00`3ooml0W4P004RLg`060?ooo`030?oOW01804P0W=oo00T0oooo00D0
oono07@000000000001809cOo`0<0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03O
ool0203oool00`3ogi`0B01809cOo`0<0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018
W03Oool02P3oool01`3ooml0W4P007Boo`3oool0gia80018W03Oool0_@3oool00?l0oooo6`3oool0
0`3o_g@0001d0;ooo`0;0?ooo`030=nLM02Lgol0oooo05h0oooo00<0okmd0000M02oool02@3oool0
0`3ogi`0B01d0;ooo`0:0?ooo`030?oog`2LB000B9cO0180oooo00<0omnL04P0B02Lgol04`3oool0
0`3OW4P004RL0=ooo`0>0?ooo`030?oog`2LB000B9cO00H0oooo00<0oono07@0001d_ol02P3oool0
0`3OW9`0_ooo0?ooo`0>0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0203oool0
0`3ookl0M00007Boo`0=0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02P3oool0
1`3ookl0M00004RLg`3oool0gia80018W03Oool0_@3oool00?l0oooo6`3oool00`3ogi`0B01809cO
o`1/0?ooo`030?oOW01804P0W=oo00T0oooo00<0oooO09a8001d_ol02P3oool00`3ooml0W4P004RL
g`0B0?ooo`030?oo_`1d0000B9cO01<0oooo00<0gia80018W03Oool03P3oool00`3ooml0W4P004RL
g`070?ooo`030;md0000M;l0oooo00T0oooo00<0omnL07BLg`3oool03`3oool01P3OW4P0001d0;oo
o`3ooml0W4P004RLg`X0oooo00<0_g@0001d_`3oool03@3oool01P3OW4P0001d0;ooo`3ooml0W4P0
04RLg`L0oooo00/0okmd0018W03Oool0oooo0=nLB00004P0W=oo0?ooo`3OW4P004RL0=ooo`2m0?oo
o`00o`3ooolK0?ooo`030?oog`2LB000B9cO06`0oooo00<0oooO09a80018W=l02P3oool00`3OW4P0
B9cO0?ooo`0:0?ooo`030=nLB00007@0_ooo0180oooo00<0gia8001d_`3oool04@3oool00`3ookl0
M000001d_`0@0?ooo`030=nLB00007@0_ooo00@0oooo00D0oono07@000000000001d0;ooo`0:0?oo
o`050;md00000000000000000018W=l03@3oool0103OW4P0000000000000M;l90?ooo`050?oo_`1d
000000000000M02oool03P3oool0103OW4P0000000000000M;l90?ooo`090?oOW018000000000000
001d_ol0oooo0?oo_`1d000007Bo0;h0oooo003o0?oooaX0oooo00@0oono07@00000000007BoJ`3o
ool0103ookl0M00000000000M;l80?ooo`040?oog`2LB0000000001d_`/0oooo00@0oooO09a80000
04P0W=oo3`3oool01@3ooml0W4P00000000007@0_ooo0100oooo00@0omnL04P00000B9`0gooo403o
ool0103ooml0W4P00000B02LgomF0?ooo`040?oOW018000004RL0=oookh0oooo003o0?ooool0oooo
o@3oool00?l0ooooo`3oooom0?ooo`00o`3ooooo0?ooood0oooo003o0?ooool0ooooo@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 762}, {384.5, 0}} -> {-0.219731, -0.108178, \
0.00263479, 0.00263479}}]
}, Closed]],

Cell["\<\
In fact, all of these orbits coincide for large times.  The initial \
conditions affect the phase on the asymptotic orbit but not its shape.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PhaseAndField[{1.5, 0.1, 0.2}, ics, 0.8, 0.35, 200, 400, 
        PlotPoints \[Rule] 50];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4424 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0122634 1.20238 0.0105333 1.20238 [
[.01226 -0.0125 -5 -15.6875 ]
[.01226 -0.0125 5 0 ]
[.25274 -0.0125 -9.5 -15.6875 ]
[.25274 -0.0125 9.5 0 ]
[.49322 -0.0125 -9.5 -15.6875 ]
[.49322 -0.0125 9.5 0 ]
[.73369 -0.0125 -9.625 -15.6875 ]
[.73369 -0.0125 9.625 0 ]
[.97417 -0.0125 -9.5 -15.6875 ]
[.97417 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.25 -31.375 ]
[.5 -0.0125 13.25 -15.6875 ]
[-0.0125 .01053 -10 -7.84375 ]
[-0.0125 .01053 0 7.84375 ]
[-0.0125 .07065 -25 -7.84375 ]
[-0.0125 .07065 0 7.84375 ]
[-0.0125 .13077 -19 -7.84375 ]
[-0.0125 .13077 0 7.84375 ]
[-0.0125 .19089 -25 -7.84375 ]
[-0.0125 .19089 0 7.84375 ]
[-0.0125 .25101 -19 -7.84375 ]
[-0.0125 .25101 0 7.84375 ]
[-0.0125 .31113 -25 -7.84375 ]
[-0.0125 .31113 0 7.84375 ]
[-0.0125 .37125 -19 -7.84375 ]
[-0.0125 .37125 0 7.84375 ]
[-0.0125 .43137 -25 -7.84375 ]
[-0.0125 .43137 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2212 -40.6875 -23.625 ]
[-0.01875 .2212 -25 23.625 ]
[ 0 .4424 .125 0 ]
[ 1 0 .125 0 ]
[.5 .4549 -110.813 0 ]
[.5 .4549 110.813 15.6875 ]
[ 0 0 0 0 ]
[ 1 .4424 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01226 0 m
.01226 .00625 L
s
gsave
.01226 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.25274 0 m
.25274 .00625 L
s
gsave
.25274 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.49322 0 m
.49322 .00625 L
s
gsave
.49322 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.73369 0 m
.73369 .00625 L
s
gsave
.73369 -0.0125 -70.625 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.97417 0 m
.97417 .00625 L
s
gsave
.97417 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.07238 0 m
.07238 .00375 L
s
.1325 0 m
.1325 .00375 L
s
.19262 0 m
.19262 .00375 L
s
.31286 0 m
.31286 .00375 L
s
.37298 0 m
.37298 .00375 L
s
.4331 0 m
.4331 .00375 L
s
.55334 0 m
.55334 .00375 L
s
.61345 0 m
.61345 .00375 L
s
.67357 0 m
.67357 .00375 L
s
.79381 0 m
.79381 .00375 L
s
.85393 0 m
.85393 .00375 L
s
.91405 0 m
.91405 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.25 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(prey) show
85.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01053 m
.00625 .01053 L
s
gsave
-0.0125 .01053 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .07065 m
.00625 .07065 L
s
gsave
-0.0125 .07065 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .13077 m
.00625 .13077 L
s
gsave
-0.0125 .13077 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .19089 m
.00625 .19089 L
s
gsave
-0.0125 .19089 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
0 .25101 m
.00625 .25101 L
s
gsave
-0.0125 .25101 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .31113 m
.00625 .31113 L
s
gsave
-0.0125 .31113 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
0 .37125 m
.00625 .37125 L
s
gsave
-0.0125 .37125 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .43137 m
.00625 .43137 L
s
gsave
-0.0125 .43137 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02256 m
.00375 .02256 L
s
0 .03458 m
.00375 .03458 L
s
0 .0466 m
.00375 .0466 L
s
0 .05863 m
.00375 .05863 L
s
0 .08268 m
.00375 .08268 L
s
0 .0947 m
.00375 .0947 L
s
0 .10672 m
.00375 .10672 L
s
0 .11875 m
.00375 .11875 L
s
0 .1428 m
.00375 .1428 L
s
0 .15482 m
.00375 .15482 L
s
0 .16684 m
.00375 .16684 L
s
0 .17887 m
.00375 .17887 L
s
0 .20291 m
.00375 .20291 L
s
0 .21494 m
.00375 .21494 L
s
0 .22696 m
.00375 .22696 L
s
0 .23899 m
.00375 .23899 L
s
0 .26303 m
.00375 .26303 L
s
0 .27506 m
.00375 .27506 L
s
0 .28708 m
.00375 .28708 L
s
0 .29911 m
.00375 .29911 L
s
0 .32315 m
.00375 .32315 L
s
0 .33518 m
.00375 .33518 L
s
0 .3472 m
.00375 .3472 L
s
0 .35922 m
.00375 .35922 L
s
0 .38327 m
.00375 .38327 L
s
0 .3953 m
.00375 .3953 L
s
0 .40732 m
.00375 .40732 L
s
0 .41934 m
.00375 .41934 L
s
.25 Mabswid
0 0 m
0 .4424 L
s
gsave
-0.01875 .2212 -117.469 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
84.625 11.8438 translate
90 rotate
-84.625 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(predator) show
106.250 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01226 .43615 m
.01226 .4424 L
s
.25274 .43615 m
.25274 .4424 L
s
.49322 .43615 m
.49322 .4424 L
s
.73369 .43615 m
.73369 .4424 L
s
.97417 .43615 m
.97417 .4424 L
s
.125 Mabswid
.07238 .43865 m
.07238 .4424 L
s
.1325 .43865 m
.1325 .4424 L
s
.19262 .43865 m
.19262 .4424 L
s
.31286 .43865 m
.31286 .4424 L
s
.37298 .43865 m
.37298 .4424 L
s
.4331 .43865 m
.4331 .4424 L
s
.55334 .43865 m
.55334 .4424 L
s
.61345 .43865 m
.61345 .4424 L
s
.67357 .43865 m
.67357 .4424 L
s
.79381 .43865 m
.79381 .4424 L
s
.85393 .43865 m
.85393 .4424 L
s
.91405 .43865 m
.91405 .4424 L
s
.25 Mabswid
0 .4424 m
1 .4424 L
s
.99375 .01053 m
1 .01053 L
s
.99375 .07065 m
1 .07065 L
s
.99375 .13077 m
1 .13077 L
s
.99375 .19089 m
1 .19089 L
s
.99375 .25101 m
1 .25101 L
s
.99375 .31113 m
1 .31113 L
s
.99375 .37125 m
1 .37125 L
s
.99375 .43137 m
1 .43137 L
s
.125 Mabswid
.99625 .02256 m
1 .02256 L
s
.99625 .03458 m
1 .03458 L
s
.99625 .0466 m
1 .0466 L
s
.99625 .05863 m
1 .05863 L
s
.99625 .08268 m
1 .08268 L
s
.99625 .0947 m
1 .0947 L
s
.99625 .10672 m
1 .10672 L
s
.99625 .11875 m
1 .11875 L
s
.99625 .1428 m
1 .1428 L
s
.99625 .15482 m
1 .15482 L
s
.99625 .16684 m
1 .16684 L
s
.99625 .17887 m
1 .17887 L
s
.99625 .20291 m
1 .20291 L
s
.99625 .21494 m
1 .21494 L
s
.99625 .22696 m
1 .22696 L
s
.99625 .23899 m
1 .23899 L
s
.99625 .26303 m
1 .26303 L
s
.99625 .27506 m
1 .27506 L
s
.99625 .28708 m
1 .28708 L
s
.99625 .29911 m
1 .29911 L
s
.99625 .32315 m
1 .32315 L
s
.99625 .33518 m
1 .33518 L
s
.99625 .3472 m
1 .3472 L
s
.99625 .35922 m
1 .35922 L
s
.99625 .38327 m
1 .38327 L
s
.99625 .3953 m
1 .3953 L
s
.99625 .40732 m
1 .40732 L
s
.99625 .41934 m
1 .41934 L
s
.25 Mabswid
1 0 m
1 .4424 L
s
gsave
.5 .4549 -171.813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(predator) show
106.250 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
115.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(prey) show
139.875 15.813 moveto
(model) show
169.375 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
175.375 15.813 moveto
(8) show
179.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
185.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
188.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
194.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
197.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
202.938 15.813 moveto
(<) show
206.875 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
215.375 15.813 moveto
(8) show
219.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
234.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
240.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
255.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
261.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
276.688 15.813 moveto
(<) show
280.625 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
.02429 .01053 m
.02441 .01053 L
s
% Start of user PostScript
0.01 0. 0.010103978 0. MAarrowhead1
% End of user PostScript
.02429 .04059 m
.02437 .0405 L
s
% Start of user PostScript
0.01 0.025 0.010068173 0.024921228 MAarrowhead1
% End of user PostScript
.02429 .07065 m
.02433 .07015 L
s
% Start of user PostScript
0.01 0.05 0.010032368 0.049579885 MAarrowhead1
% End of user PostScript
.02429 .10071 m
.02428 .09948 L
s
% Start of user PostScript
0.01 0.075 0.0099965627 0.07397597 MAarrowhead1
% End of user PostScript
.02429 .13077 m
.02424 .1285 L
s
% Start of user PostScript
0.01 0.1 0.0099607574 0.098109482 MAarrowhead1
% End of user PostScript
.02429 .16083 m
.0242 .1572 L
s
% Start of user PostScript
0.01 0.125 0.0099249522 0.12198042 MAarrowhead1
% End of user PostScript
.02429 .19089 m
.02415 .18559 L
s
% Start of user PostScript
0.01 0.15 0.0098891469 0.14558879 MAarrowhead1
% End of user PostScript
.02429 .22095 m
.02411 .21366 L
s
% Start of user PostScript
0.01 0.175 0.0098533417 0.16893459 MAarrowhead1
% End of user PostScript
.02429 .25101 m
.02407 .24141 L
s
% Start of user PostScript
0.01 0.2 0.0098175364 0.19201781 MAarrowhead1
% End of user PostScript
.02429 .28107 m
.02402 .26885 L
s
% Start of user PostScript
0.01 0.225 0.0097817312 0.21483847 MAarrowhead1
% End of user PostScript
.02429 .31113 m
.02398 .29597 L
s
% Start of user PostScript
0.01 0.25 0.0097459259 0.23739655 MAarrowhead1
% End of user PostScript
.02429 .34119 m
.02394 .32278 L
s
% Start of user PostScript
0.01 0.275 0.0097101206 0.25969206 MAarrowhead1
% End of user PostScript
.02429 .37125 m
.0239 .34927 L
s
% Start of user PostScript
0.01 0.3 0.0096743154 0.281725 MAarrowhead1
% End of user PostScript
.02429 .40131 m
.02385 .37545 L
s
% Start of user PostScript
0.01 0.325 0.0096385101 0.30349536 MAarrowhead1
% End of user PostScript
.02429 .43137 m
.02381 .40131 L
s
% Start of user PostScript
0.01 0.35 0.0096027049 0.32500316 MAarrowhead1
% End of user PostScript
.09214 .01053 m
.09292 .01053 L
s
% Start of user PostScript
0.066428571 0. 0.067079916 0. MAarrowhead1
% End of user PostScript
.09214 .04059 m
.09273 .04063 L
s
% Start of user PostScript
0.066428571 0.025 0.066922711 0.025032751 MAarrowhead1
% End of user PostScript
.09214 .07065 m
.09254 .07068 L
s
% Start of user PostScript
0.066428571 0.05 0.066765506 0.050025975 MAarrowhead1
% End of user PostScript
.09214 .10071 m
.09235 .10069 L
s
% Start of user PostScript
0.066428571 0.075 0.066608301 0.074979672 MAarrowhead1
% End of user PostScript
.09214 .13077 m
.09216 .13064 L
s
% Start of user PostScript
0.066428571 0.1 0.066451096 0.099893842 MAarrowhead1
% End of user PostScript
.09214 .16083 m
.09197 .16055 L
s
% Start of user PostScript
0.066428571 0.125 0.066293891 0.12476849 MAarrowhead1
% End of user PostScript
.09214 .19089 m
.09179 .19041 L
s
% Start of user PostScript
0.066428571 0.15 0.066136685 0.1496036 MAarrowhead1
% End of user PostScript
.09214 .22095 m
.0916 .22023 L
s
% Start of user PostScript
0.066428571 0.175 0.06597948 0.17439919 MAarrowhead1
% End of user PostScript
.09214 .25101 m
.09141 .24999 L
s
% Start of user PostScript
0.066428571 0.2 0.065822275 0.19915525 MAarrowhead1
% End of user PostScript
.09214 .28107 m
.09122 .27971 L
s
% Start of user PostScript
0.066428571 0.225 0.06566507 0.22387179 MAarrowhead1
% End of user PostScript
.09214 .31113 m
.09103 .30938 L
s
% Start of user PostScript
0.066428571 0.25 0.065507865 0.2485488 MAarrowhead1
% End of user PostScript
.09214 .34119 m
.09084 .33901 L
s
% Start of user PostScript
0.066428571 0.275 0.06535066 0.27318628 MAarrowhead1
% End of user PostScript
.09214 .37125 m
.09065 .36858 L
s
% Start of user PostScript
0.066428571 0.3 0.065193455 0.29778423 MAarrowhead1
% End of user PostScript
.09214 .40131 m
.09046 .39811 L
s
% Start of user PostScript
0.066428571 0.325 0.06503625 0.32234266 MAarrowhead1
% End of user PostScript
.09214 .43137 m
.09027 .42759 L
s
% Start of user PostScript
0.066428571 0.35 0.064879045 0.34686156 MAarrowhead1
% End of user PostScript
.15998 .01053 m
.16135 .01053 L
s
% Start of user PostScript
0.12285714 0. 0.12398897 0. MAarrowhead1
% End of user PostScript
.15998 .04059 m
.16108 .04064 L
s
% Start of user PostScript
0.12285714 0.025 0.12377184 0.025041828 MAarrowhead1
% End of user PostScript
.15998 .07065 m
.16082 .07073 L
s
% Start of user PostScript
0.12285714 0.05 0.12355471 0.050062284 MAarrowhead1
% End of user PostScript
.15998 .10071 m
.16056 .10079 L
s
% Start of user PostScript
0.12285714 0.075 0.12333759 0.075061369 MAarrowhead1
% End of user PostScript
.15998 .13077 m
.1603 .13082 L
s
% Start of user PostScript
0.12285714 0.1 0.12312046 0.10003908 MAarrowhead1
% End of user PostScript
.15998 .16083 m
.16004 .16083 L
s
% Start of user PostScript
0.12285714 0.125 0.12290333 0.12499542 MAarrowhead1
% End of user PostScript
.15998 .19089 m
.15978 .19081 L
s
% Start of user PostScript
0.12285714 0.15 0.12268621 0.14993039 MAarrowhead1
% End of user PostScript
.15998 .22095 m
.15952 .22076 L
s
% Start of user PostScript
0.12285714 0.175 0.12246908 0.17484398 MAarrowhead1
% End of user PostScript
.15998 .25101 m
.15926 .25069 L
s
% Start of user PostScript
0.12285714 0.2 0.12225195 0.19973621 MAarrowhead1
% End of user PostScript
.15998 .28107 m
.159 .2806 L
s
% Start of user PostScript
0.12285714 0.225 0.12203483 0.22460706 MAarrowhead1
% End of user PostScript
.15998 .31113 m
.15873 .31048 L
s
% Start of user PostScript
0.12285714 0.25 0.1218177 0.24945654 MAarrowhead1
% End of user PostScript
.15998 .34119 m
.15847 .34033 L
s
% Start of user PostScript
0.12285714 0.275 0.12160057 0.27428464 MAarrowhead1
% End of user PostScript
.15998 .37125 m
.15821 .37016 L
s
% Start of user PostScript
0.12285714 0.3 0.12138345 0.29909138 MAarrowhead1
% End of user PostScript
.15998 .40131 m
.15795 .39996 L
s
% Start of user PostScript
0.12285714 0.325 0.12116632 0.32387674 MAarrowhead1
% End of user PostScript
.15998 .43137 m
.15769 .42973 L
s
% Start of user PostScript
0.12285714 0.35 0.12094919 0.34864073 MAarrowhead1
% End of user PostScript
.22783 .01053 m
.22969 .01053 L
s
% Start of user PostScript
0.17928571 0. 0.18083113 0. MAarrowhead1
% End of user PostScript
.22783 .04059 m
.22939 .04065 L
s
% Start of user PostScript
0.17928571 0.025 0.1805783 0.025045192 MAarrowhead1
% End of user PostScript
.22783 .07065 m
.22908 .07074 L
s
% Start of user PostScript
0.17928571 0.05 0.18032546 0.050075738 MAarrowhead1
% End of user PostScript
.22783 .10071 m
.22878 .10082 L
s
% Start of user PostScript
0.17928571 0.075 0.18007263 0.075091639 MAarrowhead1
% End of user PostScript
.22783 .13077 m
.22848 .13088 L
s
% Start of user PostScript
0.17928571 0.1 0.17981979 0.10009289 MAarrowhead1
% End of user PostScript
.22783 .16083 m
.22817 .16093 L
s
% Start of user PostScript
0.17928571 0.125 0.17956696 0.1250795 MAarrowhead1
% End of user PostScript
.22783 .19089 m
.22787 .19095 L
s
% Start of user PostScript
0.17928571 0.15 0.17931412 0.15005147 MAarrowhead1
% End of user PostScript
.22783 .22095 m
.22756 .22096 L
s
% Start of user PostScript
0.17928571 0.175 0.17906129 0.17500879 MAarrowhead1
% End of user PostScript
.22783 .25101 m
.22726 .25095 L
s
% Start of user PostScript
0.17928571 0.2 0.17880846 0.19995146 MAarrowhead1
% End of user PostScript
.22783 .28107 m
.22696 .28092 L
s
% Start of user PostScript
0.17928571 0.225 0.17855562 0.22487949 MAarrowhead1
% End of user PostScript
.22783 .31113 m
.22665 .31088 L
s
% Start of user PostScript
0.17928571 0.25 0.17830279 0.24979287 MAarrowhead1
% End of user PostScript
.22783 .34119 m
.22635 .34082 L
s
% Start of user PostScript
0.17928571 0.275 0.17804995 0.27469161 MAarrowhead1
% End of user PostScript
.22783 .37125 m
.22604 .37074 L
s
% Start of user PostScript
0.17928571 0.3 0.17779712 0.2995757 MAarrowhead1
% End of user PostScript
.22783 .40131 m
.22574 .40064 L
s
% Start of user PostScript
0.17928571 0.325 0.17754428 0.32444515 MAarrowhead1
% End of user PostScript
.22783 .43137 m
.22544 .43053 L
s
% Start of user PostScript
0.17928571 0.35 0.17729145 0.34929995 MAarrowhead1
% End of user PostScript
.29568 .01053 m
.29796 .01053 L
s
% Start of user PostScript
0.23571429 0. 0.23760641 0. MAarrowhead1
% End of user PostScript
.29568 .04059 m
.29762 .04065 L
s
% Start of user PostScript
0.23571429 0.025 0.23732987 0.025046945 MAarrowhead1
% End of user PostScript
.29568 .07065 m
.29729 .07075 L
s
% Start of user PostScript
0.23571429 0.05 0.23705333 0.05008275 MAarrowhead1
% End of user PostScript
.29568 .10071 m
.29696 .10084 L
s
% Start of user PostScript
0.23571429 0.075 0.2367768 0.075107416 MAarrowhead1
% End of user PostScript
.29568 .13077 m
.29663 .13092 L
s
% Start of user PostScript
0.23571429 0.1 0.23650026 0.10012094 MAarrowhead1
% End of user PostScript
.29568 .16083 m
.29629 .16098 L
s
% Start of user PostScript
0.23571429 0.125 0.23622372 0.12512333 MAarrowhead1
% End of user PostScript
.29568 .19089 m
.29596 .19103 L
s
% Start of user PostScript
0.23571429 0.15 0.23594718 0.15011458 MAarrowhead1
% End of user PostScript
.29568 .22095 m
.29563 .22106 L
s
% Start of user PostScript
0.23571429 0.175 0.23567064 0.17509469 MAarrowhead1
% End of user PostScript
.29568 .25101 m
.2953 .25109 L
s
% Start of user PostScript
0.23571429 0.2 0.2353941 0.20006365 MAarrowhead1
% End of user PostScript
.29568 .28107 m
.29496 .2811 L
s
% Start of user PostScript
0.23571429 0.225 0.23511756 0.22502148 MAarrowhead1
% End of user PostScript
.29568 .31113 m
.29463 .31109 L
s
% Start of user PostScript
0.23571429 0.25 0.23484103 0.24996817 MAarrowhead1
% End of user PostScript
.29568 .34119 m
.2943 .34107 L
s
% Start of user PostScript
0.23571429 0.275 0.23456449 0.27490372 MAarrowhead1
% End of user PostScript
.29568 .37125 m
.29397 .37104 L
s
% Start of user PostScript
0.23571429 0.3 0.23428795 0.29982813 MAarrowhead1
% End of user PostScript
.29568 .40131 m
.29363 .401 L
s
% Start of user PostScript
0.23571429 0.325 0.23401141 0.32474141 MAarrowhead1
% End of user PostScript
.29568 .43137 m
.2933 .43094 L
s
% Start of user PostScript
0.23571429 0.35 0.23373487 0.34964354 MAarrowhead1
% End of user PostScript
.36353 .01053 m
.36614 .01053 L
s
% Start of user PostScript
0.29214286 0. 0.2943148 0. MAarrowhead1
% End of user PostScript
.36353 .04059 m
.36579 .04065 L
s
% Start of user PostScript
0.29214286 0.025 0.29402138 0.02504802 MAarrowhead1
% End of user PostScript
.36353 .07065 m
.36544 .07076 L
s
% Start of user PostScript
0.29214286 0.05 0.29372796 0.050087053 MAarrowhead1
% End of user PostScript
.36353 .10071 m
.36508 .10085 L
s
% Start of user PostScript
0.29214286 0.075 0.29343454 0.075117098 MAarrowhead1
% End of user PostScript
.36353 .13077 m
.36473 .13094 L
s
% Start of user PostScript
0.29214286 0.1 0.29314112 0.10013816 MAarrowhead1
% End of user PostScript
.36353 .16083 m
.36438 .16101 L
s
% Start of user PostScript
0.29214286 0.125 0.2928477 0.12515022 MAarrowhead1
% End of user PostScript
.36353 .19089 m
.36403 .19108 L
s
% Start of user PostScript
0.29214286 0.15 0.29255428 0.15015331 MAarrowhead1
% End of user PostScript
.36353 .22095 m
.36367 .22113 L
s
% Start of user PostScript
0.29214286 0.175 0.29226086 0.1751474 MAarrowhead1
% End of user PostScript
.36353 .25101 m
.36332 .25117 L
s
% Start of user PostScript
0.29214286 0.2 0.29196744 0.20013251 MAarrowhead1
% End of user PostScript
.36353 .28107 m
.36297 .2812 L
s
% Start of user PostScript
0.29214286 0.225 0.29167402 0.22510862 MAarrowhead1
% End of user PostScript
.36353 .31113 m
.36261 .31122 L
s
% Start of user PostScript
0.29214286 0.25 0.2913806 0.25007575 MAarrowhead1
% End of user PostScript
.36353 .34119 m
.36226 .34123 L
s
% Start of user PostScript
0.29214286 0.275 0.29108718 0.2750339 MAarrowhead1
% End of user PostScript
.36353 .37125 m
.36191 .37123 L
s
% Start of user PostScript
0.29214286 0.3 0.29079376 0.29998305 MAarrowhead1
% End of user PostScript
.36353 .40131 m
.36156 .40122 L
s
% Start of user PostScript
0.29214286 0.325 0.29050034 0.32492322 MAarrowhead1
% End of user PostScript
.36353 .43137 m
.3612 .43119 L
s
% Start of user PostScript
0.29214286 0.35 0.29020692 0.3498544 MAarrowhead1
% End of user PostScript
.43138 .01053 m
.43425 .01053 L
s
% Start of user PostScript
0.34857143 0. 0.35095631 0. MAarrowhead1
% End of user PostScript
.43138 .04059 m
.43388 .04065 L
s
% Start of user PostScript
0.34857143 0.025 0.35065025 0.025048748 MAarrowhead1
% End of user PostScript
.43138 .07065 m
.43351 .07076 L
s
% Start of user PostScript
0.34857143 0.05 0.3503442 0.050089963 MAarrowhead1
% End of user PostScript
.43138 .10071 m
.43314 .10086 L
s
% Start of user PostScript
0.34857143 0.075 0.35003814 0.075123646 MAarrowhead1
% End of user PostScript
.43138 .13077 m
.43278 .13095 L
s
% Start of user PostScript
0.34857143 0.1 0.34973209 0.1001498 MAarrowhead1
% End of user PostScript
.43138 .16083 m
.43241 .16103 L
s
% Start of user PostScript
0.34857143 0.125 0.34942603 0.12516841 MAarrowhead1
% End of user PostScript
.43138 .19089 m
.43204 .19111 L
s
% Start of user PostScript
0.34857143 0.15 0.34911998 0.1501795 MAarrowhead1
% End of user PostScript
.43138 .22095 m
.43167 .22117 L
s
% Start of user PostScript
0.34857143 0.175 0.34881392 0.17518305 MAarrowhead1
% End of user PostScript
.43138 .25101 m
.4313 .25123 L
s
% Start of user PostScript
0.34857143 0.2 0.34850787 0.20017907 MAarrowhead1
% End of user PostScript
.43138 .28107 m
.43094 .28127 L
s
% Start of user PostScript
0.34857143 0.225 0.34820181 0.22516755 MAarrowhead1
% End of user PostScript
.43138 .31113 m
.43057 .31131 L
s
% Start of user PostScript
0.34857143 0.25 0.34789576 0.2501485 MAarrowhead1
% End of user PostScript
.43138 .34119 m
.4302 .34134 L
s
% Start of user PostScript
0.34857143 0.275 0.3475897 0.27512192 MAarrowhead1
% End of user PostScript
.43138 .37125 m
.42983 .37135 L
s
% Start of user PostScript
0.34857143 0.3 0.34728365 0.30008781 MAarrowhead1
% End of user PostScript
.43138 .40131 m
.42946 .40136 L
s
% Start of user PostScript
0.34857143 0.325 0.34697759 0.32504617 MAarrowhead1
% End of user PostScript
.43138 .43137 m
.4291 .43136 L
s
% Start of user PostScript
0.34857143 0.35 0.34667154 0.34999699 MAarrowhead1
% End of user PostScript
.49923 .01053 m
.50227 .01053 L
s
% Start of user PostScript
0.405 0. 0.40753093 0. MAarrowhead1
% End of user PostScript
.49923 .04059 m
.50189 .04065 L
s
% Start of user PostScript
0.405 0.025 0.40721506 0.025049273 MAarrowhead1
% End of user PostScript
.49923 .07065 m
.50151 .07076 L
s
% Start of user PostScript
0.405 0.05 0.4068992 0.050092062 MAarrowhead1
% End of user PostScript
.49923 .10071 m
.50113 .10087 L
s
% Start of user PostScript
0.405 0.075 0.40658333 0.075128368 MAarrowhead1
% End of user PostScript
.49923 .13077 m
.50075 .13096 L
s
% Start of user PostScript
0.405 0.1 0.40626747 0.10015819 MAarrowhead1
% End of user PostScript
.49923 .16083 m
.50037 .16105 L
s
% Start of user PostScript
0.405 0.125 0.4059516 0.12518153 MAarrowhead1
% End of user PostScript
.49923 .19089 m
.49999 .19113 L
s
% Start of user PostScript
0.405 0.15 0.40563573 0.15019839 MAarrowhead1
% End of user PostScript
.49923 .22095 m
.49961 .2212 L
s
% Start of user PostScript
0.405 0.175 0.40531987 0.17520876 MAarrowhead1
% End of user PostScript
.49923 .25101 m
.49923 .25127 L
s
% Start of user PostScript
0.405 0.2 0.405004 0.20021265 MAarrowhead1
% End of user PostScript
.49923 .28107 m
.49885 .28132 L
s
% Start of user PostScript
0.405 0.225 0.40468813 0.22521006 MAarrowhead1
% End of user PostScript
.49923 .31113 m
.49847 .31137 L
s
% Start of user PostScript
0.405 0.25 0.40437227 0.25020098 MAarrowhead1
% End of user PostScript
.49923 .34119 m
.49809 .34141 L
s
% Start of user PostScript
0.405 0.275 0.4040564 0.27518542 MAarrowhead1
% End of user PostScript
.49923 .37125 m
.49771 .37144 L
s
% Start of user PostScript
0.405 0.3 0.40374054 0.30016338 MAarrowhead1
% End of user PostScript
.49923 .40131 m
.49733 .40147 L
s
% Start of user PostScript
0.405 0.325 0.40342467 0.32513485 MAarrowhead1
% End of user PostScript
.49923 .43137 m
.49695 .43149 L
s
% Start of user PostScript
0.405 0.35 0.4031088 0.35009984 MAarrowhead1
% End of user PostScript
.56708 .01053 m
.57022 .01053 L
s
% Start of user PostScript
0.46142857 0. 0.46403866 0. MAarrowhead1
% End of user PostScript
.56708 .04059 m
.56983 .04065 L
s
% Start of user PostScript
0.46142857 0.025 0.46371496 0.025049669 MAarrowhead1
% End of user PostScript
.56708 .07065 m
.56944 .07077 L
s
% Start of user PostScript
0.46142857 0.05 0.46339125 0.050093648 MAarrowhead1
% End of user PostScript
.56708 .10071 m
.56905 .10087 L
s
% Start of user PostScript
0.46142857 0.075 0.46306755 0.075131936 MAarrowhead1
% End of user PostScript
.56708 .13077 m
.56866 .13097 L
s
% Start of user PostScript
0.46142857 0.1 0.46274384 0.10016453 MAarrowhead1
% End of user PostScript
.56708 .16083 m
.56827 .16106 L
s
% Start of user PostScript
0.46142857 0.125 0.46242014 0.12519144 MAarrowhead1
% End of user PostScript
.56708 .19089 m
.56788 .19115 L
s
% Start of user PostScript
0.46142857 0.15 0.46209643 0.15021266 MAarrowhead1
% End of user PostScript
.56708 .22095 m
.56749 .22122 L
s
% Start of user PostScript
0.46142857 0.175 0.46177273 0.17522819 MAarrowhead1
% End of user PostScript
.56708 .25101 m
.5671 .2513 L
s
% Start of user PostScript
0.46142857 0.2 0.46144902 0.20023802 MAarrowhead1
% End of user PostScript
.56708 .28107 m
.56671 .28136 L
s
% Start of user PostScript
0.46142857 0.225 0.46112532 0.22524217 MAarrowhead1
% End of user PostScript
.56708 .31113 m
.56632 .31142 L
s
% Start of user PostScript
0.46142857 0.25 0.46080161 0.25024062 MAarrowhead1
% End of user PostScript
.56708 .34119 m
.56593 .34147 L
s
% Start of user PostScript
0.46142857 0.275 0.46047791 0.27523339 MAarrowhead1
% End of user PostScript
.56708 .37125 m
.56555 .37151 L
s
% Start of user PostScript
0.46142857 0.3 0.4601542 0.30022046 MAarrowhead1
% End of user PostScript
.56708 .40131 m
.56516 .40155 L
s
% Start of user PostScript
0.46142857 0.325 0.4598305 0.32520185 MAarrowhead1
% End of user PostScript
.56708 .43137 m
.56477 .43158 L
s
% Start of user PostScript
0.46142857 0.35 0.45950679 0.35017754 MAarrowhead1
% End of user PostScript
.63493 .01053 m
.63808 .01053 L
s
% Start of user PostScript
0.51785714 0. 0.52047951 0. MAarrowhead1
% End of user PostScript
.63493 .04059 m
.63768 .04065 L
s
% Start of user PostScript
0.51785714 0.025 0.5201494 0.025049979 MAarrowhead1
% End of user PostScript
.63493 .07065 m
.63729 .07077 L
s
% Start of user PostScript
0.51785714 0.05 0.51981929 0.050094888 MAarrowhead1
% End of user PostScript
.63493 .10071 m
.63689 .10087 L
s
% Start of user PostScript
0.51785714 0.075 0.51948918 0.075134727 MAarrowhead1
% End of user PostScript
.63493 .13077 m
.63649 .13098 L
s
% Start of user PostScript
0.51785714 0.1 0.51915906 0.10016949 MAarrowhead1
% End of user PostScript
.63493 .16083 m
.63609 .16107 L
s
% Start of user PostScript
0.51785714 0.125 0.51882895 0.12519919 MAarrowhead1
% End of user PostScript
.63493 .19089 m
.6357 .19116 L
s
% Start of user PostScript
0.51785714 0.15 0.51849884 0.15022382 MAarrowhead1
% End of user PostScript
.63493 .22095 m
.6353 .22124 L
s
% Start of user PostScript
0.51785714 0.175 0.51816873 0.17524338 MAarrowhead1
% End of user PostScript
.63493 .25101 m
.6349 .25132 L
s
% Start of user PostScript
0.51785714 0.2 0.51783862 0.20025786 MAarrowhead1
% End of user PostScript
.63493 .28107 m
.63451 .28139 L
s
% Start of user PostScript
0.51785714 0.225 0.5175085 0.22526728 MAarrowhead1
% End of user PostScript
.63493 .31113 m
.63411 .31146 L
s
% Start of user PostScript
0.51785714 0.25 0.51717839 0.25027163 MAarrowhead1
% End of user PostScript
.63493 .34119 m
.63371 .34151 L
s
% Start of user PostScript
0.51785714 0.275 0.51684828 0.2752709 MAarrowhead1
% End of user PostScript
.63493 .37125 m
.63332 .37157 L
s
% Start of user PostScript
0.51785714 0.3 0.51651817 0.30026511 MAarrowhead1
% End of user PostScript
.63493 .40131 m
.63292 .40161 L
s
% Start of user PostScript
0.51785714 0.325 0.51618806 0.32525424 MAarrowhead1
% End of user PostScript
.63493 .43137 m
.63252 .43165 L
s
% Start of user PostScript
0.51785714 0.35 0.51585794 0.35023831 MAarrowhead1
% End of user PostScript
.70277 .01053 m
.70586 .01053 L
s
% Start of user PostScript
0.57428571 0. 0.57685347 0. MAarrowhead1
% End of user PostScript
.70277 .04059 m
.70546 .04065 L
s
% Start of user PostScript
0.57428571 0.025 0.57651803 0.025050228 MAarrowhead1
% End of user PostScript
.70277 .07065 m
.70506 .07077 L
s
% Start of user PostScript
0.57428571 0.05 0.57618258 0.050095884 MAarrowhead1
% End of user PostScript
.70277 .10071 m
.70465 .10088 L
s
% Start of user PostScript
0.57428571 0.075 0.57584713 0.075136968 MAarrowhead1
% End of user PostScript
.70277 .13077 m
.70425 .13098 L
s
% Start of user PostScript
0.57428571 0.1 0.57551169 0.10017348 MAarrowhead1
% End of user PostScript
.70277 .16083 m
.70385 .16108 L
s
% Start of user PostScript
0.57428571 0.125 0.57517624 0.12520542 MAarrowhead1
% End of user PostScript
.70277 .19089 m
.70344 .19117 L
s
% Start of user PostScript
0.57428571 0.15 0.57484079 0.15023279 MAarrowhead1
% End of user PostScript
.70277 .22095 m
.70304 .22126 L
s
% Start of user PostScript
0.57428571 0.175 0.57450535 0.17525558 MAarrowhead1
% End of user PostScript
.70277 .25101 m
.70264 .25134 L
s
% Start of user PostScript
0.57428571 0.2 0.5741699 0.20027381 MAarrowhead1
% End of user PostScript
.70277 .28107 m
.70223 .28142 L
s
% Start of user PostScript
0.57428571 0.225 0.57383445 0.22528746 MAarrowhead1
% End of user PostScript
.70277 .31113 m
.70183 .31149 L
s
% Start of user PostScript
0.57428571 0.25 0.57349901 0.25029654 MAarrowhead1
% End of user PostScript
.70277 .34119 m
.70143 .34155 L
s
% Start of user PostScript
0.57428571 0.275 0.57316356 0.27530104 MAarrowhead1
% End of user PostScript
.70277 .37125 m
.70102 .37161 L
s
% Start of user PostScript
0.57428571 0.3 0.57282811 0.30030098 MAarrowhead1
% End of user PostScript
.70277 .40131 m
.70062 .40166 L
s
% Start of user PostScript
0.57428571 0.325 0.57249267 0.32529634 MAarrowhead1
% End of user PostScript
.70277 .43137 m
.70022 .43171 L
s
% Start of user PostScript
0.57428571 0.35 0.57215722 0.35028713 MAarrowhead1
% End of user PostScript
.77062 .01053 m
.77356 .01053 L
s
% Start of user PostScript
0.63071429 0. 0.63316055 0. MAarrowhead1
% End of user PostScript
.77062 .04059 m
.77316 .04065 L
s
% Start of user PostScript
0.63071429 0.025 0.63282059 0.025050433 MAarrowhead1
% End of user PostScript
.77062 .07065 m
.77275 .07077 L
s
% Start of user PostScript
0.63071429 0.05 0.63248064 0.050096703 MAarrowhead1
% End of user PostScript
.77062 .10071 m
.77234 .10088 L
s
% Start of user PostScript
0.63071429 0.075 0.63214068 0.075138809 MAarrowhead1
% End of user PostScript
.77062 .13077 m
.77193 .13098 L
s
% Start of user PostScript
0.63071429 0.1 0.63180072 0.10017675 MAarrowhead1
% End of user PostScript
.77062 .16083 m
.77152 .16108 L
s
% Start of user PostScript
0.63071429 0.125 0.63146076 0.12521053 MAarrowhead1
% End of user PostScript
.77062 .19089 m
.77111 .19118 L
s
% Start of user PostScript
0.63071429 0.15 0.63112081 0.15024015 MAarrowhead1
% End of user PostScript
.77062 .22095 m
.7707 .22127 L
s
% Start of user PostScript
0.63071429 0.175 0.63078085 0.1752656 MAarrowhead1
% End of user PostScript
.77062 .25101 m
.77029 .25135 L
s
% Start of user PostScript
0.63071429 0.2 0.63044089 0.2002869 MAarrowhead1
% End of user PostScript
.77062 .28107 m
.76989 .28144 L
s
% Start of user PostScript
0.63071429 0.225 0.63010093 0.22530402 MAarrowhead1
% End of user PostScript
.77062 .31113 m
.76948 .31151 L
s
% Start of user PostScript
0.63071429 0.25 0.62976098 0.25031699 MAarrowhead1
% End of user PostScript
.77062 .34119 m
.76907 .34158 L
s
% Start of user PostScript
0.63071429 0.275 0.62942102 0.27532579 MAarrowhead1
% End of user PostScript
.77062 .37125 m
.76866 .37165 L
s
% Start of user PostScript
0.63071429 0.3 0.62908106 0.30033043 MAarrowhead1
% End of user PostScript
.77062 .40131 m
.76825 .40171 L
s
% Start of user PostScript
0.63071429 0.325 0.6287411 0.32533091 MAarrowhead1
% End of user PostScript
.77062 .43137 m
.76784 .43176 L
s
% Start of user PostScript
0.63071429 0.35 0.62840115 0.35032722 MAarrowhead1
% End of user PostScript
.83847 .01053 m
.84119 .01053 L
s
% Start of user PostScript
0.68714286 0. 0.68940074 0. MAarrowhead1
% End of user PostScript
.83847 .04059 m
.84077 .04065 L
s
% Start of user PostScript
0.68714286 0.025 0.68905692 0.025050604 MAarrowhead1
% End of user PostScript
.83847 .07065 m
.84036 .07077 L
s
% Start of user PostScript
0.68714286 0.05 0.6887131 0.050097386 MAarrowhead1
% End of user PostScript
.83847 .10071 m
.83995 .10088 L
s
% Start of user PostScript
0.68714286 0.075 0.68836928 0.075140348 MAarrowhead1
% End of user PostScript
.83847 .13077 m
.83953 .13099 L
s
% Start of user PostScript
0.68714286 0.1 0.68802545 0.10017949 MAarrowhead1
% End of user PostScript
.83847 .16083 m
.83912 .16109 L
s
% Start of user PostScript
0.68714286 0.125 0.68768163 0.12521481 MAarrowhead1
% End of user PostScript
.83847 .19089 m
.83871 .19119 L
s
% Start of user PostScript
0.68714286 0.15 0.68733781 0.1502463 MAarrowhead1
% End of user PostScript
.83847 .22095 m
.83829 .22128 L
s
% Start of user PostScript
0.68714286 0.175 0.68699399 0.17527398 MAarrowhead1
% End of user PostScript
.83847 .25101 m
.83788 .25137 L
s
% Start of user PostScript
0.68714286 0.2 0.68665017 0.20029784 MAarrowhead1
% End of user PostScript
.83847 .28107 m
.83747 .28145 L
s
% Start of user PostScript
0.68714286 0.225 0.68630635 0.22531787 MAarrowhead1
% End of user PostScript
.83847 .31113 m
.83705 .31153 L
s
% Start of user PostScript
0.68714286 0.25 0.68596253 0.25033408 MAarrowhead1
% End of user PostScript
.83847 .34119 m
.83664 .34161 L
s
% Start of user PostScript
0.68714286 0.275 0.6856187 0.27534647 MAarrowhead1
% End of user PostScript
.83847 .37125 m
.83623 .37168 L
s
% Start of user PostScript
0.68714286 0.3 0.68527488 0.30035505 MAarrowhead1
% End of user PostScript
.83847 .40131 m
.83581 .40174 L
s
% Start of user PostScript
0.68714286 0.325 0.68493106 0.32535979 MAarrowhead1
% End of user PostScript
.83847 .43137 m
.8354 .4318 L
s
% Start of user PostScript
0.68714286 0.35 0.68458724 0.35036072 MAarrowhead1
% End of user PostScript
.90632 .01053 m
.90873 .01053 L
s
% Start of user PostScript
0.74357143 0. 0.74557404 0. MAarrowhead1
% End of user PostScript
.90632 .04059 m
.90831 .04065 L
s
% Start of user PostScript
0.74357143 0.025 0.74522687 0.025050749 MAarrowhead1
% End of user PostScript
.90632 .07065 m
.90789 .07077 L
s
% Start of user PostScript
0.74357143 0.05 0.74487971 0.050097966 MAarrowhead1
% End of user PostScript
.90632 .10071 m
.90748 .10088 L
s
% Start of user PostScript
0.74357143 0.075 0.74453254 0.075141653 MAarrowhead1
% End of user PostScript
.90632 .13077 m
.90706 .13099 L
s
% Start of user PostScript
0.74357143 0.1 0.74418537 0.10018181 MAarrowhead1
% End of user PostScript
.90632 .16083 m
.90664 .16109 L
s
% Start of user PostScript
0.74357143 0.125 0.7438382 0.12521843 MAarrowhead1
% End of user PostScript
.90632 .19089 m
.90622 .19119 L
s
% Start of user PostScript
0.74357143 0.15 0.74349103 0.15025152 MAarrowhead1
% End of user PostScript
.90632 .22095 m
.90581 .22129 L
s
% Start of user PostScript
0.74357143 0.175 0.74314386 0.17528109 MAarrowhead1
% End of user PostScript
.90632 .25101 m
.90539 .25138 L
s
% Start of user PostScript
0.74357143 0.2 0.74279669 0.20030712 MAarrowhead1
% End of user PostScript
.90632 .28107 m
.90497 .28147 L
s
% Start of user PostScript
0.74357143 0.225 0.74244953 0.22532961 MAarrowhead1
% End of user PostScript
.90632 .31113 m
.90455 .31155 L
s
% Start of user PostScript
0.74357143 0.25 0.74210236 0.25034858 MAarrowhead1
% End of user PostScript
.90632 .34119 m
.90414 .34163 L
s
% Start of user PostScript
0.74357143 0.275 0.74175519 0.27536402 MAarrowhead1
% End of user PostScript
.90632 .37125 m
.90372 .3717 L
s
% Start of user PostScript
0.74357143 0.3 0.74140802 0.30037592 MAarrowhead1
% End of user PostScript
.90632 .40131 m
.9033 .40177 L
s
% Start of user PostScript
0.74357143 0.325 0.74106085 0.3253843 MAarrowhead1
% End of user PostScript
.90632 .43137 m
.90289 .43184 L
s
% Start of user PostScript
0.74357143 0.35 0.74071368 0.35038914 MAarrowhead1
% End of user PostScript
.97417 .01053 m
.97619 .01053 L
s
% Start of user PostScript
0.8 0. 0.80168046 0. MAarrowhead1
% End of user PostScript
.97417 .04059 m
.97577 .04065 L
s
% Start of user PostScript
0.8 0.025 0.80133036 0.025050873 MAarrowhead1
% End of user PostScript
.97417 .07065 m
.97535 .07077 L
s
% Start of user PostScript
0.8 0.05 0.80098027 0.050098464 MAarrowhead1
% End of user PostScript
.97417 .10071 m
.97493 .10088 L
s
% Start of user PostScript
0.8 0.075 0.80063017 0.075142773 MAarrowhead1
% End of user PostScript
.97417 .13077 m
.97451 .13099 L
s
% Start of user PostScript
0.8 0.1 0.80028008 0.1001838 MAarrowhead1
% End of user PostScript
.97417 .16083 m
.97409 .1611 L
s
% Start of user PostScript
0.8 0.125 0.79992998 0.12522155 MAarrowhead1
% End of user PostScript
.97417 .19089 m
.97366 .1912 L
s
% Start of user PostScript
0.8 0.15 0.79957988 0.15025601 MAarrowhead1
% End of user PostScript
.97417 .22095 m
.97324 .2213 L
s
% Start of user PostScript
0.8 0.175 0.79922979 0.17528719 MAarrowhead1
% End of user PostScript
.97417 .25101 m
.97282 .25139 L
s
% Start of user PostScript
0.8 0.2 0.79887969 0.20031509 MAarrowhead1
% End of user PostScript
.97417 .28107 m
.9724 .28148 L
s
% Start of user PostScript
0.8 0.225 0.7985296 0.2253397 MAarrowhead1
% End of user PostScript
.97417 .31113 m
.97198 .31156 L
s
% Start of user PostScript
0.8 0.25 0.7981795 0.25036104 MAarrowhead1
% End of user PostScript
.97417 .34119 m
.97156 .34164 L
s
% Start of user PostScript
0.8 0.275 0.79782941 0.27537909 MAarrowhead1
% End of user PostScript
.97417 .37125 m
.97114 .37172 L
s
% Start of user PostScript
0.8 0.3 0.79747931 0.30039386 MAarrowhead1
% End of user PostScript
.97417 .40131 m
.97072 .4018 L
s
% Start of user PostScript
0.8 0.325 0.79712921 0.32540535 MAarrowhead1
% End of user PostScript
.97417 .43137 m
.9703 .43186 L
s
% Start of user PostScript
0.8 0.35 0.79677912 0.35041355 MAarrowhead1
% End of user PostScript
.5 Mabswid
.07698 .24259 m
.06508 .21501 L
.05631 .18722 L
.05086 .1641 L
.04765 .14624 L
.0464 .13742 L
.04543 .12909 L
.04506 .12513 L
.04474 .12107 L
.0444 .1146 L
.04431 .10925 L
.04442 .1042 L
.04471 .10003 L
.04513 .09666 L
.04574 .09338 L
.04655 .09033 L
.04748 .08783 L
.04845 .08585 L
.04974 .08381 L
.05132 .08193 L
.053 .08042 L
.05471 .07925 L
.05645 .07831 L
.05821 .07757 L
.06029 .07689 L
.0627 .0763 L
.06399 .07605 L
.06544 .07582 L
.06825 .07549 L
.07119 .07528 L
.0741 .07517 L
.07755 .07514 L
.08094 .07519 L
.08492 .07534 L
.08703 .07544 L
.08942 .07557 L
.10821 .07707 L
.1733 .08378 L
.44437 .10973 L
.52556 .11775 L
.61209 .12741 L
.68159 .13676 L
.74381 .14753 L
.77234 .15389 L
.79849 .16122 L
.81755 .16818 L
.83144 .17494 L
.83708 .17845 L
.84161 .18184 L
.84506 .18498 L
Mistroke
.84803 .18836 L
.85049 .19208 L
.85209 .19559 L
.85275 .19776 L
.85316 .19982 L
.8534 .20371 L
.85303 .20731 L
.85203 .21121 L
.85055 .21493 L
.84877 .21837 L
.84271 .22692 L
.83491 .2352 L
.81392 .25212 L
.7836 .27103 L
.71142 .30515 L
.62447 .33494 L
.57081 .34868 L
.54032 .35504 L
.5065 .36091 L
.47523 .36522 L
.45815 .36711 L
.43951 .36881 L
.42192 .37004 L
.40568 .37086 L
.38908 .37137 L
.37321 .37153 L
.35422 .37129 L
.3331 .37044 L
.32238 .36975 L
.31083 .36882 L
.28991 .36656 L
.26908 .36351 L
.24945 .35983 L
.21338 .35056 L
.19356 .34374 L
.17336 .33515 L
.1401 .31602 L
.12376 .30334 L
.10997 .29015 L
.09663 .27436 L
.08455 .25637 L
.06958 .22651 L
.05983 .19943 L
.05222 .17051 L
.04802 .14852 L
.04652 .13837 L
.04554 .13008 L
.04482 .12207 L
.04458 .11842 L
.04441 .1147 L
Mistroke
.04431 .10907 L
.04435 .10623 L
.04444 .1038 L
.04476 .09956 L
.04523 .09602 L
.04583 .09295 L
.0465 .09049 L
.04742 .08799 L
.0484 .08592 L
.05048 .08285 L
.05183 .08143 L
.05319 .08028 L
.05469 .07926 L
.05643 .07832 L
.05851 .07746 L
.06061 .0768 L
.06317 .0762 L
.06579 .07577 L
.06832 .07548 L
.07127 .07527 L
.07441 .07516 L
.07748 .07514 L
.08109 .0752 L
.08516 .07535 L
.08897 .07555 L
.09272 .07579 L
.10208 .07652 L
.16013 .0824 L
.40483 .106 L
.57989 .12363 L
.66086 .13375 L
.72527 .14397 L
.77274 .15399 L
.79233 .15932 L
.8105 .16538 L
.82525 .17167 L
.83195 .17523 L
.8374 .17867 L
.8417 .18192 L
.84557 .18551 L
.84839 .18882 L
.85041 .19194 L
.85215 .19575 L
.85274 .19769 L
.85317 .19984 L
.8534 .20368 L
.85303 .2073 L
.85253 .20953 L
.85188 .21165 L
.85021 .21567 L
Mistroke
.84775 .22004 L
.84436 .22486 L
.83696 .23319 L
.82699 .2422 L
.80404 .25877 L
.7459 .29022 L
.65945 .32415 L
.6037 .34065 L
.54405 .35432 L
.51607 .35938 L
.48483 .36401 L
.46621 .36626 L
.44893 .368 L
.43251 .36934 L
.41412 .37048 L
.39403 .37125 L
.38289 .37147 L
.37239 .37153 L
.35339 .37127 L
.33276 .37042 L
.3211 .36966 L
.30835 .36859 L
.2851 .36593 L
.2625 .36237 L
.24176 .35814 L
.20492 .34782 L
.18485 .34026 L
.16686 .33196 L
.13392 .31154 L
.11772 .29789 L
.10451 .2841 L
.09311 .26953 L
.0838 .2551 L
.06993 .22734 L
.05947 .19826 L
.05212 .17004 L
.04814 .14926 L
.04668 .13952 L
.04568 .13138 L
.04506 .12517 L
.04462 .11916 L
.04436 .11323 L
.04431 .10843 L
.04445 .10349 L
.04462 .10102 L
.04483 .09893 L
.04536 .09526 L
.04601 .09224 L
.04644 .09069 L
.04695 .08917 L
Mistroke
.04799 .08673 L
.04927 .08448 L
.05089 .08238 L
.05249 .08084 L
.0541 .07963 L
.05615 .07846 L
.05827 .07755 L
.0604 .07686 L
.06252 .07633 L
.06502 .07588 L
.06789 .07553 L
.07059 .07531 L
.07375 .07518 L
.0773 .07514 L
.08084 .07519 L
.0844 .07531 L
.08783 .07548 L
.09627 .07604 L
.11959 .07817 L
.14831 .08115 L
.33755 .09976 L
.49237 .11439 L
.58156 .12382 L
.65949 .13356 L
.71761 .14259 L
.76884 .15304 L
.7924 .15934 L
.81094 .16554 L
.82451 .17131 L
.83611 .1778 L
.84434 .18427 L
.84775 .188 L
.85015 .19148 L
.8517 .19458 L
.85282 .19803 L
.85336 .20167 L
.85332 .20511 L
.85306 .2071 L
.8526 .20928 L
.85127 .21329 L
.8494 .21724 L
.84719 .22092 L
.84053 .22944 L
.83113 .23867 L
.80761 .25644 L
.77915 .27349 L
.74153 .29223 L
.69274 .31242 L
.63954 .33048 L
.58347 .34573 L
Mistroke
.5236 .3581 L
.4874 .36367 L
.47082 .36574 L
.4529 .36763 L
.43615 .36907 L
.41738 .3703 L
.4 .37107 L
.38351 .37146 L
.36374 .37147 L
.34548 .37101 L
.32417 .36988 L
.30383 .36814 L
.28609 .36606 L
.26726 .36321 L
.23381 .35624 L
.21563 .35124 L
.19898 .34574 L
.18122 .33871 L
.16313 .33002 L
.14604 .32001 L
.13163 .30979 L
.10696 .28688 L
.09531 .27258 L
.08445 .25621 L
.06917 .22551 L
.06342 .21038 L
.05832 .19441 L
.05114 .16544 L
.04898 .15423 L
.04723 .14343 L
.04603 .13443 L
.04523 .127 L
.0447 .12042 L
.04439 .11421 L
.04432 .11101 L
.04431 .1082 L
.04446 .10346 L
.04477 .09947 L
.04519 .09622 L
.04581 .09307 L
.04661 .09016 L
.04741 .08801 L
.04837 .08598 L
.05043 .08291 L
.05189 .08137 L
.05341 .08012 L
.05503 .07906 L
.05663 .07823 L
.05851 .07746 L
.0607 .07677 L
Mistroke
.06289 .07626 L
.06511 .07587 L
.06788 .07553 L
.07065 .07531 L
.0739 .07518 L
.07583 .07514 L
.07765 .07514 L
.08156 .07521 L
.08543 .07536 L
.08755 .07547 L
.08998 .07561 L
.09517 .07596 L
.11703 .07791 L
.26792 .09322 L
.42324 .10773 L
.59445 .1253 L
.66369 .13415 L
.72748 .14437 L
.75574 .15003 L
.78263 .15656 L
.80171 .16227 L
.8189 .16875 L
.83203 .17527 L
.83742 .17868 L
.84226 .18239 L
.84596 .18592 L
.84865 .18919 L
.85073 .19252 L
.85213 .19571 L
.85311 .19948 L
.85334 .2014 L
.8534 .20353 L
.85302 .20734 L
.85211 .21096 L
.85132 .21316 L
.8504 .21527 L
.84824 .21926 L
.84144 .22841 L
.83411 .23596 L
.82461 .24414 L
.80342 .25917 L
.73749 .29406 L
.64285 .32946 L
.57765 .34711 L
.54347 .35443 L
.5097 .36041 L
.47854 .36481 L
.46202 .36671 L
.44364 .36847 L
.43301 .36931 L
Mistroke
.42307 .36998 L
.40316 .37096 L
.38473 .37144 L
.36484 .37148 L
.34526 .371 L
.32393 .36986 L
.30363 .36812 L
.28497 .36591 L
.2643 .36269 L
.24188 .35817 L
.21889 .35221 L
.19811 .34543 L
.17905 .33776 L
.15991 .32828 L
.12896 .30768 L
.11396 .29424 L
.10151 .28055 L
.08896 .26343 L
.07897 .24644 L
.06531 .21563 L
.0568 .18903 L
.0508 .1638 L
.04851 .15151 L
.04691 .14122 L
.04585 .1329 L
.04504 .12494 L
.04459 .11854 L
.04436 .1133 L
.04431 .10824 L
.04446 .10336 L
.04483 .09893 L
.04534 .09534 L
.04598 .09236 L
.04671 .08987 L
.04746 .08788 L
.04838 .08596 L
.04952 .08412 L
.05086 .08242 L
.05213 .08115 L
.05365 .07994 L
.0555 .0788 L
.05737 .0779 L
.05961 .07709 L
.06083 .07674 L
.06221 .0764 L
.06358 .07612 L
.0649 .0759 L
.06765 .07555 L
.07034 .07533 L
.07337 .07519 L
Mistroke
.07634 .07514 L
.07973 .07517 L
.08315 .07526 L
.08645 .07541 L
.09058 .07564 L
.09538 .07598 L
.10503 .07678 L
.26639 .09307 L
.39689 .10526 L
.56371 .12182 L
.65502 .13295 L
.72669 .14423 L
.78051 .15599 L
.80169 .16226 L
.8204 .16941 L
.82746 .17278 L
.83407 .1765 L
.83904 .17984 L
.84344 .18343 L
.84668 .18672 L
.84948 .1904 L
.85136 .19379 L
.85255 .19701 L
.85302 .19896 L
.85332 .2011 L
.85332 .20503 L
.85269 .20892 L
.85155 .21257 L
.8506 .21482 L
.84955 .21696 L
.84714 .22099 L
.83984 .23019 L
.82196 .24622 L
.79994 .26137 L
.73247 .29629 L
.6917 .31281 L
.64193 .32974 L
.59364 .34324 L
.53539 .35598 L
.49685 .36235 L
.47919 .36473 L
.4592 .36701 L
.44124 .36867 L
.42146 .37007 L
.41037 .37066 L
.40011 .37107 L
.37969 .3715 L
.36085 .37143 L
.34313 .37092 L
.32348 .36983 L
Mistroke
.30236 .36799 L
.29166 .36677 L
.28006 .36522 L
.25909 .36175 L
.23878 .35745 L
.22053 .35269 L
.18432 .34004 L
.16558 .33131 L
.14885 .3218 L
.12214 .30193 L
.10898 .28909 L
.09813 .27631 L
.0796 .24763 L
.0714 .23075 L
.06509 .21504 L
.05578 .18526 L
.04961 .15768 L
.04638 .13731 L
.0453 .12776 L
.04496 .12391 L
.04468 .12002 L
.04447 .11624 L
.04435 .11292 L
.04432 .10733 L
.04441 .10449 L
.04457 .10171 L
.04476 .09952 L
.04504 .09728 L
.04567 .09369 L
.0464 .09083 L
.04742 .08797 L
.04857 .08563 L
.04977 .08377 L
.05101 .08226 L
.05251 .08083 L
.05427 .07952 L
.05611 .07848 L
.05832 .07753 L
.06085 .07673 L
.06214 .07642 L
.06342 .07615 L
.06603 .07574 L
.06858 .07546 L
.07153 .07526 L
.07329 .07519 L
.07498 .07515 L
.07673 .07514 L
.07869 .07515 L
.08243 .07524 L
.08472 .07533 L
Mistroke
.08723 .07545 L
.09199 .07574 L
.10275 .07657 L
.1165 .07786 L
.28819 .09514 L
.43766 .10909 L
.59656 .12555 L
.67703 .13608 L
.71438 .14203 L
.74928 .14865 L
.77466 .15447 L
.79825 .16114 L
.81579 .16745 L
.82893 .17355 L
.83479 .17694 L
.84008 .18062 L
.84389 .18385 L
.84725 .18739 L
.84894 .1896 L
.85025 .19164 L
.85126 .19357 L
.85213 .19571 L
.85311 .19947 L
.85335 .20154 L
.8534 .20349 L
.853 .20745 L
.85202 .21124 L
.85067 .21468 L
.84871 .21847 L
.84255 .22711 L
.83483 .23527 L
.81706 .24988 L
.79166 .26639 L
.72312 .30031 L
.67646 .31835 L
.62582 .33455 L
.57495 .34774 L
.51333 .35983 L
.47549 .36519 L
.45691 .36724 L
.43942 .36882 L
.41873 .37023 L
.40766 .37078 L
.39582 .3712 L
.37562 .37152 L
.36401 .37147 L
.35307 .37126 L
.33209 .37038 L
.31201 .36892 L
.2939 .36705 L
Mistroke
.27417 .36434 L
.25285 .36053 L
.23046 .35539 L
.21165 .35001 L
.19165 .343 L
.15755 .32697 L
.14058 .31635 L
.12603 .30527 L
.10332 .28271 L
.08409 .25561 L
.07549 .23958 L
.0678 .22214 L
.05759 .19186 L
.05122 .16585 L
.04758 .14577 L
.04646 .13788 L
.04555 .13024 L
.04495 .12377 L
.04458 .11844 L
.04435 .11285 L
.04432 .10748 L
.04448 .10303 L
.04478 .09937 L
.04528 .09572 L
.04589 .09271 L
.04656 .09031 L
.04741 .08801 L
.04847 .08581 L
.04975 .08379 L
.05097 .0823 L
.05245 .08088 L
.0542 .07957 L
.05598 .07855 L
.05811 .07761 L
.06059 .0768 L
.06292 .07625 L
.06528 .07584 L
.06805 .07551 L
.0697 .07537 L
.07128 .07527 L
.07416 .07517 L
.07702 .07514 L
.08035 .07518 L
.08415 .0753 L
.08844 .07551 L
.09277 .07579 L
.10169 .07648 L
.25771 .09224 L
.53402 .11863 L
.61654 .12795 L
Mistroke
.69601 .13899 L
.72939 .14472 L
.75741 .1504 L
.79989 .16167 L
.81665 .1678 L
.83077 .17456 L
.83994 .18052 L
.84404 .18399 L
.84718 .1873 L
.84984 .19096 L
.85089 .19283 L
.85182 .19488 L
.85294 .19857 L
.85338 .20205 L
.85338 .20419 L
.85319 .20623 L
.85238 .21008 L
.85166 .21226 L
.85084 .21429 L
.84844 .21892 L
.84256 .2271 L
.8352 .23492 L
.81232 .25324 L
.78256 .27161 L
.74291 .2916 L
.65202 .32657 L
.58911 .34436 L
.55596 .35191 L
.52287 .35823 L
.48969 .36336 L
.47158 .36565 L
.45197 .36772 L
.43505 .36916 L
.41609 .37037 L
.39853 .37112 L
.38186 .37148 L
.37172 .37153 L
.3606 .37142 L
.34017 .37079 L
.32008 .36958 L
.30136 .36789 L
.28114 .36538 L
.25887 .3617 L
.23586 .35675 L
.21467 .35095 L
.19655 .34486 L
.17788 .33724 L
.1467 .32044 L
.12955 .30816 L
.11493 .29521 L
Mistroke
.092 .26795 L
.08249 .25285 L
.07401 .23649 L
.06241 .20745 L
.05413 .17872 L
.05091 .16434 L
.04861 .15208 L
.04714 .14284 L
.04595 .13383 L
.04518 .12647 L
.04471 .1205 L
.04439 .11419 L
.04432 .11106 L
.04431 .10832 L
.04443 .10387 L
.04475 .09965 L
.04517 .09638 L
.04577 .09322 L
.04656 .09033 L
.04742 .08797 L
.04835 .08602 L
.0493 .08444 L
.05177 .08149 L
.05328 .08021 L
.05484 .07917 L
.05669 .07821 L
.05886 .07734 L
.0612 .07664 L
.06257 .07632 L
.06389 .07607 L
.06637 .07569 L
.06928 .0754 L
.07222 .07523 L
.07518 .07515 L
.07801 .07514 L
.08126 .0752 L
.08505 .07534 L
.08934 .07557 L
.09781 .07616 L
.14951 .08128 L
.24516 .09102 L
.39182 .10479 L
.56208 .12164 L
.63409 .13016 L
.70249 .14003 L
.73357 .14551 L
.76373 .15183 L
.8058 .16367 L
.82173 .17001 L
.83476 .17693 L
Mistroke
.843 .18303 L
.84655 .18657 L
.84917 .18992 L
.85034 .19181 L
.8514 .19388 L
.85273 .19768 L
.85334 .20143 L
.85333 .20494 L
.85272 .20879 L
.8521 .211 L
.85135 .21308 L
.84935 .21732 L
.8465 .22194 L
.84014 .22986 L
.83111 .23868 L
.8095 .25517 L
.75266 .28703 L
.70963 .30587 L
.66276 .32305 L
.61463 .33771 L
.55789 .3515 L
.52585 .35771 L
.48871 .36349 L
.47175 .36563 L
.45315 .36761 L
.43532 .36914 L
.41851 .37024 L
.40814 .37076 L
.39701 .37117 L
.38572 .37143 L
.37314 .37153 L
.36221 .37145 L
.35035 .37118 L
.33907 .37074 L
.32868 .37017 L
.30899 .36865 L
.28736 .36623 L
.2648 .36278 L
.24398 .35864 L
.22355 .35354 L
.20246 .34697 L
.16674 .3319 L
.14845 .32155 L
.13262 .31056 L
.11592 .29617 L
.10197 .28111 L
.09153 .26727 L
.08174 .25152 L
.06828 .22333 L
.05757 .1918 L
Mistroke
.05126 .16604 L
.04745 .14491 L
.04623 .1361 L
.04541 .12885 L
.04488 .12289 L
.04452 .11724 L
.04434 .11215 L
.04433 .1072 L
.04451 .10249 L
.04485 .09873 L
.04542 .09493 L
.04612 .0918 L
.04692 .08927 L
.04776 .0872 L
.04882 .0852 L
.05008 .08335 L
.05145 .0818 L
.05311 .08034 L
.05483 .07917 L
.05658 .07825 L
.05845 .07748 L
.06027 .07689 L
.06253 .07633 L
.06481 .07591 L
.0675 .07557 L
.07056 .07532 L
.07336 .07519 L
.07664 .07514 L
.08045 .07518 L
.08271 .07525 L
.08485 .07533 L
.08925 .07556 L
.09372 .07585 L
.11303 .07752 L
.13559 .07981 L
.20861 .0874 L
.32294 .0984 L
.48782 .11394 L
.56895 .1224 L
.64973 .13223 L
.71591 .1423 L
.76527 .15219 L
.8046 .16325 L
.82095 .16966 L
.83312 .17592 L
.84167 .18189 L
.8474 .18756 L
.8496 .19058 L
.85143 .19395 L
.85269 .19751 L
Mistroke
.8533 .20089 L
.85336 .20461 L
.85312 .20674 L
.85273 .20872 L
.85162 .21239 L
.84986 .21635 L
.84759 .2203 L
.84499 .22405 L
.83894 .23116 L
.81988 .2478 L
.79175 .26634 L
.72339 .3002 L
.62269 .33545 L
.56124 .35079 L
.52351 .35812 L
.48706 .36371 L
.45134 .36778 L
.43044 .36949 L
.41067 .37064 L
.39309 .37128 L
.37338 .37153 L
.35247 .37124 L
.33261 .37041 L
.31342 .36904 L
.29282 .36692 L
.27338 .36421 L
.25579 .36111 L
.23529 .35661 L
.21351 .35059 L
.17588 .33632 L
.15834 .32742 L
.14036 .3162 L
.12434 .30384 L
.10899 .2891 L
.09643 .27408 L
.08651 .25959 L
.07112 .23011 L
.06051 .20163 L
.05383 .17749 L
.04906 .15464 L
.0474 .14457 L
.04608 .1349 L
.04527 .12745 L
.04476 .12132 L
.04446 .11606 L
.04432 .11108 L
.04435 .10622 L
.04453 .10221 L
.0449 .09832 L
.04547 .09468 L
Mistroke
.04617 .09162 L
.04712 .08871 L
.04831 .0861 L
.04959 .08401 L
.05095 .08233 L
.05231 .08099 L
.05405 .07967 L
.05586 .07861 L
.05799 .07766 L
.06047 .07684 L
.06303 .07623 L
.06554 .0758 L
.06718 .0756 L
.06875 .07545 L
.07055 .07532 L
.07253 .07522 L
.07434 .07517 L
.07609 .07514 L
.07809 .07515 L
.08032 .07518 L
.08231 .07524 L
.08451 .07532 L
.08868 .07553 L
.09924 .07628 L
.1231 .07852 L
.18911 .08541 L
.44294 .10959 L
.58714 .12446 L
.66317 .13408 L
.72449 .14382 L
.77428 .15438 L
.79662 .16063 L
.81346 .16652 L
.82781 .17296 L
.83398 .17644 L
.83952 .1802 L
.84356 .18354 L
.84715 .18727 L
.84969 .19072 L
.85145 .19399 L
.85277 .19783 L
.85319 .20002 L
.85338 .20207 L
.85324 .20587 L
.85241 .20997 L
.85094 .21406 L
.849 .21796 L
.84398 .22536 L
.83581 .23433 L
.82633 .24275 L
Mistroke
.79858 .26222 L
.78605 .26964 L
Mfstroke
.80713 .25676 m
.7494 .28857 L
.66339 .32284 L
.61079 .33876 L
.57911 .34677 L
.54732 .35367 L
.51608 .35937 L
.48037 .36458 L
.46403 .3665 L
.44632 .36824 L
.43082 .36946 L
.41359 .3705 L
.40299 .37097 L
.39305 .37128 L
.37316 .37153 L
.35481 .3713 L
.33502 .37054 L
.32373 .36985 L
.31147 .36887 L
.28915 .36646 L
.26743 .36324 L
.24757 .35943 L
.21182 .35007 L
.19228 .34324 L
.17474 .33579 L
.1421 .3174 L
.1258 .30508 L
.11237 .29265 L
.09915 .27761 L
.08711 .26055 L
.07042 .22849 L
.06359 .21086 L
.05849 .19498 L
.05408 .17852 L
.0506 .16282 L
.0485 .15143 L
.04679 .14034 L
.04567 .13136 L
.04498 .12414 L
.04468 .12014 L
.04449 .11662 L
.04436 .11317 L
.04431 .10972 L
.04433 .10692 L
.04442 .10417 L
.04474 .09974 L
.04521 .0961 L
.04591 .09265 L
.04672 .08981 L
.04762 .08751 L
Mistroke
.04863 .08551 L
.04966 .08391 L
.0509 .08237 L
.05234 .08096 L
.05409 .07964 L
.05585 .07861 L
.05791 .07768 L
.06039 .07686 L
.06272 .07629 L
.06543 .07582 L
.06818 .0755 L
.07087 .0753 L
.07376 .07518 L
.07705 .07514 L
.08003 .07517 L
.08353 .07528 L
.08753 .07546 L
.09216 .07575 L
.10141 .07646 L
.14877 .0812 L
.35901 .10175 L
.52829 .11804 L
.62203 .12863 L
.70058 .13972 L
.76187 .1514 L
.78932 .15843 L
.80999 .16519 L
.82406 .17109 L
.83612 .17781 L
.84091 .18128 L
.84514 .18506 L
.84829 .18869 L
.85048 .19206 L
.85207 .19554 L
.85308 .1993 L
.8534 .20255 L
.8532 .20619 L
.85236 .21013 L
.85162 .21237 L
.85078 .21444 L
.84618 .2224 L
.84047 .2295 L
.83253 .23742 L
.81153 .25379 L
.74612 .29011 L
.6641 .32261 L
.60928 .33917 L
.57759 .34713 L
.54182 .35475 L
.5087 .36057 L
Mistroke
.49043 .36326 L
.47023 .36581 L
.45123 .36779 L
.43346 .36928 L
.41522 .37042 L
.39757 .37115 L
.37813 .37151 L
.36704 .3715 L
.35676 .37135 L
.33767 .37067 L
.31732 .36937 L
.29894 .36762 L
.28176 .36547 L
.26294 .36245 L
.24294 .35841 L
.22193 .35309 L
.19969 .346 L
.18082 .33854 L
.16176 .32929 L
.14568 .31977 L
.12928 .30794 L
.10429 .28384 L
.09387 .2706 L
.08433 .25601 L
.07069 .22912 L
.06026 .20083 L
.05275 .17287 L
.04864 .15223 L
.04708 .14243 L
.04599 .13414 L
.04525 .1272 L
.04471 .12049 L
.04442 .11505 L
.04431 .11055 L
.04437 .10542 L
.04461 .10116 L
.04497 .09777 L
.0455 .09449 L
.04624 .09138 L
.0472 .08852 L
.04827 .08618 L
.04937 .08434 L
.05062 .08269 L
.05189 .08137 L
.05342 .08011 L
.05518 .07897 L
.05673 .07818 L
.05852 .07746 L
.06063 .07679 L
.06275 .07629 L
Mistroke
.0641 .07603 L
.0656 .0758 L
.06845 .07547 L
.07014 .07534 L
.07178 .07525 L
.07365 .07518 L
.07576 .07514 L
.07763 .07514 L
.07977 .07517 L
.08186 .07522 L
.08389 .07529 L
.08791 .07548 L
.0925 .07577 L
.11437 .07765 L
.14013 .08029 L
.35646 .10151 L
.50423 .11558 L
.58525 .12424 L
.66602 .13448 L
.73314 .14543 L
.78152 .15626 L
.80016 .16176 L
.81702 .16795 L
.82978 .17401 L
.83897 .17978 L
.8429 .18294 L
.8464 .1864 L
.84903 .18972 L
.85087 .1928 L
.85232 .19626 L
.8532 .2001 L
.85338 .20206 L
.85338 .20418 L
.85289 .20802 L
.85171 .21215 L
.85075 .2145 L
.84969 .21669 L
.84419 .22509 L
.83726 .2329 L
.82805 .24132 L
.77772 .27427 L
.73955 .29313 L
.69867 .31017 L
.65553 .32544 L
.60262 .34093 L
.5468 .35378 L
.51969 .35877 L
.48978 .36335 L
.47202 .3656 L
.45204 .36771 L
Mistroke
.43344 .36928 L
.41573 .37039 L
.40482 .3709 L
.39439 .37124 L
.37457 .37153 L
.36335 .37146 L
.35289 .37125 L
.34134 .37084 L
.32901 .37019 L
.30984 .36873 L
.2891 .36645 L
.26953 .36359 L
.25169 .36029 L
.21113 .34985 L
.19156 .34296 L
.17109 .33406 L
.1537 .32475 L
.13837 .31481 L
.11299 .29327 L
.10081 .27969 L
.09094 .2664 L
.07322 .23479 L
.0631 .20946 L
.05533 .1835 L
.05002 .15986 L
.04694 .14145 L
.04581 .1326 L
.04534 .12819 L
.04499 .12431 L
.04456 .11808 L
.04433 .11199 L
.04431 .1091 L
.04435 .10626 L
.04457 .10168 L
.04478 .09939 L
.04502 .0974 L
.04534 .09538 L
.04574 .09338 L
.04654 .09039 L
.04759 .08758 L
.04876 .0853 L
.04998 .08348 L
.0512 .08205 L
.05268 .08068 L
.05438 .07945 L
.05612 .07848 L
.05796 .07767 L
.06013 .07693 L
.06234 .07637 L
.06455 .07595 L
Mistroke
.06689 .07563 L
.06914 .07541 L
.07191 .07524 L
.07468 .07516 L
.07792 .07514 L
.08159 .07521 L
.08492 .07534 L
.08881 .07554 L
.09845 .07621 L
.10874 .07711 L
.25007 .0915 L
.55525 .1209 L
.64128 .1311 L
.72045 .1431 L
.77397 .1543 L
.79802 .16107 L
.81638 .16769 L
.83013 .17421 L
.83619 .17785 L
.84096 .18131 L
.84464 .18457 L
.8474 .18757 L
.84983 .19095 L
.85172 .19462 L
.85241 .19655 L
.85295 .19861 L
.85339 .20235 L
.85337 .20445 L
.85317 .20643 L
.85276 .20862 L
.8521 .21099 L
.85137 .21304 L
.85039 .21529 L
.84814 .21942 L
.84239 .22731 L
.83423 .23584 L
.8232 .24525 L
.79778 .26271 L
.73311 .296 L
.68677 .31464 L
.63022 .33327 L
.57546 .34762 L
.5083 .36063 L
.47338 .36544 L
.45291 .36763 L
.43352 .36927 L
.41624 .37037 L
.39682 .37117 L
.37616 .37152 L
.35649 .37134 L
Mistroke
.33718 .37065 L
.31864 .36947 L
.30191 .36794 L
.28359 .36572 L
.26379 .3626 L
.24284 .35839 L
.20607 .3482 L
.18472 .3402 L
.16599 .33152 L
.14709 .32069 L
.12812 .307 L
.10105 .27999 L
.08902 .26352 L
.07951 .24747 L
.06565 .21657 L
.05702 .18985 L
.0506 .16279 L
.04861 .15209 L
.04698 .14173 L
.04586 .13301 L
.04513 .12588 L
.04466 .11979 L
.04439 .11406 L
.04431 .10852 L
.04443 .10397 L
.04475 .0996 L
.04502 .0974 L
.04531 .09555 L
.04602 .09218 L
.04684 .08948 L
.04791 .0869 L
.04922 .08456 L
.05052 .08282 L
.05186 .0814 L
.05349 .08006 L
.05541 .07885 L
.05732 .07792 L
.05924 .07721 L
.06151 .07656 L
.06275 .07629 L
.06414 .07602 L
.06685 .07564 L
.0696 .07538 L
.07246 .07522 L
.07527 .07515 L
.07822 .07515 L
.08114 .0752 L
.08453 .07532 L
.0884 .07551 L
.0971 .07611 L
Mistroke
.10607 .07687 L
.26733 .09316 L
.39468 .10505 L
.56124 .12155 L
.6356 .13036 L
.70671 .14073 L
.76173 .15137 L
.80045 .16185 L
.81702 .16795 L
.82942 .17382 L
.83987 .18046 L
.84434 .18427 L
.84759 .1878 L
.8502 .19157 L
.85191 .19509 L
.85303 .19902 L
.85331 .20103 L
.85341 .20325 L
.85307 .20702 L
.85206 .21112 L
.8505 .21504 L
.84859 .21867 L
.84277 .22685 L
.83573 .23441 L
.81437 .25181 L
.75855 .28417 L
.71809 .30242 L
.66712 .32158 L
.61227 .33836 L
.55474 .35216 L
.52429 .35798 L
.49408 .36275 L
.4768 .36503 L
.45756 .36717 L
.43979 .36879 L
.4228 .36999 L
.40367 .37094 L
.39337 .37127 L
.38219 .37148 L
.37039 .37152 L
.35907 .3714 L
.34884 .37113 L
.3376 .37067 L
.31715 .36935 L
.30566 .36833 L
.29521 .3672 L
.27486 .36444 L
.25575 .36111 L
.21477 .35098 L
.19489 .34424 L
Mistroke
.17397 .33544 L
.15706 .32669 L
.1401 .31602 L
.11316 .29344 L
.09945 .278 L
.08676 .25999 L
.07743 .24347 L
.06927 .22574 L
.05806 .19352 L
.0515 .16717 L
.04766 .14627 L
.04638 .1373 L
.04538 .1286 L
.04481 .12199 L
.04445 .11572 L
.04431 .11048 L
.04435 .10624 L
.04458 .10151 L
.04498 .0977 L
.04559 .09405 L
.04597 .0924 L
.04643 .09072 L
.04734 .08818 L
.04846 .08581 L
.04968 .08388 L
.05093 .08235 L
.05229 .08101 L
.05388 .07979 L
.05537 .07887 L
.05711 .07802 L
.05934 .07718 L
.06162 .07654 L
.06401 .07605 L
.06637 .07569 L
.0688 .07544 L
.0712 .07528 L
.074 .07517 L
.0772 .07514 L
.08079 .07519 L
.08442 .07531 L
.08789 .07548 L
.0919 .07573 L
.11216 .07744 L
.13659 .07992 L
.21856 .0884 L
.34463 .10041 L
.51807 .11698 L
.67232 .13539 L
.7085 .14103 L
.7429 .14734 L
Mistroke
.76884 .15304 L
.79281 .15946 L
.81223 .16604 L
.82655 .17232 L
.83718 .17852 L
.84151 .18176 L
.84536 .18529 L
.84817 .18854 L
.85019 .19154 L
.85171 .1946 L
.85269 .19753 L
.85331 .20098 L
.85338 .20422 L
.85293 .20782 L
.85187 .21169 L
.85039 .21528 L
.84824 .21925 L
.8423 .2274 L
.83499 .23512 L
.82672 .24242 L
.77115 .27777 L
.70156 .30905 L
.60573 .34012 L
.57549 .34761 L
.54147 .35482 L
.51041 .36029 L
.4753 .36521 L
.45487 .36744 L
.43572 .36911 L
.41604 .37038 L
.39695 .37117 L
.38609 .37142 L
.37441 .37153 L
.36328 .37146 L
.35312 .37126 L
.34105 .37083 L
.32792 .37013 L
.31545 .36922 L
.30394 .36815 L
.28486 .36589 L
.26443 .36272 L
.22807 .35477 L
.20647 .34833 L
.1867 .34102 L
.15221 .32386 L
.13624 .31326 L
.12074 .30067 L
.09708 .27495 L
.08635 .25933 L
.07778 .24417 L
Mistroke
.06991 .22729 L
.06313 .20956 L
.05493 .18195 L
.04998 .15961 L
.04789 .14776 L
.04645 .13784 L
.04553 .12998 L
.04484 .12233 L
.04445 .11574 L
.04434 .11248 L
.04431 .10965 L
.04438 .10503 L
.04465 .10067 L
.04488 .09846 L
.04519 .09625 L
.04554 .09431 L
.04591 .09265 L
.04672 .08982 L
.04776 .0872 L
.0489 .08506 L
.05008 .08335 L
.05152 .08172 L
.05322 .08026 L
.05484 .07917 L
.05648 .0783 L
.05842 .07749 L
.06067 .07678 L
.06284 .07627 L
.06538 .07583 L
.06795 .07552 L
.07049 .07532 L
.07291 .0752 L
.07575 .07514 L
.0789 .07515 L
.08203 .07523 L
.08602 .07539 L
.09059 .07564 L
.09969 .07632 L
.12523 .07874 L
.19486 .086 L
.43429 .10877 L
.60533 .12659 L
.69185 .13833 L
.7274 .14436 L
.75669 .15024 L
.79956 .16156 L
.81687 .1679 L
.83145 .17494 L
.83727 .17858 L
.84252 .18261 L
Mistroke
.84647 .18648 L
.84931 .19013 L
.8512 .19346 L
.8526 .19719 L
.85332 .20114 L
.85333 .20491 L
.85277 .20854 L
.85158 .21248 L
.84992 .21624 L
.84798 .21969 L
.84153 .22831 L
.83338 .23663 L
.81174 .25365 L
.78077 .2726 L
.70741 .30675 L
.61943 .33637 L
.56496 .34998 L
.53241 .35653 L
.49981 .36192 L
.46813 .36605 L
.45084 .36783 L
.43201 .36938 L
.41424 .37047 L
.39786 .37114 L
.38113 .37149 L
.36517 .37149 L
.346 .37103 L
.32473 .36992 L
.31393 .36909 L
.30234 .36799 L
.28139 .36541 L
.26054 .36202 L
.24098 .35796 L
.20524 .34792 L
.18566 .3406 L
.16585 .33145 L
.13358 .31128 L
.11787 .29803 L
.10475 .28438 L
.09216 .26818 L
.08086 .24995 L
.06693 .21991 L
.05797 .1932 L
.05107 .16513 L
.04733 .14409 L
.04602 .13442 L
.04519 .12656 L
.04485 .12251 L
.04461 .11897 L
.04444 .11553 L
Mistroke
.04433 .11203 L
.04434 .10666 L
.04452 .10236 L
.04469 .10021 L
.04494 .09802 L
.04551 .09445 L
.04617 .09163 L
.04691 .08928 L
.04785 .08701 L
.04902 .08487 L
.05033 .08304 L
.05187 .08139 L
.05333 .08018 L
.05507 .07904 L
.05686 .07813 L
.05861 .07742 L
.0608 .07675 L
.06302 .07623 L
.06522 .07585 L
.06739 .07558 L
.06991 .07536 L
.07277 .07521 L
.07598 .07514 L
.07974 .07517 L
.08356 .07528 L
.08734 .07545 L
.09518 .07596 L
.10463 .07674 L
.16262 .08266 L
.36797 .10258 L
.53632 .11888 L
.62476 .12898 L
.70721 .14081 L
.76528 .15219 L
.79151 .15907 L
.81154 .16577 L
.82624 .17216 L
.83668 .17818 L
.8413 .18159 L
.84543 .18536 L
.8485 .18898 L
.85065 .19238 L
.85218 .19585 L
.85312 .19956 L
.8534 .20277 L
.85318 .20633 L
.85234 .21022 L
.85161 .21242 L
.85078 .21443 L
.84635 .22216 L
Mistroke
.84049 .22948 L
.83235 .23758 L
.81321 .25262 L
.78377 .27093 L
.74516 .29056 L
.70223 .30879 L
.65726 .32487 L
.60892 .33926 L
.55008 .35312 L
.515 .35955 L
.4807 .36454 L
.44633 .36824 L
.42648 .36976 L
.40812 .37076 L
.39035 .37134 L
.37129 .37153 L
.3548 .3713 L
.33652 .37062 L
.31663 .36931 L
.29521 .3672 L
.27497 .36446 L
.2566 .36127 L
.22153 .35297 L
.20231 .34692 L
.18512 .34037 L
.15546 .32578 L
.12752 .30651 L
.11483 .29511 L
.1024 .28162 L
.09176 .26761 L
.08199 .25198 L
.06826 .22329 L
.05924 .19752 L
.05177 .16846 L
.04931 .15606 L
.04759 .1458 L
.04642 .13756 L
.04547 .12945 L
.04483 .12222 L
.04444 .1155 L
.04431 .10989 L
.04438 .1052 L
.04459 .10146 L
.04496 .09784 L
.04552 .09438 L
.0463 .09118 L
.04709 .08879 L
.04811 .08647 L
.04919 .0846 L
.05029 .08309 L
Mistroke
.05159 .08166 L
.05316 .0803 L
.05616 .07846 L
.05799 .07766 L
.05982 .07703 L
.06219 .07641 L
.06357 .07612 L
.06492 .0759 L
.06743 .07557 L
.0704 .07532 L
.07216 .07523 L
.07389 .07518 L
.07733 .07514 L
.07935 .07516 L
.08131 .0752 L
.08354 .07528 L
.08602 .07539 L
.09045 .07564 L
.0956 .07599 L
.10601 .07686 L
.12966 .0792 L
.29968 .09623 L
.45607 .11085 L
.61607 .1279 L
.68821 .13777 L
.75241 .14931 L
.78186 .15635 L
.80479 .16332 L
.82133 .16983 L
.82906 .17362 L
.83514 .17717 L
.84369 .18366 L
.84705 .18715 L
.84979 .19087 L
.85153 .19418 L
.85263 .19729 L
.85328 .20075 L
.85336 .2045 L
.85313 .20666 L
.85275 .20866 L
.85214 .21087 L
.85129 .21322 L
.8494 .21723 L
.84668 .22169 L
.83996 .23007 L
.83181 .23806 L
.80783 .25629 L
.7794 .27335 L
.74175 .29213 L
.69422 .31186 L
Mistroke
.64332 .32932 L
.59129 .34382 L
.56403 .35018 L
.53303 .35641 L
.50247 .36153 L
.47268 .36552 L
.45377 .36755 L
.43617 .36907 L
.41619 .37037 L
.40501 .37089 L
.39434 .37124 L
.38387 .37146 L
.37267 .37153 L
.35233 .37124 L
.34091 .37083 L
.33016 .37026 L
.3183 .36945 L
.30549 .36831 L
.2847 .36587 L
.26205 .36229 L
.24083 .35793 L
.22143 .35294 L
.1862 .34082 L
.16763 .33235 L
.1517 .32355 L
.12314 .3028 L
.10909 .28921 L
.0975 .27549 L
.07858 .24571 L
.07043 .22851 L
.06435 .21302 L
.05621 .18688 L
.05043 .16194 L
.04708 .14238 L
.04601 .13431 L
.04529 .12765 L
.04472 .12077 L
.04439 .11424 L
.04431 .10917 L
.04441 .10445 L
.04472 .09992 L
.04519 .09623 L
.04553 .09433 L
.04589 .09272 L
.04684 .08949 L
.04794 .08683 L
.04912 .08472 L
.05059 .08273 L
.05236 .08095 L
.05406 .07966 L
Mistroke
.05582 .07863 L
.05791 .07768 L
.06038 .07686 L
.06292 .07625 L
.06542 .07582 L
.06688 .07563 L
.06853 .07547 L
.0717 .07525 L
.07491 .07515 L
.07856 .07515 L
.08189 .07522 L
.08578 .07538 L
.08829 .07551 L
.09075 .07565 L
.09563 .07599 L
.10795 .07704 L
.13573 .07983 L
.33488 .09951 L
.48812 .11397 L
.57696 .1233 L
.65522 .13297 L
.71816 .14269 L
.76566 .15228 L
.80591 .16371 L
.82178 .17003 L
.83475 .17692 L
.8397 .18033 L
.84415 .18409 L
.84751 .1877 L
.84991 .19107 L
.85152 .19416 L
.85271 .19761 L
.85333 .20125 L
.85335 .2047 L
.85272 .20879 L
.85149 .21272 L
.8499 .21629 L
.84764 .22022 L
.84074 .2292 L
.83222 .2377 L
.81382 .2522 L
.78785 .26861 L
.71844 .30227 L
.67386 .31926 L
.62033 .33612 L
.56909 .34907 L
.50692 .36084 L
.48764 .36364 L
.46894 .36595 L
.45153 .36776 L
Mistroke
.43266 .36933 L
.42273 .37 L
.41166 .3706 L
.39188 .37131 L
.38059 .37149 L
.36833 .37151 L
.35666 .37135 L
.3459 .37103 L
.32523 .36995 L
.30589 .36835 L
.28459 .36586 L
.26193 .36227 L
.24051 .35785 L
.22066 .35272 L
.18499 .34032 L
.16819 .33263 L
.15115 .32322 L
.1235 .30311 L
.10886 .28896 L
.09668 .27442 L
.07829 .24515 L
.07097 .22977 L
.06457 .21362 L
.05605 .18625 L
.05017 .1606 L
.04805 .14874 L
.04644 .13771 L
.04553 .13001 L
.04485 .12253 L
.04448 .11651 L
.04432 .11151 L
.04435 .10628 L
.04454 .10209 L
.04496 .09785 L
.04553 .09437 L
.04615 .09169 L
.04695 .08918 L
.04773 .08727 L
.04869 .08541 L
.04986 .08365 L
.05125 .082 L
.05271 .08066 L
.05416 .0796 L
.05606 .07851 L
.05802 .07764 L
.05991 .077 L
.06211 .07642 L
.06472 .07593 L
.0661 .07573 L
.06769 .07555 L
Mistroke
.07067 .07531 L
.07365 .07518 L
.07687 .07514 L
.08013 .07518 L
.08324 .07527 L
.08681 .07543 L
.09096 .07567 L
.09567 .076 L
.10497 .07677 L
.26462 .0929 L
.40084 .10563 L
Mfstroke
.82749 .24179 m
.80546 .25785 L
.77979 .27314 L
.70423 .30801 L
.60755 .33963 L
.57529 .34766 L
.5429 .35455 L
.50981 .36039 L
.47724 .36497 L
.45913 .36701 L
.44219 .36859 L
.42297 .36998 L
.4122 .37057 L
.40185 .37101 L
.39181 .37131 L
.381 .37149 L
.36131 .37143 L
.34912 .37114 L
.33756 .37067 L
.32712 .37008 L
.31577 .36924 L
.29664 .36737 L
.27561 .36456 L
.25375 .36071 L
.23356 .35618 L
.19848 .34556 L
.17972 .33805 L
.16339 .33016 L
.14521 .31947 L
.12751 .3065 L
.10054 .27935 L
.0884 .26256 L
.0788 .24612 L
.07005 .22761 L
.06276 .20845 L
.05405 .17841 L
.04911 .15494 L
.04738 .14445 L
.04604 .13452 L
.04546 .12937 L
.04505 .12503 L
.04476 .12122 L
.04453 .11741 L
.04433 .11171 L
.04433 .10699 L
.04441 .10437 L
.04454 .10206 L
.04492 .09813 L
.0455 .09452 L
.04618 .0916 L
Mistroke
.04709 .0888 L
.04824 .08623 L
.04939 .08431 L
.05078 .08251 L
.05224 .08105 L
.05372 .07989 L
.05688 .07812 L
.05865 .07741 L
.06074 .07676 L
.06201 .07645 L
.06345 .07615 L
.06622 .07571 L
.06915 .07541 L
.07206 .07524 L
.07543 .07515 L
.07746 .07514 L
.07944 .07516 L
.08161 .07521 L
.08367 .07528 L
.08602 .07539 L
.0886 .07552 L
.09782 .07616 L
.10757 .07701 L
.1347 .07972 L
.31394 .09756 L
.46639 .11184 L
.63837 .13072 L
.71327 .14184 L
.74692 .14816 L
.77779 .15527 L
.80123 .16211 L
.81855 .1686 L
.83219 .17537 L
.84181 .182 L
.84533 .18526 L
.84845 .18891 L
.84972 .19077 L
.85087 .19279 L
.85239 .19649 L
.85319 .20002 L
.8534 .2038 L
.85307 .20706 L
.8522 .21068 L
.85142 .21291 L
.85051 .21503 L
.84837 .21904 L
.84161 .22821 L
.83372 .23632 L
.82315 .24529 L
.76982 .27846 L
Mistroke
.72949 .29759 L
.68533 .31517 L
.63306 .33243 L
.5769 .34728 L
.54314 .3545 L
.50399 .36129 L
.48599 .36386 L
.4663 .36625 L
.44751 .36813 L
.42958 .36955 L
.41076 .37064 L
.40065 .37105 L
.3897 .37135 L
.37811 .37151 L
.36703 .3715 L
.34603 .37103 L
.32618 .37001 L
.30768 .36852 L
.2873 .36622 L
.26568 .36294 L
.24435 .35873 L
.22174 .35303 L
.18257 .33929 L
.16141 .3291 L
.14079 .3165 L
.12331 .30295 L
.10913 .28925 L
.08778 .26161 L
.07844 .24543 L
.07106 .22997 L
.06097 .20305 L
.05357 .1764 L
.04851 .1515 L
.04687 .1409 L
.0456 .13068 L
.04489 .12306 L
.04462 .1192 L
.04445 .11591 L
.04431 .11012 L
.04437 .1053 L
.04464 .10085 L
.04487 .09859 L
.04512 .09666 L
.04572 .09346 L
.0465 .0905 L
.04734 .08816 L
.04823 .08624 L
.04934 .08438 L
.05066 .08265 L
.05224 .08106 L
Mistroke
.05415 .0796 L
.05615 .07846 L
.05816 .07759 L
.06013 .07693 L
.06247 .07634 L
.06511 .07587 L
.06778 .07554 L
.07045 .07532 L
.07358 .07518 L
.07675 .07514 L
.07988 .07517 L
.08318 .07527 L
.08634 .0754 L
.09409 .07588 L
.11525 .07774 L
.14094 .08038 L
.32249 .09836 L
.48603 .11376 L
.57155 .12269 L
.64546 .13165 L
.71451 .14206 L
.76766 .15276 L
.79117 .15897 L
.80934 .16495 L
.8254 .17174 L
.83262 .17562 L
.83823 .17925 L
.84245 .18255 L
.84624 .18622 L
.8492 .18997 L
.85049 .19207 L
.85145 .19399 L
.85271 .1976 L
.85335 .20151 L
.85331 .20518 L
.85274 .20869 L
.8522 .21069 L
.85142 .2129 L
.8493 .21741 L
.8467 .22165 L
.84374 .22566 L
.82356 .24497 L
.79849 .26227 L
.76385 .28152 L
.72728 .29854 L
.68219 .3163 L
.63112 .33301 L
.57916 .34676 L
.55205 .35272 L
.52124 .35851 L
Mistroke
.49059 .36324 L
.46145 .36677 L
.44363 .36847 L
.42641 .36976 L
.40787 .37077 L
.39725 .37116 L
.38734 .3714 L
.37066 .37152 L
.35203 .37123 L
.33234 .37039 L
.31372 .36907 L
.29281 .36692 L
.27081 .3638 L
.25211 .36038 L
.23192 .35577 L
.21052 .34965 L
.18844 .34173 L
.15157 .32348 L
.13356 .31127 L
.11852 .29864 L
.10414 .28367 L
.09057 .26586 L
.07287 .23404 L
.06565 .21656 L
.06024 .20075 L
.05283 .17323 L
.04857 .15188 L
.04698 .14174 L
.04574 .13198 L
.04496 .12391 L
.04452 .11733 L
.04433 .11173 L
.04434 .10653 L
.04451 .10261 L
.04484 .09879 L
.04537 .09517 L
.04574 .09335 L
.04612 .0918 L
.04698 .0891 L
.04792 .08686 L
.04892 .08502 L
.05011 .08331 L
.05257 .08077 L
.05413 .07962 L
.0557 .07869 L
.05758 .07782 L
.05977 .07704 L
.06232 .07638 L
.06489 .0759 L
.06646 .07568 L
Mistroke
.06795 .07552 L
.06974 .07537 L
.0715 .07526 L
.0749 .07516 L
.07826 .07515 L
.08011 .07518 L
.08222 .07523 L
.08451 .07532 L
.08674 .07542 L
.09567 .076 L
.10494 .07677 L
.13037 .07927 L
.33039 .09909 L
.47322 .11251 L
.55458 .12082 L
.63852 .13074 L
.70951 .1412 L
.76278 .15161 L
.80183 .16231 L
.81704 .16796 L
.8304 .17435 L
.83638 .17798 L
.84115 .18146 L
.84476 .18468 L
.84786 .18814 L
.85043 .19196 L
.85208 .19555 L
.85311 .19946 L
.85336 .20171 L
.85339 .20383 L
.85297 .20763 L
.85201 .21127 L
.85071 .21458 L
.84884 .21823 L
.84302 .22655 L
.83572 .23442 L
.81436 .25182 L
.78336 .27116 L
.70793 .30655 L
.66367 .32275 L
.61086 .33874 L
.56058 .35093 L
.49982 .36192 L
.46447 .36645 L
.44376 .36846 L
.42417 .36991 L
.40671 .37082 L
.38711 .3714 L
.36629 .3715 L
.34648 .37105 L
Mistroke
.32707 .37007 L
.30846 .3686 L
.2917 .36678 L
.27338 .36421 L
.25365 .36069 L
.23283 .356 L
.19652 .34485 L
.1756 .3362 L
.15739 .32688 L
.13915 .31535 L
.12101 .30092 L
.0955 .27284 L
.08432 .256 L
.07558 .23977 L
.06297 .20907 L
.05521 .18304 L
.04951 .15712 L
.04777 .14697 L
.04637 .13718 L
.04542 .12898 L
.04483 .12228 L
.04448 .11657 L
.04432 .1112 L
.04435 .10601 L
.04456 .10176 L
.04498 .09768 L
.04529 .09562 L
.04562 .09389 L
.04643 .09074 L
.04732 .08822 L
.04846 .08582 L
.04986 .08364 L
.05123 .08202 L
.05265 .08071 L
.05435 .07947 L
.05637 .07836 L
.05836 .07752 L
.06036 .07687 L
.06272 .07629 L
.06401 .07605 L
.06545 .07582 L
.06827 .07549 L
.07112 .07528 L
.07409 .07517 L
.077 .07514 L
.08005 .07517 L
.08308 .07526 L
.08659 .07541 L
.09059 .07564 L
.10887 .07713 L
Mistroke
.26419 .09286 L
.41193 .10666 L
.50692 .11585 L
.59639 .12553 L
.67504 .13579 L
.73633 .14604 L
.78926 .15841 L
.81034 .16532 L
.82767 .17289 L
.83805 .17912 L
.84262 .1827 L
.84603 .18599 L
.8486 .18912 L
.85075 .19255 L
.85218 .19584 L
.85301 .19891 L
.8534 .20253 L
.85323 .20596 L
.85247 .20977 L
.851 .21392 L
.85003 .21602 L
.84879 .21832 L
.84607 .22256 L
.83944 .23063 L
.81863 .24873 L
.79184 .26629 L
.72478 .29961 L
.62833 .33382 L
.5625 .35052 L
.52775 .35737 L
.49433 .36271 L
.4781 .36487 L
.46007 .36692 L
.44415 .36843 L
.42625 .36977 L
.40688 .37081 L
.39612 .37119 L
.38595 .37142 L
.36754 .37151 L
.34746 .37108 L
.32863 .37017 L
.3079 .36854 L
.28825 .36634 L
.27 .36367 L
.23589 .35676 L
.21721 .35171 L
.20066 .34634 L
.18125 .33873 L
.16177 .3293 L
.13025 .30871 L
Mistroke
.11495 .29522 L
.10227 .28146 L
.08948 .26422 L
.07932 .24711 L
.06543 .21597 L
.05682 .1891 L
.05077 .16364 L
.04845 .15113 L
.04687 .14093 L
.04587 .13309 L
.04509 .12543 L
.04459 .11863 L
.04434 .11234 L
.04432 .10745 L
.04449 .10285 L
.04482 .09902 L
.04524 .09593 L
.04556 .09419 L
.04595 .09247 L
.04676 .0897 L
.04781 .08711 L
.04915 .08467 L
.05047 .08287 L
.05206 .08122 L
.05373 .07989 L
.05539 .07886 L
.05742 .07788 L
.05978 .07704 L
.0622 .0764 L
.06457 .07595 L
.06612 .07573 L
.0676 .07555 L
.0693 .0754 L
.07117 .07528 L
.07451 .07516 L
.07652 .07514 L
.07848 .07515 L
.08035 .07518 L
.08247 .07524 L
.08653 .07541 L
.09077 .07566 L
.09494 .07594 L
.11826 .07804 L
.2942 .09571 L
.44264 .10956 L
.59445 .1253 L
.66551 .13441 L
.72312 .14357 L
.77223 .15387 L
.79331 .15961 L
Mistroke
.81205 .16597 L
.82716 .17263 L
.83363 .17623 L
.83941 .18011 L
.84359 .18357 L
.84729 .18743 L
.84987 .19101 L
.85162 .19439 L
.85281 .19798 L
.85334 .20143 L
.85336 .20457 L
.85289 .20803 L
.85182 .21183 L
.85008 .21592 L
.84812 .21945 L
.84546 .2234 L
.82992 .23973 L
.8059 .25756 L
.7456 .29036 L
.65716 .32491 L
.59591 .34266 L
.56322 .35036 L
.53125 .35674 L
.49922 .36201 L
.46214 .3667 L
.44216 .36859 L
.423 .36998 L
.41227 .37057 L
.40234 .37099 L
.39077 .37133 L
.37967 .3715 L
.3608 .37143 L
.34042 .3708 L
.321 .36965 L
.30327 .36809 L
.28231 .36554 L
.25969 .36186 L
.23853 .35739 L
.21939 .35236 L
.18529 .34044 L
.1558 .32598 L
.12711 .30617 L
.11303 .29331 L
.10157 .28062 L
.08252 .25291 L
.07405 .23658 L
.06754 .22147 L
.05844 .19482 L
.05199 .16946 L
.04795 .14813 L
Mistroke
.0465 .13822 L
.04553 .13004 L
.04495 .12377 L
.04454 .11777 L
.04433 .11187 L
.04433 .10713 L
.04453 .10229 L
.04489 .09838 L
.04547 .09463 L
.04584 .09294 L
.04629 .09122 L
.04716 .08861 L
.04826 .08619 L
.04946 .08421 L
.05067 .08263 L
.05201 .08126 L
.05358 .08 L
.05505 .07905 L
.05676 .07817 L
.05896 .0773 L
.06121 .07664 L
.06357 .07612 L
.0659 .07575 L
.0683 .07549 L
.07067 .07531 L
.07343 .07519 L
.07659 .07514 L
.08014 .07518 L
.08374 .07529 L
.08716 .07544 L
.09112 .07568 L
.11117 .07734 L
.13536 .07979 L
.21656 .0882 L
.34945 .10086 L
.51477 .11664 L
.66964 .135 L
.70611 .14063 L
.74083 .14693 L
.76705 .15261 L
.79131 .15901 L
.81103 .16558 L
.8256 .17184 L
.83647 .17804 L
.84091 .18127 L
.84487 .18479 L
.84778 .18803 L
.84988 .19103 L
.85149 .19408 L
.85255 .19701 L
Mistroke
.85325 .20045 L
.8534 .20368 L
.85303 .20727 L
.85206 .21114 L
.85065 .21472 L
.84858 .2187 L
.84277 .22685 L
.83558 .23455 L
.82741 .24186 L
.77224 .2772 L
.70296 .30851 L
.6075 .33965 L
.57732 .34719 L
.54338 .35445 L
.51239 .35998 L
.47737 .36496 L
.45697 .36723 L
.43785 .36894 L
.4182 .37026 L
.39915 .3711 L
.3883 .37138 L
.37663 .37152 L
.36551 .37149 L
.35537 .37132 L
.34331 .37093 L
.33019 .37027 L
.31773 .3694 L
.30624 .36838 L
.28713 .3662 L
.26669 .36311 L
.23025 .35534 L
.20857 .34903 L
.18872 .34184 L
.15402 .32494 L
.1379 .31447 L
.12224 .30201 L
.09827 .2765 L
.08736 .26095 L
.07864 .24583 L
.07062 .22895 L
.0637 .21118 L
.05529 .18336 L
.0502 .16079 L
.04806 .1488 L
.04657 .13875 L
.04561 .13079 L
.04489 .12304 L
.04447 .11635 L
.04436 .11305 L
.04431 .11018 L
Mistroke
.04437 .1055 L
.04462 .10107 L
.04484 .09884 L
.04514 .09659 L
.04547 .09463 L
.04584 .09294 L
.04664 .09007 L
.04766 .08742 L
.04867 .08545 L
.04971 .08384 L
.05097 .0823 L
.05244 .08088 L
.05524 .07894 L
.05703 .07805 L
.05882 .07735 L
.06109 .07667 L
.06341 .07615 L
.06564 .07579 L
.06824 .07549 L
.07127 .07527 L
.07289 .0752 L
.07474 .07516 L
.0782 .07515 L
.08168 .07522 L
.08564 .07537 L
.08798 .07549 L
.09019 .07562 L
.09924 .07628 L
.12466 .07868 L
.19396 .08591 L
.43272 .10862 L
.58896 .12467 L
.6681 .13478 L
.73136 .14509 L
.78508 .15723 L
.80692 .16407 L
.82533 .17171 L
.83182 .17515 L
.83783 .17897 L
.84226 .18239 L
.84612 .18609 L
.84885 .18946 L
.8511 .19324 L
.85247 .19674 L
.8532 .20006 L
.8534 .20363 L
.85299 .20751 L
.85203 .21121 L
.8507 .21461 L
.84859 .21867 L
Mistroke
.84567 .22311 L
.83878 .23133 L
.81741 .24962 L
.79061 .26701 L
.72627 .29897 L
.68217 .31631 L
.63647 .33141 L
.58576 .34518 L
.52424 .35799 L
.48768 .36363 L
.46917 .36593 L
.45201 .36772 L
.43507 .36916 L
.4164 .37036 L
.39627 .37119 L
.37699 .37152 L
.3588 .37139 L
.34165 .37086 L
.32264 .36977 L
.30216 .36797 L
.28059 .3653 L
.26024 .36196 L
.2419 .35817 L
.22271 .35331 L
.18907 .34198 L
.1601 .32839 L
.13213 .31018 L
.11802 .29817 L
.1061 .28592 L
.0953 .27256 L
.08527 .25757 L
.07093 .22966 L
.05919 .19732 L
.05234 .17106 L
.04793 .148 L
.04635 .13708 L
.04535 .12828 L
.04477 .12147 L
.04441 .11487 L
.04433 .11186 L
.04431 .10886 L
.04443 .10397 L
.04474 .09973 L
.04518 .09628 L
.04583 .09296 L
.04622 .09145 L
.0467 .0899 L
.0476 .08756 L
.04872 .08537 L
.04992 .08356 L
Mistroke
.05114 .08212 L
.05375 .07987 L
.05542 .07884 L
.05711 .07802 L
.05903 .07728 L
.06091 .07672 L
.06324 .07619 L
.0656 .0758 L
.06815 .0755 L
.07111 .07528 L
.07409 .07517 L
.077 .07514 L
.08064 .07519 L
.08281 .07525 L
.0849 .07534 L
.08894 .07554 L
.09355 .07584 L
.11693 .0779 L
.14475 .08078 L
.33201 .09924 L
.4796 .11313 L
.64199 .13119 L
.7146 .14207 L
.7473 .14824 L
.77735 .15516 L
.80032 .16181 L
.8174 .16811 L
.83098 .17468 L
.84069 .1811 L
.84437 .1843 L
.8476 .18781 L
.84997 .19117 L
.85158 .19429 L
.85276 .1978 L
.85336 .20169 L
.8534 .20368 L
.85325 .20581 L
.85248 .2097 L
.85181 .21187 L
.85102 .21388 L
.8487 .21848 L
.84267 .22697 L
.83526 .23486 L
.82557 .24337 L
.77808 .27408 L
.70351 .30829 L
.65362 .32606 L
.59984 .34166 L
.54601 .35393 L
.51342 .35981 L
Mistroke
.48121 .36448 L
.46235 .36668 L
.44145 .36865 L
.42201 .37004 L
.4038 .37094 L
.38363 .37146 L
.37204 .37153 L
.36114 .37143 L
.34953 .37115 L
.33889 .37073 L
.32654 .37004 L
.3148 .36916 L
.29493 .36717 L
.27384 .36428 L
.2559 .36113 L
.23633 .35686 L
.2157 .35126 L
.19416 .34396 L
.15773 .32707 L
.14035 .31619 L
.12584 .30511 L
.1117 .29196 L
.09824 .27645 L
.08747 .26113 L
.079 .2465 L
.06599 .21747 L
.05645 .18776 L
.04997 .15957 L
.04785 .1475 L
.04624 .13614 L
.04521 .12684 L
.04464 .11944 L
.04436 .11326 L
.04432 .10753 L
.04447 .10323 L
.04481 .09906 L
.04508 .09696 L
.04537 .09517 L
.04574 .09337 L
.04619 .09156 L
.04708 .08882 L
.04819 .08633 L
.04941 .08427 L
.05067 .08264 L
.05228 .08102 L
.05396 .07973 L
.05567 .07871 L
.05737 .0779 L
.05939 .07716 L
.0617 .07652 L
Mistroke
.0641 .07603 L
.06693 .07563 L
.06981 .07536 L
.07267 .07521 L
.0757 .07515 L
.07863 .07515 L
.08222 .07523 L
.08583 .07538 L
.09006 .07561 L
.09484 .07594 L
.1043 .07671 L
.13052 .07929 L
.29813 .09608 L
.45242 .1105 L
.61324 .12755 L
.67679 .13604 L
.73496 .14578 L
.76078 .15116 L
.78542 .15732 L
.80334 .16282 L
.819 .1688 L
.8325 .17555 L
.84173 .18194 L
.84566 .1856 L
.84855 .18905 L
.85092 .19289 L
.8519 .19507 L
.85257 .19707 L
.85328 .20072 L
.85338 .20414 L
.85291 .20793 L
.85176 .212 L
.85025 .21558 L
.84842 .21897 L
.84282 .22679 L
.83427 .2358 L
.82412 .24452 L
.80012 .26126 L
.76782 .2795 L
.72451 .29973 L
.63296 .33246 L
.57265 .34826 L
.54255 .35461 L
.50909 .3605 L
.4787 .36479 L
.46209 .36671 L
.44392 .36844 L
.42683 .36974 L
.411 .37063 L
.39482 .37123 L
Mistroke
.37932 .3715 L
.361 .37143 L
.34133 .37084 L
.32438 .36989 L
.30559 .36832 L
.28534 .36596 L
.26361 .36257 L
.24324 .35848 L
.22488 .35391 L
.20475 .34776 L
.1864 .3409 L
.1543 .3251 L
.13789 .31446 L
.12399 .30354 L
.10937 .28951 L
.09736 .27531 L
.08089 .25 L
.06748 .22133 L
.05835 .19451 L
.05185 .16882 L
.04752 .14535 L
.04601 .13434 L
.04549 .12962 L
.04509 .12549 L
.0446 .11872 L
.04444 .11546 L
.04434 .11219 L
.04431 .10917 L
.04435 .10622 L
.04459 .10149 L
.04498 .09772 L
.04556 .09419 L
.04627 .09128 L
.04703 .08895 L
.04808 .08655 L
.04939 .0843 L
.0508 .08249 L
.05224 .08106 L
.0539 .07977 L
.05562 .07873 L
.0573 .07794 L
.05926 .0772 L
.06157 .07655 L
.06292 .07625 L
.06423 .07601 L
.06696 .07562 L
.06961 .07538 L
.07233 .07523 L
.0754 .07515 L
.07819 .07515 L
Mistroke
.08144 .07521 L
.08516 .07535 L
.08943 .07557 L
.09791 .07617 L
.15589 .08195 L
.24398 .09091 L
.33536 .09955 L
Mfstroke
.8382 .23193 m
.82002 .24769 L
.79766 .26279 L
.72918 .29772 L
.63956 .33047 L
.5791 .34677 L
.51736 .35916 L
.48151 .36444 L
.46109 .36681 L
.44147 .36865 L
.42442 .36989 L
.40572 .37086 L
.39492 .37123 L
.38456 .37145 L
.36486 .37148 L
.35354 .37127 L
.3432 .37092 L
.3312 .37033 L
.31983 .36956 L
.29948 .36768 L
.27742 .36483 L
.25314 .36059 L
.22784 .35471 L
.20676 .34843 L
.18445 .34009 L
.16473 .33086 L
.1472 .32076 L
.11807 .29822 L
.10418 .28372 L
.09294 .2693 L
.08178 .2516 L
.07311 .23456 L
.06221 .20684 L
.05412 .17869 L
.04916 .15522 L
.0473 .14388 L
.04606 .13474 L
.04521 .12681 L
.04468 .12017 L
.04438 .11397 L
.04431 .11081 L
.04431 .1081 L
.04443 .10396 L
.04472 .09993 L
.04519 .09622 L
.04578 .09318 L
.04617 .09162 L
.04665 .09005 L
.04764 .08748 L
.04875 .08531 L
Mistroke
.04992 .08356 L
.05148 .08176 L
.05306 .08038 L
.05507 .07904 L
.05716 .07799 L
.05923 .07721 L
.06169 .07652 L
.06301 .07623 L
.06449 .07596 L
.06732 .07558 L
.07038 .07533 L
.0735 .07519 L
.07649 .07514 L
.07996 .07517 L
.08402 .0753 L
.08647 .07541 L
.08886 .07554 L
.09991 .07633 L
.1247 .07869 L
.28721 .09505 L
.44279 .10958 L
.52844 .11805 L
.60504 .12656 L
.67591 .13591 L
.74096 .14695 L
.77047 .15343 L
.79347 .15966 L
.81172 .16584 L
.82715 .17262 L
.83849 .17944 L
.84337 .18337 L
.84694 .18701 L
.84952 .19046 L
.85157 .19427 L
.85279 .19792 L
.85334 .20135 L
.85329 .20536 L
.85262 .20918 L
.85197 .21139 L
.85121 .21343 L
.84893 .21808 L
.84621 .22236 L
.84256 .2271 L
.83316 .23684 L
.80983 .25495 L
.78094 .27251 L
.71022 .30563 L
.66474 .32239 L
.60998 .33898 L
.57861 .34689 L
Mistroke
.54179 .35476 L
.50891 .36053 L
.49085 .3632 L
.47108 .36571 L
.45066 .36784 L
.4317 .3694 L
.41223 .37057 L
.39354 .37126 L
.37416 .37153 L
.35608 .37133 L
.33598 .37059 L
.31455 .36914 L
.2965 .36735 L
.27713 .36479 L
.24243 .35829 L
.22162 .353 L
.20239 .34695 L
.16823 .33265 L
.15182 .32362 L
.13498 .31233 L
.12001 .30002 L
.10564 .2854 L
.09394 .2707 L
.08465 .25654 L
.07017 .2279 L
.05927 .19759 L
.05171 .16815 L
.04917 .15528 L
.04718 .1431 L
.04596 .1339 L
.04547 .12947 L
.04505 .12503 L
.04474 .12106 L
.04454 .11768 L
.04433 .11168 L
.04431 .10876 L
.04436 .10582 L
.04447 .10324 L
.04462 .10102 L
.04506 .0971 L
.0456 .094 L
.04639 .09085 L
.04729 .08829 L
.04845 .08583 L
.04987 .08363 L
.05124 .08202 L
.0529 .0805 L
.0549 .07914 L
.05728 .07794 L
.05976 .07704 L
Mistroke
.06223 .0764 L
.06476 .07592 L
.06611 .07573 L
.06766 .07555 L
.07056 .07531 L
.07348 .07519 L
.07533 .07515 L
.07716 .07514 L
.08078 .07519 L
.08292 .07526 L
.08498 .07534 L
.08993 .0756 L
.09934 .07629 L
.10905 .07714 L
.13555 .07981 L
.34538 .10048 L
.49153 .11431 L
.57288 .12284 L
.65496 .13294 L
.72405 .14374 L
.77453 .15444 L
.79419 .15988 L
.81215 .166 L
.82591 .17199 L
.83598 .17771 L
.84036 .18084 L
.84433 .18426 L
.84715 .18727 L
.84961 .1906 L
.8516 .19435 L
.85237 .19642 L
.85289 .19836 L
.85337 .20188 L
.85326 .20569 L
.85246 .20979 L
.85172 .21212 L
.85084 .21429 L
.8488 .21832 L
.84602 .22263 L
.8398 .23023 L
.83102 .23877 L
.8072 .25671 L
.7779 .27417 L
.70652 .30711 L
.66091 .32367 L
.60579 .3401 L
.57089 .34866 L
.53722 .35563 L
.5041 .36128 L
.48587 .36387 L
Mistroke
.46581 .3663 L
.44661 .36821 L
.42873 .36961 L
.41039 .37066 L
.39271 .37129 L
.37258 .37153 L
.35368 .37127 L
.33269 .37041 L
.32201 .36973 L
.31019 .36876 L
.29062 .36665 L
.27268 .3641 L
.25308 .36057 L
.23269 .35596 L
.1993 .34586 L
.18121 .33871 L
.16513 .33107 L
.14752 .32096 L
.12996 .30848 L
.11594 .29619 L
.10273 .28202 L
.09228 .26835 L
.08237 .25264 L
.06868 .22431 L
.05779 .19259 L
.05363 .17666 L
.05062 .16291 L
.0485 .15141 L
.04678 .14028 L
.04567 .13133 L
.04497 .12405 L
.04455 .11789 L
.04433 .11213 L
.04433 .10703 L
.04454 .10215 L
.04488 .09844 L
.04541 .09495 L
.04606 .09206 L
.04676 .08972 L
.0478 .08711 L
.04892 .08503 L
.05031 .08306 L
.05198 .08129 L
.05359 .07998 L
.05524 .07894 L
.05721 .07797 L
.05953 .07712 L
.06212 .07642 L
.06472 .07593 L
.06632 .0757 L
Mistroke
.06783 .07553 L
.06965 .07538 L
.07144 .07527 L
.07309 .0752 L
.07491 .07516 L
.07834 .07515 L
.08035 .07518 L
.08231 .07523 L
.08453 .07532 L
.08701 .07544 L
.09681 .07608 L
.10751 .077 L
.13195 .07943 L
.30027 .09628 L
.45767 .111 L
.54309 .11959 L
.61926 .12829 L
.6868 .13755 L
.74883 .14856 L
.7754 .15466 L
.79641 .16056 L
.81477 .16703 L
.83015 .17422 L
.8414 .18167 L
.84603 .186 L
.84926 .19006 L
.8513 .19367 L
.85215 .19575 L
.85274 .19771 L
.85316 .19979 L
.85336 .20171 L
.85339 .20394 L
.85321 .20607 L
.85246 .20981 L
.85104 .21384 L
.84915 .21769 L
.84699 .22122 L
.83999 .23003 L
.83132 .2385 L
.8104 .25456 L
.78076 .27261 L
.74555 .29038 L
.70111 .30923 L
.65304 .32624 L
.60371 .34065 L
.54856 .35342 L
.4911 .36317 L
.47507 .36524 L
.45741 .36719 L
.44183 .36862 L
Mistroke
.42448 .36989 L
.41381 .37049 L
.4038 .37094 L
.38374 .37146 L
.36521 .37149 L
.34517 .371 L
.33398 .37048 L
.32363 .36984 L
.31222 .36894 L
.30012 .36775 L
.27974 .36518 L
.25743 .36143 L
.23774 .3572 L
.21698 .35165 L
.18109 .33866 L
.16353 .33024 L
.14818 .32138 L
.13281 .3107 L
.11735 .29754 L
.09533 .27261 L
.08541 .2578 L
.07742 .24347 L
.06557 .21634 L
.0578 .19262 L
.05193 .1692 L
.04797 .14826 L
.04658 .13883 L
.0455 .12977 L
.04483 .12225 L
.04446 .11613 L
.04432 .11121 L
.04434 .10639 L
.04455 .10195 L
.0449 .09829 L
.04549 .09455 L
.04622 .09147 L
.047 .08904 L
.048 .08671 L
.04924 .08453 L
.05075 .08254 L
.05235 .08096 L
.05396 .07973 L
.05563 .07873 L
.05755 .07783 L
.05931 .07719 L
.06139 .07659 L
.0638 .07608 L
.06659 .07567 L
.06943 .07539 L
.07221 .07523 L
Mistroke
.0752 .07515 L
.07813 .07515 L
.08157 .07521 L
.08546 .07536 L
.08906 .07555 L
.09263 .07578 L
.10153 .07647 L
.23042 .08958 L
.36522 .10232 L
.52408 .1176 L
.60663 .12675 L
.67796 .13622 L
.71307 .14181 L
.74688 .14815 L
.79444 .15995 L
.81316 .1664 L
.82932 .17376 L
.83578 .17758 L
.84151 .18176 L
.84583 .18579 L
.84889 .18952 L
.85112 .19329 L
.8525 .19683 L
.85329 .20077 L
.85341 .203 L
.85332 .20503 L
.85271 .20881 L
.8514 .21295 L
.84957 .21691 L
.84741 .22059 L
.84121 .22867 L
.83387 .23618 L
.81196 .25349 L
.75539 .28571 L
.71476 .30379 L
.66342 .32283 L
.60822 .33945 L
.55005 .35312 L
.51988 .35874 L
.48981 .36334 L
.47267 .36552 L
.4535 .36757 L
.43579 .3691 L
.41877 .37023 L
.40876 .37073 L
.39782 .37114 L
.37846 .37151 L
.36733 .37151 L
.35547 .37132 L
.34527 .371 L
Mistroke
.33401 .37048 L
.3137 .36907 L
.30226 .36798 L
.29181 .36679 L
.25237 .36043 L
.23142 .35564 L
.20963 .34937 L
.17246 .33472 L
.15338 .32456 L
.13675 .31364 L
.11997 .29997 L
.10439 .28396 L
.09342 .26996 L
.08309 .25389 L
.06891 .22488 L
.06287 .20878 L
.05772 .19234 L
.05119 .16571 L
.04724 .14348 L
.04598 .13407 L
.04544 .12918 L
.04505 .12501 L
.04457 .11827 L
.04433 .11191 L
.04433 .10676 L
.04452 .10245 L
.04471 .10009 L
.04493 .0981 L
.04523 .09597 L
.04558 .09412 L
.04631 .09113 L
.04727 .08834 L
.04853 .08569 L
.05009 .08334 L
.05161 .08164 L
.05346 .08008 L
.05539 .07886 L
.05739 .07789 L
.05935 .07717 L
.06163 .07653 L
.06434 .07599 L
.06579 .07577 L
.06746 .07557 L
.06894 .07543 L
.0706 .07531 L
.07378 .07518 L
.077 .07514 L
.08076 .07519 L
.08277 .07525 L
.085 .07534 L
Mistroke
.08923 .07556 L
.09834 .07621 L
.10771 .07702 L
.27328 .09373 L
.403 .10583 L
.56998 .12251 L
.64435 .13151 L
.71449 .14205 L
.76813 .15287 L
.80524 .16347 L
.82173 .17001 L
.8337 .17627 L
.84338 .18338 L
.84698 .18706 L
.84856 .18906 L
.84998 .1912 L
.85181 .19486 L
.85287 .19826 L
.85338 .20198 L
.85338 .20411 L
.85321 .20611 L
.85246 .20978 L
.85132 .21316 L
.84947 .2171 L
.84722 .22087 L
.8412 .22868 L
.83392 .23613 L
.81187 .25355 L
.74646 .28996 L
.66889 .32098 L
.61665 .33715 L
.56314 .35038 L
.53201 .3566 L
.50117 .36172 L
.48346 .36419 L
.46381 .36652 L
.44708 .36817 L
.42832 .36964 L
.41017 .37067 L
.39294 .37128 L
.37444 .37153 L
.35432 .37129 L
.33537 .37056 L
.31727 .36936 L
.30093 .36784 L
.28312 .36566 L
.2622 .36232 L
.24273 .35836 L
.21994 .35252 L
.19962 .34597 L
Mistroke
.16076 .32875 L
.14223 .31748 L
.12446 .30395 L
.11156 .29181 L
.09929 .27779 L
.08119 .25054 L
.07251 .23324 L
.06582 .21701 L
.05658 .18821 L
.05079 .16375 L
.0474 .14456 L
.04614 .13533 L
.04528 .12755 L
.04494 .12364 L
.04465 .11967 L
.04437 .11339 L
.04431 .11025 L
.04432 .10749 L
.04449 .10284 L
.04467 .10048 L
.04488 .09847 L
.04516 .09641 L
.04552 .0944 L
.04623 .0914 L
.04704 .08894 L
.04806 .08658 L
.04933 .08439 L
.05065 .08266 L
.05201 .08126 L
.05364 .07995 L
.05555 .07877 L
.05736 .07791 L
.05919 .07723 L
.06134 .07661 L
.06385 .07607 L
.06623 .07571 L
.06901 .07542 L
.07184 .07525 L
.07464 .07516 L
.07758 .07514 L
.08041 .07518 L
.08387 .07529 L
.08733 .07545 L
.09604 .07603 L
.10528 .0768 L
.13091 .07933 L
.20837 .08738 L
.45765 .111 L
.54173 .11945 L
.63025 .12967 L
Mistroke
.70428 .14033 L
.76041 .15107 L
.79921 .16145 L
.81633 .16767 L
.82923 .17371 L
.83468 .17688 L
.83961 .18026 L
.84645 .18646 L
.84921 .18999 L
.85114 .19332 L
.85256 .19704 L
.85305 .19914 L
.85331 .20106 L
.85335 .2047 L
.85286 .20814 L
.85177 .21197 L
.84997 .21614 L
.84743 .22056 L
.84441 .2248 L
.83725 .23291 L
.81981 .24785 L
.79466 .26461 L
.76057 .28317 L
.71688 .30292 L
.61904 .33648 L
.55584 .35193 L
.52304 .3582 L
.49082 .3632 L
.45412 .36751 L
.43397 .36924 L
.42255 .37001 L
.41187 .37059 L
.40057 .37105 L
.38814 .37139 L
.37708 .37152 L
.36522 .37149 L
.34448 .37097 L
.33256 .3704 L
.32133 .36968 L
.30206 .36796 L
.28095 .36535 L
.25897 .36172 L
.23872 .35744 L
.20335 .34728 L
.1844 .34007 L
.16793 .3325 L
.13394 .31156 L
.11725 .29745 L
.10365 .2831 L
.08325 .25416 L
Mistroke
.07514 .23886 L
.06775 .22202 L
.05777 .19251 L
.0509 .16429 L
.04879 .15311 L
.04709 .14245 L
.046 .13423 L
.04517 .12633 L
.04465 .11962 L
.04439 .11415 L
.04431 .10947 L
.04438 .10507 L
.04464 .1008 L
.04503 .09729 L
.04562 .0939 L
.04643 .09074 L
.04747 .08785 L
.04861 .08556 L
.05004 .08341 L
.05177 .08149 L
.05345 .08009 L
.05519 .07897 L
.05727 .07795 L
.05973 .07705 L
.0621 .07643 L
.06343 .07615 L
.06491 .0759 L
.06779 .07554 L
.07067 .07531 L
.07394 .07517 L
.07724 .07514 L
.08041 .07518 L
.08406 .0753 L
.08818 .0755 L
.09219 .07575 L
.10217 .07652 L
.12403 .07862 L
.19798 .08632 L
.32374 .09847 L
.48239 .1134 L
.63476 .13025 L
.70198 .13995 L
.73562 .14591 L
.76275 .15161 L
.78613 .15752 L
.80744 .16425 L
.82447 .17129 L
.83206 .17529 L
.83788 .179 L
.84223 .18236 L
Mistroke
.84609 .18606 L
.84925 .19004 L
.85139 .19386 L
.85269 .1975 L
.85334 .2014 L
.85334 .20478 L
.85277 .20855 L
.85154 .21261 L
.84983 .21642 L
.84737 .22065 L
.84409 .22522 L
.82751 .24177 L
.80426 .25863 L
.77781 .27422 L
.74059 .29266 L
.69303 .31231 L
.6414 .32991 L
.58689 .34491 L
.52967 .35703 L
.49506 .36261 L
.46197 .36672 L
.44247 .36857 L
.42404 .36992 L
.41426 .37047 L
.40338 .37095 L
.39189 .37131 L
.381 .37149 L
.3608 .37143 L
.34205 .37087 L
.32125 .36967 L
.31074 .36881 L
.29923 .36766 L
.27588 .3646 L
.25397 .36075 L
.2345 .35642 L
.21382 .35069 L
.19194 .34311 L
.16988 .33347 L
.15196 .32371 L
.13417 .31173 L
.11908 .29916 L
.10671 .2866 L
.08652 .25961 L
.07751 .24364 L
.06941 .22609 L
.05858 .19529 L
.05222 .17049 L
.04792 .14795 L
.04662 .13911 L
.04561 .13078 L
Mistroke
.045 .12442 L
.04457 .11819 L
.04441 .11471 L
.04433 .11165 L
.04434 .10646 L
.04444 .10384 L
.04458 .10159 L
.04479 .09929 L
.04507 .09704 L
.04567 .09369 L
.04637 .09093 L
.04729 .08829 L
.04845 .08583 L
.04983 .08368 L
.05128 .08197 L
.05307 .08037 L
.05519 .07897 L
.05743 .07788 L
.05976 .07704 L
.06203 .07644 L
.06468 .07593 L
.06731 .07558 L
.06889 .07543 L
.07043 .07532 L
.0737 .07518 L
.07565 .07515 L
.07749 .07514 L
.08096 .0752 L
.08501 .07534 L
.08911 .07555 L
.09314 .07581 L
.11271 .07749 L
.13998 .08027 L
.21081 .08762 L
.3276 .09883 L
.4978 .11493 L
.58194 .12386 L
.66553 .13441 L
.73271 .14535 L
.78099 .15612 L
.8034 .16284 L
.82011 .16928 L
.83427 .17662 L
.83983 .18043 L
.84477 .18469 L
.84815 .18851 L
.85047 .19205 L
.85146 .19402 L
.8523 .1962 L
.85287 .19827 L
Mistroke
.85322 .2002 L
.85339 .20403 L
.85298 .20754 L
.85188 .21166 L
.85025 .21557 L
.8482 .21932 L
.84548 .22337 L
.83927 .2308 L
.81938 .24817 L
.79046 .2671 L
.75765 .28461 L
.67749 .31798 L
.6302 .33328 L
.5808 .34637 L
.52284 .35823 L
.48971 .36336 L
.45223 .3677 L
.43284 .36932 L
.42241 .37001 L
.41116 .37062 L
.40025 .37106 L
.39025 .37134 L
.37047 .37152 L
.35111 .3712 L
.32992 .37025 L
.30972 .36871 L
.29105 .3667 L
.27361 .36425 L
.25498 .36095 L
.2219 .35308 L
.20228 .34691 L
.18431 .34003 L
.1528 .32421 L
.1381 .31461 L
.12369 .30328 L
.10126 .28024 L
.09082 .26623 L
.08231 .25253 L
.06721 .22064 L
.05764 .19203 L
.05174 .1683 L
.04768 .14639 L
.04622 .13606 L
.0453 .12779 L
.04496 .12395 L
.04468 .12015 L
.04438 .11397 L
.04431 .10816 L
.04438 .1052 L
.0445 .10263 L
Mistroke
.04488 .09847 L
.04538 .09514 L
.04572 .09347 L
.04613 .09177 L
.04701 .08901 L
.04804 .08663 L
.04914 .08468 L
.05025 .08314 L
.05157 .08168 L
.05316 .0803 L
.05502 .07907 L
.05675 .07818 L
.0588 .07736 L
.06088 .07672 L
.06292 .07625 L
.06544 .07582 L
.06801 .07551 L
.07054 .07532 L
.07303 .0752 L
.07592 .07514 L
.07919 .07516 L
.08265 .07525 L
.0867 .07542 L
.09123 .07569 L
.09574 .076 L
.1153 .07774 L
.18052 .08453 L
.40355 .10588 L
.57877 .1235 L
.65992 .13362 L
.7245 .14383 L
.77218 .15385 L
.79185 .15917 L
.8101 .16523 L
.82495 .17152 L
.83169 .17508 L
.83718 .17852 L
.84151 .18176 L
.84542 .18535 L
.84826 .18866 L
.85032 .19177 L
.85195 .19522 L
.85301 .19891 L
.85338 .20211 L
.85326 .20565 L
.85253 .20952 L
.85186 .21171 L
.85109 .21371 L
.84917 .21765 L
.84686 .22142 L
Mistroke
.8411 .22879 L
.83435 .23573 L
.81439 .25179 L
.75244 .28713 L
.71179 .305 L
.6598 .32404 L
.60401 .34057 L
.54435 .35426 L
.51634 .35933 L
.4851 .36397 L
.46647 .36623 L
.44919 .36798 L
.43277 .36933 L
.41439 .37046 L
.39427 .37125 L
.38312 .37147 L
.37262 .37153 L
.3536 .37127 L
.33297 .37043 L
.3213 .36967 L
.30855 .36861 L
.28529 .36595 L
.26268 .36241 L
.24194 .35818 L
.20508 .34787 L
.185 .34032 L
.167 .33203 L
.13404 .31163 L
.11783 .29799 L
.10462 .28423 L
.09319 .26964 L
.08385 .25519 L
.06996 .2274 L
.05947 .19828 L
.05212 .17004 L
.04813 .14924 L
.04667 .13949 L
.04567 .13136 L
.04506 .12514 L
.04462 .11913 L
.04436 .11321 L
.04431 .10841 L
.04446 .10347 L
.04463 .10099 L
.04483 .09891 L
.04536 .09524 L
.04601 .09222 L
.04645 .09066 L
.04696 .08915 L
.048 .08671 L
Mistroke
.04928 .08446 L
.05091 .08237 L
.05251 .08082 L
.05412 .07962 L
.05617 .07845 L
.05829 .07754 L
.06042 .07685 L
.06254 .07633 L
.06505 .07588 L
.06792 .07552 L
.07052 .07532 L
.07357 .07518 L
.07664 .07514 L
.07968 .07517 L
.08288 .07525 L
.08594 .07538 L
.08968 .07559 L
.09342 .07583 L
.11221 .07744 L
.13827 .08009 L
.29537 .09582 L
Mfstroke
.84465 .2245 m
.82961 .23999 L
.80991 .2549 L
.74695 .28973 L
.66267 .32308 L
.60538 .34021 L
.54663 .35381 L
.5124 .35998 L
.47405 .36536 L
.45767 .36716 L
.43966 .3688 L
.42917 .36958 L
.41946 .37019 L
.40013 .37107 L
.38937 .37136 L
.37779 .37151 L
.36676 .3715 L
.35668 .37135 L
.34471 .37098 L
.33167 .37035 L
.31929 .36952 L
.30785 .36854 L
.28702 .36618 L
.26418 .36267 L
.24053 .35786 L
.21885 .3522 L
.19915 .3458 L
.17853 .33753 L
.16126 .32902 L
.14404 .3187 L
.12972 .30829 L
.11532 .29559 L
.0938 .27051 L
.0832 .25409 L
.07502 .23862 L
.06772 .22194 L
.06132 .20415 L
.05359 .1765 L
.04857 .15187 L
.04703 .14206 L
.04584 .13282 L
.04537 .12844 L
.04496 .12396 L
.0445 .11685 L
.04432 .111 L
.04431 .10803 L
.04437 .10551 L
.04462 .10107 L
.04502 .09738 L
.04555 .09426 L
Mistroke
.04625 .09134 L
.04705 .08891 L
.04788 .08696 L
.04898 .08493 L
.05034 .08303 L
.05177 .08149 L
.05321 .08026 L
.05491 .07913 L
.0569 .07811 L
.05894 .07731 L
.06095 .0767 L
.0635 .07614 L
.06504 .07588 L
.06652 .07568 L
.06939 .07539 L
.07093 .07529 L
.07269 .07521 L
.07447 .07516 L
.07641 .07514 L
.08009 .07518 L
.08227 .07523 L
.08436 .07531 L
.08942 .07557 L
.09888 .07625 L
.11051 .07728 L
.26991 .09341 L
.42028 .10745 L
.51585 .11676 L
.60474 .12652 L
.68308 .13698 L
.74322 .14741 L
.76989 .15329 L
.79451 .15997 L
.81553 .16734 L
.83087 .17462 L
.84045 .18091 L
.84465 .18458 L
.84782 .18808 L
.85035 .19182 L
.85198 .1953 L
.85306 .19917 L
.85332 .20115 L
.8534 .20332 L
.85307 .20704 L
.85226 .21047 L
.85076 .21447 L
.8488 .2183 L
.84408 .22523 L
.83726 .23289 L
.81759 .24949 L
Mistroke
.79321 .26547 L
.75728 .28479 L
.71807 .30243 L
.61913 .33646 L
.58864 .34448 L
.55319 .35248 L
.51741 .35915 L
.48265 .36429 L
.44595 .36827 L
.42597 .36979 L
.41574 .37039 L
.40439 .37091 L
.38498 .37144 L
.37396 .37153 L
.36383 .37147 L
.34395 .37095 L
.32492 .36993 L
.3065 .36841 L
.28687 .36616 L
.27013 .36369 L
.25174 .3603 L
.23226 .35585 L
.21168 .35002 L
.17615 .33645 L
.15763 .32702 L
.14153 .31701 L
.12401 .30356 L
.10979 .28995 L
.08601 .25879 L
.07594 .24052 L
.06821 .22316 L
.05806 .19351 L
.05192 .16912 L
.04772 .14665 L
.04635 .13707 L
.04531 .1278 L
.0447 .12033 L
.04439 .11424 L
.04431 .10839 L
.04437 .10546 L
.04448 .10301 L
.04483 .09892 L
.0451 .09684 L
.04539 .09507 L
.04604 .09211 L
.04688 .08937 L
.04776 .08721 L
.04883 .08518 L
.04996 .0835 L
.0511 .08216 L
Mistroke
.05257 .08077 L
.05433 .07949 L
.05615 .07846 L
.05797 .07766 L
.06005 .07696 L
.06248 .07634 L
.06496 .07589 L
.0674 .07558 L
.07045 .07532 L
.07229 .07523 L
.07406 .07517 L
.0775 .07514 L
.07953 .07516 L
.08145 .07521 L
.08355 .07528 L
.08585 .07538 L
.09022 .07562 L
.10128 .07645 L
.12628 .07885 L
.30855 .09706 L
.43976 .10929 L
.59715 .12562 L
.67655 .13601 L
.73875 .14652 L
.7856 .15737 L
.80434 .16316 L
.82124 .16979 L
.82843 .17329 L
.83494 .17704 L
.84399 .18394 L
.84766 .18788 L
.85023 .19161 L
.85135 .19378 L
.85216 .19577 L
.85283 .19809 L
.85323 .2003 L
.85339 .20404 L
.85288 .20805 L
.85193 .21152 L
.85034 .21538 L
.84804 .21959 L
.8449 .22416 L
.83757 .23258 L
.81626 .25046 L
.78972 .26753 L
.75031 .28814 L
.70752 .30671 L
.61001 .33897 L
.58021 .34651 L
.54601 .35393 L
Mistroke
.51435 .35966 L
.47865 .3648 L
.45974 .36695 L
.44142 .36865 L
.42463 .36988 L
.40603 .37085 L
.38809 .37139 L
.36874 .37151 L
.352 .37123 L
.33334 .37045 L
.32263 .36977 L
.31132 .36886 L
.29103 .3667 L
.2692 .36353 L
.2455 .35898 L
.22522 .354 L
.20409 .34753 L
.16809 .33258 L
.14876 .32174 L
.13234 .31034 L
.11634 .29658 L
.10095 .27986 L
.0803 .24893 L
.07167 .23135 L
.06509 .21506 L
.05595 .18587 L
.05055 .16256 L
.04848 .1513 L
.0468 .14038 L
.04566 .13126 L
.04495 .12386 L
.04454 .11772 L
.04433 .11198 L
.04433 .1069 L
.04454 .10204 L
.0449 .09834 L
.04543 .09486 L
.04608 .09198 L
.04678 .08965 L
.04783 .08705 L
.04895 .08498 L
.05035 .08301 L
.05202 .08125 L
.05364 .07995 L
.05529 .07891 L
.05727 .07795 L
.05959 .0771 L
.06218 .07641 L
.06479 .07592 L
.06639 .07569 L
Mistroke
.06791 .07552 L
.06973 .07537 L
.07153 .07526 L
.07318 .0752 L
.075 .07515 L
.07843 .07515 L
.08045 .07518 L
.08241 .07524 L
.08464 .07532 L
.08712 .07544 L
.09694 .07609 L
.10766 .07701 L
.13215 .07945 L
.30071 .09632 L
.45822 .11105 L
.54365 .11965 L
.61978 .12835 L
.68726 .13762 L
.7492 .14863 L
.77571 .15474 L
.79668 .16065 L
.81498 .16712 L
.83031 .1743 L
.83664 .17815 L
.84152 .18177 L
.84585 .1858 L
.84767 .18789 L
.84932 .19016 L
.85145 .194 L
.85273 .19766 L
.85318 .19992 L
.85338 .20208 L
.85339 .20403 L
.8532 .20617 L
.85232 .21028 L
.85095 .21404 L
.84872 .21844 L
.84602 .22264 L
.8398 .23024 L
.83119 .23862 L
.80887 .25559 L
.78221 .2718 L
.74359 .29128 L
.70207 .30885 L
.65544 .32547 L
.5979 .34216 L
.56313 .35038 L
.52896 .35715 L
.49443 .3627 L
.47624 .3651 L
Mistroke
.45584 .36735 L
.43669 .36903 L
.41852 .37024 L
.40082 .37104 L
.38161 .37148 L
.36244 .37145 L
.34413 .37096 L
.32753 .3701 L
.30944 .36869 L
.28949 .3665 L
.26757 .36326 L
.24486 .35884 L
.22395 .35365 L
.18793 .34152 L
.16887 .33297 L
.15243 .32399 L
.13789 .31446 L
.12362 .30322 L
.10137 .28038 L
.08253 .25293 L
.07407 .23662 L
.06747 .2213 L
.05895 .19654 L
.05275 .17288 L
.04838 .15075 L
.04599 .1341 L
.04516 .12625 L
.04485 .12249 L
.0446 .11876 L
.04434 .11259 L
.04432 .10757 L
.04446 .10332 L
.04474 .09977 L
.04518 .09631 L
.04581 .09304 L
.04665 .09003 L
.04776 .0872 L
.04899 .08492 L
.05028 .0831 L
.05171 .08154 L
.05314 .08032 L
.05494 .07911 L
.0568 .07815 L
.05856 .07744 L
.06064 .07679 L
.06298 .07624 L
.06533 .07584 L
.06768 .07555 L
.06995 .07535 L
.07274 .07521 L
Mistroke
.07556 .07515 L
.07881 .07515 L
.0825 .07524 L
.08585 .07538 L
.08978 .07559 L
.09948 .0763 L
.10989 .07722 L
.25128 .09161 L
.39462 .10505 L
.55609 .12099 L
.63655 .13048 L
.704 .14028 L
.73642 .14606 L
.76704 .15261 L
.79051 .15878 L
.80884 .16476 L
.82467 .17139 L
.83208 .17531 L
.83781 .17895 L
.84248 .18258 L
.84658 .1866 L
.84839 .18884 L
.84982 .19093 L
.85094 .19293 L
.85191 .19511 L
.8526 .19717 L
.85304 .19907 L
.8534 .20285 L
.85318 .20633 L
.85239 .21005 L
.85092 .21411 L
.84901 .21794 L
.8428 .22681 L
.83458 .23551 L
.82515 .2437 L
.79782 .26269 L
.72869 .29793 L
.64484 .32884 L
.59469 .34297 L
.53304 .35641 L
.49994 .3619 L
.48176 .36441 L
.46187 .36673 L
.44228 .36858 L
.42412 .36991 L
.40549 .37087 L
.38763 .3714 L
.36989 .37152 L
.35089 .3712 L
.33449 .37051 L
Mistroke
.31635 .36929 L
.2967 .36737 L
.27561 .36456 L
.25577 .36111 L
.23786 .35723 L
.21732 .35175 L
.19612 .3447 L
.16037 .32854 L
.14227 .31752 L
.12668 .30581 L
.11112 .29135 L
.09687 .27466 L
.08695 .26029 L
.0777 .24402 L
.06518 .21529 L
.05543 .18391 L
.04982 .15878 L
.04792 .1479 L
.04643 .13766 L
.04551 .12981 L
.04484 .12233 L
.04459 .11853 L
.04443 .1153 L
.04431 .10956 L
.04434 .10667 L
.04444 .10376 L
.04461 .10123 L
.04481 .09905 L
.04536 .09525 L
.04604 .09213 L
.04677 .08967 L
.0477 .08733 L
.04887 .08511 L
.05029 .08309 L
.05164 .08161 L
.05328 .08021 L
.05503 .07906 L
.05684 .07814 L
.05859 .07743 L
.06064 .07679 L
.06305 .07623 L
.06444 .07597 L
.06581 .07577 L
.06835 .07548 L
.07135 .07527 L
.07418 .07517 L
.07734 .07514 L
.08021 .07518 L
.08354 .07528 L
.08737 .07546 L
Mistroke
.09174 .07572 L
.10039 .07637 L
.24308 .09082 L
.38351 .10402 L
.56687 .12217 L
.64335 .13137 L
.71531 .14219 L
.75022 .14885 L
.77753 .15521 L
.80074 .16195 L
.81819 .16845 L
.83069 .17452 L
.8408 .18118 L
.84479 .18472 L
.84782 .18809 L
.85036 .19185 L
.85145 .19399 L
.85222 .19597 L
.85309 .19934 L
.8534 .20251 L
.85322 .20603 L
.85244 .20985 L
.85101 .21391 L
.84909 .2178 L
.8441 .2252 L
.83706 .23309 L
.82887 .24062 L
.80494 .25819 L
.7361 .29468 L
.65562 .32541 L
.60166 .34118 L
.54652 .35383 L
.51449 .35964 L
.48281 .36427 L
.46464 .36643 L
.4445 .36839 L
.42576 .36981 L
.40819 .37076 L
.39125 .37132 L
.37521 .37153 L
.35738 .37136 L
.33804 .37069 L
.31755 .36939 L
.29804 .36752 L
.28048 .36528 L
.26144 .36218 L
.22154 .35298 L
.19959 .34596 L
.17978 .33808 L
.14316 .31811 L
Mistroke
.12501 .30441 L
.11017 .29036 L
.08933 .264 L
.07983 .24806 L
.0724 .23299 L
.06098 .20309 L
.05305 .17416 L
.04831 .15029 L
.04676 .14009 L
.04555 .13024 L
.04488 .12287 L
.04446 .11592 L
.04431 .11018 L
.04437 .10556 L
.04448 .10303 L
.04466 .10053 L
.04515 .09651 L
.04554 .09431 L
.04597 .09241 L
.04692 .08926 L
.04802 .08667 L
.04918 .08462 L
.05063 .08268 L
.05236 .08095 L
.05404 .07968 L
.0557 .07869 L
.0578 .07773 L
.05997 .07698 L
.06212 .07642 L
.06426 .076 L
.06677 .07565 L
.06964 .07538 L
.07272 .07521 L
.07456 .07516 L
.0763 .07514 L
.07987 .07517 L
.08351 .07528 L
.08565 .07537 L
.08803 .07549 L
.09254 .07577 L
.10402 .07669 L
.25297 .09178 L
.39735 .1053 L
.58145 .12381 L
.65671 .13318 L
.72643 .14418 L
.75982 .15094 L
.78566 .15739 L
.80716 .16415 L
.82347 .17081 L
Mistroke
.83493 .17704 L
.83996 .18053 L
.84391 .18387 L
.84691 .18698 L
.84913 .18987 L
.85104 .19313 L
.85246 .19669 L
.85323 .20031 L
.8534 .20372 L
.85299 .20751 L
.85189 .21162 L
.85109 .21371 L
.85004 .216 L
.84766 .22019 L
.84164 .22818 L
.83403 .23603 L
.824 .24462 L
.80133 .2605 L
.72979 .29745 L
.67993 .31711 L
.62521 .33473 L
.56972 .34893 L
.53541 .35597 L
.50206 .36159 L
.46629 .36625 L
.44677 .3682 L
.43665 .36904 L
.42567 .36981 L
.40688 .37081 L
.38904 .37137 L
.378 .37151 L
.36746 .37151 L
.3475 .37109 L
.32923 .37021 L
.30968 .36871 L
.29292 .36693 L
.27443 .36438 L
.2547 .3609 L
.23367 .35621 L
.1968 .34495 L
.17719 .33692 L
.15986 .32826 L
.14065 .3164 L
.12474 .30418 L
.09728 .2752 L
.08525 .25754 L
.07583 .24029 L
.06316 .20963 L
.05529 .18337 L
.04974 .15838 L
Mistroke
.04785 .14748 L
.04634 .13696 L
.04535 .12825 L
.04475 .12114 L
.04442 .11513 L
.04431 .1095 L
.04438 .10507 L
.0446 .10135 L
.04497 .09773 L
.04554 .09429 L
.04627 .09129 L
.04723 .08843 L
.04843 .08587 L
.04972 .08383 L
.05108 .08218 L
.05244 .08088 L
.05417 .07959 L
.05597 .07855 L
.05765 .07779 L
.05964 .07708 L
.06188 .07648 L
.06414 .07602 L
.0664 .07569 L
.0686 .07546 L
.07129 .07527 L
.07402 .07517 L
.07715 .07514 L
.08071 .07519 L
.0843 .07531 L
.08776 .07548 L
.09715 .07611 L
.10728 .07698 L
.24353 .09086 L
.38315 .10398 L
.54378 .11967 L
.62437 .12893 L
.69311 .13853 L
.72645 .14418 L
.75837 .15061 L
.80265 .16259 L
.81965 .16908 L
.8341 .17652 L
.83975 .18037 L
.84467 .1846 L
.84827 .18867 L
.8507 .19246 L
.85226 .19606 L
.85311 .19946 L
.85341 .20324 L
.85329 .20538 L
Mistroke
.85302 .20734 L
.85199 .21134 L
.85113 .21362 L
.85017 .21573 L
.84512 .22387 L
.8382 .23193 L
.83026 .23943 L
.80716 .25674 L
.74873 .28889 L
.70727 .30681 L
.65486 .32566 L
.60263 .34093 L
.53924 .35525 L
.50245 .36153 L
.48566 .3639 L
.46679 .3662 L
.44973 .36793 L
.43107 .36945 L
.42058 .37012 L
.41093 .37063 L
.39178 .37131 L
.37297 .37153 L
.35535 .37132 L
.33578 .37058 L
.31482 .36916 L
.29655 .36736 L
.2794 .36513 L
.26064 .36203 L
.2406 .35788 L
.20046 .34627 L
.17888 .33768 L
.15989 .32827 L
.12556 .30488 L
.10921 .28933 L
.09631 .27392 L
.07774 .24409 L
.06972 .22684 L
.06371 .2112 L
.0555 .18416 L
.04992 .15933 L
.04808 .14889 L
.04657 .13872 L
.04561 .13075 L
.0449 .12323 L
.04452 .11725 L
.04432 .1114 L
.04434 .1067 L
.0445 .10277 L
.04486 .09867 L
.04542 .0949 L
Mistroke
.04605 .09209 L
.04688 .08938 L
.04793 .08684 L
.04925 .08451 L
.05067 .08263 L
.05211 .08117 L
.0536 .07998 L
.05533 .07889 L
.05692 .0781 L
.05881 .07735 L
.061 .07669 L
.06356 .07613 L
.06616 .07572 L
.06872 .07545 L
.07145 .07527 L
.07415 .07517 L
.07731 .07514 L
.08091 .07519 L
.08458 .07532 L
.08827 .0755 L
.09578 .07601 L
.1162 .07783 L
.14526 .08083 L
.23215 .08975 L
.49748 .1149 L
.58525 .12424 L
.66267 .13401 L
.72302 .14356 L
.7759 .15479 L
.79761 .16094 L
.81713 .168 L
.82523 .17166 L
.83272 .17568 L
.83819 .17923 L
.84315 .18317 L
.84686 .18693 L
.84954 .19048 L
.85158 .19429 L
.85238 .19645 L
.85291 .19842 L
.85338 .20201 L
.85323 .20595 L
.85248 .20972 L
.85129 .21324 L
.8494 .21723 L
.84709 .22107 L
.84147 .22838 L
.82312 .24531 L
.80148 .26041 L
.77231 .27716 L
Mistroke
.73392 .29565 L
.68582 .31498 L
.63751 .33109 L
.58002 .34656 L
.54841 .35346 L
.5117 .36009 L
.47643 .36507 L
.46011 .36691 L
.44199 .36861 L
.43079 .36947 L
.42033 .37014 L
.41041 .37066 L
.39938 .37109 L
.37998 .3715 L
.35906 .3714 L
.34707 .37107 L
.33603 .37059 L
.32322 .36981 L
.31097 .36883 L
.28918 .36646 L
.26541 .36289 L
.24323 .35848 L
.22265 .35329 L
.18567 .3406 L
.16618 .33162 L
.14931 .32209 L
.13113 .3094 L
.11583 .29608 L
.09431 .27121 L
.08491 .25698 L
.07632 .24128 L
.06306 .20934 L
.05502 .18232 L
.05 .15976 L
.04663 .1392 L
.04558 .13054 L
.04517 .1264 L
.04484 .12234 L
.04444 .11559 L
.04431 .11014 L
.04436 .10567 L
.04459 .10144 L
.04495 .09791 L
.0454 .09505 L
.04606 .09206 L
.04693 .08922 L
.04791 .0869 L
.04893 .08502 L
.05016 .08325 L
.05163 .08162 L
Mistroke
.05318 .08029 L
.05472 .07925 L
.05668 .07821 L
.05902 .07728 L
.06145 .07658 L
.06388 .07607 L
.06529 .07584 L
.06687 .07563 L
.06991 .07536 L
.0731 .0752 L
.07626 .07514 L
.07993 .07517 L
.08213 .07523 L
.08427 .07531 L
.08883 .07554 L
.09412 .07588 L
.1172 .07793 L
.14516 .08082 L
.24011 .09053 L
.37765 .10347 L
.53784 .11904 L
.6796 .13646 L
.74404 .14757 L
.78989 .15859 L
.80908 .16485 L
.82358 .17087 L
.83597 .1777 L
.84136 .18163 L
.84534 .18526 L
.84863 .18916 L
.85088 .1928 L
.85176 .19473 L
.85251 .19687 L
.85305 .19912 L
.85333 .20124 L
.85331 .20519 L
.8527 .20885 L
.85213 .21089 L
.85133 .21313 L
.8494 .21724 L
.84444 .22477 L
.83708 .23307 L
.81892 .24852 L
.7899 .26743 L
.75671 .28507 L
.66925 .32085 L
.61537 .3375 L
.58431 .34553 L
.54838 .35346 L
.51264 .35994 L
Mistroke
.47782 .3649 L
.44292 .36853 L
.42474 .36987 L
.41423 .37047 L
.40429 .37092 L
.38563 .37143 L
.36761 .37151 L
.35124 .37121 L
.33318 .37044 L
.31345 .36905 L
.29231 .36685 L
.27236 .36405 L
.25434 .36083 L
.2332 .35609 L
.21132 .34991 L
.17407 .33548 L
.15485 .32542 L
.13817 .31466 L
.12049 .30045 L
.10569 .28546 L
.09454 .27153 L
.08408 .25558 L
.06971 .2268 L
.06354 .21072 L
.0583 .19433 L
.05162 .16774 L
.04773 .14672 L
.04643 .13769 L
.04542 .12893 L
.04483 .12228 L
.04446 .11598 L
.04431 .11071 L
.04434 .10644 L
.04457 .10168 L
.04496 .09785 L
.04556 .09418 L
.04594 .09252 L
.0464 .09082 L
.0473 .08827 L
.04842 .08589 L
.04963 .08395 L
.05087 .08241 L
.05223 .08106 L
.05381 .07983 L
.0553 .07891 L
.05704 .07805 L
.05926 .0772 L
.06153 .07656 L
.06392 .07606 L
.06628 .07571 L
Mistroke
.0687 .07545 L
.07109 .07528 L
.07389 .07518 L
.07708 .07514 L
.08066 .07519 L
.08429 .07531 L
.08775 .07548 L
.09174 .07572 L
.11554 .07777 L
.15142 .08148 L
.26721 .09315 L
Mfstroke
.05009 .08334 m
.05143 .08182 L
.05277 .08061 L
.05445 .07941 L
.05619 .07844 L
.0578 .07773 L
.05964 .07708 L
.0618 .0765 L
.06394 .07606 L
.06641 .07569 L
.06927 .0754 L
.07216 .07523 L
.07499 .07515 L
.07852 .07515 L
.08064 .07519 L
.08268 .07525 L
.08662 .07542 L
.09112 .07568 L
.10105 .07643 L
.11348 .07757 L
.14126 .08041 L
.21658 .0882 L
.50576 .11573 L
.5889 .12466 L
.67127 .13524 L
.71293 .14178 L
.74644 .14806 L
.77393 .15429 L
.79843 .1612 L
.81605 .16755 L
.83127 .17484 L
.83659 .17812 L
.84145 .18171 L
.84521 .18513 L
.84804 .18837 L
.85058 .19224 L
.85158 .19431 L
.85241 .19654 L
.85301 .1989 L
.85332 .20116 L
.85341 .2032 L
.85329 .20543 L
.85301 .20738 L
.85253 .20955 L
.85182 .21182 L
.85099 .21396 L
.84907 .21783 L
.84643 .22204 L
.8396 .23045 L
.82982 .23981 L
Mistroke
.80627 .25732 L
.74399 .2911 L
.69938 .3099 L
.651 .3269 L
.60146 .34124 L
.54318 .35449 L
.51028 .36032 L
.49217 .36302 L
.47223 .36557 L
.45341 .36758 L
.43588 .36909 L
.41789 .37028 L
.40055 .37105 L
.38004 .3715 L
.36955 .37152 L
.35789 .37137 L
.33708 .37064 L
.31737 .36937 L
.30603 .36836 L
.29407 .36707 L
.2727 .3641 L
.24983 .35991 L
.22521 .354 L
.18604 .34075 L
.16536 .33119 L
.14752 .32096 L
.11842 .29854 L
.10582 .2856 L
.09366 .27031 L
.07673 .2421 L
.06935 .22595 L
.06379 .21145 L
.05606 .18631 L
.05059 .16276 L
.04851 .15152 L
.04681 .14046 L
.04569 .13149 L
.04498 .12421 L
.0447 .12042 L
.04449 .11671 L
.04436 .11325 L
.04431 .10975 L
.04433 .10694 L
.04442 .10416 L
.04475 .09966 L
.04527 .09573 L
.04565 .09375 L
.04605 .09207 L
.04691 .08928 L
.04799 .08672 L
Mistroke
.0491 .08474 L
.05027 .08311 L
.05169 .08156 L
.05338 .08014 L
.05526 .07893 L
.05714 .078 L
.05949 .07713 L
.06192 .07647 L
.06435 .07599 L
.06675 .07565 L
.06958 .07538 L
.0728 .07521 L
.07631 .07514 L
.0784 .07515 L
.08037 .07518 L
.08444 .07531 L
.08857 .07552 L
.09889 .07625 L
.11203 .07743 L
.27561 .09395 L
.40913 .1064 L
.57657 .12325 L
.66651 .13455 L
.73605 .14599 L
.78749 .1579 L
.80745 .16426 L
.82486 .17148 L
.83136 .17489 L
.83738 .17866 L
.84185 .18204 L
.84573 .18567 L
.84852 .189 L
.85083 .19272 L
.85228 .19615 L
.8531 .1994 L
.85334 .20137 L
.8534 .20353 L
.85299 .2075 L
.85196 .21142 L
.85047 .2151 L
.84807 .21954 L
.84532 .2236 L
.83728 .23287 L
.81851 .24881 L
.79143 .26653 L
.72586 .29915 L
.6357 .33164 L
.57419 .34791 L
.50975 .3604 L
.49181 .36307 L
Mistroke
.47179 .36563 L
.45369 .36756 L
.43405 .36923 L
.41598 .37038 L
.39568 .37121 L
.37688 .37152 L
.35901 .37139 L
.34825 .37111 L
.33643 .37061 L
.3252 .36995 L
.31473 .36916 L
.29489 .36716 L
.27371 .36426 L
.2489 .35971 L
.22587 .35418 L
.20558 .34804 L
.18457 .34014 L
.16645 .33175 L
.15083 .32302 L
.12325 .3029 L
.10982 .28999 L
.09695 .27477 L
.07818 .24494 L
.07094 .2297 L
.06437 .21307 L
.05485 .18163 L
.04944 .15674 L
.04779 .1471 L
.04643 .13764 L
.04556 .13027 L
.0449 .12323 L
.04449 .11665 L
.04432 .11125 L
.04434 .10646 L
.04452 .10245 L
.04479 .09923 L
.04522 .09609 L
.04581 .09305 L
.04662 .09011 L
.04764 .08746 L
.04875 .08531 L
.04992 .08356 L
.0511 .08216 L
.0525 .08083 L
.05416 .07959 L
.05607 .0785 L
.05802 .07764 L
.06008 .07695 L
.06211 .07642 L
.06448 .07597 L
Mistroke
.06728 .07559 L
.06878 .07544 L
.07045 .07532 L
.07363 .07518 L
.07683 .07514 L
.08055 .07519 L
.08432 .07531 L
.08804 .07549 L
.09573 .076 L
.10492 .07677 L
.26441 .09288 L
.39879 .10544 L
.56664 .12214 L
.63375 .13012 L
.69822 .13934 L
.75701 .15031 L
.79879 .16132 L
.81647 .16773 L
.83144 .17494 L
.83691 .17834 L
.84179 .18199 L
.84528 .18521 L
.8483 .18871 L
.85054 .19216 L
.852 .19535 L
.85295 .1986 L
.85336 .20172 L
.85329 .20539 L
.85271 .20883 L
.85152 .21266 L
.84964 .21678 L
.8472 .2209 L
.84447 .22473 L
.83664 .23351 L
.81708 .24987 L
.78795 .26856 L
.74943 .28856 L
.66648 .3218 L
.61009 .33895 L
.55227 .35267 L
.52398 .35803 L
.49255 .36296 L
.47555 .36518 L
.45636 .36729 L
.4383 .36891 L
.42145 .37007 L
.4041 .37092 L
.38734 .3714 L
.36939 .37152 L
.34952 .37115 L
Mistroke
.33205 .37038 L
.31328 .36903 L
.29548 .36723 L
.27932 .36512 L
.24153 .35809 L
.2205 .35268 L
.20135 .34659 L
.16487 .33094 L
.14612 .32006 L
.13037 .3088 L
.10588 .28566 L
.09424 .27112 L
.08491 .25698 L
.07117 .23022 L
.06073 .20232 L
.05332 .17532 L
.05058 .16272 L
.04839 .15076 L
.04693 .14134 L
.04576 .13218 L
.04503 .1248 L
.04459 .1187 L
.04443 .11525 L
.04433 .11179 L
.04431 .10876 L
.04435 .10616 L
.04457 .1017 L
.04499 .09758 L
.04529 .09566 L
.04565 .09375 L
.04645 .09066 L
.04702 .08898 L
.04762 .08752 L
.04889 .08508 L
.05017 .08324 L
.05173 .08152 L
.05336 .08015 L
.05501 .07907 L
.05663 .07823 L
.05854 .07745 L
.06069 .07677 L
.06286 .07626 L
.06415 .07602 L
.0656 .0758 L
.06841 .07548 L
.07135 .07527 L
.07426 .07517 L
.07762 .07514 L
.07964 .07517 L
.0816 .07521 L
Mistroke
.08578 .07538 L
.08827 .0755 L
.09063 .07565 L
.10888 .07713 L
.13455 .07971 L
.20167 .0867 L
.3297 .09903 L
.49309 .11446 L
.64483 .13157 L
.71768 .14261 L
.74535 .14784 L
.77145 .15367 L
.79341 .15964 L
.81024 .16528 L
.82429 .17121 L
.83466 .17687 L
.84368 .18365 L
.8472 .18732 L
.84868 .18922 L
.85004 .19129 L
.85178 .19477 L
.85283 .19809 L
.85319 .20003 L
.85338 .20209 L
.85324 .20582 L
.85248 .20973 L
.85125 .21332 L
.84924 .21753 L
.84677 .22155 L
.84108 .22882 L
.83314 .23685 L
.80884 .25562 L
.77934 .27339 L
.70494 .30773 L
.61425 .33781 L
.55262 .3526 L
.52082 .35858 L
.48983 .36334 L
.45252 .36767 L
.43209 .36937 L
.42046 .37013 L
.40979 .37068 L
.38989 .37135 L
.37853 .37151 L
.36798 .37151 L
.34837 .37112 L
.32742 .37009 L
.30751 .36851 L
.29622 .36732 L
.28577 .36602 L
Mistroke
.267 .36316 L
.24643 .35918 L
.21156 .34998 L
.19313 .34357 L
.17648 .3366 L
.15897 .32777 L
.14173 .31715 L
.11454 .29483 L
.10162 .28068 L
.0911 .26664 L
.08127 .25069 L
.07241 .23302 L
.06128 .20403 L
.05417 .17891 L
.0496 .15763 L
.0469 .1411 L
.04593 .13362 L
.04517 .1264 L
.04464 .11937 L
.04437 .11357 L
.04432 .10786 L
.04447 .10313 L
.04478 .09939 L
.04526 .09579 L
.04559 .09405 L
.04598 .09233 L
.04681 .08958 L
.04786 .087 L
.0492 .08459 L
.05053 .0828 L
.05212 .08116 L
.05379 .07985 L
.05544 .07883 L
.05732 .07793 L
.05919 .07722 L
.06141 .07659 L
.06395 .07606 L
.06632 .0757 L
.06869 .07545 L
.07147 .07526 L
.07467 .07516 L
.07651 .07514 L
.07855 .07515 L
.08244 .07524 L
.08497 .07534 L
.08745 .07546 L
.09237 .07576 L
.1151 .07772 L
.17951 .08442 L
.40294 .10582 L
Mistroke
.57626 .12322 L
.65645 .13314 L
.72008 .14303 L
.74797 .14838 L
.77451 .15443 L
.79417 .15987 L
.81237 .16609 L
.82771 .17291 L
.83407 .1765 L
.83984 .18043 L
.84424 .18417 L
.84747 .18766 L
.84989 .19104 L
.85173 .19465 L
.85294 .19858 L
.85339 .20221 L
.85338 .20424 L
.85316 .20646 L
.85225 .21053 L
.8508 .21439 L
.84867 .21854 L
.84339 .2261 L
.83502 .23509 L
.82519 .24368 L
.79612 .26372 L
.72223 .30069 L
.67606 .31849 L
.62736 .33411 L
.57397 .34796 L
.52057 .35862 L
.4878 .36361 L
.45552 .36738 L
.43718 .36899 L
.41998 .37016 L
.40073 .37105 L
.3909 .37133 L
.38003 .3715 L
.35929 .3714 L
.33987 .37078 L
.32965 .37023 L
.31833 .36945 L
.29531 .36721 L
.27509 .36448 L
.25341 .36064 L
.23488 .35651 L
.21498 .35105 L
.17908 .33777 L
.16078 .32876 L
.14481 .31921 L
.11914 .29921 L
Mistroke
.09654 .27423 L
.08522 .25749 L
.07646 .24156 L
.06867 .22431 L
.06185 .20577 L
.05371 .177 L
.05063 .16294 L
.04849 .15139 L
.04702 .14195 L
.04583 .13279 L
.04535 .12824 L
.04499 .1243 L
.04452 .11726 L
.04433 .11196 L
.04433 .10678 L
.04454 .10205 L
.04492 .09816 L
.04544 .09482 L
.04615 .09169 L
.04697 .08911 L
.04784 .08704 L
.049 .08491 L
.05043 .08292 L
.05195 .08132 L
.0535 .08005 L
.05525 .07893 L
.05704 .07805 L
.05917 .07723 L
.06166 .07653 L
.06299 .07624 L
.0645 .07596 L
.06589 .07576 L
.06744 .07557 L
.07053 .07532 L
.07363 .07518 L
.07702 .07514 L
.08036 .07518 L
.08429 .07531 L
.08638 .0754 L
.08875 .07553 L
.09778 .07616 L
.10736 .07699 L
.15748 .08212 L
.36245 .10206 L
.52253 .11744 L
.61146 .12733 L
.68702 .13758 L
.75204 .14924 L
.77997 .15584 L
.80472 .16329 L
Mistroke
.82173 .17001 L
.82934 .17377 L
.83541 .17734 L
.84387 .18383 L
.84721 .18733 L
.84995 .19114 L
.85101 .19307 L
.85192 .19512 L
.853 .19885 L
.8533 .20095 L
.85341 .20292 L
.85332 .20511 L
.853 .20747 L
.85253 .20951 L
.85184 .21176 L
.8501 .21589 L
.84781 .21996 L
.84519 .22377 L
.8305 .23922 L
.80792 .25623 L
.74023 .29282 L
.69059 .31323 L
.63761 .33107 L
.58499 .34537 L
.52054 .35863 L
.48529 .36395 L
.46512 .36638 L
.44554 .3683 L
.4269 .36973 L
.4162 .37037 L
.40622 .37084 L
.38833 .37138 L
.36905 .37152 L
.34986 .37116 L
.32865 .37017 L
.30845 .3686 L
.2896 .36652 L
.27095 .36382 L
.25412 .36078 L
.21703 .35166 L
.19691 .34499 L
.17907 .33777 L
.16079 .32877 L
.14206 .31737 L
.11432 .29461 L
.10143 .28045 L
.0909 .26635 L
.07447 .23746 L
.06329 .21 L
.05621 .18687 L
Mistroke
.05094 .16448 L
.04732 .14404 L
.04613 .13526 L
.0452 .12668 L
.04469 .12024 L
.04439 .11409 L
.04431 .10896 L
.04439 .10478 L
.04469 .10031 L
.04513 .09662 L
.04567 .09369 L
.04638 .09089 L
.04732 .08822 L
.04848 .08578 L
.04962 .08397 L
.05102 .08225 L
.05246 .08086 L
.0539 .07977 L
.05572 .07868 L
.0576 .07781 L
.05947 .07714 L
.06132 .07661 L
.06349 .07614 L
.06598 .07574 L
.06749 .07557 L
.06915 .07541 L
.0723 .07523 L
.07417 .07517 L
.07597 .07514 L
.07803 .07514 L
.08034 .07518 L
.08242 .07524 L
.08476 .07533 L
.08928 .07556 L
.09868 .07623 L
.15055 .08139 L
.35889 .10173 L
.52649 .11785 L
.61555 .12783 L
.69915 .13949 L
.7595 .15087 L
.7869 .15774 L
.80786 .1644 L
.82342 .17079 L
.83454 .17679 L
.83952 .18019 L
.84399 .18394 L
.84738 .18754 L
.84981 .19091 L
.85151 .19413 L
Mistroke
.85272 .19763 L
.85331 .20098 L
.85338 .20407 L
.85294 .20774 L
.85183 .21179 L
.85021 .21566 L
.84822 .21929 L
.84296 .22662 L
.83523 .23489 L
.81394 .25211 L
.78661 .26933 L
.75121 .28772 L
.67157 .32005 L
.61793 .3368 L
.56169 .35069 L
.52721 .35747 L
.49277 .36293 L
.47296 .36549 L
.45086 .36782 L
.43023 .36951 L
.41076 .37064 L
.39152 .37131 L
.37293 .37153 L
.35601 .37133 L
.33733 .37066 L
.31691 .36934 L
.30543 .3683 L
.29501 .36718 L
.27468 .36442 L
.25562 .36108 L
.23782 .35722 L
.21931 .35233 L
.18734 .34129 L
.15546 .32578 L
.13894 .31521 L
.12474 .30418 L
.11089 .29112 L
.09764 .27568 L
.08753 .26122 L
.07837 .24531 L
.06507 .215 L
.05666 .18853 L
.05043 .16195 L
.04694 .14144 L
.0457 .13161 L
.04494 .12371 L
.04467 .11997 L
.04447 .11616 L
.04434 .11249 L
.04431 .10933 L
Mistroke
.04442 .10428 L
.04455 .10198 L
.04475 .09963 L
.04525 .09589 L
.04586 .09283 L
.0463 .09116 L
.04677 .08969 L
.04776 .08721 L
.04899 .08491 L
.05054 .08278 L
.0521 .08118 L
.05365 .07994 L
.05562 .07873 L
.05765 .07779 L
.05971 .07706 L
.06174 .07651 L
.06414 .07602 L
.06687 .07563 L
.06954 .07538 L
.07213 .07523 L
.07533 .07515 L
.07857 .07515 L
.08176 .07522 L
.08488 .07533 L
.0885 .07552 L
.09259 .07578 L
.11193 .07742 L
.13957 .08023 L
.35745 .1016 L
.50614 .11577 L
.58731 .12448 L
.66765 .13471 L
.73525 .14583 L
.78345 .15678 L
.80197 .16236 L
.81856 .16861 L
.83105 .17471 L
.83994 .18051 L
.84376 .18372 L
.84711 .18722 L
.8496 .19057 L
.8513 .19368 L
.85265 .19736 L
.85311 .19947 L
.85334 .20143 L
.85332 .20507 L
.85267 .209 L
.85147 .21277 L
.84958 .2169 L
.84465 .22449 L
Mistroke
.83641 .23374 L
.82675 .2424 L
.77324 .27667 L
.70178 .30897 L
.65243 .32644 L
.5996 .34172 L
.56771 .34937 L
.53089 .3568 L
.49808 .36218 L
.47928 .36472 L
.46096 .36682 L
.44318 .36851 L
.43363 .36926 L
.42335 .36996 L
.40494 .37089 L
.38755 .3714 L
.36812 .37151 L
.34957 .37115 L
.33273 .37041 L
.31438 .36913 L
.29383 .36704 L
.27128 .36388 L
.24787 .35949 L
.22633 .3543 L
.18918 .34203 L
.16954 .3333 L
.15265 .32412 L
.13596 .31306 L
.11984 .29985 L
.09546 .27278 L
.08454 .25635 L
.07591 .24045 L
.06803 .22272 L
.06144 .20452 L
.0535 .17609 L
.04892 .15387 L
.0473 .1439 L
.04602 .13441 L
.04547 .12948 L
.04508 .12531 L
.04478 .12163 L
.04455 .11795 L
.04434 .11217 L
.04432 .10739 L
.0444 .10474 L
.04452 .1024 L
.04489 .09843 L
.04545 .09478 L
.04612 .09182 L
.04702 .08899 L
Mistroke
.04816 .08639 L
.04929 .08445 L
.05068 .08263 L
.05213 .08115 L
.0536 .07998 L
.05674 .07818 L
.0585 .07746 L
.06058 .07681 L
.06184 .07649 L
.06327 .07618 L
.06459 .07595 L
.06604 .07574 L
.06895 .07543 L
.07184 .07525 L
.07353 .07518 L
.07542 .07515 L
.07904 .07516 L
.08138 .07521 L
.0837 .07528 L
.08586 .07538 L
.08832 .07551 L
.09762 .07615 L
.10904 .07714 L
.13422 .07967 L
.32938 .099 L
.49557 .11471 L
.59143 .12495 L
.67381 .1356 L
.73634 .14605 L
.78853 .1582 L
.81103 .16558 L
.82762 .17286 L
.83878 .17965 L
.84361 .18358 L
.84717 .18729 L
.84952 .19046 L
.85142 .19392 L
.85262 .19724 L
.85323 .20032 L
.8534 .20378 L
.85297 .20761 L
.85188 .21166 L
.85029 .21548 L
.84802 .21961 L
.84535 .22356 L
.83903 .23106 L
.81909 .24838 L
.79477 .26454 L
.76166 .28262 L
.72326 .30026 L
Mistroke
.67528 .31876 L
.624 .33508 L
.57147 .34853 L
.54423 .35429 L
.51301 .35988 L
.48196 .36438 L
.45219 .3677 L
.43383 .36925 L
.41402 .37048 L
.39372 .37126 L
.38204 .37148 L
.37103 .37152 L
.35084 .37119 L
.33224 .37039 L
.32187 .36972 L
.31057 .36879 L
.28996 .36656 L
.27159 .36393 L
.25144 .36024 L
.23203 .3558 L
.21154 .34998 L
.19298 .34351 L
.17659 .33665 L
.14667 .32041 L
.13141 .30962 L
.11659 .29682 L
.09405 .27086 L
.08292 .25361 L
.07419 .23688 L
.06192 .20596 L
.05351 .17613 L
.04875 .15287 L
.04697 .14165 L
.04579 .1324 L
.04496 .12394 L
.04467 .11992 L
.04445 .11592 L
.04431 .1103 L
.04432 .10741 L
.04439 .10488 L
.04469 .1003 L
.04494 .09799 L
.04523 .09603 L
.04581 .09304 L
.04661 .09016 L
.0476 .08755 L
.04867 .08544 L
.05013 .08328 L
.0517 .08156 L
.05326 .08023 L
Mistroke
.05512 .07901 L
.05735 .07791 L
.05997 .07698 L
.06242 .07635 L
.06391 .07606 L
.06536 .07583 L
.06811 .0755 L
.06976 .07537 L
.07135 .07527 L
.07442 .07516 L
.07794 .07514 L
.08165 .07521 L
.08539 .07536 L
.08897 .07555 L
.09307 .07581 L
.11646 .07786 L
.14482 .08078 L
.36112 .10194 L
.52342 .11753 L
.66869 .13486 L
.72868 .14459 L
.75574 .15003 L
.78072 .15604 L
.7993 .16148 L
.81638 .16769 L
.82889 .17353 L
.83813 .17918 L
.84596 .18592 L
.8488 .18939 L
.8511 .19325 L
.85243 .1966 L
.85322 .20023 L
.8534 .2037 L
.85309 .2069 L
.85211 .21098 L
.85062 .21479 L
.84838 .21903 L
.84534 .22358 L
.83876 .23134 L
.82954 .24006 L
.78592 .26972 L
.7299 .29741 L
.6926 .31247 L
.64673 .32825 L
.54861 .35341 L
Mfstroke
.85084 .19273 m
.8523 .1962 L
.8531 .1994 L
.85341 .20315 L
.85312 .20674 L
.85237 .2101 L
.85129 .21323 L
.84968 .21671 L
.8475 .22044 L
.8415 .22833 L
.83419 .23588 L
.8119 .25353 L
.75202 .28733 L
.66243 .32316 L
.6048 .34036 L
.57125 .34858 L
.53306 .35641 L
.49401 .36276 L
.45659 .36727 L
.43786 .36894 L
.42784 .36967 L
.41713 .37032 L
.39713 .37116 L
.3784 .37151 L
.35854 .37139 L
.3402 .37079 L
.31881 .36949 L
.29841 .36757 L
.27955 .36515 L
.26214 .36231 L
.2233 .35347 L
.20377 .34742 L
.18601 .34074 L
.16584 .33144 L
.14849 .32157 L
.11725 .29745 L
.10338 .28278 L
.09077 .26615 L
.08158 .25125 L
.0732 .23475 L
.06168 .20525 L
.05416 .17887 L
.04962 .15775 L
.04657 .13875 L
.04549 .12968 L
.04483 .12221 L
.04443 .11532 L
.04431 .1098 L
.04433 .10705 L
.04442 .10426 L
Mistroke
.04474 .09971 L
.04524 .09597 L
.04585 .09289 L
.04652 .09044 L
.04737 .08809 L
.04844 .08585 L
.04974 .0838 L
.05098 .08229 L
.05248 .08085 L
.05399 .07971 L
.05555 .07877 L
.05749 .07785 L
.05941 .07715 L
.06135 .0766 L
.06326 .07618 L
.06549 .07581 L
.06803 .07551 L
.07074 .0753 L
.07391 .07517 L
.07747 .07514 L
.08103 .0752 L
.08461 .07532 L
.08805 .07549 L
.09653 .07606 L
.11994 .0782 L
.14876 .0812 L
.33857 .09985 L
.49368 .11452 L
.58288 .12397 L
.66068 .13373 L
.71865 .14278 L
.76967 .15324 L
.7931 .15955 L
.81152 .16576 L
.82497 .17153 L
.83645 .17803 L
.84459 .18452 L
.84795 .18825 L
.8503 .19174 L
.85181 .19485 L
.85288 .19829 L
.85338 .20194 L
.85329 .20538 L
.85301 .20738 L
.85252 .20957 L
.85115 .21358 L
.84924 .21753 L
.84699 .22122 L
.84025 .22975 L
.83077 .23899 L
Mistroke
.80711 .25677 L
.77853 .27383 L
.74077 .29258 L
.69185 .31275 L
.63848 .3308 L
.58225 .34603 L
.52221 .35834 L
.48592 .36387 L
.46931 .36591 L
.45136 .36778 L
.43456 .36919 L
.41576 .37039 L
.39833 .37113 L
.38181 .37148 L
.36202 .37144 L
.34373 .37094 L
.3224 .36975 L
.30205 .36796 L
.2843 .36582 L
.26548 .3629 L
.23206 .3558 L
.21392 .35072 L
.19732 .34514 L
.17963 .33802 L
.16163 .32922 L
.14462 .31909 L
.13031 .30876 L
.10587 .28565 L
.09434 .27126 L
.08363 .25483 L
.06859 .2241 L
.06294 .209 L
.05794 .19309 L
.05091 .16433 L
.04881 .15322 L
.0471 .14253 L
.04593 .13363 L
.04516 .12629 L
.04466 .11978 L
.04437 .11365 L
.04431 .11048 L
.04432 .10771 L
.04448 .10303 L
.04481 .09908 L
.04525 .09588 L
.04588 .09277 L
.0467 .0899 L
.0475 .08778 L
.04849 .08577 L
.05057 .08275 L
Mistroke
.05204 .08123 L
.05357 .08 L
.05521 .07896 L
.05682 .07814 L
.05872 .07739 L
.06093 .07671 L
.06313 .07621 L
.06538 .07583 L
.06817 .0755 L
.07096 .07529 L
.07424 .07517 L
.07618 .07514 L
.07802 .07514 L
.0799 .07517 L
.08196 .07522 L
.08585 .07538 L
.09035 .07563 L
.09567 .076 L
.11768 .07798 L
.26953 .09337 L
.42551 .10794 L
.59676 .12558 L
.6658 .13445 L
.72924 .1447 L
.75729 .15038 L
.78394 .15691 L
.80281 .16264 L
.81978 .16913 L
.83271 .17568 L
.838 .17909 L
.84274 .18281 L
.84636 .18635 L
.84896 .18963 L
.85096 .19296 L
.85229 .19616 L
.85318 .19994 L
.85337 .20187 L
.85339 .204 L
.85293 .20782 L
.85195 .21144 L
.85112 .21365 L
.85016 .21576 L
.84793 .21976 L
.84099 .22892 L
.83354 .23648 L
.82393 .24468 L
.80255 .25973 L
.73624 .29462 L
.64113 .32999 L
.57564 .34758 L
Mistroke
.54133 .35485 L
.50744 .36076 L
.47616 .36511 L
.45957 .36697 L
.44114 .36868 L
.43047 .36949 L
.4205 .37013 L
.40053 .37105 L
.38205 .37148 L
.36213 .37145 L
.34251 .37089 L
.32114 .36966 L
.30083 .36783 L
.28217 .36552 L
.26151 .36219 L
.23913 .35753 L
.21621 .35142 L
.19552 .34448 L
.17656 .33663 L
.15755 .32697 L
.12693 .30602 L
.11214 .2924 L
.0999 .27856 L
.08759 .26131 L
.07783 .24427 L
.06452 .21348 L
.05626 .18706 L
.05047 .16212 L
.04826 .15002 L
.04673 .1399 L
.04573 .13186 L
.04507 .12525 L
.04459 .11869 L
.04434 .11246 L
.04432 .10749 L
.0445 .10271 L
.04489 .09837 L
.04543 .09484 L
.04609 .09192 L
.04684 .08949 L
.04761 .08754 L
.04855 .08565 L
.04971 .08385 L
.05107 .08219 L
.05236 .08095 L
.0539 .07977 L
.05578 .07865 L
.05768 .07778 L
.05994 .07699 L
.06117 .07665 L
Mistroke
.06257 .07632 L
.06397 .07605 L
.0653 .07584 L
.06808 .07551 L
.0708 .0753 L
.07387 .07518 L
.07687 .07514 L
.0803 .07518 L
.08375 .07529 L
.0871 .07544 L
.09611 .07603 L
.10586 .07685 L
.26874 .0933 L
.54766 .12008 L
.62878 .12948 L
.70621 .14065 L
.73685 .14615 L
.76523 .15218 L
.80563 .16361 L
.82111 .16973 L
.83407 .1765 L
.83908 .17987 L
.84308 .1831 L
.84606 .18602 L
.84872 .18928 L
.85094 .19294 L
.85185 .19496 L
.85251 .19686 L
.85323 .20031 L
.85339 .20406 L
.8532 .20618 L
.85278 .20851 L
.85219 .21072 L
.85146 .21279 L
.84966 .21674 L
.84714 .221 L
.84006 .22996 L
.82977 .23986 L
.80475 .25831 L
.7382 .29374 L
.65172 .32667 L
.59242 .34354 L
.5301 .35695 L
.49333 .36286 L
.47449 .36531 L
.45665 .36727 L
.44045 .36873 L
.42222 .37003 L
.40354 .37095 L
.38334 .37146 L
Mistroke
.37193 .37153 L
.36098 .37143 L
.34021 .37079 L
.32852 .37016 L
.3176 .36939 L
.29273 .36691 L
.27085 .36381 L
.2511 .36017 L
.2286 .35491 L
.20786 .3488 L
.19021 .34244 L
.17202 .33451 L
.14173 .31714 L
.12521 .30458 L
.11113 .29136 L
.08915 .26373 L
.08015 .24865 L
.07211 .23235 L
.06115 .20362 L
.05335 .17549 L
.05046 .1621 L
.04817 .14948 L
.04682 .14059 L
.04573 .13189 L
.04504 .12485 L
.04461 .11899 L
.04435 .11284 L
.04432 .1079 L
.04449 .1029 L
.04484 .09879 L
.0453 .09561 L
.04591 .09264 L
.04654 .09038 L
.04734 .08816 L
.04833 .08605 L
.04954 .08408 L
.05082 .08247 L
.05211 .08118 L
.0538 .07984 L
.05555 .07877 L
.05726 .07795 L
.05925 .07721 L
.0616 .07654 L
.06297 .07624 L
.0643 .076 L
.06679 .07564 L
.06973 .07537 L
.07267 .07521 L
.07565 .07515 L
.07849 .07515 L
Mistroke
.08177 .07522 L
.08556 .07537 L
.08988 .0756 L
.09842 .07621 L
.24638 .09114 L
.37438 .10317 L
.54039 .11931 L
.67649 .136 L
.73958 .14668 L
.78575 .15741 L
.80594 .16372 L
.82146 .16989 L
.83259 .1756 L
.84179 .18199 L
.84546 .18539 L
.84865 .18918 L
.84994 .19112 L
.85108 .19322 L
.85256 .19705 L
.8533 .20091 L
.85335 .20464 L
.85289 .20802 L
.85185 .21175 L
.85101 .21391 L
.84991 .21625 L
.84743 .22054 L
.84119 .2287 L
.83139 .23843 L
.82019 .24756 L
.76109 .28291 L
.72458 .2997 L
.67947 .31728 L
.63533 .33175 L
.58182 .34613 L
.54618 .3539 L
.51124 .36016 L
.476 .36513 L
.45732 .3672 L
.43672 .36903 L
.41774 .37029 L
.40004 .37107 L
.38194 .37148 L
.36448 .37148 L
.34398 .37095 L
.32473 .36992 L
.30346 .36811 L
.29152 .36676 L
.2807 .36531 L
.24292 .35841 L
.22187 .35307 L
Mistroke
.2027 .34706 L
.16612 .33158 L
.14729 .32081 L
.13144 .30964 L
.10677 .28667 L
.09503 .27219 L
.08559 .2581 L
.07167 .23136 L
.06108 .20341 L
.05354 .17629 L
.04852 .15155 L
.04701 .14188 L
.04584 .13281 L
.04513 .12592 L
.04462 .1192 L
.04444 .11546 L
.04434 .11218 L
.04434 .10667 L
.04443 .10389 L
.04458 .10152 L
.04481 .09911 L
.04511 .09676 L
.04576 .09328 L
.04652 .09044 L
.04753 .08773 L
.04879 .08524 L
.05016 .08325 L
.05154 .0817 L
.05332 .08018 L
.05518 .07898 L
.05706 .07804 L
.05894 .07731 L
.06116 .07665 L
.06369 .0761 L
.06648 .07568 L
.06814 .0755 L
.06972 .07537 L
.07296 .0752 L
.07627 .07514 L
.07824 .07515 L
.08042 .07518 L
.08235 .07524 L
.08457 .07532 L
.08981 .0756 L
.09515 .07596 L
.1436 .08065 L
.23049 .08958 L
.51515 .11668 L
.60456 .1265 L
.69068 .13815 L
Mistroke
.72684 .14425 L
.75684 .15028 L
.78004 .15586 L
.80162 .16224 L
.81863 .16864 L
.83125 .17483 L
.84129 .18158 L
.84554 .18547 L
.84857 .18908 L
.8507 .19247 L
.85211 .19565 L
.85306 .19919 L
.85341 .20301 L
.85318 .20635 L
.85253 .20953 L
.85136 .21306 L
.84958 .21691 L
.84426 .225 L
.83608 .23406 L
.81279 .25292 L
.78384 .27089 L
.75096 .28784 L
.71011 .30567 L
.65872 .32439 L
.60713 .33974 L
.54573 .35399 L
.51687 .35924 L
.48433 .36407 L
.46499 .36639 L
.44686 .36819 L
.42822 .36964 L
.41016 .37067 L
.39366 .37126 L
.3758 .37152 L
.35872 .37139 L
.34306 .37092 L
.32442 .3699 L
.30412 .36817 L
.28489 .3659 L
.26722 .3632 L
.2467 .35924 L
.22752 .35462 L
.19275 .34342 L
.17428 .33558 L
.15804 .32725 L
.14032 .31617 L
.12506 .30445 L
.10317 .28253 L
.08399 .25542 L
.07007 .22767 L
Mistroke
.05956 .19856 L
.05245 .17152 L
.04776 .14691 L
.04629 .13654 L
.04568 .1314 L
.04522 .12689 L
.04488 .12296 L
.04461 .119 L
.04435 .11277 L
.04432 .10762 L
.0445 .10268 L
.04467 .10044 L
.04491 .0982 L
.04549 .09457 L
.04622 .09144 L
.04707 .08884 L
.04796 .08679 L
.04905 .08482 L
.05045 .08289 L
.05189 .08137 L
.05365 .07995 L
.05569 .07869 L
.05765 .07779 L
.05963 .07708 L
.06198 .07645 L
.06337 .07616 L
.06471 .07593 L
.06733 .07558 L
.0704 .07532 L
.07332 .07519 L
.07662 .07514 L
.07978 .07517 L
.08292 .07526 L
.08658 .07541 L
.09078 .07566 L
.10113 .07644 L
.1143 .07764 L
.14422 .08072 L
.22742 .08928 L
.3683 .10261 L
.53752 .119 L
.6117 .12736 L
.68325 .13701 L
.71642 .14239 L
.74885 .14856 L
.79494 .16011 L
.81407 .16676 L
.82845 .1733 L
.83839 .17937 L
.84282 .18288 L
Mistroke
.8462 .18618 L
.84905 .18975 L
.85106 .19316 L
.85253 .19695 L
.85305 .19911 L
.85332 .20111 L
.85333 .20494 L
.85306 .20713 L
.85262 .20919 L
.85197 .21138 L
.85123 .21339 L
.84901 .21794 L
.84362 .22581 L
.83693 .23322 L
.8163 .25043 L
.76129 .28281 L
.68058 .31688 L
.63356 .33228 L
.58371 .34568 L
.55336 .35245 L
.51832 .359 L
.48472 .36402 L
.45208 .36771 L
.43142 .36942 L
.41153 .3706 L
.39332 .37127 L
.3733 .37153 L
.36273 .37146 L
.35104 .3712 L
.33876 .37073 L
.32723 .37008 L
.30645 .3684 L
.29477 .36715 L
.28411 .36579 L
.2468 .35926 L
.22592 .35419 L
.20677 .34843 L
.17017 .33361 L
.15118 .32323 L
.13505 .31239 L
.11107 .2913 L
.09942 .27796 L
.08989 .26484 L
.07427 .23705 L
.06241 .20743 L
.05381 .1774 L
.05073 .16344 L
.0483 .15024 L
.04675 .14002 L
.04554 .13015 L
Mistroke
.04483 .12232 L
.04445 .11589 L
.04431 .10999 L
.04438 .10509 L
.04461 .10121 L
.04501 .09746 L
.04562 .09391 L
.04599 .0923 L
.04646 .09064 L
.0474 .08802 L
.04843 .08588 L
.04957 .08404 L
.05094 .08233 L
.05237 .08094 L
.0538 .07984 L
.05562 .07873 L
.0578 .07773 L
.06004 .07696 L
.06228 .07639 L
.06477 .07592 L
.06728 .07559 L
.07024 .07533 L
.072 .07524 L
.07368 .07518 L
.07723 .07514 L
.07936 .07516 L
.08141 .07521 L
.08539 .07536 L
.08774 .07548 L
.08995 .0756 L
.10831 .07707 L
.13395 .07964 L
.20074 .0866 L
.46206 .11142 L
.55212 .12056 L
.64435 .13151 L
.71966 .14296 L
.77419 .15435 L
.7957 .16034 L
.81455 .16695 L
.82747 .17279 L
.8385 .17944 L
.84326 .18326 L
.84677 .18682 L
.84974 .1908 L
.85089 .19282 L
.85189 .19505 L
.853 .19888 L
.85331 .20104 L
.85341 .20302 L
Mistroke
.85309 .20692 L
.85221 .21066 L
.8509 .21416 L
.84895 .21805 L
.84342 .22606 L
.83652 .23364 L
.82861 .24085 L
.77493 .27577 L
.73871 .29351 L
.69231 .31258 L
.64535 .32869 L
.58887 .34442 L
.55737 .35161 L
.52605 .35767 L
.49397 .36276 L
.46313 .36659 L
.44745 .36814 L
.43255 .36934 L
.41675 .37034 L
.39911 .3711 L
.38088 .37149 L
.36403 .37147 L
.34433 .37097 L
.3255 .36997 L
.30684 .36844 L
.28669 .36614 L
.26767 .36328 L
.25036 .36002 L
.21099 .3498 L
.19197 .34312 L
.17205 .33452 L
.13761 .31426 L
.1207 .30064 L
.10704 .28697 L
.09577 .2732 L
.08521 .25748 L
.07019 .22796 L
.06038 .20121 L
.05313 .17451 L
.04841 .15091 L
.04692 .14127 L
.04587 .13308 L
.04517 .12632 L
.04466 .11975 L
.0444 .11442 L
.04431 .10999 L
.04436 .1057 L
.04458 .10149 L
.04499 .09763 L
.04551 .09443 L
Mistroke
.0462 .09154 L
.04708 .08883 L
.04805 .0866 L
.04905 .08482 L
.05037 .08298 L
.05198 .08129 L
.05368 .07993 L
.05539 .07886 L
.05731 .07793 L
.05927 .0772 L
.06158 .07655 L
.06429 .076 L
.06573 .07578 L
.06737 .07558 L
.06899 .07543 L
.07055 .07532 L
.07366 .07518 L
.07723 .07514 L
.08089 .07519 L
.0845 .07532 L
.08872 .07553 L
.09352 .07584 L
.11352 .07757 L
.1672 .08314 L
.40201 .10574 L
.54615 .11992 L
.62086 .12849 L
.69248 .13843 L
.72457 .14384 L
.75591 .15007 L
.80012 .16175 L
.8166 .16778 L
.83069 .17451 L
.83595 .17769 L
.84068 .18109 L
.84433 .18427 L
.84718 .1873 L
.84992 .1911 L
.85171 .1946 L
.85291 .19842 L
.85327 .2006 L
.8534 .20263 L
.85322 .20605 L
.85244 .20985 L
.85102 .21388 L
.84915 .21769 L
.84294 .22664 L
.83512 .235 L
.81067 .25438 L
.78323 .27123 L
Mistroke
.7477 .28937 L
.66784 .32134 L
.6085 .33938 L
.57639 .3474 L
.5451 .35411 L
.51561 .35945 L
.48169 .36442 L
.44591 .36827 L
.43621 .36907 L
.4257 .36981 L
.40646 .37083 L
.38748 .3714 L
.37654 .37152 L
.3662 .3715 L
.34516 .371 L
.33322 .37044 L
.32223 .36974 L
.30263 .36802 L
.28117 .36538 L
.26095 .36209 L
.24231 .35827 L
.21924 .35231 L
.1981 .34542 L
.16101 .32889 L
.14208 .31738 L
.12614 .30536 L
.11057 .29078 L
.09609 .27363 L
.078 .2446 L
.06577 .21688 L
.05594 .18586 L
.0503 .16129 L
.04678 .14026 L
.04557 .13037 L
.04515 .12612 L
.04484 .12239 L
.04447 .11627 L
.04431 .11032 L
.04438 .10525 L
.0445 .10268 L
.04467 .10049 L
.04514 .09657 L
.04574 .09334 L
.04642 .09078 L
.04727 .08833 L
.04836 .086 L
.04969 .08388 L
.05096 .08231 L
.05251 .08082 L
.0541 .07963 L
Mistroke
.05568 .0787 L
.05766 .07778 L
.0597 .07706 L
.06172 .07651 L
.06372 .0761 L
.06606 .07573 L
.06874 .07545 L
.07036 .07533 L
.07215 .07523 L
.07554 .07515 L
.07753 .07514 L
.07947 .07516 L
.08168 .07522 L
.08415 .0753 L
.08889 .07554 L
.09372 .07586 L
.10378 .07666 L
.1591 .08229 L
.35989 .10183 L
.52893 .1181 L
.61267 .12748 L
.68251 .1369 L
.74173 .14711 L
.79031 .15872 L
.80981 .16512 L
.82445 .17128 L
.83684 .17829 L
.84218 .18232 L
.84607 .18604 L
.84909 .18981 L
.8504 .19191 L
.85139 .19388 L
.85266 .1974 L
.85334 .20132 L
.8534 .20354 L
.85326 .20566 L
.85249 .20968 L
.85178 .21195 L
.85094 .21407 L
.84844 .21892 L
.84301 .22656 L
.83492 .23519 L
.81242 .25318 L
.78468 .27042 L
.74888 .28882 L
.66851 .32111 L
.61444 .33776 L
.55779 .35152 L
.52307 .35819 L
.48841 .36353 L
Mistroke
.46848 .36601 L
.44625 .36824 L
.43624 .36907 L
.42551 .36982 L
.40595 .37085 L
.38727 .3714 L
.36655 .3715 L
.34669 .37106 L
.32804 .37013 L
.30944 .36869 L
.29251 .36688 L
.27296 .36415 L
.25463 .36088 L
.23476 .35648 L
.21416 .35079 L
.17889 .33769 L
.16052 .32862 L
.14443 .31896 L
.12826 .30711 L
.11245 .29273 L
.10044 .27923 L
.09066 .26599 L
.07501 .2386 L
.06454 .21355 L
.05663 .18843 L
.05097 .16462 L
.04758 .14575 L
.04635 .13706 L
.04542 .12891 L
.04505 .12501 L
.04474 .12104 L
.04441 .11472 L
.04431 .1088 L
.04443 .10403 L
.04456 .10177 L
.04477 .09947 L
.04504 .09723 L
.04535 .0953 L
.04604 .0921 L
.04682 .08954 L
.04787 .08696 L
.04903 .08485 L
.0502 .0832 L
.05157 .08168 L
.05287 .08053 L
.05439 .07945 L
.05636 .07836 L
.05837 .07751 L
.0605 .07683 L
.06261 .07632 L
Mistroke
.06509 .07587 L
.06796 .07552 L
.07087 .0753 L
.07372 .07518 L
.0773 .07514 L
.07944 .07516 L
.0815 .07521 L
.08549 .07536 L
.08762 .07547 L
.09004 .07561 L
.10023 .07636 L
.11298 .07752 L
.14162 .08045 L
.16777 .0832 L
Mfstroke
.84692 .22132 m
.83331 .2367 L
.81479 .25151 L
.75426 .28626 L
.67228 .31981 L
.61634 .33724 L
.55887 .35129 L
.52534 .3578 L
.48773 .36362 L
.45396 .36753 L
.43409 .36923 L
.41506 .37043 L
.40442 .37091 L
.39269 .37129 L
.3815 .37148 L
.37101 .37152 L
.35099 .3712 L
.33969 .37077 L
.32939 .37022 L
.31715 .36935 L
.30585 .36835 L
.28027 .36525 L
.25779 .3615 L
.2343 .35636 L
.19624 .34474 L
.17601 .33638 L
.15851 .32751 L
.14322 .31815 L
.12782 .30676 L
.10358 .28301 L
.09224 .2683 L
.08158 .25125 L
.07297 .23424 L
.06544 .216 L
.05581 .18534 L
.05013 .16041 L
.04683 .14063 L
.04567 .13131 L
.04495 .12385 L
.04454 .11768 L
.04433 .11176 L
.04433 .10683 L
.04449 .1028 L
.04486 .09867 L
.04536 .09527 L
.04607 .09201 L
.04654 .09037 L
.04702 .08899 L
.0481 .08649 L
.04948 .08417 L
Mistroke
.05096 .08231 L
.0525 .08083 L
.05429 .07951 L
.05643 .07833 L
.05865 .07741 L
.06087 .07673 L
.06304 .07623 L
.0656 .0758 L
.06848 .07547 L
.07137 .07527 L
.07309 .0752 L
.07504 .07515 L
.07695 .07514 L
.07879 .07515 L
.08245 .07524 L
.08662 .07542 L
.09143 .0757 L
.09628 .07604 L
.10869 .07711 L
.24851 .09135 L
.39088 .1047 L
.55211 .12056 L
.63301 .13002 L
.70102 .13979 L
.7338 .14556 L
.76482 .15209 L
.78864 .15823 L
.8073 .1642 L
.82347 .17082 L
.83107 .17472 L
.83695 .17836 L
.84178 .18198 L
.84603 .18599 L
.84793 .18822 L
.84943 .19031 L
.85062 .19231 L
.85166 .19448 L
.85282 .19805 L
.85335 .20146 L
.8534 .20345 L
.85327 .20557 L
.85257 .20939 L
.8512 .21344 L
.84938 .21726 L
.8468 .22151 L
.84338 .22611 L
.82483 .24396 L
.80054 .261 L
.7674 .27972 L
.72294 .30039 L
Mistroke
.62934 .33353 L
.5677 .34938 L
.53497 .35606 L
.50293 .36146 L
.46939 .3659 L
.44997 .36791 L
.43196 .36938 L
.42216 .37003 L
.4117 .3706 L
.4001 .37107 L
.38931 .37136 L
.36961 .37152 L
.35829 .37138 L
.34766 .37109 L
.32696 .37006 L
.3072 .36848 L
.28939 .36649 L
.27004 .36367 L
.24912 .35976 L
.2272 .35454 L
.20713 .34855 L
.18929 .34207 L
.15799 .32722 L
.14287 .31792 L
.12811 .30699 L
.10627 .28611 L
.087 .26038 L
.0781 .24479 L
.07128 .23048 L
.05976 .1992 L
.0528 .17308 L
.0486 .15205 L
.04714 .1428 L
.04596 .1339 L
.04523 .12703 L
.0447 .12035 L
.04449 .11666 L
.04437 .11348 L
.04432 .10782 L
.04446 .10331 L
.04481 .0991 L
.04508 .09699 L
.04537 .09519 L
.04573 .09338 L
.04619 .09156 L
.04709 .08881 L
.0482 .0863 L
.04937 .08433 L
.05078 .08251 L
.05227 .08103 L
Mistroke
.05375 .07987 L
.0554 .07885 L
.05729 .07794 L
.05904 .07728 L
.06111 .07667 L
.0635 .07614 L
.06628 .07571 L
.06911 .07542 L
.0719 .07524 L
.07486 .07516 L
.0778 .07514 L
.08123 .0752 L
.08514 .07535 L
.08913 .07555 L
.09313 .07581 L
.10129 .07645 L
.22849 .08939 L
.36173 .102 L
.52014 .1172 L
.67342 .13555 L
.71108 .14147 L
.74289 .14734 L
.79143 .15905 L
.81069 .16545 L
.82695 .17252 L
.83754 .17877 L
.84229 .18241 L
.84594 .1859 L
.84905 .18975 L
.85029 .19171 L
.8514 .19388 L
.85275 .19777 L
.85334 .20144 L
.8534 .2037 L
.85324 .20585 L
.85242 .20992 L
.85168 .21223 L
.85081 .21437 L
.84824 .21926 L
.84247 .22721 L
.8355 .23463 L
.81443 .25177 L
.75931 .28379 L
.71964 .30178 L
.66921 .32087 L
.61879 .33655 L
.55741 .3516 L
.52176 .35842 L
.48713 .36371 L
.45236 .36768 L
Mistroke
.43427 .36922 L
.42391 .36992 L
.41399 .37048 L
.39517 .37122 L
.37774 .37152 L
.35871 .37139 L
.33774 .37068 L
.31926 .36952 L
.29952 .36769 L
.28262 .36559 L
.26403 .36265 L
.24253 .35832 L
.2203 .35262 L
.18225 .33916 L
.16241 .32964 L
.14515 .31943 L
.1267 .30583 L
.11119 .29142 L
.0993 .2778 L
.08811 .26212 L
.07262 .23348 L
.06589 .21721 L
.06017 .20054 L
.05282 .17319 L
.04825 .14994 L
.04677 .1402 L
.04576 .13215 L
.0451 .1256 L
.04463 .11937 L
.04438 .11379 L
.04431 .10834 L
.04447 .10329 L
.04479 .09923 L
.04534 .09535 L
.04569 .0936 L
.04612 .09183 L
.04697 .08913 L
.04804 .08663 L
.0492 .08459 L
.05039 .08297 L
.05172 .08154 L
.05326 .08023 L
.05471 .07925 L
.05641 .07834 L
.05837 .07751 L
.06036 .07687 L
.06291 .07625 L
.06544 .07582 L
.06795 .07552 L
.07043 .07532 L
Mistroke
.07333 .07519 L
.07664 .07514 L
.08002 .07517 L
.08342 .07527 L
.08665 .07542 L
.09035 .07563 L
.09937 .07629 L
.11041 .07727 L
.13454 .0797 L
.21563 .08811 L
.51388 .11655 L
.59598 .12548 L
.67612 .13594 L
.71304 .1418 L
.749 .14859 L
.77728 .15514 L
.79906 .1614 L
.8162 .16762 L
.83049 .1744 L
.84114 .18146 L
.84563 .18556 L
.84884 .18945 L
.85105 .19316 L
.85246 .1967 L
.85318 .19993 L
.8534 .20348 L
.85301 .20739 L
.85257 .20939 L
.8519 .2116 L
.85026 .21555 L
.84822 .21928 L
.84204 .22771 L
.83438 .2357 L
.81078 .2543 L
.74786 .2893 L
.6698 .32067 L
.61739 .33694 L
.56425 .35014 L
.50072 .36179 L
.46626 .36625 L
.446 .36826 L
.42665 .36975 L
.40844 .37074 L
.39091 .37133 L
.37494 .37153 L
.35736 .37136 L
.338 .37069 L
.31727 .36936 L
.29945 .36768 L
.27978 .36518 L
Mistroke
.25718 .36138 L
.2359 .35676 L
.19717 .34508 L
.17667 .33668 L
.15862 .32757 L
.13905 .31528 L
.12231 .30208 L
.10926 .28939 L
.09678 .27455 L
.07911 .24672 L
.07127 .23046 L
.06451 .21345 L
.05567 .18481 L
.04996 .15952 L
.04806 .14877 L
.04672 .13982 L
.04582 .13266 L
.0451 .12554 L
.04462 .11917 L
.04436 .11317 L
.04432 .10748 L
.04449 .10291 L
.04465 .10075 L
.04487 .09854 L
.04517 .0964 L
.04549 .09456 L
.04621 .09148 L
.047 .08903 L
.04807 .08656 L
.04923 .08454 L
.05035 .08302 L
.0517 .08156 L
.05325 .08024 L
.05483 .07917 L
.05801 .07765 L
.05999 .07697 L
.06194 .07646 L
.06436 .07599 L
.06678 .07564 L
.06962 .07538 L
.07289 .07521 L
.07624 .07514 L
.07963 .07517 L
.08286 .07525 L
.08659 .07541 L
.0909 .07566 L
.09509 .07595 L
.10551 .07682 L
.12832 .07906 L
.20527 .08706 L
Mistroke
.33499 .09952 L
.4958 .11473 L
.64708 .13187 L
.71257 .14172 L
.74498 .14776 L
.7709 .15354 L
.79307 .15954 L
.81305 .16635 L
.8288 .17348 L
.83563 .17748 L
.84092 .18128 L
.84504 .18497 L
.84814 .1885 L
.85029 .19172 L
.85197 .19527 L
.85306 .19919 L
.85332 .20119 L
.8534 .2034 L
.85301 .20736 L
.85206 .21112 L
.85049 .21508 L
.84818 .21935 L
.8425 .22717 L
.83333 .23668 L
.82293 .24546 L
.76645 .2802 L
.68867 .31394 L
.59474 .34296 L
.53739 .3556 L
.50221 .36156 L
.46769 .36609 L
.44823 .36807 L
.42941 .36956 L
.41216 .37057 L
.3931 .37128 L
.38308 .37147 L
.37196 .37153 L
.36024 .37142 L
.34917 .37114 L
.32922 .37021 L
.31794 .36942 L
.30758 .36851 L
.28897 .36644 L
.26915 .36353 L
.23384 .35625 L
.21273 .35035 L
.19342 .34368 L
.17651 .33661 L
.15949 .32806 L
.13062 .309 L
Mistroke
.10799 .28802 L
.08831 .26243 L
.07927 .24701 L
.07213 .2324 L
.06032 .20102 L
.05318 .17472 L
.04832 .15034 L
.04673 .13994 L
.04551 .12988 L
.04483 .12224 L
.04446 .11606 L
.04431 .11009 L
.04432 .10739 L
.0444 .10463 L
.04467 .10043 L
.04515 .0965 L
.04576 .09326 L
.04645 .09067 L
.0473 .08827 L
.04834 .08604 L
.04935 .08436 L
.05058 .08274 L
.05204 .08123 L
.05378 .07985 L
.05559 .07875 L
.05739 .0779 L
.05933 .07718 L
.06127 .07662 L
.06355 .07613 L
.06617 .07572 L
.06885 .07544 L
.07155 .07526 L
.07413 .07517 L
.07709 .07514 L
.08073 .07519 L
.08427 .07531 L
.08864 .07553 L
.09308 .07581 L
.11244 .07746 L
.1784 .08431 L
.44453 .10974 L
.6057 .12664 L
.67959 .13646 L
.74767 .14832 L
.79215 .15926 L
.81152 .16576 L
.82578 .17193 L
.83572 .17754 L
.8439 .18385 L
.84702 .18711 L
Mistroke
.84964 .19064 L
.85146 .19403 L
.85259 .19713 L
.85328 .20074 L
.85338 .20415 L
.8529 .20794 L
.85174 .21206 L
.85091 .21415 L
.84982 .21644 L
.84737 .22065 L
.84121 .22867 L
.82378 .24479 L
.80184 .26018 L
.73314 .29599 L
.68893 .31384 L
.63256 .33258 L
.57675 .34732 L
.54357 .35441 L
.5109 .36022 L
.47907 .36475 L
.44888 .36801 L
.43111 .36944 L
.41399 .37048 L
.39559 .37121 L
.37527 .37153 L
.35471 .3713 L
.33521 .37055 L
.32395 .36986 L
.31361 .36906 L
.29024 .3666 L
.26788 .36331 L
.24366 .35857 L
.22117 .35287 L
.20084 .34641 L
.18124 .33872 L
.16364 .3303 L
.13365 .31134 L
.11878 .29888 L
.10649 .28636 L
.09398 .27075 L
.08383 .25516 L
.0689 .22486 L
.05941 .19808 L
.05257 .17205 L
.04798 .14829 L
.0457 .13158 L
.045 .12445 L
.04453 .1175 L
.04434 .11228 L
.04432 .10728 L
Mistroke
.04448 .1031 L
.04475 .09968 L
.04522 .09607 L
.0459 .09269 L
.04669 .08992 L
.04753 .08771 L
.04868 .08543 L
.05011 .08332 L
.05163 .08162 L
.05319 .08028 L
.05496 .0791 L
.05677 .07817 L
.05893 .07731 L
.06146 .07658 L
.06282 .07627 L
.06436 .07599 L
.06578 .07577 L
.06736 .07558 L
.06899 .07543 L
.07053 .07532 L
.07369 .07518 L
.07698 .07514 L
.08025 .07518 L
.08408 .0753 L
.08634 .0754 L
.08848 .07552 L
.09835 .07621 L
.10908 .07715 L
.16345 .08275 L
.40929 .10642 L
.57055 .12258 L
.65441 .13286 L
.72241 .14345 L
.7694 .15317 L
.80782 .16439 L
.82411 .17112 L
.83604 .17775 L
.84394 .18389 L
.84731 .18745 L
.84974 .1908 L
.8517 .19457 L
.85239 .19649 L
.85295 .19861 L
.8534 .20241 L
.85322 .20601 L
.85285 .20822 L
.85231 .21032 L
.85084 .2143 L
.8486 .21865 L
.84544 .22344 L
Mistroke
.83842 .2317 L
.82883 .24066 L
.8065 .25717 L
.74953 .28852 L
.66424 .32256 L
.61229 .33835 L
.55069 .353 L
.52314 .35818 L
.49231 .363 L
.47394 .36537 L
.45685 .36725 L
.4406 .36872 L
.42236 .37002 L
.40255 .37098 L
.39154 .37131 L
.38114 .37149 L
.36232 .37145 L
.34183 .37086 L
.33026 .37027 L
.31759 .36939 L
.29439 .3671 L
.27178 .36396 L
.25092 .36013 L
.22962 .35517 L
.20999 .34948 L
.175 .33592 L
.15672 .3265 L
.141 .31664 L
.12428 .30379 L
.11009 .29028 L
.09883 .2772 L
.08814 .26216 L
.07316 .23467 L
.06092 .20291 L
.05352 .17619 L
.04933 .15618 L
.04645 .1378 L
.04552 .12996 L
.04485 .12246 L
.04447 .11622 L
.04432 .11113 L
.04435 .10612 L
.04459 .10144 L
.04499 .09758 L
.0455 .09449 L
.04626 .0913 L
.04677 .08969 L
.04728 .08832 L
.04833 .08605 L
.04961 .08398 L
Mistroke
.05099 .08228 L
.05265 .08071 L
.05438 .07946 L
.0561 .07848 L
.05831 .07753 L
.05955 .07711 L
.06094 .07671 L
.06221 .0764 L
.06367 .07611 L
.06642 .07569 L
.06918 .07541 L
.07193 .07524 L
.07517 .07515 L
.07708 .07514 L
.07889 .07515 L
.08274 .07525 L
.08504 .07534 L
.08725 .07545 L
.09636 .07605 L
.11609 .07782 L
.14282 .08057 L
.36263 .10208 L
.51563 .11673 L
.60177 .12617 L
.67683 .13605 L
.73616 .14601 L
.76268 .15159 L
.78704 .15778 L
.80594 .16372 L
.82013 .16929 L
.83166 .17506 L
.84014 .18067 L
.84397 .18392 L
.84732 .18747 L
.84978 .19086 L
.85145 .194 L
.85275 .19774 L
.85317 .19987 L
.85337 .20186 L
.85327 .20555 L
.85253 .20953 L
.85124 .21335 L
.84924 .21753 L
.84408 .22523 L
.83554 .23459 L
.82558 .24336 L
.77663 .27486 L
.70311 .30845 L
.6065 .33991 L
.57429 .34789 L
Mistroke
.54201 .35472 L
.51107 .36019 L
.47664 .36505 L
.44515 .36834 L
.4267 .36974 L
.40909 .37072 L
.39266 .37129 L
.37744 .37152 L
.35963 .37141 L
.34253 .37089 L
.32392 .36986 L
.30398 .36816 L
.28509 .36593 L
.26801 .36334 L
.24796 .35951 L
.22659 .35437 L
.20678 .34844 L
.18928 .34207 L
.15535 .32571 L
.13838 .31481 L
.12365 .30325 L
.10101 .27993 L
.09033 .26549 L
.08178 .2516 L
.06771 .2219 L
.05724 .19064 L
.05049 .16224 L
.04847 .15128 L
.04682 .14058 L
.04573 .13187 L
.04494 .12369 L
.04465 .11961 L
.04447 .11618 L
.04431 .11012 L
.04438 .10526 L
.04465 .10065 L
.0451 .09686 L
.04565 .09379 L
.04645 .09067 L
.04735 .08814 L
.04851 .08573 L
.04995 .08352 L
.05167 .08158 L
.0535 .08005 L
.05533 .07889 L
.05752 .07784 L
.05959 .0771 L
.06164 .07653 L
.06406 .07604 L
.06681 .07564 L
Mistroke
.06939 .07539 L
.07195 .07524 L
.07495 .07515 L
.07838 .07515 L
.08043 .07518 L
.0824 .07524 L
.08464 .07532 L
.08711 .07544 L
.0967 .07608 L
.11878 .07809 L
.3049 .09672 L
.45959 .11118 L
.54364 .11965 L
.61944 .12831 L
.68682 .13755 L
.73912 .14659 L
.7856 .15737 L
.80567 .16363 L
.82111 .16973 L
.83334 .17605 L
.83871 .1796 L
.84292 .18296 L
.84614 .18612 L
.84854 .18904 L
.85062 .19232 L
.8522 .19589 L
.85315 .19975 L
.8534 .20338 L
.85301 .20741 L
.85255 .20947 L
.85185 .21176 L
.85023 .21562 L
.84789 .21983 L
.84216 .22758 L
.83403 .23603 L
.82293 .24546 L
.79411 .26494 L
.72285 .30043 L
.67517 .3188 L
.62373 .33515 L
.57199 .34841 L
.50979 .36039 L
.47491 .36526 L
.45432 .36749 L
.43459 .36919 L
.42372 .36993 L
.41329 .37052 L
.39343 .37127 L
.38217 .37148 L
.37165 .37153 L
Mistroke
.36 .37141 L
.3475 .37109 L
.32637 .37003 L
.31439 .36913 L
.30336 .36809 L
.283 .36564 L
.26157 .3622 L
.22491 .35391 L
.20471 .34774 L
.1865 .34094 L
.16812 .3326 L
.14977 .32237 L
.12047 .30043 L
.1065 .28637 L
.095 .27216 L
.08353 .25465 L
.07448 .23749 L
.06229 .20708 L
.05478 .18135 L
.04955 .15737 L
.04759 .14581 L
.04624 .13615 L
.04537 .12842 L
.04474 .12102 L
.04442 .11508 L
.04431 .11021 L
.04437 .10552 L
.04462 .10099 L
.04509 .09688 L
.0457 .09354 L
.04641 .09079 L
.04721 .08848 L
.04803 .08664 L
.04903 .08486 L
.05024 .08316 L
.05166 .08159 L
.053 .08042 L
.05461 .07931 L
.05644 .07832 L
.05828 .07755 L
.06046 .07684 L
.063 .07624 L
.06436 .07599 L
.06589 .07576 L
.06886 .07544 L
.07198 .07524 L
.07507 .07515 L
.07815 .07515 L
.08121 .0752 L
.08478 .07533 L
Mistroke
.08888 .07554 L
.09813 .07619 L
.10776 .07702 L
.27359 .09376 L
.41692 .10713 L
.50797 .11595 L
.59389 .12524 L
.66828 .1348 L
.73669 .14611 L
.76202 .15144 L
.78525 .15727 L
.8034 .16284 L
.81779 .16828 L
.83086 .17461 L
.84 .18056 L
.84402 .18396 L
.84706 .18716 L
.84969 .19072 L
.85169 .19456 L
.85272 .19765 L
.85331 .20102 L
.85338 .20425 L
.85304 .20723 L
.85223 .21058 L
.85085 .21429 L
.84886 .2182 L
.84654 .22188 L
.8396 .23045 L
.83108 .23871 L
.81044 .25453 L
.74398 .29111 L
.65714 .32491 L
.60431 .34049 L
.57109 .34862 L
.53888 .35532 L
.50987 .36038 L
.47675 .36503 L
.45792 .36714 L
.44007 .36876 L
.42265 .37 L
.40377 .37094 L
.38749 .3714 L
.36965 .37152 L
.35259 .37124 L
.33678 .37063 L
.31912 .36951 L
.29967 .3677 L
.27931 .36511 L
.2604 .36199 L
.23983 .3577 L
Mistroke
.2184 .35207 L
.18158 .33887 L
.16243 .32965 L
.14562 .31973 L
.12759 .30656 L
.11225 .29252 L
.10062 .27945 L
.08952 .26429 L
.07396 .23638 L
.06715 .22049 L
.06127 .204 L
.05362 .17661 L
.04891 .15382 L
.04724 .14353 L
.04596 .13388 L
.04517 .1264 L
.04462 .11914 L
.04436 .11334 L
.04431 .10853 L
.04443 .10406 L
.04469 .1003 L
.04504 .09728 L
.04553 .09434 L
.0462 .09151 L
.04706 .08887 L
.04791 .08688 L
.04897 .08494 L
.05023 .08316 L
.05153 .08172 L
.0531 .08035 L
.05496 .0791 L
.0571 .07802 L
.05932 .07718 L
.06148 .07657 L
.06401 .07605 L
.06638 .07569 L
.06917 .07541 L
.0723 .07523 L
.07546 .07515 L
.0786 .07515 L
.08165 .07521 L
.0854 .07536 L
.08919 .07556 L
.09859 .07623 L
.1101 .07724 L
.1354 .07979 L
.22148 .08869 L
.25574 .09205 L
Mfstroke
.84663 .22176 m
.83282 .23715 L
.81413 .25198 L
.75327 .28674 L
.67097 .32026 L
.61484 .33765 L
.5572 .35165 L
.52357 .3581 L
.48586 .36387 L
.452 .36772 L
.43208 .36937 L
.41301 .37053 L
.40236 .37099 L
.3906 .37134 L
.37939 .3715 L
.36888 .37152 L
.34884 .37113 L
.33752 .37067 L
.32721 .37008 L
.31496 .36917 L
.30365 .36812 L
.27807 .36493 L
.25561 .36108 L
.23215 .35583 L
.19421 .34398 L
.17407 .33548 L
.15669 .32648 L
.14151 .317 L
.12627 .30547 L
.10231 .28151 L
.09115 .26671 L
.08067 .2496 L
.07221 .23258 L
.06485 .21438 L
.05543 .18389 L
.04989 .15919 L
.04669 .13964 L
.04557 .13045 L
.04489 .12309 L
.0445 .11699 L
.04432 .11116 L
.04434 .1063 L
.04452 .10233 L
.04491 .09825 L
.04542 .09491 L
.04615 .0917 L
.04664 .09008 L
.04712 .08872 L
.04822 .08626 L
.04962 .08397 L
Mistroke
.05112 .08214 L
.05267 .08069 L
.05448 .07939 L
.05664 .07823 L
.05888 .07733 L
.06112 .07666 L
.06331 .07617 L
.06589 .07576 L
.0688 .07544 L
.07171 .07525 L
.07344 .07519 L
.0754 .07515 L
.07733 .07514 L
.07918 .07516 L
.08287 .07525 L
.08707 .07544 L
.09192 .07573 L
.0968 .07608 L
.10931 .07717 L
.25002 .09149 L
.39299 .1049 L
.55436 .1208 L
.63508 .13029 L
.7028 .14008 L
.73539 .14586 L
.76618 .1524 L
.78979 .15857 L
.80825 .16454 L
.82422 .17117 L
.8317 .17509 L
.83749 .17873 L
.84222 .18236 L
.84638 .18638 L
.84823 .18861 L
.84968 .1907 L
.85082 .1927 L
.85182 .19488 L
.85292 .19846 L
.85337 .20187 L
.85339 .20386 L
.85323 .20598 L
.85246 .20981 L
.85103 .21387 L
.84915 .2177 L
.84302 .22655 L
.83484 .23526 L
.82545 .24346 L
.7982 .26245 L
.72918 .29772 L
.64541 .32867 L
Mistroke
.59531 .34282 L
.53375 .35628 L
.50061 .3618 L
.48243 .36432 L
.46253 .36666 L
.44293 .36853 L
.42477 .36987 L
.40614 .37084 L
.38828 .37138 L
.37052 .37152 L
.35151 .37121 L
.33511 .37054 L
.31696 .36934 L
.2973 .36744 L
.2762 .36465 L
.25635 .36122 L
.23843 .35737 L
.21786 .35191 L
.19661 .34488 L
.1608 .32877 L
.14265 .31777 L
.12702 .3061 L
.11141 .29166 L
.09712 .275 L
.08716 .26063 L
.07788 .24436 L
.0653 .21562 L
.05551 .18421 L
.04987 .15904 L
.04795 .14812 L
.04645 .13784 L
.04552 .12995 L
.04484 .12245 L
.04459 .11864 L
.04443 .11539 L
.04431 .10964 L
.04433 .10674 L
.04444 .10382 L
.0446 .10128 L
.04481 .0991 L
.04535 .09529 L
.04603 .09217 L
.04676 .0897 L
.04769 .08735 L
.04886 .08512 L
.05028 .0831 L
.05163 .08162 L
.05326 .08023 L
.05502 .07907 L
.05683 .07814 L
Mistroke
.05858 .07743 L
.06063 .07679 L
.06304 .07623 L
.06443 .07597 L
.0658 .07577 L
.06834 .07548 L
.07134 .07527 L
.07432 .07517 L
.07733 .07514 L
.08021 .07518 L
.08353 .07528 L
.08736 .07546 L
.09172 .07572 L
.10037 .07637 L
.24323 .09083 L
.38382 .10405 L
.56719 .1222 L
.64377 .13143 L
.71572 .14227 L
.75061 .14893 L
.77788 .1553 L
.80104 .16205 L
.81843 .16855 L
.83089 .17463 L
.84095 .1813 L
.84492 .18484 L
.84792 .18822 L
.85044 .19198 L
.8515 .19412 L
.85227 .19611 L
.85311 .19947 L
.8534 .20265 L
.8532 .20617 L
.8524 .20999 L
.85095 .21406 L
.84901 .21795 L
.84399 .22535 L
.8369 .23326 L
.82867 .2408 L
.80463 .25839 L
.73559 .2949 L
.65492 .32564 L
.60085 .34139 L
.54564 .35401 L
.5135 .3598 L
.48173 .36441 L
.46351 .36655 L
.44332 .3685 L
.42455 .36988 L
.40694 .37081 L
Mistroke
.38996 .37135 L
.37389 .37153 L
.35602 .37133 L
.33666 .37062 L
.31614 .36927 L
.29661 .36736 L
.27905 .36508 L
.26002 .36192 L
.22012 .35257 L
.1982 .34546 L
.17845 .33749 L
.14197 .31731 L
.12393 .30349 L
.10922 .28935 L
.08859 .26286 L
.0792 .24689 L
.07187 .23181 L
.06063 .20198 L
.05283 .17322 L
.04817 .14948 L
.04665 .13936 L
.04548 .12959 L
.04483 .12229 L
.04443 .11541 L
.04431 .10973 L
.04438 .10516 L
.0445 .10265 L
.0447 .10018 L
.0452 .09619 L
.04556 .09422 L
.04594 .0925 L
.04643 .09074 L
.047 .08903 L
.04811 .08647 L
.04929 .08445 L
.05073 .08257 L
.0525 .08083 L
.05433 .07948 L
.05624 .07842 L
.0581 .07761 L
.06029 .07689 L
.06288 .07626 L
.06427 .076 L
.06587 .07576 L
.06729 .07559 L
.06888 .07544 L
.07193 .07524 L
.07518 .07515 L
.07713 .07514 L
.07901 .07516 L
Mistroke
.08263 .07525 L
.08677 .07542 L
.09113 .07568 L
.09553 .07599 L
.10453 .07673 L
.23675 .0902 L
.37361 .1031 L
.53336 .11857 L
.61463 .12772 L
.68462 .13722 L
.71883 .14281 L
.75177 .14918 L
.79791 .16104 L
.81584 .16747 L
.83128 .17485 L
.83739 .17867 L
.84281 .18286 L
.84684 .1869 L
.84965 .19066 L
.85156 .19424 L
.85272 .19761 L
.85334 .20137 L
.8534 .20349 L
.85329 .20544 L
.85256 .20941 L
.85187 .21168 L
.85106 .21378 L
.84915 .21768 L
.84656 .22186 L
.83986 .23017 L
.83163 .23823 L
.81166 .2537 L
.74722 .2896 L
.67109 .32022 L
.61952 .33635 L
.56596 .34976 L
.53468 .35611 L
.49985 .36191 L
.48088 .36452 L
.45951 .36698 L
.43956 .36881 L
.42053 .37013 L
.40074 .37105 L
.38168 .37148 L
.3643 .37148 L
.34518 .371 L
.32414 .36988 L
.31346 .36905 L
.30164 .36792 L
.28074 .36532 L
Mistroke
.26119 .36214 L
.24262 .35834 L
.22262 .35328 L
.20538 .34797 L
.18753 .34136 L
.15593 .32605 L
.12977 .30832 L
.11572 .29597 L
.10219 .28137 L
.09177 .26761 L
.08224 .25242 L
.06813 .22296 L
.05902 .19678 L
.05204 .16967 L
.04795 .14811 L
.04577 .13227 L
.04502 .12468 L
.04458 .11845 L
.04434 .11257 L
.04432 .10768 L
.04448 .10296 L
.04466 .10057 L
.04487 .09852 L
.0454 .09502 L
.04577 .09323 L
.04616 .09168 L
.04706 .08887 L
.04821 .08628 L
.04939 .0843 L
.05061 .08271 L
.05209 .08119 L
.05383 .07982 L
.05548 .07881 L
.05715 .078 L
.05913 .07725 L
.06143 .07658 L
.06362 .07612 L
.06619 .07572 L
.06879 .07544 L
.07137 .07527 L
.07409 .07517 L
.0767 .07514 L
.07989 .07517 L
.08309 .07526 L
.08688 .07543 L
.09123 .07569 L
.09986 .07633 L
.12385 .0786 L
.19667 .08619 L
.43693 .10902 L
Mistroke
.60648 .12673 L
.69232 .1384 L
.72768 .14441 L
.75694 .1503 L
.7995 .16155 L
.81676 .16785 L
.83136 .17489 L
.84198 .18215 L
.84593 .18589 L
.84925 .19005 L
.85131 .19368 L
.85214 .19574 L
.85272 .19762 L
.85334 .20132 L
.85334 .20486 L
.8528 .20844 L
.85164 .21232 L
.85002 .21604 L
.84811 .21947 L
.84179 .228 L
.83376 .23628 L
.81243 .25317 L
.78174 .27207 L
.7091 .30608 L
.62155 .33578 L
.56198 .35063 L
.52785 .35735 L
.48973 .36335 L
.45446 .36748 L
.43374 .36925 L
.41398 .37048 L
.39542 .37121 L
.37826 .37151 L
.35814 .37138 L
.33888 .37073 L
.32149 .36969 L
.30221 .36798 L
.28203 .3655 L
.26315 .36249 L
.22983 .35523 L
.21155 .34998 L
.19525 .34437 L
.16084 .32879 L
.14302 .31802 L
.12778 .30672 L
.1036 .28304 L
.09229 .26837 L
.08342 .25446 L
.06931 .22585 L
.05864 .19548 L
Mistroke
.05154 .16738 L
.04924 .15564 L
.04756 .14561 L
.04638 .13729 L
.04544 .12919 L
.04486 .12263 L
.04451 .11718 L
.04433 .11193 L
.04433 .10679 L
.04454 .10209 L
.04491 .09823 L
.04545 .09476 L
.04582 .093 L
.04622 .09147 L
.04713 .08868 L
.0483 .08613 L
.04955 .08408 L
.05087 .08241 L
.05219 .0811 L
.05375 .07987 L
.05563 .07873 L
.0579 .07769 L
.06051 .07683 L
.06185 .07648 L
.06318 .0762 L
.0659 .07575 L
.06858 .07546 L
.07168 .07525 L
.07354 .07518 L
.07534 .07515 L
.07898 .07516 L
.08091 .07519 L
.08312 .07526 L
.08724 .07545 L
.09135 .07569 L
.10168 .07648 L
.11451 .07767 L
.178 .08427 L
.40386 .10591 L
.57336 .12289 L
.65801 .13336 L
.7342 .14563 L
.78549 .15734 L
.80791 .16442 L
.82456 .17133 L
.83625 .17789 L
.84415 .18409 L
.84727 .18741 L
.84993 .1911 L
.85097 .19299 L
Mistroke
.85187 .19501 L
.85297 .19871 L
.8534 .20245 L
.85336 .2046 L
.85314 .20663 L
.85272 .20878 L
.85218 .21075 L
.85136 .21305 L
.85041 .21525 L
.84588 .22283 L
.83882 .23128 L
.81564 .2509 L
.78601 .26966 L
.71334 .30437 L
.66771 .32138 L
.61013 .33894 L
.55163 .3528 L
.51973 .35876 L
.48288 .36426 L
.44975 .36793 L
.43059 .36948 L
.41279 .37054 L
.39589 .3712 L
.37725 .37152 L
.35939 .3714 L
.34272 .3709 L
.32331 .36982 L
.30228 .36798 L
.28237 .36555 L
.2642 .36268 L
.24311 .35845 L
.22048 .35267 L
.18107 .33865 L
.16099 .32888 L
.14398 .31866 L
.12715 .30621 L
.11089 .29112 L
.09771 .27577 L
.08725 .26077 L
.07825 .24508 L
.07109 .23004 L
.06013 .20041 L
.05344 .17584 L
.04879 .15316 L
.04718 .14308 L
.04588 .13324 L
.04512 .12578 L
.04465 .11954 L
.04437 .11369 L
.04431 .10815 L
Mistroke
.04444 .10384 L
.04473 .09984 L
.04511 .09679 L
.04564 .09383 L
.04603 .09217 L
.0465 .09051 L
.04749 .08781 L
.04861 .08555 L
.04979 .08373 L
.05122 .08203 L
.05297 .08045 L
.05502 .07907 L
.05713 .078 L
.0593 .07719 L
.06154 .07656 L
.06369 .0761 L
.06622 .07571 L
.06916 .07541 L
.07091 .07529 L
.07255 .07522 L
.07594 .07514 L
.07937 .07516 L
.08293 .07526 L
.087 .07544 L
.09111 .07568 L
.09509 .07595 L
.11761 .07797 L
.18626 .08512 L
.41771 .10721 L
.57258 .1228 L
.65298 .13267 L
.71865 .14278 L
.77531 .15464 L
.79885 .16134 L
.81914 .16886 L
.82638 .17223 L
.83322 .17598 L
.83837 .17935 L
.84296 .183 L
.84664 .18668 L
.84926 .19006 L
.85123 .19352 L
.85249 .19682 L
.85323 .2003 L
.85338 .20409 L
.85295 .20771 L
.85208 .21105 L
.85051 .21502 L
.84816 .21939 L
.84223 .22749 L
Mistroke
.83391 .23614 L
.82285 .24552 L
.79768 .26277 L
.73769 .29397 L
.64943 .3274 L
.59562 .34274 L
.56356 .35029 L
.53197 .35661 L
.50113 .36173 L
.47182 .36562 L
.45571 .36736 L
.43787 .36894 L
.41861 .37024 L
.40005 .37107 L
.37988 .3715 L
.36068 .37142 L
.34956 .37115 L
.33933 .37075 L
.32746 .3701 L
.31613 .36927 L
.29351 .367 L
.2725 .36407 L
.24957 .35985 L
.22551 .35408 L
.20518 .3479 L
.18398 .33989 L
.16616 .33161 L
.14846 .32155 L
.13359 .31129 L
.11868 .29879 L
.09636 .27399 L
.08583 .25849 L
.07754 .2437 L
.06336 .2102 L
.05514 .18278 L
.04961 .15766 L
.04798 .14831 L
.04664 .13922 L
.04576 .13213 L
.04506 .12516 L
.04457 .1183 L
.04433 .11198 L
.04433 .10685 L
.0445 .10264 L
.0449 .09834 L
.0452 .09617 L
.04554 .09432 L
.04627 .09126 L
.04722 .08845 L
.04822 .08627 L
Mistroke
.04928 .08447 L
.05057 .08275 L
.05212 .08116 L
.05395 .07974 L
.05617 .07845 L
.05849 .07747 L
.06084 .07674 L
.06312 .07621 L
.06585 .07576 L
.06731 .07559 L
.06894 .07543 L
.07208 .07524 L
.07536 .07515 L
.07856 .07515 L
.08251 .07524 L
.08652 .07541 L
.09048 .07564 L
.09437 .0759 L
.10404 .07669 L
.16406 .08281 L
.41459 .10691 L
.56502 .12196 L
.64448 .13152 L
.71102 .14146 L
.74324 .14741 L
.77362 .15421 L
.797 .16074 L
.81443 .1669 L
.82884 .1735 L
.83483 .17697 L
.84031 .1808 L
.84449 .18441 L
.84758 .18779 L
.84991 .19107 L
.8517 .19458 L
.85286 .19821 L
.85323 .20029 L
.85339 .20222 L
.85325 .20581 L
.8525 .20966 L
.85132 .21315 L
.84981 .21645 L
.84493 .22412 L
.8376 .23255 L
.82911 .24042 L
.80425 .25864 L
.74566 .29033 L
.66275 .32306 L
.60959 .33908 L
.55557 .35199 L
Mistroke
.52322 .35817 L
.48619 .36383 L
.46853 .366 L
.44937 .36796 L
.43265 .36933 L
.41389 .37049 L
.39504 .37122 L
.37684 .37152 L
.36027 .37142 L
.342 .37087 L
.32199 .36972 L
.30053 .3678 L
.28022 .36525 L
.26188 .36226 L
.22647 .35434 L
.20706 .34853 L
.18976 .34226 L
.1597 .32817 L
.13134 .30956 L
.11741 .2976 L
.1039 .28339 L
.09343 .26998 L
.08379 .25509 L
.06941 .22609 L
.06001 .20001 L
.05276 .17289 L
.04848 .15132 L
.04694 .14141 L
.04576 .13216 L
.0453 .12777 L
.04491 .12331 L
.04447 .11627 L
.04431 .11049 L
.04436 .1057 L
.04456 .10187 L
.04491 .09819 L
.04547 .09466 L
.04623 .09142 L
.04702 .08899 L
.04802 .08666 L
.0491 .08475 L
.05019 .08321 L
.05148 .08176 L
.05304 .0804 L
.05461 .07931 L
.05618 .07845 L
.05777 .07774 L
.05963 .07708 L
.0618 .07649 L
.06427 .076 L
Mistroke
.06672 .07565 L
.06916 .07541 L
.07225 .07523 L
.07527 .07515 L
.07702 .07514 L
.079 .07516 L
.08279 .07525 L
.08631 .0754 L
.09042 .07563 L
.09962 .07631 L
.11945 .07815 L
.30124 .09637 L
.45203 .11046 L
.60953 .1271 L
.68758 .13767 L
.7236 .14366 L
.75722 .15036 L
.78368 .15684 L
.80374 .16295 L
.82022 .16933 L
.83248 .17554 L
.83748 .17872 L
.84203 .18219 L
.8453 .18523 L
.8482 .18858 L
.84964 .19065 L
.85076 .19258 L
.85237 .19642 L
.85319 .19997 L
.8534 .20379 L
.85298 .20754 L
.85188 .21165 L
.85025 .21557 L
.84827 .21921 L
.84196 .22781 L
.8329 .23707 L
.81303 .25275 L
.78946 .26768 L
.71915 .30198 L
.67319 .31949 L
.61613 .33729 L
.55501 .35211 L
.52334 .35814 L
.49222 .36301 L
.46294 .36661 L
.44745 .36814 L
.43024 .36951 L
.41105 .37063 L
.3925 .37129 L
.37413 .37153 L
Mistroke
.35688 .37135 L
.33673 .37063 L
.31761 .36939 L
.30033 .36778 L
.28164 .36545 L
.26123 .36214 L
.23989 .35771 L
.20274 .34707 L
.18425 .34001 L
.1651 .33106 L
.14919 .32201 L
.13349 .31121 L
.1205 .30046 L
.10757 .28755 L
.08841 .26258 L
.079 .2465 L
.07176 .23156 L
.05963 .1988 L
.05246 .17158 L
.04822 .14974 L
.0459 .13334 L
.0451 .12558 L
.04463 .11933 L
.04439 .1141 L
.04431 .10905 L
.04439 .10481 L
.0446 .10131 L
.04498 .09767 L
.04547 .09465 L
.04614 .09172 L
.04702 .08898 L
.04811 .08649 L
.04929 .08445 L
.05049 .08285 L
.05192 .08134 L
.0535 .08005 L
.05508 .07903 L
.05696 .07808 L
.05911 .07725 L
.06115 .07665 L
.06318 .0762 L
.06556 .0758 L
.0683 .07549 L
.06994 .07535 L
.07152 .07526 L
.07332 .07519 L
.07531 .07515 L
.07884 .07515 L
.08097 .0752 L
.08303 .07526 L
Mistroke
.08709 .07544 L
.09105 .07567 L
.10092 .07642 L
.25651 .09212 L
.39409 .105 L
.5704 .12256 L
.6523 .13257 L
.71935 .1429 L
.76839 .15293 L
.79091 .15889 L
.80834 .16458 L
.82244 .17034 L
.83441 .17671 L
.83908 .17987 L
.84286 .18291 L
.84571 .18566 L
.84831 .18872 L
.85053 .19214 L
.85217 .19582 L
.85308 .19927 L
.8534 .20256 L
.85316 .20647 L
.85237 .2101 L
.85091 .21413 L
.84873 .21843 L
.84341 .22607 L
.83573 .2344 L
.81716 .24981 L
.7878 .26864 L
.75479 .286 L
.71609 .30325 L
.66884 .32099 L
.62264 .33546 L
.5673 .34946 L
.53351 .35632 L
.50095 .36175 L
.46656 .36622 L
.45054 .36785 L
.43246 .36935 L
.41267 .37055 L
.40164 .37102 L
.39116 .37132 L
.37224 .37153 L
.35151 .37121 L
.34044 .3708 L
.32824 .37015 L
.31544 .36922 L
.30348 .36811 L
.28199 .3655 L
.25907 .36174 L
Mistroke
.23921 .35755 L
.21772 .35187 L
.19735 .34515 L
.17632 .33653 L
.15775 .32709 L
.14186 .31724 L
.11431 .2946 L
.10045 .27924 L
.08933 .264 L
.07824 .24506 L
.07006 .22764 L
.0589 .19639 L
.05145 .16693 L
.04919 .15536 L
.04737 .14439 L
.04621 .13593 L
.04531 .12785 L
.04494 .12371 L
.04469 .12019 L
.04438 .11394 L
.04431 .11078 L
.04432 .1076 L
.04439 .10482 L
.04452 .10243 L
.04486 .09862 L
.04532 .09544 L
.04598 .09237 L
.04684 .08948 L
.04786 .087 L
.0491 .08474 L
.0503 .08308 L
.05176 .0815 L
.05346 .08008 L
.05518 .07897 L
.05725 .07795 L
.05966 .07708 L
.06193 .07646 L
.06422 .07601 L
.06693 .07563 L
.06854 .07546 L
.07007 .07535 L
.07304 .0752 L
.07598 .07514 L
.07943 .07516 L
.08337 .07527 L
.08741 .07546 L
.09146 .0757 L
.09975 .07632 L
.25263 .09175 L
.2573 .0922 L
Mistroke
Mfstroke
.84853 .21877 m
.84341 .22607 L
.83611 .23403 L
.81857 .24877 L
.76003 .28343 L
.71817 .30238 L
.67218 .31984 L
.62582 .33455 L
.56863 .34917 L
.5378 .35552 L
.50278 .36148 L
.48264 .36429 L
.46371 .36653 L
.44398 .36844 L
.42523 .36984 L
.40776 .37077 L
.38879 .37137 L
.37781 .37151 L
.36738 .37151 L
.34767 .37109 L
.32856 .37017 L
.31085 .36882 L
.29132 .36673 L
.27069 .36378 L
.2485 .35963 L
.22853 .35489 L
.20749 .34867 L
.18541 .34049 L
.166 .33152 L
.14911 .32196 L
.11946 .29951 L
.10539 .28511 L
.09383 .27055 L
.08217 .25228 L
.07335 .23507 L
.06022 .20069 L
.05545 .18396 L
.05165 .16786 L
.04938 .15644 L
.04751 .14532 L
.04629 .13657 L
.04536 .12833 L
.04479 .12173 L
.04443 .1153 L
.04431 .11013 L
.04436 .10583 L
.04462 .10109 L
.04505 .09716 L
.04559 .09407 L
.04632 .0911 L
Mistroke
.04728 .08831 L
.0485 .08576 L
.04982 .0837 L
.05116 .08209 L
.05258 .08076 L
.05422 .07956 L
.05576 .07866 L
.05754 .07783 L
.05962 .07709 L
.0617 .07652 L
.06305 .07622 L
.06438 .07598 L
.06702 .07562 L
.0695 .07539 L
.07231 .07523 L
.07486 .07516 L
.07784 .07514 L
.08124 .0752 L
.08516 .07535 L
.08912 .07555 L
.09297 .0758 L
.11304 .07752 L
.14088 .08037 L
.21307 .08785 L
.50353 .11551 L
.58692 .12443 L
.66865 .13486 L
.70662 .14072 L
.7436 .14748 L
.77281 .15401 L
.79531 .16022 L
.81412 .16677 L
.8283 .17322 L
.83961 .18027 L
.84443 .18436 L
.84792 .18822 L
.8502 .19157 L
.85177 .19476 L
.85288 .19831 L
.85339 .2022 L
.85321 .2061 L
.85287 .20809 L
.85232 .21028 L
.85088 .2142 L
.84903 .2179 L
.84313 .22641 L
.8357 .23444 L
.81248 .25313 L
.78529 .27008 L
.75008 .28826 L
Mistroke
.67397 .31922 L
.622 .33565 L
.56733 .34946 L
.53708 .35566 L
.5031 .36143 L
.48273 .36428 L
.46375 .36653 L
.44397 .36844 L
.42536 .36983 L
.40731 .37079 L
.3879 .37139 L
.36808 .37151 L
.35669 .37135 L
.346 .37103 L
.32644 .37003 L
.30849 .3686 L
.28769 .36627 L
.268 .36333 L
.23183 .35575 L
.21399 .35074 L
.19483 .34422 L
.16288 .32989 L
.13588 .313 L
.12203 .30182 L
.10885 .28895 L
.08906 .26359 L
.08009 .24855 L
.07301 .23433 L
.06084 .20267 L
.05298 .17386 L
.0485 .15143 L
.04682 .14059 L
.0457 .13164 L
.04492 .12344 L
.04464 .11953 L
.04444 .11563 L
.04431 .10979 L
.04433 .10681 L
.04442 .10425 L
.04471 .10001 L
.04522 .09608 L
.04589 .09272 L
.04668 .08996 L
.04751 .08778 L
.04853 .0857 L
.04968 .08389 L
.05087 .08241 L
.0523 .081 L
.054 .0797 L
.05596 .07856 L
Mistroke
.05798 .07766 L
.05996 .07699 L
.06226 .07639 L
.06441 .07598 L
.06695 .07563 L
.06979 .07537 L
.07265 .07521 L
.07549 .07515 L
.07824 .07515 L
.08162 .07521 L
.08504 .07534 L
.08924 .07556 L
.09411 .07588 L
.10392 .07668 L
.12608 .07883 L
.19944 .08647 L
.4404 .10935 L
.52373 .11756 L
.61173 .12736 L
.68567 .13738 L
.74469 .1477 L
.77111 .15359 L
.79545 .16026 L
.81362 .16658 L
.82716 .17262 L
.83862 .17953 L
.84359 .18357 L
.84729 .18743 L
.84882 .18943 L
.85019 .19155 L
.85202 .1954 L
.8527 .19757 L
.85313 .19961 L
.85337 .20186 L
.85337 .20429 L
.85287 .20809 L
.85232 .21027 L
.85164 .21233 L
.84978 .21652 L
.84708 .22109 L
.84047 .2295 L
.83261 .23734 L
.80687 .25693 L
.77444 .27603 L
.69867 .31017 L
.64566 .32859 L
.58966 .34423 L
.5264 .35761 L
.48764 .36364 L
.46843 .36601 L
Mistroke
.45005 .3679 L
.43217 .36937 L
.41556 .3704 L
.39677 .37118 L
.37628 .37152 L
.35628 .37134 L
.34486 .37099 L
.33425 .3705 L
.31463 .36915 L
.2937 .36702 L
.27492 .36445 L
.25777 .3615 L
.23947 .35761 L
.21979 .35247 L
.18774 .34145 L
.15646 .32635 L
.13975 .31578 L
.12576 .30505 L
.11208 .29235 L
.09898 .2774 L
.0801 .24855 L
.06713 .22043 L
.05779 .19258 L
.05128 .16612 L
.04751 .14529 L
.0464 .13739 L
.04551 .12983 L
.04513 .12594 L
.04481 .12192 L
.04444 .1155 L
.04434 .11225 L
.04431 .10899 L
.04435 .10614 L
.04444 .10371 L
.04475 .09968 L
.04526 .09583 L
.04558 .09408 L
.04598 .09234 L
.04682 .08953 L
.04795 .0868 L
.04917 .08464 L
.05069 .08261 L
.05252 .08081 L
.0543 .0795 L
.05613 .07847 L
.05831 .07753 L
.0609 .07672 L
.06338 .07616 L
.06488 .0759 L
.06633 .0757 L
Mistroke
.06914 .07541 L
.07237 .07522 L
.07579 .07514 L
.07925 .07516 L
.08257 .07524 L
.08639 .07541 L
.09068 .07565 L
.09485 .07594 L
.10523 .07679 L
.12794 .07902 L
.20458 .08699 L
.33387 .09942 L
.49448 .1146 L
.64575 .13169 L
.71139 .14152 L
.74393 .14755 L
.76999 .15332 L
.79228 .1593 L
.81241 .1661 L
.8283 .17322 L
.83528 .17726 L
.84057 .181 L
.84447 .1844 L
.84786 .18813 L
.84936 .19021 L
.85053 .19215 L
.85223 .196 L
.85309 .19936 L
.85341 .20309 L
.85307 .20705 L
.85216 .21081 L
.85063 .21476 L
.84838 .21903 L
.84279 .22683 L
.83372 .23632 L
.82341 .24509 L
.76724 .2798 L
.68977 .31353 L
.59611 .34261 L
.53899 .3553 L
.50393 .3613 L
.46952 .36589 L
.45013 .36789 L
.43136 .36943 L
.41417 .37047 L
.39514 .37122 L
.38516 .37144 L
.37406 .37153 L
.36236 .37145 L
.35131 .37121 L
Mistroke
.33139 .37034 L
.32011 .36958 L
.30975 .36872 L
.29118 .36672 L
.27136 .36389 L
.23602 .35679 L
.21488 .35101 L
.1955 .34447 L
.17852 .33752 L
.16139 .32909 L
.13228 .31029 L
.10938 .28952 L
.08939 .26409 L
.08019 .24872 L
.0729 .2341 L
.06085 .20267 L
.05352 .17619 L
.04852 .15156 L
.04689 .14103 L
.04562 .13083 L
.04489 .12308 L
.0445 .11681 L
.04431 .11075 L
.04431 .108 L
.04438 .10521 L
.04463 .10094 L
.04508 .09694 L
.04568 .09365 L
.04635 .09101 L
.04718 .08857 L
.0482 .0863 L
.04919 .0846 L
.0504 .08295 L
.05185 .08141 L
.05357 .08 L
.05535 .07888 L
.05713 .07801 L
.05906 .07727 L
.06097 .0767 L
.06323 .07619 L
.06582 .07577 L
.06848 .07547 L
.07116 .07528 L
.07371 .07518 L
.07665 .07514 L
.08025 .07518 L
.08375 .07529 L
.08808 .07549 L
.09248 .07577 L
.11164 .07739 L
Mistroke
.177 .08416 L
.4416 .10946 L
.60269 .12628 L
.67688 .13606 L
.74552 .14787 L
.79051 .15878 L
.81017 .16525 L
.82471 .17141 L
.83487 .177 L
.84329 .18329 L
.84653 .18654 L
.84926 .19007 L
.85119 .19344 L
.85241 .19654 L
.85321 .20013 L
.8534 .20353 L
.85302 .20731 L
.85196 .21142 L
.85118 .2135 L
.85015 .21578 L
.8478 .21998 L
.84181 .22799 L
.83437 .23571 L
.82469 .24407 L
.80301 .25943 L
.76807 .27937 L
.72807 .2982 L
.68664 .31468 L
.63489 .33188 L
.57733 .34719 L
.51744 .35915 L
.48169 .36442 L
.44754 .36813 L
.42801 .36966 L
.41679 .37034 L
.40632 .37084 L
.3868 .37141 L
.37683 .37152 L
.36575 .37149 L
.34606 .37103 L
.32714 .37008 L
.31003 .36874 L
.29127 .36673 L
.27097 .36383 L
.24944 .35983 L
.21153 .34998 L
.19375 .34381 L
.17522 .33602 L
.15967 .32816 L
.14418 .31879 L
Mistroke
.11793 .29809 L
.09785 .27595 L
.08779 .26162 L
.07845 .24546 L
.06537 .21581 L
.05666 .18854 L
.05128 .16614 L
.04758 .14574 L
.0462 .13587 L
.0453 .12769 L
.04468 .12014 L
.04439 .11407 L
.04431 .10822 L
.04437 .10558 L
.04449 .1029 L
.04484 .09879 L
.04533 .09539 L
.0459 .09268 L
.04664 .09007 L
.04759 .08758 L
.04876 .0853 L
.04989 .0836 L
.05127 .08198 L
.05267 .08069 L
.05411 .07963 L
.05592 .07858 L
.05772 .07776 L
.05941 .07715 L
.06133 .07661 L
.0636 .07612 L
.06584 .07576 L
.06864 .07546 L
.07032 .07533 L
.07196 .07524 L
.07375 .07518 L
.07545 .07515 L
.07749 .07514 L
.0795 .07516 L
.08325 .07527 L
.08696 .07543 L
.09132 .07569 L
.09627 .07604 L
.15529 .08189 L
.38107 .10379 L
.5357 .11881 L
.61661 .12796 L
.69323 .13855 L
.74949 .14869 L
.77427 .15437 L
.79678 .16068 L
Mistroke
.81397 .16672 L
.82668 .17238 L
.83679 .17825 L
.844 .18395 L
.84713 .18724 L
.84976 .19083 L
.85157 .19427 L
.85267 .19745 L
.85333 .20122 L
.8534 .20338 L
.85329 .20539 L
.85264 .20912 L
.85133 .21314 L
.84952 .217 L
.84699 .22122 L
.84093 .22899 L
.8314 .23843 L
.82058 .24727 L
.76901 .27888 L
.69287 .31237 L
.6448 .32885 L
.59372 .34322 L
.56304 .3504 L
.52773 .35737 L
.49674 .36237 L
.4797 .36467 L
.46093 .36683 L
.44269 .36855 L
.42565 .36981 L
.40821 .37076 L
.39134 .37132 L
.37223 .37153 L
.35424 .37129 L
.33426 .3705 L
.31276 .36899 L
.29407 .36707 L
.27384 .36428 L
.25482 .36092 L
.23748 .35714 L
.20538 .34797 L
.17331 .33512 L
.1563 .32626 L
.13904 .31528 L
.12504 .30444 L
.11155 .2918 L
.09016 .26524 L
.07508 .23874 L
.06271 .2083 L
.05491 .18185 L
.04945 .15683 L
Mistroke
.04745 .14492 L
.04611 .13516 L
.04528 .12758 L
.04477 .12142 L
.04443 .11532 L
.04431 .10959 L
.0444 .10475 L
.0447 .10016 L
.04517 .09639 L
.04575 .09334 L
.04639 .09085 L
.0471 .08877 L
.04798 .08674 L
.04905 .08482 L
.05031 .08306 L
.05164 .08161 L
.05306 .08038 L
.05448 .07939 L
.05635 .07836 L
.05856 .07744 L
.06067 .07678 L
.06308 .07622 L
.06541 .07582 L
.06773 .07554 L
.07045 .07532 L
.07357 .07518 L
.07716 .07514 L
.07931 .07516 L
.08137 .07521 L
.08538 .07536 L
.08751 .07546 L
.08995 .0756 L
.10969 .0772 L
.24973 .09146 L
.39718 .10529 L
.56723 .12221 L
.63853 .13074 L
.70619 .14064 L
.73981 .14672 L
.7665 .15248 L
.80782 .16439 L
.82321 .17069 L
.8358 .17759 L
.84371 .18368 L
.84711 .18721 L
.84959 .19056 L
.85069 .19244 L
.85167 .1945 L
.85288 .19829 L
.85338 .20204 L
Mistroke
.85327 .20555 L
.85257 .20938 L
.8519 .21159 L
.85111 .21368 L
.84902 .21792 L
.84608 .22255 L
.83997 .23005 L
.83142 .23841 L
.80869 .25572 L
.75148 .28759 L
.70861 .30628 L
.66181 .32337 L
.61382 .33793 L
.55707 .35167 L
.52519 .35782 L
.48814 .36357 L
.47125 .36569 L
.45266 .36765 L
.43485 .36917 L
.41799 .37027 L
.40768 .37078 L
.39658 .37118 L
.38414 .37145 L
.37275 .37153 L
.36185 .37144 L
.34998 .37117 L
.3387 .37072 L
.32827 .37015 L
.30861 .36861 L
.29741 .36745 L
.28695 .36617 L
.26586 .36297 L
.24344 .35852 L
.20291 .34713 L
.18339 .33964 L
.16293 .32992 L
.14662 .32039 L
.13036 .3088 L
.10491 .28456 L
.09287 .2692 L
.08173 .2515 L
.07278 .23383 L
.0651 .21509 L
.05534 .18357 L
.04974 .1584 L
.04641 .1375 L
.0453 .12778 L
.04494 .12363 L
.04467 .12 L
.04438 .11403 L
Mistroke
.04431 .10827 L
.04446 .10338 L
.04463 .10091 L
.04484 .09882 L
.04536 .09527 L
.04598 .09237 L
.0468 .08958 L
.04785 .08701 L
.04889 .08507 L
.04999 .08347 L
.05132 .08193 L
.0529 .0805 L
.05462 .0793 L
.05633 .07837 L
.05847 .07748 L
.06067 .07678 L
.06287 .07626 L
.06504 .07588 L
.06758 .07556 L
.07048 .07532 L
.07361 .07518 L
.07547 .07515 L
.07724 .07514 L
.08084 .07519 L
.08452 .07532 L
.08668 .07542 L
.08908 .07555 L
.09363 .07585 L
.10519 .07679 L
.26938 .09336 L
.40698 .1062 L
.57766 .12337 L
.6617 .13387 L
.70145 .13986 L
.73929 .14662 L
.76928 .15314 L
.79244 .15935 L
.81041 .16534 L
.82632 .1722 L
.83778 .17893 L
.84264 .18272 L
.84634 .18633 L
.84905 .18975 L
.85094 .19293 L
.85239 .19647 L
.85322 .20026 L
.85338 .20416 L
.85317 .20637 L
.85281 .20839 L
.85162 .21237 L
Mistroke
.84996 .21617 L
.84736 .22066 L
.84437 .22486 L
.83562 .23452 L
.81705 .24989 L
.79019 .26726 L
.717 .30287 L
.66918 .32088 L
.61744 .33693 L
.56552 .34986 L
.53401 .35623 L
.50281 .36147 L
.48453 .36405 L
.46425 .36647 L
.44696 .36818 L
.4276 .36969 L
.41652 .37035 L
.40607 .37085 L
.39493 .37123 L
.38287 .37147 L
.37153 .37153 L
.36071 .37142 L
.34024 .37079 L
.32054 .36962 L
.2995 .36769 L
.28149 .36543 L
.26168 .36222 L
.24062 .35788 L
.21834 .35205 L
.1978 .34532 L
.17984 .33811 L
.14658 .32036 L
.13019 .30866 L
.11615 .29639 L
.09484 .27194 L
.08495 .25705 L
.07715 .24293 L
.06439 .21313 L
.05511 .18265 L
.05187 .1689 L
.04922 .15557 L
.04749 .14514 L
.04613 .13529 L
.04562 .13083 L
.04516 .12623 L
.04461 .11891 L
.04443 .11521 L
.04432 .11153 L
.04431 .10833 L
.04436 .1056 L
Mistroke
.04461 .10112 L
.04484 .09883 L
.0451 .09685 L
.04576 .09327 L
.04621 .09148 L
.04667 .08997 L
.04767 .0874 L
.04874 .08533 L
.05007 .08337 L
.05166 .08159 L
.05319 .08028 L
.05476 .07922 L
.05663 .07823 L
.05882 .07735 L
.06122 .07664 L
.06358 .07612 L
.06497 .07589 L
.06653 .07567 L
.06954 .07538 L
.07258 .07522 L
.07605 .07514 L
.07921 .07516 L
.08292 .07526 L
.0853 .07535 L
.08764 .07547 L
.09228 .07576 L
.10402 .07669 L
.13051 .07928 L
.32222 .09833 L
.47286 .11247 L
.56187 .12162 L
.64148 .13113 L
.70641 .14068 L
.75615 .15012 L
.79901 .16138 L
.81622 .16762 L
.83054 .17443 L
.8361 .17779 L
.84119 .1815 L
.8449 .18482 L
.84806 .1884 L
.85026 .19167 L
.85199 .19531 L
.85296 .19868 L
.85337 .20186 L
.85323 .2059 L
.85246 .20979 L
.85125 .21333 L
.8494 .21723 L
.8468 .22151 L
Mistroke
.84337 .22612 L
.83558 .23456 L
.81477 .25153 L
.78904 .26792 L
.7263 .29896 L
.63347 .33231 L
.57745 .34716 L
.54237 .35465 L
.50853 .36059 L
.47567 .36516 L
.4432 .36851 L
.42483 .36987 L
.40753 .37078 L
.38819 .37138 L
.37831 .37151 L
.36733 .37151 L
.34884 .37113 L
.33173 .37036 L
.31183 .36891 L
.29282 .36692 L
.27532 .36451 L
.25913 .36175 L
.22295 .35337 L
.20292 .34713 L
.18252 .33927 L
.14864 .32167 L
.1317 .30985 L
.11733 .29752 L
.10247 .28171 L
.09036 .26555 L
.07326 .23487 L
.06226 .20699 L
.05428 .17934 L
.0489 .15374 L
.04627 .13643 L
.04533 .12809 L
.04475 .12116 L
.04441 .11475 L
.04431 .10956 L
.0444 .10454 L
.04453 .10227 L
.04472 .09995 L
.04517 .09639 L
.0457 .09353 L
.04646 .09062 L
.04732 .08821 L
.04824 .08624 L
.04918 .08463 L
.0503 .08308 L
.05165 .0816 L
Mistroke
.05325 .08024 L
.05491 .07913 L
.05667 .07821 L
.05843 .07749 L
.06069 .07678 L
.0629 .07625 L
.0642 .07601 L
.06566 .07579 L
.06846 .07547 L
.07109 .07528 L
.07417 .07517 L
.07762 .07514 L
.08106 .0752 L
.0845 .07532 L
.08782 .07548 L
.09599 .07602 L
.11859 .07807 L
.15111 .08145 L
.23854 .09037 L
.52337 .11753 L
.61118 .1273 L
.69596 .13898 L
.72961 .14477 L
.76068 .15113 L
.78555 .15736 L
.80454 .16323 L
.82058 .16949 L
.83256 .17559 L
.84209 .18224 L
.84611 .18609 L
.84901 .18969 L
.8509 .19285 L
.85218 .19583 L
.85305 .19916 L
.8534 .20277 L
.85314 .2066 L
.85232 .21028 L
.85113 .21363 L
.84936 .21731 L
.84405 .22526 L
.83589 .23425 L
.81264 .25302 L
.7838 .27092 L
.75074 .28794 L
.66536 .32218 L
.61329 .33808 L
.54889 .35336 L
.51802 .35905 L
.48741 .36367 L
.4699 .36584 L
Mistroke
.45043 .36786 L
.43232 .36936 L
.41527 .37042 L
.39895 .37111 L
.38344 .37146 L
.3662 .3715 L
.3474 .37108 L
.32754 .3701 L
.30852 .3686 L
.29138 .36674 L
.27267 .3641 L
.25102 .36015 L
.23134 .35562 L
.21059 .34968 L
.18856 .34178 L
.15399 .32492 L
.13688 .31373 L
.12227 .30204 L
.10936 .2895 L
.09846 .27674 L
.0815 .25111 L
.06796 .22253 L
.05784 .19274 L
.05136 .1665 L
.04712 .1427 L
.04583 .13279 L
.04533 .1281 L
.04493 .12352 L
.04466 .11978 L
.04446 .11598 L
.04431 .10999 L
.04433 .10716 L
.0444 .10468 L
.04467 .10046 L
.04515 .0965 L
.0455 .0945 L
.04587 .09279 L
.0466 .0902 L
.04754 .0877 L
.04868 .08544 L
.04989 .0836 L
.0513 .08195 L
.05296 .08045 L
.0547 .07926 L
.05641 .07833 L
.05862 .07742 L
.06123 .07664 L
.06251 .07634 L
.06392 .07606 L
.0666 .07567 L
Mistroke
.06929 .0754 L
.07239 .07522 L
.07554 .07515 L
.07859 .07515 L
.08241 .07524 L
.0847 .07533 L
.08689 .07543 L
.09596 .07602 L
.11456 .07767 L
.14062 .08034 L
.21669 .08821 L
.24674 .09117 L
Mfstroke
.05644 .07832 m
.05836 .07752 L
.06024 .0769 L
.06257 .07632 L
.06495 .07589 L
.0673 .07559 L
.06961 .07538 L
.0723 .07523 L
.07535 .07515 L
.07862 .07515 L
.08239 .07524 L
.08619 .0754 L
.0899 .0756 L
.09993 .07634 L
.11091 .07732 L
.26944 .09336 L
.42091 .10751 L
.51764 .11694 L
.60814 .12693 L
.68489 .13726 L
.72036 .14308 L
.7534 .14953 L
.7775 .1552 L
.7999 .16167 L
.8155 .16733 L
.82919 .17369 L
.83534 .17729 L
.84017 .18069 L
.84397 .18392 L
.84738 .18754 L
.84976 .19083 L
.85143 .19396 L
.85263 .1973 L
.8533 .20096 L
.85335 .20474 L
.85309 .20691 L
.85268 .20894 L
.85135 .21309 L
.85031 .21544 L
.84921 .21759 L
.84367 .22574 L
.83654 .23361 L
.81788 .24928 L
.79548 .26412 L
.72805 .29821 L
.68703 .31454 L
.63689 .33128 L
.58831 .34456 L
.52958 .35704 L
.49095 .36319 L
Mistroke
.47133 .36568 L
.45312 .36761 L
.4338 .36925 L
.41523 .37042 L
.39524 .37122 L
.38381 .37146 L
.37322 .37153 L
.35439 .37129 L
.33663 .37062 L
.31696 .36934 L
.29578 .36727 L
.27352 .36423 L
.25256 .36047 L
.23386 .35626 L
.21409 .35077 L
.19501 .34428 L
.17816 .33736 L
.14741 .32089 L
.13261 .31055 L
.11784 .29801 L
.10397 .28348 L
.09296 .26932 L
.07474 .23803 L
.0672 .22062 L
.06147 .20461 L
.054 .17819 L
.0489 .15376 L
.04628 .13647 L
.04534 .12816 L
.04476 .12128 L
.04441 .11488 L
.04431 .10972 L
.04441 .10449 L
.0447 .10017 L
.04509 .0969 L
.04564 .09381 L
.04622 .09146 L
.04696 .08915 L
.04788 .08695 L
.04901 .08488 L
.05022 .08318 L
.05144 .08181 L
.05304 .08039 L
.05471 .07925 L
.05633 .07837 L
.05823 .07756 L
.06048 .07683 L
.06307 .07622 L
.06546 .07582 L
.06828 .07549 L
Mistroke
.07112 .07528 L
.07388 .07518 L
.0773 .07514 L
.08077 .07519 L
.08418 .0753 L
.08754 .07546 L
.09587 .07601 L
.11932 .07814 L
.147 .08101 L
.23879 .0904 L
.37226 .10297 L
.54842 .12016 L
.62054 .12845 L
.69052 .13812 L
.72577 .14406 L
.75423 .1497 L
.79914 .16143 L
.81601 .16754 L
.83023 .17426 L
.83951 .18019 L
.84367 .18364 L
.84686 .18693 L
.84959 .19057 L
.85076 .19258 L
.85165 .19447 L
.85277 .19784 L
.85336 .20158 L
.8534 .20371 L
.85325 .20574 L
.85252 .20956 L
.85186 .21172 L
.85108 .21373 L
.84879 .21832 L
.84378 .2256 L
.8376 .23254 L
.81858 .24876 L
.79398 .26502 L
.76139 .28276 L
.67634 .31839 L
.6169 .33708 L
.58548 .34525 L
.5541 .35229 L
.52245 .3583 L
.48641 .3638 L
.46985 .36585 L
.45199 .36772 L
.4349 .36917 L
.41905 .37021 L
.40013 .37107 L
.38958 .37136 L
Mistroke
.37951 .3715 L
.36141 .37144 L
.34149 .37085 L
.33097 .37031 L
.31932 .36952 L
.29564 .36725 L
.27367 .36426 L
.25317 .36059 L
.23313 .35607 L
.21218 .35018 L
.17622 .33648 L
.15578 .32596 L
.13794 .3145 L
.12311 .30278 L
.10902 .28913 L
.09792 .27604 L
.0873 .26085 L
.0724 .233 L
.06031 .20099 L
.053 .17397 L
.04855 .15172 L
.04707 .14231 L
.04603 .13446 L
.04534 .12816 L
.0448 .12188 L
.04447 .11623 L
.04432 .11088 L
.04436 .10577 L
.04457 .10164 L
.04498 .09765 L
.0456 .094 L
.04629 .09122 L
.04704 .08892 L
.048 .0867 L
.04917 .08463 L
.05047 .08287 L
.05207 .08121 L
.05393 .07975 L
.05586 .07861 L
.05783 .07772 L
.05978 .07704 L
.06221 .0764 L
.06471 .07593 L
.06621 .07571 L
.06763 .07555 L
.06932 .0754 L
.07099 .07529 L
.07413 .07517 L
.076 .07514 L
.07778 .07514 L
Mistroke
.0798 .07517 L
.08176 .07522 L
.084 .0753 L
.08649 .07541 L
.09192 .07573 L
.09729 .07612 L
.23687 .09021 L
.36801 .10258 L
.54284 .11957 L
.61474 .12773 L
.6853 .13732 L
.72094 .14318 L
.74997 .1488 L
.77412 .15434 L
.79615 .16048 L
.8138 .16665 L
.82679 .17244 L
.83707 .17844 L
.84434 .18427 L
.84747 .18765 L
.85003 .19128 L
.85163 .19442 L
.85279 .19792 L
.85337 .20174 L
.85339 .20391 L
.85324 .2059 L
.85246 .20981 L
.85115 .21357 L
.84945 .21715 L
.84704 .22115 L
.84055 .22941 L
.82393 .24467 L
.79721 .26306 L
.76549 .28069 L
.68503 .31528 L
.63553 .33169 L
.57407 .34794 L
.51519 .35952 L
.47964 .36468 L
.46219 .3667 L
.44572 .36829 L
.4302 .36951 L
.41279 .37054 L
.39498 .37123 L
.37577 .37152 L
.35866 .37139 L
.34005 .37079 L
.3223 .36975 L
.30597 .36836 L
.28491 .3659 L
Mistroke
.26509 .36283 L
.22852 .35489 L
.20854 .34902 L
.19071 .34263 L
.17075 .3339 L
.15318 .32444 L
.12672 .30585 L
.11333 .29362 L
.10237 .28158 L
.08371 .25495 L
.0755 .23962 L
.06897 .22504 L
.05858 .19529 L
.05152 .16728 L
.04782 .14726 L
.04648 .13803 L
.04546 .1294 L
.04508 .12532 L
.04475 .12117 L
.0444 .1146 L
.04432 .11126 L
.04431 .10796 L
.04438 .10509 L
.0445 .10267 L
.04489 .09843 L
.04518 .09629 L
.04551 .09445 L
.04623 .09142 L
.04716 .08863 L
.04817 .08637 L
.04943 .08425 L
.05077 .08252 L
.05216 .08113 L
.05363 .07996 L
.05513 .079 L
.05701 .07806 L
.05885 .07734 L
.06108 .07667 L
.06362 .07612 L
.06595 .07575 L
.0687 .07545 L
.07189 .07524 L
.07379 .07518 L
.07559 .07515 L
.07929 .07516 L
.08305 .07526 L
.08647 .07541 L
.09048 .07564 L
.09941 .07629 L
.11858 .07807 L
Mistroke
.18118 .0846 L
.4492 .11019 L
.53026 .11824 L
.61496 .12776 L
.68613 .13745 L
.74296 .14735 L
.76838 .15293 L
.79196 .1592 L
.80845 .16462 L
.82336 .17076 L
.83616 .17783 L
.84156 .1818 L
.84564 .18558 L
.84864 .18918 L
.85072 .19251 L
.85237 .19641 L
.85321 .20016 L
.8534 .20345 L
.85306 .20713 L
.85209 .21102 L
.85065 .21472 L
.84886 .21821 L
.84685 .22144 L
.84107 .22883 L
.82354 .24499 L
.79803 .26256 L
.73214 .29643 L
.68642 .31476 L
.63695 .33127 L
.58514 .34533 L
.55556 .35199 L
.52246 .3583 L
.49322 .36287 L
.47718 .36498 L
.45954 .36697 L
.44302 .36852 L
.42762 .36968 L
.41187 .37059 L
.39667 .37118 L
.3772 .37152 L
.3661 .37149 L
.35581 .37133 L
.3367 .37063 L
.31633 .36929 L
.29794 .36751 L
.28075 .36532 L
.26194 .36227 L
.24194 .35818 L
.22094 .3528 L
.19873 .34565 L
Mistroke
.1799 .33813 L
.16089 .32882 L
.14486 .31924 L
.12853 .30733 L
.10368 .28313 L
.09333 .26985 L
.08386 .25522 L
.07035 .22832 L
.06002 .20006 L
.0526 .17222 L
.04854 .15168 L
.04701 .14193 L
.04594 .13369 L
.04521 .1268 L
.04468 .12013 L
.04441 .11473 L
.04431 .11026 L
.04438 .10517 L
.04463 .10093 L
.045 .09757 L
.04554 .09432 L
.04628 .09123 L
.04725 .08838 L
.04833 .08606 L
.04944 .08423 L
.0507 .0826 L
.05198 .08129 L
.05351 .08004 L
.05528 .07892 L
.05685 .07813 L
.05864 .07741 L
.06076 .07676 L
.06289 .07626 L
.06425 .076 L
.06575 .07577 L
.06862 .07546 L
.07031 .07533 L
.07196 .07524 L
.07384 .07518 L
.07596 .07514 L
.07784 .07514 L
.07998 .07517 L
.08209 .07523 L
.08412 .0753 L
.08816 .0755 L
.09277 .07579 L
.11473 .07769 L
.14059 .08034 L
.35764 .10162 L
.50559 .11571 L
Mistroke
.58658 .12439 L
.66719 .13465 L
.73413 .14562 L
.78229 .15646 L
.80081 .16197 L
.81755 .16818 L
.8302 .17424 L
.83929 .18002 L
.84317 .18319 L
.84662 .18665 L
.8492 .18997 L
.851 .19306 L
.8524 .19652 L
.85324 .20037 L
.85339 .20233 L
.85337 .20445 L
.85283 .2083 L
.8516 .21243 L
.85062 .21479 L
.84954 .21697 L
.84396 .22538 L
.83696 .23319 L
.82769 .24163 L
.77711 .2746 L
.73881 .29346 L
.69781 .3105 L
.65456 .32575 L
.60152 .34122 L
.54557 .35402 L
.51841 .35899 L
.48845 .36353 L
.47064 .36576 L
.45062 .36785 L
.43198 .36938 L
.41423 .37047 L
.4033 .37096 L
.39284 .37128 L
.373 .37153 L
.36176 .37144 L
.35129 .37121 L
.33973 .37077 L
.32738 .37009 L
.30819 .36857 L
.28744 .36624 L
.26787 .36331 L
.25004 .35995 L
.20955 .34934 L
.19003 .34236 L
.16964 .33335 L
.15233 .32393 L
Mistroke
.1371 .31389 L
.11192 .29218 L
.09986 .27851 L
.0901 .26516 L
.07263 .23351 L
.06268 .20822 L
.05504 .18239 L
.04984 .15892 L
.04684 .14067 L
.04573 .13191 L
.04528 .12754 L
.04494 .12371 L
.04453 .11753 L
.04432 .11151 L
.04431 .10865 L
.04436 .10584 L
.0446 .10132 L
.04481 .09905 L
.04506 .09709 L
.04539 .09509 L
.0458 .09311 L
.04661 .09015 L
.04768 .08738 L
.04886 .08513 L
.0501 .08333 L
.05133 .08192 L
.05282 .08057 L
.05454 .07936 L
.05629 .07839 L
.05814 .0776 L
.06033 .07688 L
.06256 .07632 L
.06479 .07592 L
.06714 .0756 L
.0694 .07539 L
.07219 .07523 L
.07498 .07515 L
.07824 .07515 L
.08193 .07522 L
.08529 .07535 L
.0892 .07556 L
.09889 .07625 L
.10925 .07716 L
.2514 .09163 L
.55723 .12111 L
.64313 .13134 L
.72198 .14337 L
.77515 .1546 L
.799 .16138 L
.81716 .16801 L
Mistroke
.83074 .17454 L
.83671 .1782 L
.84139 .18166 L
.845 .18493 L
.8477 .18793 L
.85006 .19132 L
.85187 .19499 L
.85253 .19693 L
.85302 .199 L
.8534 .20274 L
.85334 .20484 L
.85311 .20683 L
.85266 .20902 L
.85197 .21139 L
.85019 .21569 L
.84789 .21983 L
.84203 .22772 L
.83363 .2364 L
.82388 .24472 L
.80119 .26059 L
.73096 .29695 L
.64947 .32738 L
.59486 .34293 L
.53887 .35532 L
.50624 .36095 L
.4751 .36523 L
.45727 .3672 L
.43745 .36897 L
.41831 .37025 L
.40028 .37106 L
.3834 .37146 L
.36736 .37151 L
.34955 .37115 L
.33017 .37027 L
.30976 .36872 L
.29025 .3666 L
.27275 .36411 L
.25371 .3607 L
.23117 .35557 L
.21037 .34961 L
.17339 .33516 L
.15419 .32504 L
.13776 .31437 L
.12033 .3003 L
.10591 .2857 L
.08612 .25897 L
.0777 .24401 L
.07014 .22782 L
.05875 .19587 L
.05208 .16987 L
Mistroke
.04814 .1493 L
.04663 .13916 L
.04562 .1309 L
.0449 .12322 L
.04465 .11956 L
.04446 .11598 L
.04431 .1105 L
.04438 .10524 L
.04463 .10096 L
.045 .09752 L
.0456 .09402 L
.04631 .09114 L
.0471 .08878 L
.04793 .08685 L
.04895 .08498 L
.05017 .08324 L
.05165 .0816 L
.05314 .08031 L
.05504 .07905 L
.05702 .07805 L
.059 .07729 L
.06098 .0767 L
.06332 .07617 L
.06601 .07574 L
.06764 .07555 L
.06921 .07541 L
.071 .07529 L
.07298 .0752 L
.07652 .07514 L
.07865 .07515 L
.08072 .07519 L
.08482 .07533 L
.08881 .07554 L
.09881 .07624 L
.24738 .09124 L
.36816 .10259 L
.5325 .11848 L
.60872 .127 L
.68358 .13706 L
.7432 .1474 L
.78643 .15761 L
.80547 .16355 L
.8201 .16928 L
.83287 .17577 L
.84289 .18294 L
.84663 .18666 L
.84825 .18864 L
.84971 .19075 L
.85078 .19262 L
.85174 .19469 L
Mistroke
.8529 .19837 L
.85338 .202 L
.85323 .20595 L
.85248 .20973 L
.8513 .21322 L
.84955 .21695 L
.84746 .2205 L
.84116 .22873 L
.83307 .23692 L
.82234 .24592 L
.77053 .2781 L
.7312 .29684 L
.68239 .31623 L
.6297 .33342 L
.57565 .34758 L
.5466 .35382 L
.51336 .35982 L
.48033 .36459 L
.44844 .36805 L
.43046 .36949 L
.41328 .37052 L
.39408 .37125 L
.38314 .37147 L
.37304 .37153 L
.3526 .37124 L
.34091 .37082 L
.32999 .37025 L
.30987 .36873 L
.28832 .36635 L
.26804 .36334 L
.24949 .35984 L
.22977 .35521 L
.20858 .34903 L
.17457 .33572 L
.15722 .32679 L
.14203 .31735 L
.11624 .29648 L
.09673 .27448 L
.07909 .24667 L
.06681 .21961 L
.05757 .1918 L
.05178 .16848 L
.04776 .14689 L
.0463 .13663 L
.04536 .12833 L
.04475 .12112 L
.04443 .11519 L
.04431 .10946 L
.04434 .10657 L
.04442 .10412 L
Mistroke
.04475 .09967 L
.04502 .09742 L
.04532 .09549 L
.04599 .09231 L
.04688 .08938 L
.04778 .08716 L
.04872 .08536 L
.04994 .08354 L
.05122 .08203 L
.05381 .07983 L
.05546 .07882 L
.05712 .07801 L
.05924 .07721 L
.06141 .07659 L
.0635 .07614 L
.06591 .07575 L
.06875 .07545 L
.07026 .07533 L
.07199 .07524 L
.07521 .07515 L
.07843 .07515 L
.08223 .07523 L
.08425 .07531 L
.08656 .07541 L
.0952 .07596 L
.11945 .07815 L
.18578 .08507 L
.41811 .10724 L
.57572 .12316 L
.6568 .13319 L
.72211 .14339 L
.77855 .15547 L
.8017 .16227 L
.82135 .16983 L
.82839 .17327 L
.83496 .17705 L
.83986 .18045 L
.84417 .18411 L
.84731 .18746 L
.84998 .1912 L
.85173 .19465 L
.85279 .19792 L
.85336 .20172 L
.8534 .20365 L
.85325 .20581 L
.8525 .20966 L
.85126 .21332 L
.84917 .21766 L
.84667 .2217 L
.83911 .23097 L
Mistroke
.82055 .24729 L
.79398 .26501 L
.73198 .2965 L
.64198 .32973 L
.58293 .34586 L
.55118 .35289 L
.52026 .35867 L
.4914 .36312 L
.45819 .36711 L
.44038 .36874 L
.42336 .36996 L
.40504 .37089 L
.38497 .37144 L
.37438 .37153 L
.363 .37146 L
.34231 .37089 L
.32952 .37023 L
.31741 .36938 L
.29468 .36714 L
.27286 .36413 L
.25288 .36054 L
.23121 .35559 L
.20884 .34911 L
.19067 .34262 L
.17198 .33449 L
.14096 .31662 L
.1241 .30364 L
.10981 .28998 L
.0984 .27666 L
.08769 .26146 L
.07213 .23239 L
.06173 .2054 L
.0535 .17608 L
.04882 .15328 L
.04609 .13493 L
.04516 .12625 L
.04462 .11917 L
.04445 .11568 L
.04435 .11261 L
.04432 .10741 L
.04451 .1025 L
.04471 .10003 L
.04495 .09791 L
.04542 .09489 L
.04607 .09202 L
.04679 .08962 L
.04755 .08766 L
.04857 .08563 L
.04981 .0837 L
.05113 .08212 L
Mistroke
.05248 .08085 L
.05414 .07961 L
.05585 .07861 L
.05751 .07785 L
.05944 .07714 L
.06172 .07651 L
.06432 .07599 L
.06671 .07565 L
.06951 .07539 L
.07276 .07521 L
.07598 .07514 L
.07776 .07514 L
.07979 .07517 L
.082 .07522 L
.08415 .0753 L
.08831 .07551 L
.09239 .07576 L
.10255 .07656 L
.15344 .08169 L
.38864 .10449 L
.54038 .1193 L
.62277 .12873 L
.69267 .13846 L
.72753 .14438 L
.76051 .15109 L
.78398 .15693 L
.80556 .16359 L
.82199 .17012 L
.82893 .17355 L
.83534 .17729 L
.84039 .18086 L
.84423 .18417 L
.8474 .18756 L
.84973 .19079 L
.85146 .19401 L
.85269 .19753 L
.85335 .20149 L
.85331 .20518 L
.8527 .20886 L
.85141 .21293 L
.85052 .21501 L
.84939 .21725 L
.84693 .22131 L
.84055 .22941 L
.83275 .23721 L
.81386 .25217 L
.7519 .28739 L
.70613 .30726 L
.65702 .32495 L
.60689 .33981 L
Mistroke
.54658 .35382 L
.51491 .35957 L
.48333 .3642 L
.45376 .36755 L
.43652 .36905 L
.42023 .37014 L
.40038 .37106 L
.38904 .37137 L
.37851 .37151 L
.3589 .37139 L
.33793 .37069 L
.31891 .36949 L
.30106 .36785 L
.28143 .36542 L
.26046 .362 L
.23828 .35733 L
.21465 .35094 L
.19444 .34407 L
.17389 .3354 L
.1564 .32632 L
.13845 .31486 L
.12346 .30308 L
.11084 .29106 L
.08955 .26433 L
.08047 .24924 L
.07233 .23284 L
.06002 .20007 L
.05284 .17326 L
.04861 .15206 L
.04709 .14244 L
.0459 .13335 L
.04516 .12628 L
.04464 .11937 L
.04438 .11381 L
.04431 .10917 L
.04443 .10407 L
.04458 .10149 L
.04479 .09928 L
.0453 .09561 L
.04601 .09222 L
.0468 .08959 L
.04767 .08741 L
.04875 .08531 L
.05008 .08335 L
.05158 .08167 L
.05341 .08011 L
.05555 .07877 L
.05775 .07775 L
.06001 .07697 L
.06224 .0764 L
Mistroke
.06354 .07613 L
.06502 .07588 L
.06788 .07553 L
.07078 .0753 L
.07363 .07518 L
.07715 .07514 L
.08075 .07519 L
.08428 .07531 L
.08777 .07548 L
.09646 .07606 L
.11897 .07811 L
.15056 .08139 L
.38359 .10402 L
.55348 .1207 L
.64058 .13101 L
.72028 .14307 L
.77532 .15464 L
.79977 .16163 L
.81815 .16843 L
.8314 .17492 L
.84059 .18102 L
.84455 .18448 L
.84798 .1883 L
.85043 .19196 L
.85202 .1954 L
.85301 .19892 L
.8534 .20268 L
.85323 .20593 L
.85253 .20952 L
.8512 .21346 L
.8502 .21568 L
.84913 .21772 L
.84384 .22553 L
.83724 .23292 L
.82834 .24107 L
.80794 .25622 L
.7771 .27461 L
.73708 .29424 L
.64666 .32828 L
.61073 .33878 L
.56889 .34911 L
.48453 .36405 L
Mfstroke
.69301 .13851 m
.75024 .14885 L
.792 .15922 L
.8108 .16549 L
.82469 .1714 L
.83111 .17475 L
.83709 .17846 L
.8418 .182 L
.84543 .18536 L
.84825 .18865 L
.85058 .19223 L
.85158 .1943 L
.85233 .19628 L
.8532 .20003 L
.85339 .20404 L
.85293 .2078 L
.8524 .21 L
.85176 .212 L
.84977 .21653 L
.84748 .22047 L
.84492 .22414 L
.8376 .23255 L
.8193 .24823 L
.79252 .26589 L
.76161 .28265 L
.71774 .30256 L
.67102 .32025 L
.61892 .33652 L
.55477 .35215 L
.51614 .35936 L
.47822 .36485 L
.45876 .36705 L
.44004 .36877 L
.42008 .37015 L
.4093 .37071 L
.39754 .37115 L
.37794 .37151 L
.35985 .37141 L
.3387 .37072 L
.31852 .36946 L
.29972 .36771 L
.28234 .36555 L
.26331 .36252 L
.24331 .35849 L
.22347 .35352 L
.20268 .34705 L
.16715 .33211 L
.14724 .32078 L
.12992 .30845 L
.11455 .29483 L
Mistroke
.10219 .28137 L
.08168 .25142 L
.07298 .23427 L
.06626 .21819 L
.0573 .19085 L
.051 .16479 L
.04691 .14121 L
.04568 .13142 L
.04517 .12637 L
.04482 .12213 L
.04443 .11527 L
.04433 .11188 L
.04431 .1089 L
.04442 .10411 L
.04457 .10167 L
.04476 .09958 L
.04522 .09604 L
.04588 .09278 L
.04656 .09032 L
.04743 .08795 L
.04852 .08571 L
.04985 .08365 L
.05127 .08198 L
.05269 .08068 L
.05415 .0796 L
.05584 .07862 L
.05785 .07771 L
.05985 .07702 L
.06186 .07648 L
.06386 .07607 L
.0662 .07572 L
.0689 .07543 L
.07049 .07532 L
.07226 .07523 L
.07561 .07515 L
.07758 .07514 L
.07951 .07516 L
.0817 .07522 L
.08417 .0753 L
.08862 .07552 L
.09367 .07585 L
.10372 .07666 L
.159 .08228 L
.38549 .1042 L
.5288 .11809 L
.67816 .13624 L
.7449 .14775 L
.76919 .15312 L
.79219 .15927 L
.80917 .16488 L
Mistroke
.82411 .17112 L
.83093 .17465 L
.83632 .17794 L
.84461 .18453 L
.84792 .18822 L
.84939 .19026 L
.85056 .19221 L
.85225 .19603 L
.85312 .19955 L
.85336 .20161 L
.85339 .20381 L
.85293 .20779 L
.85239 .21003 L
.85171 .21213 L
.84954 .21697 L
.84699 .22123 L
.84401 .22531 L
.83706 .23309 L
.81541 .25107 L
.79032 .26718 L
.75642 .28521 L
.71732 .30274 L
.66849 .32111 L
.61655 .33718 L
.56327 .35035 L
.50707 .36082 L
.47686 .36502 L
.46029 .36689 L
.44236 .36858 L
.42263 .37 L
.40408 .37093 L
.38373 .37146 L
.37201 .37153 L
.36095 .37143 L
.34076 .37082 L
.32214 .36973 L
.31179 .3689 L
.30049 .36779 L
.27989 .3652 L
.25977 .36187 L
.24171 .35813 L
.22254 .35326 L
.20233 .34693 L
.18416 .33997 L
.16816 .33261 L
.13915 .31536 L
.12461 .30408 L
.11057 .29077 L
.08941 .26411 L
.07909 .24668 L
Mistroke
.07104 .22993 L
.05981 .19938 L
.05223 .17053 L
.04798 .14826 L
.04653 .13839 L
.04541 .12883 L
.04501 .12451 L
.04469 .1202 L
.04448 .11643 L
.04436 .11322 L
.04432 .10764 L
.04448 .10303 L
.04478 .09938 L
.04525 .09588 L
.04593 .09254 L
.04634 .09102 L
.04684 .08948 L
.04784 .08703 L
.04891 .08504 L
.05013 .08329 L
.0514 .08184 L
.05413 .07961 L
.05586 .07861 L
.05758 .07782 L
.05962 .07709 L
.06198 .07645 L
.06453 .07596 L
.06705 .07561 L
.07003 .07535 L
.07162 .07526 L
.07342 .07519 L
.07665 .07514 L
.08034 .07518 L
.08408 .0753 L
.0877 .07547 L
.09756 .07614 L
.11 .07723 L
.13817 .08008 L
.33173 .09922 L
.49543 .11469 L
.59054 .12485 L
.67369 .13559 L
.73958 .14668 L
.77027 .15338 L
.79421 .15988 L
.81219 .16602 L
.82591 .172 L
.83222 .17539 L
.83805 .17912 L
.84245 .18255 L
Mistroke
.84585 .1858 L
.84851 .18899 L
.8507 .19246 L
.85235 .19636 L
.85319 .19997 L
.8534 .20378 L
.85323 .20596 L
.85289 .20799 L
.85185 .21175 L
.85015 .21579 L
.84825 .21924 L
.84576 .223 L
.84011 .2299 L
.82216 .24606 L
.79669 .26338 L
.7673 .27977 L
.72548 .29931 L
.68113 .31668 L
.63147 .3329 L
.57063 .34872 L
.53393 .35625 L
.49806 .36218 L
.46191 .36672 L
.44303 .36852 L
.4328 .36932 L
.42179 .37005 L
.40197 .371 L
.38327 .37146 L
.36283 .37146 L
.35104 .3712 L
.33989 .37078 L
.31974 .36956 L
.30112 .36786 L
.28062 .3653 L
.25908 .36174 L
.24112 .358 L
.22219 .35316 L
.18925 .34206 L
.17019 .33362 L
.15316 .32443 L
.12447 .30396 L
.11144 .29169 L
.09871 .27705 L
.08797 .2619 L
.07819 .24496 L
.06487 .21443 L
.05639 .18751 L
.05275 .17286 L
.04975 .15841 L
.04778 .14706 L
Mistroke
.04626 .13637 L
.04524 .12713 L
.04466 .11983 L
.04437 .11339 L
.04431 .10808 L
.04445 .1036 L
.04478 .09938 L
.04525 .09588 L
.04581 .09306 L
.04661 .09015 L
.04767 .08741 L
.04883 .08519 L
.05004 .0834 L
.05144 .08181 L
.05288 .08052 L
.05461 .07931 L
.05667 .07821 L
.05891 .07732 L
.06148 .07657 L
.06387 .07607 L
.06531 .07584 L
.0667 .07565 L
.06935 .0754 L
.07243 .07522 L
.07555 .07515 L
.07862 .07515 L
.08156 .07521 L
.08498 .07534 L
.08878 .07553 L
.09255 .07577 L
.11177 .0774 L
.1384 .08011 L
.33625 .09964 L
.50244 .1154 L
.59771 .12569 L
.6796 .13646 L
.7457 .14791 L
.77597 .1548 L
.79913 .16142 L
.81526 .16723 L
.82944 .17382 L
.83524 .17724 L
.84051 .18095 L
.84433 .18426 L
.84761 .18782 L
.85018 .19154 L
.85188 .19502 L
.85299 .19882 L
.85331 .20101 L
.85341 .20308 L
Mistroke
.8531 .20684 L
.85231 .21033 L
.85079 .21441 L
.84878 .21834 L
.84373 .22567 L
.83753 .23262 L
.81854 .2488 L
.79144 .26653 L
.75472 .28604 L
.71622 .30319 L
.66927 .32085 L
.62123 .33586 L
.56203 .35062 L
.53386 .35626 L
.50213 .36158 L
.47074 .36575 L
.44092 .3687 L
.42336 .36996 L
.40656 .37083 L
.38781 .37139 L
.36723 .3715 L
.34653 .37105 L
.33601 .37059 L
.32445 .3699 L
.30383 .36814 L
.28458 .36586 L
.26508 .36283 L
.24678 .35926 L
.21322 .3505 L
.19506 .3443 L
.17887 .33768 L
.14499 .31933 L
.13024 .3087 L
.1158 .29605 L
.09372 .27039 L
.08283 .25344 L
.0742 .23689 L
.06199 .20619 L
.05365 .17674 L
.04886 .15354 L
.04707 .14235 L
.04586 .13306 L
.04536 .12839 L
.04494 .12372 L
.04466 .11984 L
.04448 .11641 L
.04431 .1106 L
.04435 .10594 L
.04458 .10151 L
.04479 .09925 L
Mistroke
.04503 .09731 L
.04553 .09437 L
.04621 .09149 L
.04707 .08886 L
.04801 .08669 L
.0492 .08458 L
.05063 .08268 L
.05199 .08128 L
.05363 .07996 L
.05558 .07876 L
.05787 .0777 L
.06025 .0769 L
.0626 .07632 L
.06529 .07584 L
.06673 .07565 L
.06839 .07548 L
.07149 .07526 L
.0746 .07516 L
.0766 .07514 L
.07856 .07515 L
.08247 .07524 L
.08478 .07533 L
.087 .07544 L
.09235 .07576 L
.1132 .07754 L
.14234 .08052 L
.34948 .10086 L
.51952 .11713 L
.61433 .12768 L
.69358 .1386 L
.75263 .14936 L
.77969 .15577 L
.80042 .16184 L
.81892 .16876 L
.82695 .17252 L
.83421 .17658 L
.83953 .1802 L
.84433 .18426 L
.84777 .18802 L
.85022 .1916 L
.8519 .19508 L
.85301 .19894 L
.8534 .20264 L
.85321 .20612 L
.85251 .20961 L
.85146 .21281 L
.84977 .21654 L
.84772 .2201 L
.84159 .22824 L
.83419 .23588 L
Mistroke
.81179 .25361 L
.75049 .28806 L
.67214 .31986 L
.61785 .33681 L
.56213 .3506 L
.52868 .3572 L
.49014 .3633 L
.47174 .36563 L
.45169 .36775 L
.43417 .36922 L
.41442 .37046 L
.39574 .37121 L
.37807 .37151 L
.35839 .37138 L
.34725 .37108 L
.33707 .37064 L
.31633 .36929 L
.30457 .36822 L
.2937 .36702 L
.27373 .36427 L
.25268 .3605 L
.235 .35654 L
.21632 .35145 L
.18386 .33984 L
.16519 .33111 L
.14851 .32159 L
.12052 .30047 L
.10679 .28669 L
.09582 .27327 L
.08555 .25804 L
.07621 .24105 L
.06355 .21076 L
.05551 .18419 L
.0495 .15707 L
.04754 .14548 L
.04602 .13435 L
.04514 .12605 L
.0448 .12185 L
.04457 .11829 L
.04433 .11203 L
.04433 .10685 L
.04451 .10258 L
.04487 .09853 L
.04537 .09517 L
.04596 .09245 L
.04674 .08977 L
.04775 .08723 L
.04898 .08494 L
.05028 .08311 L
.05183 .08143 L
Mistroke
.05346 .08008 L
.05507 .07904 L
.05695 .07808 L
.0592 .07722 L
.0618 .07649 L
.06421 .07601 L
.06566 .07579 L
.06707 .07561 L
.06971 .07537 L
.0728 .07521 L
.07592 .07514 L
.07901 .07516 L
.08195 .07522 L
.08539 .07536 L
.0892 .07556 L
.09301 .07581 L
.1123 .07745 L
.13916 .08019 L
.3361 .09962 L
.50146 .1153 L
.59657 .12555 L
.67878 .13634 L
.74439 .14764 L
.77461 .15446 L
.79792 .16104 L
.81413 .16678 L
.8285 .17332 L
.8344 .1767 L
.83979 .1804 L
.84373 .18369 L
.84714 .18726 L
.84981 .19092 L
.85161 .19437 L
.8524 .19651 L
.85293 .19854 L
.85339 .20237 L
.85321 .2061 L
.85252 .20958 L
.85121 .21344 L
.84922 .21757 L
.84437 .22485 L
.83834 .23179 L
.81965 .24797 L
.79321 .26548 L
.75717 .28485 L
.71934 .3019 L
.67297 .31957 L
.62573 .33458 L
.56722 .34948 L
.53943 .35521 L
Mistroke
.50798 .36068 L
.47671 .36504 L
.44712 .36817 L
.4288 .3696 L
.41117 .37062 L
.39221 .3713 L
.38138 .37149 L
.3713 .37153 L
.3543 .37129 L
.3354 .37056 L
.31548 .36922 L
.29674 .36738 L
.27458 .3644 L
.25365 .36069 L
.21515 .3511 L
.19442 .34406 L
.17597 .33636 L
.15693 .32662 L
.13787 .31444 L
.12093 .30084 L
.10707 .28701 L
.09564 .27303 L
.08484 .25686 L
.07012 .22777 L
.05936 .19792 L
.05187 .16889 L
.04914 .15509 L
.04724 .14352 L
.04598 .13403 L
.04547 .12949 L
.04505 .125 L
.04455 .11786 L
.04433 .11207 L
.04433 .10696 L
.04454 .10208 L
.04493 .09807 L
.04544 .09479 L
.04609 .09193 L
.04679 .08963 L
.04773 .08728 L
.04873 .08534 L
.04998 .08348 L
.05145 .0818 L
.05284 .08055 L
.05451 .07937 L
.05648 .0783 L
.05879 .07736 L
.06119 .07665 L
.06355 .07613 L
.06592 .07575 L
Mistroke
.06863 .07546 L
.07109 .07528 L
.07399 .07517 L
.07731 .07514 L
.08116 .0752 L
.08506 .07534 L
.08888 .07554 L
.0965 .07606 L
.10588 .07685 L
.12864 .07909 L
.33365 .0994 L
.49286 .11444 L
.64438 .13151 L
.71025 .14133 L
.76707 .15262 L
.7907 .15883 L
.80916 .16488 L
.82543 .17176 L
.83277 .17571 L
.8385 .17944 L
.84296 .183 L
.84628 .18627 L
.84919 .18996 L
.85047 .19203 L
.85143 .19396 L
.85269 .1975 L
.85334 .20139 L
.85334 .20487 L
.85276 .20859 L
.85177 .21196 L
.85023 .21562 L
.84623 .22233 L
.83958 .23047 L
.83183 .23804 L
.81035 .25459 L
.78075 .27261 L
.71127 .30521 L
.66714 .32157 L
.61322 .3381 L
.57924 .34674 L
.54607 .35392 L
.50989 .36038 L
.47524 .36522 L
.45844 .36709 L
.43983 .36878 L
.42189 .37005 L
.40505 .37089 L
.38686 .37141 L
.36653 .3715 L
.35618 .37134 L
Mistroke
.34499 .37099 L
.32461 .36991 L
.3055 .36831 L
.28461 .36586 L
.26491 .3628 L
.24678 .35926 L
.2132 .3505 L
.19677 .34494 L
.17923 .33784 L
.16077 .32876 L
.14259 .31773 L
.11402 .29431 L
.10058 .2794 L
.0897 .26456 L
.07899 .24648 L
.07068 .2291 L
.05958 .19863 L
.05291 .17359 L
.04837 .15069 L
.04671 .13973 L
.04561 .13082 L
.04491 .12326 L
.0445 .11691 L
.04433 .11184 L
.04433 .10692 L
.04453 .10224 L
.04473 .09989 L
.04495 .0979 L
.04552 .09441 L
.0462 .09153 L
.04697 .08913 L
.04791 .0869 L
.04881 .08521 L
.04992 .08357 L
.05123 .08202 L
.0528 .08059 L
.05442 .07943 L
.05602 .07852 L
.05808 .07762 L
.06046 .07684 L
.06266 .0763 L
.06528 .07584 L
.06683 .07564 L
.06832 .07548 L
.07002 .07535 L
.07188 .07524 L
.07522 .07515 L
.07722 .07514 L
.07916 .07516 L
.08314 .07526 L
Mistroke
.08717 .07545 L
.09103 .07567 L
.09549 .07598 L
.11844 .07805 L
.28438 .09478 L
.43666 .10899 L
.53206 .11843 L
.62071 .12847 L
.69548 .1389 L
.72981 .1448 L
.76177 .15138 L
.78691 .15774 L
.80597 .16373 L
.82164 .16997 L
.83331 .17603 L
.84233 .18244 L
.8458 .18575 L
.84882 .18942 L
.85078 .19261 L
.85226 .19608 L
.8531 .19939 L
.8534 .20245 L
.85318 .20633 L
.85241 .20997 L
.85096 .21401 L
.84877 .21836 L
.84363 .22579 L
.83599 .23415 L
.81553 .25098 L
.78685 .26919 L
.71881 .30212 L
.62187 .33568 L
.59086 .34393 L
.55556 .35199 L
.52343 .35813 L
.48616 .36383 L
.449 .368 L
.4389 .36886 L
.42794 .36966 L
.41836 .37025 L
.40781 .37077 L
.38737 .3714 L
.36764 .37151 L
.34817 .37111 L
.32993 .37025 L
.30844 .36859 L
.28815 .36633 L
.26591 .36298 L
.24211 .35822 L
.21894 .35223 L
Mistroke
.19527 .34438 L
.17408 .33549 L
.15588 .32602 L
.12571 .305 L
.11131 .29155 L
.09927 .27777 L
.08163 .25133 L
.06758 .22157 L
.05715 .19031 L
.05035 .16156 L
.04695 .14149 L
.04573 .1319 L
.04497 .12401 L
.04452 .11726 L
.04438 .11384 L
.04432 .11096 L
.04436 .10587 L
.04457 .10166 L
.04477 .09948 L
.04503 .09735 L
.04562 .09391 L
.04602 .09219 L
.04644 .0907 L
.04755 .08768 L
.04868 .08544 L
.0499 .08359 L
.05111 .08215 L
.05256 .08078 L
.0543 .07951 L
.05633 .07837 L
.05823 .07757 L
.06049 .07683 L
.06272 .07629 L
.06524 .07585 L
.06755 .07556 L
.07024 .07533 L
.07336 .07519 L
.07521 .07515 L
.07695 .07514 L
.08053 .07518 L
.08413 .0753 L
.08774 .07548 L
.0918 .07572 L
.09974 .07632 L
.12131 .07834 L
.29575 .09586 L
.42379 .10778 L
.58122 .12378 L
.66222 .13395 L
.72685 .14426 L
Mistroke
.77641 .15492 L
.79849 .16122 L
.81502 .16714 L
.83026 .17427 L
.84065 .18107 L
.8448 .18472 L
.84836 .18879 L
.84978 .19087 L
.85103 .19311 L
.85197 .19525 L
.85261 .19721 L
.85332 .20112 L
.85334 .20478 L
.8527 .20885 L
.85212 .21092 L
.85129 .21323 L
.84946 .21712 L
.8469 .22136 L
.84077 .22916 L
.82112 .24686 L
.79597 .26382 L
.75816 .28436 L
.71675 .30297 L
.622 .33565 L
.55957 .35114 L
.52636 .35762 L
.49366 .36281 L
.462 .36671 L
.44366 .36847 L
.42658 .36975 L
.40752 .37079 L
.39658 .37118 L
.38636 .37142 L
.36739 .37151 L
.34694 .37107 L
.32728 .37009 L
.30591 .36835 L
.28566 .366 L
.2671 .36318 L
.24666 .35923 L
.22462 .35384 L
.20235 .34694 L
.18211 .3391 L
.16544 .33123 L
.14839 .32151 L
.12166 .3015 L
.10847 .28854 L
.09616 .27372 L
.07832 .24522 L
.06629 .21826 L
Mistroke
.05824 .19412 L
.05217 .17025 L
.04802 .14853 L
.04654 .13849 L
.04554 .13013 L
.04513 .12591 L
.04479 .12167 L
.04442 .11501 L
.04431 .10941 L
.04442 .10425 L
.04468 .10038 L
.04513 .09663 L
.04548 .09459 L
.04587 .0928 L
.04673 .0898 L
.04784 .08702 L
.04928 .08447 L
.05071 .08259 L
.05243 .08089 L
.05406 .07966 L
.05603 .07852 L
.05807 .07762 L
.06041 .07685 L
.06257 .07632 L
.06512 .07587 L
.06665 .07566 L
.06809 .07551 L
.06983 .07536 L
.07154 .07526 L
.07477 .07516 L
.07669 .07514 L
.07852 .07515 L
.08201 .07523 L
.08548 .07536 L
.08954 .07558 L
.0942 .07589 L
.11583 .07779 L
.28149 .09451 L
.43461 .1088 L
.53042 .11826 L
.61874 .12822 L
.69417 .1387 L
.75173 .14917 L
.77742 .15518 L
.8002 .16177 L
.81869 .16866 L
.82723 .17266 L
.83411 .17652 L
.83902 .17983 L
.84349 .18347 L
Mistroke
.84653 .18655 L
.84921 .18999 L
.85135 .19377 L
.85219 .19587 L
.85277 .19784 L
.85334 .20141 L
.8533 .20531 L
.85267 .20897 L
.85138 .21302 L
.84958 .21689 L
.84745 .22053 L
.84223 .2275 L
.83505 .23507 L
.81208 .25341 L
.78409 .27075 L
.74712 .28965 L
.69862 .31019 L
.653 .32626 L
.59774 .3422 L
.56429 .35013 L
.53193 .35662 L
.5002 .36186 L
.48272 .36428 L
.4634 .36657 L
.44456 .36839 L
.42691 .36973 L
.40972 .37069 L
.39129 .37132 L
.37145 .37153 L
.35273 .37125 L
.33193 .37037 L
.3202 .36959 L
.3095 .36869 L
.29023 .3666 L
.27246 .36407 L
.25304 .36057 L
.23272 .35597 L
.19953 .34594 L
.18149 .33883 L
.16534 .33118 L
.14798 .32125 L
.13054 .30894 L
.1166 .29682 L
.10335 .28275 L
.09189 .26779 L
.08293 .25362 L
.06908 .2253 L
.05811 .19369 L
.05407 .17847 L
.05081 .16383 L
Mistroke
.04864 .15228 L
.04688 .14101 L
.04574 .13194 L
.04501 .12453 L
.0447 .12032 L
.04447 .11621 L
.04434 .1124 L
.04431 .10857 L
.04437 .10554 L
.04451 .10255 L
.04472 .09995 L
.04497 .09776 L
.04529 .09567 L
.04563 .09387 L
.0461 .0919 L
.04658 .09025 L
.04761 .08754 L
.0489 .08506 L
.05064 .08268 L
.05247 .08086 L
.05474 .07923 L
.056 .07854 L
.05746 .07787 L
.06014 .07693 L
.06176 .0765 L
.06332 .07617 L
.06484 .07591 L
.06658 .07567 L
.0683 .07549 L
.06996 .07535 L
Mfstroke
.85271 .19761 m
.85332 .20115 L
.85337 .20441 L
.85284 .20823 L
.8518 .21188 L
.85038 .2153 L
.8487 .21849 L
.84362 .22581 L
.83682 .23333 L
.8275 .24178 L
.80324 .25929 L
.73395 .29563 L
.64562 .3286 L
.58518 .34532 L
.55248 .35263 L
.52036 .35866 L
.48731 .36368 L
.45595 .36733 L
.43743 .36897 L
.41962 .37018 L
.40044 .37106 L
.38948 .37136 L
.3793 .3715 L
.35928 .3714 L
.34793 .3711 L
.33752 .37067 L
.31715 .36935 L
.29773 .36749 L
.27511 .36448 L
.25427 .36081 L
.23167 .3557 L
.20821 .34891 L
.18809 .34159 L
.16741 .33224 L
.13353 .31125 L
.11647 .2967 L
.10081 .27969 L
.08931 .26397 L
.07882 .24617 L
.06491 .21456 L
.05612 .18652 L
.05056 .16259 L
.04732 .14406 L
.04619 .13574 L
.0453 .12776 L
.04493 .1236 L
.04468 .12006 L
.04438 .11376 L
.04431 .1081 L
.04438 .10522 L
Mistroke
.0445 .10275 L
.04486 .09866 L
.04543 .09487 L
.04613 .09176 L
.04692 .08925 L
.04793 .08684 L
.04916 .08464 L
.05038 .08298 L
.05162 .08163 L
.05312 .08033 L
.05488 .07915 L
.05658 .07825 L
.05859 .07743 L
.06064 .07679 L
.06268 .0763 L
.06463 .07594 L
.06691 .07563 L
.06945 .07539 L
.07199 .07524 L
.07508 .07515 L
.07861 .07515 L
.08218 .07523 L
.08563 .07537 L
.08998 .07561 L
.09503 .07595 L
.10523 .07679 L
.16543 .08295 L
.37705 .10342 L
.54645 .11995 L
.62822 .12941 L
.69521 .13886 L
.7541 .14968 L
.7806 .15601 L
.80169 .16226 L
.82018 .16931 L
.83341 .17609 L
.83888 .17972 L
.84385 .18381 L
.84788 .18816 L
.84944 .19033 L
.85062 .19232 L
.85216 .19578 L
.85312 .19953 L
.85341 .20306 L
.85317 .20643 L
.85228 .21041 L
.85091 .21413 L
.84882 .21827 L
.84596 .22271 L
.83902 .23108 L
Mistroke
.83067 .23907 L
.8056 .25776 L
.74771 .28937 L
.66362 .32276 L
.60782 .33956 L
.54953 .35323 L
.51303 .35987 L
.4781 .36487 L
.45796 .36713 L
.43561 .36911 L
.42514 .36985 L
.41396 .37048 L
.39362 .37126 L
.37401 .37153 L
.35588 .37133 L
.33468 .37052 L
.31442 .36913 L
.2956 .36725 L
.27818 .36495 L
.25912 .36175 L
.23906 .35752 L
.21931 .35233 L
.19859 .3456 L
.16328 .3301 L
.14455 .31904 L
.12655 .3057 L
.11267 .29295 L
.09938 .2779 L
.08816 .26221 L
.07935 .24717 L
.06591 .21726 L
.05746 .1914 L
.05147 .16702 L
.04928 .15589 L
.04748 .14512 L
.04632 .13679 L
.04539 .12867 L
.04498 .1242 L
.0447 .12035 L
.0445 .11692 L
.04437 .11352 L
.04431 .11041 L
.04432 .10768 L
.04448 .10307 L
.04477 .09947 L
.04523 .09597 L
.04588 .09277 L
.04661 .09015 L
.04742 .08797 L
.04825 .08621 L
Mistroke
.04926 .08449 L
.05045 .08289 L
.05189 .08138 L
.05334 .08017 L
.05505 .07905 L
.05711 .07802 L
.05904 .07727 L
.06129 .07662 L
.06358 .07612 L
.06582 .07577 L
.06871 .07545 L
.07164 .07526 L
.07445 .07516 L
.0777 .07514 L
.0815 .07521 L
.08352 .07528 L
.08582 .07538 L
.09443 .07591 L
.10361 .07665 L
.11478 .07769 L
.13901 .08017 L
.35173 .10107 L
.51601 .11677 L
.60491 .12654 L
.69024 .13808 L
.7515 .14912 L
.77988 .15582 L
.80206 .16239 L
.81859 .16862 L
.83073 .17453 L
.84087 .18124 L
.84477 .18469 L
.84817 .18853 L
.85065 .19236 L
.85222 .19595 L
.85277 .19785 L
.85318 .19995 L
.85339 .20216 L
.85338 .20425 L
.85287 .20813 L
.85186 .21172 L
.85109 .21372 L
.85008 .21592 L
.84781 .21995 L
.84213 .22761 L
.83414 .23593 L
.81512 .25128 L
.78334 .27117 L
.74604 .29015 L
.70695 .30694 L
Mistroke
.6577 .32473 L
.60705 .33976 L
.54625 .35389 L
.50965 .36042 L
.47444 .36531 L
.45685 .36725 L
.43729 .36899 L
.4184 .37025 L
.4006 .37105 L
.38413 .37145 L
.36613 .37149 L
.34893 .37113 L
.33301 .37043 L
.31521 .3692 L
.29566 .36725 L
.27522 .3645 L
.25629 .36121 L
.23625 .35684 L
.21767 .35185 L
.18423 .34 L
.16655 .3318 L
.15113 .32321 L
.13449 .31197 L
.12007 .30007 L
.1078 .28781 L
.09597 .27347 L
.07906 .24661 L
.07151 .23099 L
.0649 .21454 L
.05614 .18661 L
.05084 .16399 L
.04761 .14593 L
.04642 .13757 L
.04549 .12967 L
.04481 .122 L
.04445 .11581 L
.04431 .10987 L
.04438 .10513 L
.0445 .10276 L
.04468 .10036 L
.04516 .09644 L
.04577 .09324 L
.04657 .09027 L
.04739 .08805 L
.04842 .0859 L
.0498 .08372 L
.05123 .08202 L
.05309 .08036 L
.05505 .07905 L
.05705 .07804 L
Mistroke
.05906 .07727 L
.06146 .07658 L
.06286 .07626 L
.06424 .07601 L
.0669 .07563 L
.0684 .07548 L
.07007 .07535 L
.07189 .07524 L
.07369 .07518 L
.07727 .07514 L
.08086 .07519 L
.08441 .07531 L
.08857 .07552 L
.09331 .07583 L
.11609 .07782 L
.14989 .08132 L
.36885 .10266 L
.52285 .11747 L
.60785 .12689 L
.68006 .13653 L
.74596 .14796 L
.77446 .15442 L
.79977 .16163 L
.81837 .16852 L
.83203 .17528 L
.84125 .18154 L
.84524 .18516 L
.84818 .18855 L
.85056 .19219 L
.85213 .1957 L
.853 .19889 L
.8534 .20242 L
.85318 .20629 L
.85279 .20848 L
.85226 .21047 L
.8508 .2144 L
.8489 .21814 L
.84385 .22551 L
.83772 .23242 L
.81904 .24842 L
.79373 .26517 L
.75922 .28383 L
.71629 .30316 L
.66898 .32095 L
.61769 .33686 L
.55481 .35215 L
.52463 .35792 L
.49094 .36319 L
.46084 .36684 L
.44318 .36851 L
Mistroke
.42628 .36977 L
.40671 .37082 L
.39545 .37121 L
.38489 .37144 L
.36531 .37149 L
.35424 .37129 L
.34412 .37096 L
.32485 .36992 L
.30383 .36814 L
.28391 .36577 L
.2656 .36292 L
.24452 .35876 L
.2251 .35397 L
.20257 .34701 L
.18277 .33938 L
.14551 .31967 L
.12734 .30636 L
.11195 .29221 L
.10088 .27977 L
.09036 .26555 L
.07496 .23849 L
.06204 .20633 L
.05425 .17923 L
.04935 .15626 L
.04619 .1358 L
.04525 .12723 L
.04489 .12298 L
.04463 .11925 L
.04446 .11599 L
.04435 .1127 L
.04432 .1075 L
.04447 .10315 L
.04476 .09954 L
.04523 .09603 L
.04589 .09272 L
.04676 .08972 L
.04774 .08725 L
.04875 .08531 L
.04999 .08347 L
.05131 .08194 L
.05261 .08074 L
.05414 .07961 L
.05594 .07856 L
.05776 .07774 L
.05956 .07711 L
.0614 .07659 L
.06347 .07614 L
.06603 .07574 L
.06756 .07556 L
.06904 .07542 L
Mistroke
.07189 .07524 L
.07514 .07515 L
.07824 .07515 L
.08133 .07521 L
.08494 .07534 L
.08908 .07555 L
.09877 .07624 L
.11054 .07728 L
.13632 .07989 L
.31174 .09736 L
.45835 .11107 L
.54663 .11997 L
.6272 .12928 L
.69476 .13879 L
.75553 .14999 L
.77764 .15523 L
.79776 .16099 L
.81235 .16608 L
.82553 .17181 L
.83214 .17534 L
.8374 .17867 L
.84201 .18218 L
.84547 .1854 L
.84807 .18841 L
.85028 .1917 L
.85195 .19522 L
.85294 .19858 L
.85339 .2023 L
.85337 .20443 L
.85317 .20643 L
.85225 .21051 L
.85145 .21282 L
.85055 .21494 L
.84577 .22298 L
.83933 .23074 L
.82199 .24619 L
.80077 .26086 L
.73599 .29473 L
.69625 .3111 L
.64749 .32801 L
.60017 .34157 L
.5428 .35456 L
.50508 .36113 L
.4859 .36387 L
.46805 .36605 L
.45041 .36787 L
.4309 .36946 L
.41997 .37016 L
.4098 .37068 L
.38952 .37136 L
Mistroke
.37096 .37152 L
.3534 .37127 L
.3339 .37048 L
.31281 .36899 L
.30217 .36797 L
.29058 .36664 L
.26951 .36359 L
.24912 .35976 L
.23048 .3554 L
.21193 .3501 L
.19294 .3435 L
.16095 .32885 L
.14452 .31902 L
.13033 .30878 L
.11526 .29553 L
.10261 .28187 L
.08374 .255 L
.07081 .22939 L
.06075 .20237 L
.0534 .17566 L
.04867 .15246 L
.04692 .14126 L
.04575 .13202 L
.04528 .12751 L
.04493 .12351 L
.04449 .11671 L
.04436 .11329 L
.04431 .11033 L
.04432 .10732 L
.04441 .10436 L
.04472 .09991 L
.04498 .09767 L
.04527 .09576 L
.04592 .09258 L
.04678 .08966 L
.04768 .08737 L
.04865 .08549 L
.04983 .08368 L
.05125 .082 L
.05277 .08061 L
.05462 .07931 L
.05675 .07818 L
.05894 .07731 L
.06116 .07665 L
.06335 .07617 L
.06593 .07575 L
.06887 .07544 L
.07053 .07532 L
.0721 .07524 L
.07399 .07517 L
Mistroke
.07584 .07514 L
.07932 .07516 L
.08139 .07521 L
.08337 .07527 L
.08778 .07548 L
.09302 .07581 L
.10496 .07677 L
.25743 .09221 L
.40884 .10638 L
.57981 .12362 L
.65038 .13231 L
.71634 .14237 L
.7459 .14795 L
.77429 .15438 L
.79464 .16002 L
.81321 .16641 L
.82759 .17285 L
.8336 .17621 L
.83908 .17987 L
.84337 .18336 L
.84657 .18659 L
.84914 .18988 L
.85099 .19303 L
.85248 .19676 L
.85296 .19866 L
.85329 .20077 L
.85336 .20454 L
.85287 .20812 L
.85231 .2103 L
.85162 .21239 L
.84987 .21634 L
.84737 .22065 L
.84393 .22542 L
.82817 .24122 L
.80423 .25865 L
.74461 .29081 L
.65237 .32646 L
.5886 .34449 L
.55512 .35208 L
.522 .35838 L
.48881 .36348 L
.45714 .36722 L
.43848 .36889 L
.42043 .37013 L
.401 .37104 L
.38986 .37135 L
.37946 .3715 L
.35993 .37141 L
.34138 .37085 L
.32081 .36964 L
Mistroke
.30918 .36866 L
.29849 .36757 L
.27817 .36495 L
.25602 .36116 L
.23317 .35608 L
.21234 .35023 L
.19276 .34343 L
.17289 .33492 L
.14023 .31611 L
.12411 .30364 L
.11054 .29074 L
.09664 .27437 L
.08542 .25782 L
.0698 .22702 L
.05987 .19958 L
.05275 .17288 L
.04998 .15966 L
.04801 .14849 L
.04666 .13941 L
.0456 .13068 L
.04494 .12365 L
.04455 .11788 L
.04434 .11229 L
.04433 .1069 L
.04455 .10201 L
.04494 .09803 L
.04546 .09473 L
.04608 .09197 L
.04674 .08977 L
.04757 .08763 L
.0486 .08558 L
.04983 .08368 L
.051 .08227 L
.05242 .0809 L
.05414 .07961 L
.05589 .07859 L
.05799 .07766 L
.06043 .07685 L
.06298 .07624 L
.06557 .0758 L
.06808 .07551 L
.07098 .07529 L
.07383 .07518 L
.07718 .07514 L
.08093 .07519 L
.08469 .07533 L
.08844 .07551 L
.09207 .07574 L
.10101 .07643 L
.25524 .092 L
Mistroke
.39298 .1049 L
.56957 .12247 L
.63955 .13087 L
.70671 .14073 L
.73993 .14675 L
.76663 .15251 L
.78849 .15819 L
.80811 .16449 L
.82339 .17078 L
.83436 .17668 L
.8387 .17959 L
.84273 .18279 L
.84589 .18584 L
.84832 .18873 L
.85053 .19214 L
.85222 .19595 L
.85315 .19971 L
.85337 .20185 L
.85339 .20382 L
.85302 .20735 L
.85201 .21126 L
.85052 .215 L
.84869 .21851 L
.84275 .22687 L
.8352 .23492 L
.8164 .25036 L
.75447 .28616 L
.67059 .32039 L
.61932 .33641 L
.55576 .35195 L
.52534 .3578 L
.49512 .3626 L
.47784 .3649 L
.45858 .36707 L
.4422 .36859 L
.42376 .36993 L
.40611 .37084 L
.38927 .37136 L
.37122 .37153 L
.35151 .37121 L
.33395 .37048 L
.31532 .3692 L
.29933 .36767 L
.28183 .36548 L
.26022 .36196 L
.24049 .35785 L
.21961 .35242 L
.19729 .34513 L
.16198 .32941 L
.1443 .31887 L
Mistroke
.12905 .30775 L
.11552 .29578 L
.10397 .28348 L
.08579 .25842 L
.07106 .22996 L
.05989 .19964 L
.05267 .1725 L
.04785 .14751 L
.04635 .13703 L
.04575 .13206 L
.04525 .12718 L
.0449 .12321 L
.04462 .11915 L
.04435 .11275 L
.04433 .10709 L
.04451 .10258 L
.04468 .10033 L
.04493 .09806 L
.04553 .09437 L
.04625 .09136 L
.04717 .08858 L
.0481 .08651 L
.04925 .08451 L
.05062 .08269 L
.05204 .08123 L
.05376 .07987 L
.05579 .07864 L
.05791 .07768 L
.0601 .07694 L
.06221 .0764 L
.06467 .07593 L
.0671 .07561 L
.06995 .07535 L
.07316 .0752 L
.07637 .07514 L
.07959 .07517 L
.0827 .07525 L
.08652 .07541 L
.09038 .07563 L
.09999 .07634 L
.11174 .0774 L
.13754 .08002 L
.22512 .08905 L
.34459 .10041 L
.50666 .11582 L
.64709 .13187 L
.71524 .14218 L
.76691 .15258 L
.79017 .15868 L
.80856 .16466 L
Mistroke
.82217 .17021 L
.83394 .17642 L
.84342 .18341 L
.84695 .18703 L
.84861 .18914 L
.84991 .19108 L
.8517 .19458 L
.8529 .1984 L
.85338 .20199 L
.85329 .20545 L
.85253 .20953 L
.85127 .21328 L
.85035 .21538 L
.84917 .21766 L
.84658 .22183 L
.83997 .23005 L
.83216 .23775 L
.80834 .25595 L
.77513 .27567 L
.7008 .30935 L
.64943 .3274 L
.59633 .34256 L
.54121 .35487 L
.50761 .36074 L
.47498 .36525 L
.44527 .36833 L
.42787 .36967 L
.41125 .37062 L
.39347 .37127 L
.37693 .37152 L
.35853 .37138 L
.33894 .37073 L
.31881 .36949 L
.30741 .3685 L
.29688 .36739 L
.27752 .36485 L
.25711 .36137 L
.22228 .35318 L
.20308 .34719 L
.18571 .34061 L
.16662 .33184 L
.14958 .32225 L
.12102 .30093 L
.10726 .28721 L
.09601 .27353 L
.08541 .2578 L
.07583 .24028 L
.06453 .2135 L
.05699 .18971 L
.05097 .16461 L
Mistroke
.04751 .14529 L
.04639 .13736 L
.0455 .12972 L
.04483 .12229 L
.04447 .11617 L
.04431 .11011 L
.04438 .10511 L
.04461 .10115 L
.04502 .09736 L
.04561 .09397 L
.04628 .09124 L
.04721 .08849 L
.04825 .08622 L
.04933 .08439 L
.05045 .0829 L
.05178 .08147 L
.05338 .08014 L
.0553 .0789 L
.0573 .07793 L
.05941 .07715 L
.06151 .07656 L
.06397 .07605 L
.06545 .07582 L
.06688 .07563 L
.06844 .07547 L
.06997 .07535 L
.0718 .07525 L
.07354 .07518 L
.07681 .07514 L
.07878 .07515 L
.08069 .07519 L
.08475 .07533 L
.08717 .07545 L
.08947 .07558 L
.10891 .07713 L
.17641 .0841 L
.43175 .10853 L
.59856 .12579 L
.67111 .13521 L
.72889 .14463 L
.77764 .15524 L
.79822 .16113 L
.81618 .16761 L
.8287 .17343 L
.83792 .17903 L
.84543 .18536 L
.84852 .189 L
.85065 .19237 L
.85222 .19596 L
.85317 .19983 L
Mistroke
.8534 .20354 L
.85309 .20694 L
.85209 .21101 L
.85125 .21333 L
.8503 .21547 L
.84524 .2237 L
.83905 .23104 L
.83049 .23923 L
.808 .25618 L
.74094 .2925 L
.65743 .32482 L
.60179 .34115 L
.56964 .34894 L
.53336 .35635 L
.49981 .36192 L
.4813 .36447 L
.46085 .36684 L
.44162 .36864 L
.42364 .36994 L
.40521 .37088 L
.38737 .3714 L
.36781 .37151 L
.35666 .37135 L
.34633 .37104 L
.32717 .37008 L
.30676 .36843 L
.28839 .36636 L
.27123 .36387 L
.23264 .35595 L
.21175 .35004 L
.19253 .34334 L
.1587 .32762 L
.14142 .31693 L
.12669 .30583 L
.11218 .29245 L
.09843 .2767 L
.08127 .25069 L
.06912 .22539 L
.05888 .19632 L
.05262 .17228 L
.04859 .15197 L
.04594 .13374 L
.04514 .12602 L
.0446 .11875 L
.04435 .11274 L
.04432 .1079 L
.04446 .10334 L
.04476 .09956 L
.04525 .09591 L
.04595 .09249 L
Mistroke
.04636 .09096 L
.04687 .08941 L
.04791 .08689 L
.04909 .08476 L
.05032 .08305 L
.05171 .08154 L
.05316 .0803 L
.05621 .07843 L
.05813 .0776 L
.06003 .07696 L
.06228 .07639 L
.06484 .07591 L
.06768 .07555 L
.07046 .07532 L
.07208 .07524 L
.07391 .07517 L
.07744 .07514 L
.08098 .0752 L
.08501 .07534 L
.08869 .07553 L
.09301 .07581 L
.11729 .07794 L
.14766 .08108 L
.33927 .09992 L
.50689 .11584 L
.59204 .12502 L
.66387 .13418 L
.73055 .14494 L
.78038 .15595 L
.80198 .16236 L
.81827 .16848 L
.83233 .17545 L
.83796 .17906 L
.84308 .1831 L
.84702 .18711 L
.84985 .19098 L
.85167 .19451 L
.8529 .1984 L
.85325 .20044 L
.8534 .2027 L
.85332 .20509 L
.85302 .20735 L
.85196 .21143 L
.85108 .21375 L
.85009 .2159 L
.84536 .22354 L
.83803 .2321 L
.81704 .2499 L
.78827 .26837 L
.75459 .2861 L
Mistroke
.67517 .3188 L
.62122 .33587 L
.5651 .34995 L
.53049 .35688 L
.49622 .36244 L
.45856 .36707 L
.43782 .36894 L
.42611 .36978 L
.41494 .37043 L
.40516 .37088 L
.39448 .37124 L
.3756 .37152 L
.36475 .37148 L
.35319 .37126 L
.33231 .37039 L
.31279 .36899 L
.29448 .36711 L
.27437 .36437 L
.25292 .36054 L
.23008 .3553 L
.20585 .34813 L
.18383 .33983 L
.16447 .33073 L
.13138 .3096 L
.11677 .29699 L
.10249 .28173 L
.09142 .26711 L
.08145 .25101 L
.06759 .22162 L
.05745 .19139 L
.05055 .16256 L
.04703 .14208 L
.04579 .13244 L
.04503 .12474 L
.04458 .11836 L
.04434 .11227 L
.04433 .10721 L
.04448 .10308 L
.04483 .0989 L
.04533 .09542 L
.0459 .09266 L
.04666 .09 L
.04764 .08748 L
.04884 .08516 L
.05014 .08328 L
.05145 .0818 L
.05282 .08057 L
.05439 .07945 L
.05627 .0784 L
.05816 .07759 L
Mistroke
.06005 .07696 L
.06194 .07646 L
.06415 .07602 L
.06669 .07566 L
.0682 .0755 L
.06988 .07536 L
.07307 .0752 L
.07494 .07515 L
.07677 .07514 L
.07885 .07515 L
.0812 .0752 L
.08328 .07527 L
.08565 .07537 L
.09023 .07562 L
.09978 .07632 L
.15239 .08158 L
.18081 .08456 L
Mfstroke
.85272 .20879 m
.85158 .21248 L
.8501 .21587 L
.8453 .22362 L
.83913 .23095 L
.83187 .23801 L
.81093 .2542 L
.78146 .27222 L
.74627 .29005 L
.70227 .30878 L
.60576 .34011 L
.54571 .35399 L
.509 .36052 L
.47352 .36542 L
.45702 .36723 L
.43904 .36885 L
.42852 .36962 L
.41888 .37022 L
.39977 .37108 L
.38157 .37148 L
.36157 .37144 L
.34243 .37089 L
.32464 .36991 L
.3038 .36814 L
.29208 .36683 L
.28139 .36541 L
.2412 .35802 L
.2192 .3523 L
.19596 .34464 L
.1566 .32643 L
.13893 .3152 L
.12124 .30112 L
.105 .28466 L
.09193 .26785 L
.07373 .23589 L
.0661 .21776 L
.06052 .20164 L
.05312 .17446 L
.04883 .15335 L
.0472 .14325 L
.04592 .13353 L
.04509 .12546 L
.04461 .11889 L
.04437 .11349 L
.04431 .10897 L
.0444 .10455 L
.04468 .10035 L
.04515 .0965 L
.04575 .09331 L
.04642 .09078 L
Mistroke
.04727 .08834 L
.04848 .08579 L
.04979 .08374 L
.05111 .08215 L
.05269 .08068 L
.05461 .07931 L
.05685 .07813 L
.05896 .0773 L
.06147 .07657 L
.06405 .07604 L
.06657 .07567 L
.06805 .07551 L
.06972 .07537 L
.07294 .0752 L
.07618 .07514 L
.07987 .07517 L
.08323 .07527 L
.08719 .07545 L
.09146 .0757 L
.0957 .076 L
.10634 .07689 L
.13278 .07952 L
.2016 .08669 L
.32649 .09873 L
.48577 .11374 L
.64677 .13183 L
.72323 .1436 L
.75375 .1496 L
.77847 .15545 L
.8127 .16622 L
.82633 .1722 L
.83765 .17884 L
.84211 .18226 L
.84607 .18604 L
.84899 .18967 L
.85102 .19308 L
.8523 .19618 L
.85314 .19966 L
.8534 .20334 L
.8531 .20684 L
.85226 .21049 L
.85077 .21445 L
.84885 .21823 L
.84667 .2217 L
.83969 .23036 L
.83107 .23872 L
.80858 .25579 L
.77677 .27478 L
.70199 .30889 L
.61263 .33826 L
Mistroke
.55745 .35159 L
.5245 .35794 L
.49151 .36311 L
.45948 .36698 L
.44076 .36871 L
.423 .36998 L
.40627 .37084 L
.39087 .37133 L
.37283 .37153 L
.35561 .37132 L
.33634 .37061 L
.315 .36918 L
.30418 .36818 L
.29257 .36689 L
.27163 .36393 L
.25087 .36012 L
.23144 .35564 L
.19614 .3447 L
.17695 .33681 L
.15765 .32703 L
.12655 .30571 L
.1116 .29185 L
.09922 .27771 L
.08745 .26109 L
.07699 .24262 L
.06425 .21274 L
.05615 .18664 L
.04999 .15967 L
.0467 .13967 L
.04558 .13054 L
.0449 .12313 L
.04465 .11961 L
.04446 .116 L
.04434 .1125 L
.04431 .10946 L
.04441 .10443 L
.04468 .10039 L
.04489 .09837 L
.04518 .09632 L
.04583 .09296 L
.04664 .09006 L
.04755 .08768 L
.04848 .08579 L
.0496 .08399 L
.05098 .08229 L
.0526 .08075 L
.05412 .07962 L
.05594 .07856 L
.0578 .07773 L
.05962 .07709 L
Mistroke
.06189 .07647 L
.06419 .07601 L
.06648 .07568 L
.06872 .07545 L
.07133 .07527 L
.07429 .07517 L
.0776 .07514 L
.08148 .07521 L
.08542 .07536 L
.08932 .07557 L
.09741 .07613 L
.10715 .07697 L
.16686 .0831 L
.37658 .10337 L
.54568 .11987 L
.63337 .13007 L
.71433 .14202 L
.77075 .1535 L
.79601 .16044 L
.81515 .16719 L
.82907 .17363 L
.83884 .17969 L
.8431 .18312 L
.84686 .18692 L
.84959 .19057 L
.85145 .19399 L
.85268 .19748 L
.85333 .20121 L
.85337 .20444 L
.85289 .20801 L
.85179 .21193 L
.85091 .21414 L
.84996 .21616 L
.84507 .22393 L
.83882 .23128 L
.83029 .2394 L
.81049 .2545 L
.78035 .27283 L
.74102 .29246 L
.69743 .31065 L
.65182 .32664 L
.6029 .34086 L
.54338 .35445 L
.50795 .36068 L
.4733 .36545 L
.45562 .36737 L
.43861 .36888 L
.42904 .36959 L
.41859 .37024 L
.40008 .37107 L
Mistroke
.38225 .37148 L
.36538 .37149 L
.34663 .37105 L
.32634 .37002 L
.30486 .36825 L
.28447 .36584 L
.26618 .36302 L
.24644 .35919 L
.21131 .34991 L
.1942 .34398 L
.17602 .33639 L
.1462 .32011 L
.1216 .30145 L
.1091 .28922 L
.09726 .27518 L
.07982 .24804 L
.07147 .23091 L
.06504 .2149 L
.05614 .18661 L
.05016 .16059 L
.04686 .14087 L
.04576 .13214 L
.04494 .12371 L
.04467 .11989 L
.04446 .11608 L
.04435 .11275 L
.04431 .10991 L
.04438 .10528 L
.04463 .10094 L
.04498 .09766 L
.04551 .09445 L
.04623 .09142 L
.04717 .08859 L
.04822 .08627 L
.04931 .08442 L
.05164 .08161 L
.05315 .08031 L
.05468 .07927 L
.05641 .07834 L
.05817 .07759 L
.06036 .07687 L
.06252 .07633 L
.06485 .07591 L
.06755 .07556 L
.07028 .07533 L
.07295 .0752 L
.07628 .07514 L
.07828 .07515 L
.0802 .07518 L
.08391 .07529 L
Mistroke
.08815 .0755 L
.0929 .0758 L
.09845 .07621 L
.10969 .0772 L
.13538 .07979 L
.31099 .09729 L
.47006 .1122 L
.62917 .12953 L
.69949 .13955 L
.76122 .15125 L
.78915 .15838 L
.81066 .16544 L
.82597 .17202 L
.83303 .17587 L
.83851 .17946 L
.84604 .18601 L
.8489 .18953 L
.85112 .19329 L
.85244 .19663 L
.85316 .19977 L
.85341 .20326 L
.85307 .20704 L
.85261 .20921 L
.85202 .21123 L
.85012 .21584 L
.84781 .21995 L
.84475 .22436 L
.82861 .24085 L
.80413 .25872 L
.77484 .27582 L
.73634 .29457 L
.68666 .31468 L
.63239 .33263 L
.57531 .34765 L
.51442 .35965 L
.47766 .36492 L
.46085 .36684 L
.44272 .36855 L
.42571 .36981 L
.40669 .37082 L
.38909 .37137 L
.37243 .37153 L
.35247 .37124 L
.33407 .37049 L
.31264 .36898 L
.29227 .36685 L
.27449 .36439 L
.25571 .3611 L
.22253 .35325 L
.2046 .34771 L
Mistroke
.18828 .34167 L
.15351 .32463 L
.13751 .31419 L
.1219 .30171 L
.09796 .27609 L
.08605 .25885 L
.07668 .242 L
.06345 .21047 L
.05506 .18245 L
.05005 .15999 L
.04669 .13959 L
.04563 .13096 L
.04521 .12683 L
.04486 .12264 L
.04446 .11609 L
.04431 .11062 L
.04436 .10591 L
.04454 .10204 L
.0449 .09833 L
.04546 .09473 L
.04622 .09147 L
.04709 .0888 L
.04798 .08674 L
.04905 .08482 L
.05128 .08197 L
.0527 .08066 L
.05414 .07961 L
.05586 .07861 L
.05786 .07771 L
.05999 .07697 L
.06254 .07633 L
.0639 .07606 L
.06543 .07582 L
.06681 .07564 L
.06838 .07548 L
.07154 .07526 L
.07478 .07516 L
.07816 .07515 L
.08151 .07521 L
.08369 .07528 L
.08615 .07539 L
.09087 .07566 L
.10069 .0764 L
.12829 .07906 L
.3175 .09789 L
.47822 .11299 L
.63675 .13051 L
.70603 .14062 L
.76627 .15243 L
.79332 .15961 L
Mistroke
.81398 .16672 L
.82856 .17335 L
.83522 .17722 L
.84035 .18083 L
.84402 .18396 L
.84729 .18744 L
.84985 .19098 L
.85178 .19478 L
.85285 .19818 L
.85337 .20186 L
.85329 .20538 L
.85276 .20861 L
.85221 .21064 L
.85146 .2128 L
.84968 .21671 L
.84716 .22096 L
.8437 .22571 L
.82653 .24259 L
.80094 .26075 L
.76551 .28068 L
.7252 .29943 L
.68179 .31645 L
.62765 .33402 L
.57228 .34835 L
.54014 .35508 L
.50339 .36139 L
.48225 .36434 L
.46227 .36669 L
.44283 .36854 L
.43195 .36938 L
.42153 .37007 L
.40221 .371 L
.38432 .37145 L
.36729 .3715 L
.34856 .37112 L
.3277 .37011 L
.3171 .36935 L
.30539 .3683 L
.28464 .36586 L
.26522 .36286 L
.24364 .35857 L
.22343 .35351 L
.1869 .34111 L
.1677 .33239 L
.15089 .32306 L
.1337 .31138 L
.11729 .29748 L
.10447 .28405 L
.09219 .26822 L
.07504 .23865 L
Mistroke
.06766 .22177 L
.06132 .20413 L
.05322 .17493 L
.05053 .16245 L
.0483 .15023 L
.04683 .14062 L
.04569 .13154 L
.04499 .12433 L
.04452 .11731 L
.04433 .11169 L
.04433 .10701 L
.04449 .10292 L
.04482 .09897 L
.04534 .09534 L
.04597 .09238 L
.04669 .08992 L
.04744 .08793 L
.04842 .08589 L
.04947 .08419 L
.05073 .08257 L
.05221 .08108 L
.0536 .07998 L
.05526 .07893 L
.0572 .07798 L
.05947 .07713 L
.06181 .07649 L
.06411 .07603 L
.06687 .07563 L
.06968 .07537 L
.07237 .07522 L
.07548 .07515 L
.07913 .07516 L
.08107 .0752 L
.08328 .07527 L
.08742 .07546 L
.09154 .07571 L
.10963 .0772 L
.13439 .07969 L
.34076 .10006 L
.50383 .11554 L
.59347 .12519 L
.68045 .13659 L
.74379 .14752 L
.7734 .15416 L
.7967 .16065 L
.81321 .16642 L
.82728 .17269 L
.83335 .17606 L
.839 .17981 L
.84303 .18306 L
Mistroke
.84653 .18655 L
.84946 .19037 L
.85142 .19394 L
.85277 .19784 L
.8532 .20008 L
.85339 .20219 L
.85322 .20606 L
.8525 .20963 L
.85189 .21163 L
.85105 .21381 L
.84907 .21783 L
.8439 .22545 L
.83641 .23374 L
.81821 .24904 L
.79062 .26701 L
.75855 .28416 L
.71715 .30281 L
.66404 .32262 L
.61396 .33789 L
.55385 .35235 L
.5176 .35912 L
.48275 .36428 L
.46532 .36636 L
.44595 .36827 L
.42723 .36971 L
.40961 .37069 L
.39321 .37127 L
.37531 .37153 L
.35817 .37138 L
.34232 .37089 L
.32364 .36984 L
.3031 .36807 L
.28364 .36573 L
.26561 .36292 L
.24541 .35896 L
.22665 .35439 L
.19271 .34341 L
.17461 .33574 L
.15877 .32765 L
.14154 .31702 L
.12653 .30569 L
.11356 .29385 L
.10097 .27989 L
.08281 .25341 L
.07462 .23778 L
.06742 .22117 L
.0578 .19262 L
.05192 .16913 L
.0483 .15023 L
.04587 .13311 L
Mistroke
.04505 .12502 L
.04458 .11848 L
.04435 .1126 L
.04433 .10709 L
.04451 .10254 L
.04483 .09889 L
.04538 .09512 L
.04577 .09321 L
.04618 .09159 L
.04705 .0889 L
.04813 .08644 L
.04933 .0844 L
.05078 .08251 L
.05231 .08099 L
.05385 .0798 L
.05583 .07862 L
.05822 .07757 L
.06069 .07677 L
.06319 .0762 L
.06589 .07576 L
.06733 .07558 L
.06897 .07543 L
.07205 .07524 L
.07513 .07515 L
.0771 .07514 L
.07904 .07516 L
.08289 .07525 L
.08516 .07535 L
.08734 .07545 L
.09258 .07578 L
.11293 .07751 L
.1411 .08039 L
.3264 .09872 L
.47348 .11253 L
.56069 .12149 L
.63986 .13091 L
.70496 .14044 L
.735 .14579 L
.7633 .15173 L
.78586 .15745 L
.80332 .16281 L
.81809 .16841 L
.82938 .1738 L
.83944 .18013 L
.8436 .18357 L
.8472 .18732 L
.84868 .18923 L
.85005 .19132 L
.85193 .19517 L
.85302 .19897 L
Mistroke
.8534 .20255 L
.85323 .2059 L
.85264 .20909 L
.85152 .21264 L
.84979 .2165 L
.84754 .22038 L
.84464 .22451 L
.83812 .23201 L
.81757 .24951 L
.79186 .26628 L
.7572 .28483 L
.71205 .30489 L
.66094 .32366 L
.60706 .33976 L
.54926 .35328 L
.5177 .3591 L
.4811 .36449 L
.46348 .36656 L
.44637 .36823 L
.43051 .36949 L
.4133 .37052 L
.39432 .37124 L
.37642 .37152 L
.36532 .37149 L
.3548 .3713 L
.33495 .37054 L
.31717 .36936 L
.2983 .36755 L
.28216 .36552 L
.26449 .36273 L
.24557 .359 L
.22559 .3541 L
.19078 .34266 L
.17287 .33492 L
.15419 .32504 L
.13728 .31402 L
.1207 .30064 L
.10693 .28685 L
.0958 .27324 L
.07807 .24473 L
.07031 .22822 L
.06437 .21307 L
.05469 .18099 L
.04904 .15455 L
.04704 .14213 L
.04578 .13228 L
.04501 .12449 L
.04473 .12092 L
.04452 .11725 L
.04432 .11139 L
Mistroke
.04434 .10657 L
.04443 .10392 L
.04458 .10159 L
.04499 .09764 L
.04529 .09565 L
.04561 .09394 L
.04651 .09048 L
.04737 .08809 L
.0483 .08611 L
.04945 .08421 L
.05085 .08243 L
.0524 .08092 L
.05421 .07957 L
.0559 .07859 L
.05791 .07769 L
.06019 .07691 L
.06248 .07634 L
.0652 .07585 L
.06665 .07566 L
.06833 .07548 L
.0713 .07527 L
.07306 .0752 L
.07474 .07516 L
.07817 .07515 L
.08166 .07521 L
.08521 .07535 L
.08925 .07556 L
.09721 .07612 L
.11908 .07812 L
.30486 .09671 L
.46197 .11141 L
.55295 .12065 L
.64472 .13155 L
.71479 .1421 L
.74649 .14807 L
.77581 .15476 L
.79839 .16119 L
.81534 .16727 L
.82901 .17359 L
.83896 .17978 L
.84292 .18296 L
.84643 .18644 L
.84907 .18978 L
.85091 .19288 L
.85235 .19636 L
.85322 .20023 L
.85339 .2022 L
.85337 .20432 L
.85285 .20819 L
.8523 .21035 L
Mistroke
.85163 .21235 L
.84957 .21691 L
.84714 .22099 L
.84397 .22537 L
.8276 .2417 L
.80621 .25736 L
.78128 .27232 L
.70789 .30656 L
.66105 .32362 L
.60282 .34088 L
.57359 .34805 L
.54063 .35498 L
.50801 .36067 L
.47655 .36506 L
.46013 .36691 L
.44172 .36863 L
.42281 .36999 L
.41232 .37057 L
.40244 .37099 L
.38392 .37145 L
.3668 .3715 L
.34678 .37106 L
.32762 .37011 L
.31028 .36877 L
.29181 .36679 L
.27603 .36462 L
.25869 .36167 L
.24025 .35779 L
.2207 .35274 L
.18666 .34101 L
.16837 .33272 L
.15266 .32413 L
.13685 .31371 L
.12119 .30108 L
.10815 .28819 L
.09747 .27545 L
.08014 .24863 L
.06647 .21873 L
.05643 .18767 L
.04999 .15968 L
.04655 .13855 L
.0455 .1297 L
.04509 .12547 L
.04476 .12128 L
.04455 .11789 L
.0444 .11439 L
.04431 .10882 L
.04442 .10409 L
.04475 .09964 L
.04524 .09596 L
Mistroke
.04582 .093 L
.04667 .08997 L
.04762 .08752 L
.04882 .0852 L
.0503 .08308 L
.05207 .08121 L
.05395 .07974 L
.05581 .07863 L
.05803 .07764 L
.06018 .07692 L
.06229 .07638 L
.06491 .0759 L
.06761 .07555 L
.07027 .07533 L
.0729 .0752 L
.07597 .07514 L
.07948 .07516 L
.0816 .07521 L
.08362 .07528 L
.08847 .07552 L
.09307 .07581 L
.0983 .0762 L
.12091 .0783 L
.31095 .09728 L
.45622 .11086 L
.54401 .11969 L
.62462 .12896 L
.69218 .13838 L
.75339 .14952 L
.77569 .15473 L
.79611 .16047 L
.81096 .16555 L
.82444 .17128 L
.83598 .17771 L
.84095 .18131 L
.84478 .18471 L
.84767 .18789 L
.84983 .19094 L
.85167 .1945 L
.85276 .19778 L
.85335 .20148 L
.85329 .20545 L
.8527 .20888 L
.8515 .2127 L
.8496 .21687 L
.84687 .22139 L
.84027 .22972 L
.82186 .24629 L
.79813 .2625 L
.7387 .29352 L
Mistroke
.65145 .32676 L
.5925 .34352 L
.56203 .35062 L
.5325 .35651 L
.50355 .36136 L
.47034 .36579 L
.45366 .36756 L
.43542 .36913 L
.41575 .37039 L
.39704 .37117 L
.37908 .37151 L
.35929 .3714 L
.34035 .3708 L
.32269 .36977 L
.30669 .36843 L
.289 .36644 L
.27054 .36376 L
.25332 .36062 L
.23327 .35611 L
.21231 .35022 L
.17634 .33654 L
.15589 .32602 L
.13804 .31457 L
.1232 .30286 L
.1091 .28921 L
.09799 .27613 L
.08735 .26093 L
.07244 .23308 L
.06034 .20107 L
.05302 .17404 L
.04856 .15178 L
.04707 .14236 L
.04603 .13451 L
.04534 .1282 L
.04481 .12192 L
.04447 .11626 L
.04432 .1109 L
.04436 .10579 L
.04457 .10166 L
.04498 .09767 L
.0456 .09402 L
.04628 .09123 L
.04704 .08893 L
.048 .08671 L
.04917 .08464 L
.05046 .08288 L
.05206 .08121 L
.05392 .07975 L
.05585 .07861 L
.05782 .07772 L
Mistroke
.05977 .07704 L
.06221 .0764 L
.06471 .07593 L
.0662 .07572 L
.06762 .07555 L
.06931 .0754 L
.07098 .07529 L
.07412 .07517 L
.07598 .07514 L
.07777 .07514 L
.07979 .07517 L
.08175 .07522 L
.08399 .0753 L
.08648 .07541 L
.09191 .07573 L
.09728 .07612 L
.23684 .09021 L
.36798 .10258 L
.54282 .11956 L
.61474 .12773 L
.68529 .13732 L
.72093 .14318 L
.74997 .1488 L
.77412 .15434 L
.79615 .16048 L
.8138 .16665 L
.82679 .17244 L
.83707 .17844 L
.84434 .18427 L
.84747 .18765 L
.85003 .19128 L
.85163 .19442 L
.85279 .19792 L
.85337 .20174 L
.85339 .20391 L
.85323 .2059 L
.85245 .20981 L
.85115 .21357 L
.84944 .21715 L
.84703 .22116 L
.84055 .22941 L
.82392 .24468 L
.79719 .26307 L
.76547 .2807 L
.68499 .31529 L
.63548 .33171 L
.57402 .34795 L
.51512 .35953 L
.47956 .36468 L
.46211 .3667 L
Mistroke
.44564 .3683 L
.43012 .36951 L
.41271 .37055 L
.39489 .37123 L
.37568 .37152 L
.35857 .37139 L
.33996 .37078 L
.32221 .36974 L
.30589 .36835 L
.28481 .36589 L
.26499 .36282 L
.22842 .35486 L
.20844 .34898 L
.19061 .34259 L
.17066 .33385 L
.15308 .32438 L
.12664 .30578 L
.11326 .29354 L
.1023 .2815 L
.08365 .25486 L
.07546 .23953 L
.06894 .22495 L
.05855 .1952 L
.05151 .1672 L
.0478 .14719 L
.04647 .13797 L
.04546 .12934 L
.04507 .12527 L
.04475 .12112 L
.0444 .11455 L
.04432 .11122 L
.04431 .10793 L
.04438 .10506 L
.0445 .10264 L
.04489 .0984 L
.04519 .09626 L
.04551 .09443 L
.04623 .0914 L
.04716 .08861 L
.04817 .08636 L
.04944 .08423 L
.05078 .08251 L
.05217 .08112 L
.05364 .07995 L
.05515 .07899 L
.05703 .07805 L
.05887 .07733 L
.06109 .07667 L
.06364 .07611 L
.06598 .07575 L
Mistroke
.06872 .07545 L
.07192 .07524 L
.07382 .07518 L
.07562 .07515 L
.07932 .07516 L
.08308 .07526 L
.08651 .07541 L
.09052 .07564 L
.09945 .0763 L
.11864 .07807 L
.18127 .08461 L
.21374 .08792 L
Mfstroke
.85226 .21047 m
.85089 .21418 L
.84921 .21759 L
.84396 .22537 L
.83741 .23274 L
.82981 .23982 L
.80606 .25746 L
.77798 .27413 L
.70464 .30785 L
.65706 .32494 L
.59962 .34171 L
.53885 .35532 L
.50173 .36164 L
.48336 .3642 L
.46588 .3663 L
.4478 .3681 L
.43106 .36945 L
.41209 .37058 L
.40152 .37102 L
.39146 .37132 L
.37292 .37153 L
.35562 .37132 L
.3364 .37061 L
.31591 .36925 L
.30439 .3682 L
.29345 .36699 L
.27295 .36414 L
.25099 .36015 L
.22743 .3546 L
.20735 .34863 L
.18672 .34103 L
.15224 .32388 L
.13486 .31225 L
.11794 .29809 L
.09254 .26873 L
.08098 .25016 L
.07114 .23015 L
.0644 .21316 L
.05863 .19547 L
.05173 .16825 L
.04774 .14678 L
.04649 .1381 L
.04552 .12989 L
.04494 .12362 L
.04453 .11745 L
.04439 .11411 L
.04432 .11115 L
.04435 .10611 L
.04459 .10137 L
.04482 .09897 L
Mistroke
.04509 .09691 L
.04571 .09352 L
.0464 .09082 L
.04737 .0881 L
.04843 .08588 L
.04947 .08419 L
.05073 .08257 L
.05219 .0811 L
.05369 .07992 L
.05671 .0782 L
.05859 .07743 L
.06043 .07685 L
.06276 .07628 L
.06506 .07587 L
.06778 .07554 L
.0709 .0753 L
.07379 .07518 L
.07669 .07514 L
.08007 .07517 L
.08397 .0753 L
.08815 .0755 L
.09221 .07575 L
.10229 .07654 L
.12436 .07865 L
.19899 .08643 L
.32598 .09868 L
.48505 .11366 L
.63854 .13074 L
.70567 .14056 L
.76574 .1523 L
.79081 .15886 L
.80975 .1651 L
.82706 .17258 L
.83345 .17612 L
.83919 .17995 L
.84326 .18327 L
.84692 .18699 L
.8495 .19043 L
.85132 .19371 L
.85272 .19761 L
.85333 .20125 L
.85341 .20317 L
.8533 .20529 L
.85298 .20753 L
.85251 .20962 L
.85113 .21362 L
.85021 .21566 L
.84902 .21792 L
.84365 .22577 L
.83496 .23515 L
Mistroke
.82464 .24411 L
.76889 .27894 L
.69746 .31063 L
.65246 .32643 L
.5984 .34203 L
.56562 .34984 L
.53413 .35621 L
.50036 .36184 L
.46775 .36609 L
.44853 .36804 L
.42773 .36968 L
.41673 .37034 L
.40636 .37083 L
.39485 .37123 L
.38239 .37147 L
.37154 .37153 L
.35964 .37141 L
.34831 .37111 L
.33776 .37068 L
.31768 .3694 L
.29621 .36732 L
.27596 .36461 L
.25746 .36144 L
.23773 .3572 L
.21654 .35152 L
.18224 .33915 L
.16464 .33082 L
.14918 .32201 L
.13194 .31003 L
.11718 .29738 L
.09391 .27065 L
.08338 .25439 L
.07519 .23898 L
.06145 .20454 L
.05381 .17739 L
.04931 .15602 L
.04758 .14576 L
.04619 .13582 L
.04528 .12753 L
.04472 .12074 L
.04441 .11467 L
.04431 .10961 L
.04437 .10555 L
.04457 .10162 L
.04496 .09783 L
.04554 .09432 L
.04616 .09168 L
.04697 .08912 L
.0481 .08649 L
.04935 .08436 L
Mistroke
.05061 .0827 L
.05213 .08115 L
.05398 .07972 L
.05615 .07846 L
.05818 .07758 L
.06064 .07679 L
.06312 .07621 L
.06557 .0758 L
.067 .07562 L
.06862 .07546 L
.07177 .07525 L
.07491 .07515 L
.07851 .07515 L
.08216 .07523 L
.08569 .07537 L
.08978 .07559 L
.09386 .07587 L
.10411 .07669 L
.12961 .07919 L
.19617 .08614 L
.31744 .09789 L
.47484 .11266 L
.63533 .13032 L
.71329 .14184 L
.74488 .14774 L
.77081 .15352 L
.80692 .16407 L
.8216 .16995 L
.83409 .17651 L
.84323 .18324 L
.84667 .1867 L
.84958 .19055 L
.85141 .19391 L
.8527 .19754 L
.85331 .20102 L
.85338 .20422 L
.85291 .20789 L
.85197 .21138 L
.85041 .21525 L
.84812 .21946 L
.84161 .22821 L
.83365 .23638 L
.81333 .25254 L
.78844 .26828 L
.7152 .30361 L
.663 .32297 L
.60742 .33967 L
.54628 .35388 L
.50874 .36056 L
.47225 .36557 L
Mistroke
.45621 .36731 L
.43867 .36888 L
.41901 .37021 L
.4003 .37106 L
.39007 .37135 L
.37886 .37151 L
.35822 .37138 L
.33785 .37068 L
.31884 .36949 L
.30142 .36789 L
.28262 .36559 L
.26489 .3628 L
.24875 .35968 L
.21203 .35013 L
.19422 .34399 L
.1755 .33615 L
.14279 .31787 L
.12647 .30564 L
.11307 .29335 L
.10184 .28095 L
.09112 .26667 L
.07539 .23939 L
.06345 .21046 L
.05486 .18167 L
.04971 .1582 L
.04679 .14038 L
.04565 .13117 L
.04494 .12366 L
.04468 .1201 L
.04448 .11643 L
.04435 .11288 L
.04431 .10979 L
.0444 .10469 L
.04466 .10059 L
.04513 .09664 L
.04543 .09485 L
.04581 .09304 L
.04673 .08979 L
.04779 .08715 L
.04888 .0851 L
.05022 .08317 L
.05187 .08139 L
.05384 .07981 L
.05571 .07869 L
.05796 .07766 L
.06026 .07689 L
.06254 .07633 L
.06388 .07607 L
.0654 .07582 L
.06691 .07563 L
Mistroke
.06834 .07548 L
.0713 .07527 L
.07469 .07516 L
.07807 .07515 L
.08147 .07521 L
.08515 .07535 L
.08936 .07557 L
.09774 .07616 L
.12104 .07831 L
.1919 .0857 L
.42808 .10818 L
.5976 .12567 L
.68467 .13722 L
.72084 .14317 L
.75095 .149 L
.79507 .16014 L
.81315 .16639 L
.82861 .17338 L
.84002 .18058 L
.84436 .18429 L
.84808 .18842 L
.85047 .19203 L
.85148 .19407 L
.85221 .19594 L
.85313 .19962 L
.85341 .20314 L
.85313 .20669 L
.85224 .21055 L
.85087 .21424 L
.84918 .21765 L
.84336 .22613 L
.83578 .23436 L
.81527 .25117 L
.78539 .27002 L
.71415 .30404 L
.6279 .33395 L
.5692 .34904 L
.53554 .35595 L
.49789 .3622 L
.46306 .3666 L
.44257 .36856 L
.42301 .36998 L
.40464 .3709 L
.38761 .3714 L
.36765 .37151 L
.34849 .37112 L
.3312 .37033 L
.312 .36892 L
.29185 .3668 L
.27294 .36414 L
Mistroke
.23945 .35761 L
.22098 .35281 L
.20443 .34765 L
.16925 .33316 L
.15084 .32303 L
.13497 .31233 L
.10948 .28963 L
.09742 .27539 L
.08786 .26173 L
.07254 .23331 L
.06079 .20248 L
.05287 .1734 L
.04835 .15055 L
.0469 .14116 L
.04588 .13317 L
.0452 .12664 L
.0447 .1204 L
.0444 .11438 L
.04431 .10943 L
.0444 .10472 L
.0447 .10017 L
.0452 .09619 L
.04552 .0944 L
.04592 .09257 L
.04677 .08968 L
.0477 .08733 L
.04898 .08493 L
.05031 .08306 L
.05205 .08123 L
.05389 .07978 L
.05566 .07871 L
.0577 .07777 L
.0596 .0771 L
.06184 .07649 L
.06445 .07597 L
.06601 .07574 L
.06749 .07557 L
.07055 .07532 L
.07368 .07518 L
.07707 .07514 L
.07908 .07516 L
.08101 .0752 L
.08474 .07533 L
.08896 .07554 L
.097 .0761 L
.10699 .07695 L
.16739 .08316 L
.37914 .10361 L
.54434 .11972 L
.62478 .12898 L
Mistroke
.69184 .13833 L
.75578 .15004 L
.78292 .15663 L
.80659 .16395 L
.82235 .17029 L
.83399 .17645 L
.84344 .18343 L
.84731 .18745 L
.84999 .1912 L
.85185 .19496 L
.85294 .19857 L
.85337 .20184 L
.85329 .20544 L
.85256 .20942 L
.85195 .21144 L
.85111 .21368 L
.84915 .21768 L
.84682 .22147 L
.84091 .22901 L
.83404 .23602 L
.81383 .25219 L
.78531 .27006 L
.74682 .28979 L
.65746 .32481 L
.59975 .34168 L
.56872 .34915 L
.53858 .35538 L
.51026 .36032 L
.47777 .36491 L
.44361 .36847 L
.42434 .3699 L
.40603 .37085 L
.38574 .37143 L
.37414 .37153 L
.36333 .37146 L
.34326 .37092 L
.33305 .37043 L
.32175 .36971 L
.30214 .36797 L
.28099 .36536 L
.26106 .36211 L
.24297 .35842 L
.20108 .34649 L
.17859 .33755 L
.15887 .32771 L
.12651 .30568 L
.11094 .29116 L
.09853 .27682 L
.08041 .24912 L
.07233 .23285 L
Mistroke
.06609 .21774 L
.05673 .18878 L
.05039 .16172 L
.04847 .15129 L
.04689 .1411 L
.04587 .13308 L
.04509 .12548 L
.04464 .1194 L
.04437 .11343 L
.04431 .10863 L
.0444 .10459 L
.04468 .10035 L
.04492 .09817 L
.04518 .09629 L
.04585 .09287 L
.0463 .09116 L
.04676 .08972 L
.04768 .08738 L
.04884 .08517 L
.05007 .08337 L
.05133 .08191 L
.05295 .08047 L
.05461 .07931 L
.05661 .07824 L
.05897 .0773 L
.06023 .0769 L
.06168 .07652 L
.06301 .07623 L
.0645 .07596 L
.06603 .07574 L
.06748 .07557 L
.07048 .07532 L
.07353 .07519 L
.07656 .07514 L
.08013 .07518 L
.08423 .07531 L
.08641 .07541 L
.08887 .07554 L
.0936 .07585 L
.10342 .07663 L
.15426 .08178 L
.38889 .10452 L
.55803 .1212 L
.63851 .13074 L
.70401 .14028 L
.76079 .15116 L
.78503 .15721 L
.80629 .16384 L
.82372 .17093 L
.83606 .17777 L
Mistroke
.84157 .18181 L
.84561 .18554 L
.84746 .18764 L
.84918 .18994 L
.8505 .19209 L
.85152 .19415 L
.85277 .19783 L
.85333 .20123 L
.85333 .20494 L
.85307 .20706 L
.85266 .20904 L
.85163 .21235 L
.85002 .21605 L
.84781 .21996 L
.84527 .22367 L
.82916 .24038 L
.80356 .25908 L
.77071 .278 L
.72842 .29805 L
.68176 .31646 L
.63329 .33236 L
.58159 .34618 L
.51912 .35887 L
.48193 .36439 L
.46495 .3664 L
.44582 .36828 L
.42738 .3697 L
.40977 .37069 L
.39084 .37133 L
.37012 .37152 L
.35067 .37119 L
.33242 .3704 L
.31222 .36894 L
.30088 .36784 L
.29058 .36664 L
.27168 .36394 L
.25134 .36022 L
.23394 .35628 L
.21518 .35111 L
.18143 .3388 L
.16409 .33053 L
.14879 .32176 L
.12397 .30352 L
.10155 .2806 L
.091 .26649 L
.08102 .25024 L
.07289 .23406 L
.06571 .21673 L
.05637 .18744 L
.05071 .16333 L
Mistroke
.04673 .13989 L
.04555 .1302 L
.04507 .12522 L
.04474 .12104 L
.04453 .11745 L
.04439 .11428 L
.04432 .11115 L
.04431 .10802 L
.04437 .10547 L
.04449 .10295 L
.04483 .09888 L
.04536 .09525 L
.04599 .09233 L
.04687 .08939 L
.04787 .08698 L
.04892 .08503 L
.05001 .08344 L
.05133 .08192 L
.05289 .08052 L
.05478 .07921 L
.05704 .07805 L
.05939 .07716 L
.06175 .07651 L
.06406 .07604 L
.06678 .07564 L
.06824 .07549 L
.06985 .07536 L
.07294 .0752 L
.07622 .07514 L
.07818 .07515 L
.0801 .07518 L
.08417 .0753 L
.0866 .07542 L
.08891 .07554 L
.09827 .0762 L
.10844 .07709 L
.17661 .08412 L
.42551 .10794 L
.58529 .12424 L
.66693 .13461 L
.73257 .14532 L
.78116 .15616 L
.80276 .16262 L
.81901 .1688 L
.83009 .17418 L
.83961 .18026 L
.8434 .1834 L
.84676 .18681 L
.84927 .19008 L
.85103 .1931 L
Mistroke
.85242 .19658 L
.85318 .19989 L
.8534 .20358 L
.85297 .20761 L
.85188 .21166 L
.85109 .21372 L
.85005 .21599 L
.84512 .22387 L
.83868 .23143 L
.82997 .23968 L
.80991 .25489 L
.77708 .27462 L
.73889 .29343 L
.69913 .30999 L
.64903 .32753 L
.59783 .34217 L
.53628 .35581 L
.49935 .36199 L
.46374 .36653 L
.44601 .36826 L
.43648 .36905 L
.42623 .36978 L
.40714 .3708 L
.38911 .37137 L
.36948 .37152 L
.35118 .3712 L
.33086 .37031 L
.32055 .36962 L
.30921 .36867 L
.29003 .36657 L
.2695 .36358 L
.25022 .35999 L
.23286 .356 L
.19909 .34578 L
.18087 .33856 L
.16476 .33088 L
.13749 .31417 L
.11251 .29279 L
.10134 .28034 L
.0906 .2659 L
.07343 .23524 L
.06224 .20693 L
.05507 .1825 L
.04956 .1574 L
.04657 .1387 L
.04552 .12995 L
.04512 .12577 L
.04479 .12166 L
.04441 .11485 L
.04431 .10936 L
Mistroke
.04439 .10482 L
.04461 .10114 L
.04502 .09738 L
.04555 .09423 L
.04616 .09165 L
.04683 .08951 L
.04766 .08742 L
.04867 .08545 L
.0498 .08373 L
.05115 .08211 L
.05244 .08089 L
.05397 .07972 L
.05583 .07862 L
.05798 .07766 L
.06015 .07693 L
.06233 .07637 L
.06491 .0759 L
.06628 .07571 L
.06786 .07553 L
.07082 .0753 L
.07379 .07518 L
.07568 .07515 L
.07755 .07514 L
.08125 .0752 L
.08344 .07527 L
.08554 .07536 L
.09061 .07565 L
.10025 .07636 L
.1102 .07725 L
.13745 .08001 L
.31752 .09789 L
.46209 .11143 L
.62578 .1291 L
.70088 .13977 L
.73521 .14583 L
.76714 .15263 L
.79185 .15917 L
.8105 .16538 L
.8256 .17184 L
.83668 .17818 L
.84098 .18133 L
.84486 .18478 L
.8476 .18781 L
.84997 .19117 L
.85185 .19495 L
.85256 .19704 L
.85303 .199 L
.8534 .20255 L
.85317 .20639 L
.85278 .20853 L
Mistroke
.85225 .21052 L
.85149 .21271 L
.8505 .21506 L
.84542 .22346 L
.83897 .23112 L
.82993 .23972 L
.80898 .25552 L
.78023 .2729 L
.71296 .30453 L
.66756 .32143 L
.61254 .33828 L
.57762 .34712 L
.54389 .35435 L
.50751 .36075 L
.47222 .36558 L
.45419 .36751 L
.437 .36901 L
.41871 .37023 L
.40887 .37073 L
.39824 .37113 L
.38746 .3714 L
.37564 .37152 L
.36438 .37148 L
.35389 .37128 L
.33386 .37048 L
.3124 .36896 L
.29357 .36701 L
.27328 .3642 L
.25421 .3608 L
.23691 .357 L
.1979 .34535 L
.17925 .33785 L
.15991 .32829 L
.12754 .30653 L
.11181 .29207 L
.09907 .27752 L
.0801 .24855 L
.0726 .23344 L
.06579 .21694 L
.057 .18975 L
.05085 .16405 L
.0473 .14387 L
.04626 .13635 L
.04541 .12887 L
.04476 .12127 L
.04453 .11751 L
.04439 .11422 L
.04431 .1089 L
.04444 .10387 L
.04459 .10148 L
Mistroke
.04481 .09905 L
.04512 .09672 L
.04546 .09471 L
.04621 .0915 L
.0467 .08989 L
.04719 .08853 L
.0483 .08612 L
.04946 .0842 L
.0509 .08237 L
.05262 .08074 L
.05426 .07953 L
.05594 .07857 L
.05794 .07767 L
.06029 .07689 L
.06282 .07627 L
.0653 .07584 L
.06676 .07565 L
.0684 .07548 L
.07156 .07526 L
.07476 .07516 L
.07839 .07515 L
.0817 .07522 L
.08559 .07537 L
.08808 .07549 L
.09053 .07564 L
.09539 .07598 L
.10766 .07701 L
.13534 .07979 L
.33388 .09942 L
.48678 .11384 L
.57559 .12314 L
.65396 .1328 L
.71705 .1425 L
.76476 .15207 L
.80525 .16348 L
.82125 .16979 L
.83436 .17668 L
.83936 .18008 L
.84387 .18383 L
.84729 .18743 L
.84974 .19079 L
.8514 .19388 L
.85264 .19731 L
.8533 .20095 L
.85337 .20439 L
.85279 .20847 L
.85161 .2124 L
.85006 .21596 L
.84785 .21989 L
.84105 .22885 L
Mistroke
.83261 .23734 L
.81214 .25337 L
.78852 .26823 L
.71937 .30189 L
.67498 .31887 L
.62164 .33575 L
.57059 .34873 L
.50859 .36058 L
.4894 .3634 L
.47075 .36575 L
.45339 .36758 L
.43457 .36919 L
.42467 .36988 L
.41363 .3705 L
.39389 .37126 L
.38263 .37147 L
.37039 .37152 L
.35873 .37139 L
.34798 .3711 L
.32735 .37009 L
.30803 .36856 L
.28674 .36615 L
.26406 .36265 L
.24262 .35834 L
.22272 .35331 L
.18691 .34111 L
.17005 .33355 L
.15291 .32428 L
.12504 .30444 L
.11024 .29043 L
.0979 .27601 L
.07919 .24686 L
.07174 .23151 L
.0652 .21533 L
.05647 .18782 L
.05043 .16193 L
.04825 .14993 L
.04657 .13875 L
.04563 .13095 L
.04491 .12336 L
.04452 .11725 L
.04434 .11218 L
.04433 .10686 L
.04451 .10261 L
.0449 .09831 L
.04545 .09477 L
.04606 .09204 L
.04684 .08949 L
.0476 .08755 L
.04855 .08566 L
Mistroke
.0497 .08386 L
.05107 .08219 L
.05251 .08082 L
.05395 .07974 L
.05583 .07862 L
.05776 .07774 L
.05964 .07708 L
.06181 .07649 L
.06439 .07598 L
.06576 .07577 L
.06733 .07558 L
.07028 .07533 L
.07323 .07519 L
.07642 .07514 L
.07965 .07517 L
.08273 .07525 L
.08627 .0754 L
.09038 .07563 L
.09504 .07595 L
.10426 .07671 L
.26261 .09271 L
.39641 .10522 L
.56415 .12187 L
.63144 .12982 L
.69622 .13902 L
.75543 .14997 L
.79762 .16094 L
.81553 .16734 L
.83073 .17454 L
.83631 .17793 L
.84129 .18158 L
.84487 .18479 L
.84798 .18828 L
.8503 .19173 L
.85184 .19491 L
.85285 .19816 L
.85333 .20128 L
.85333 .20494 L
.85281 .20838 L
.85169 .2122 L
.84988 .21631 L
.84751 .22043 L
.84483 .22425 L
.83713 .23302 L
.81777 .24936 L
.78884 .26804 L
.75053 .28804 L
.66791 .32131 L
.61171 .33851 L
.55408 .3523 L
Mistroke
.52587 .3577 L
.49452 .36269 L
.47757 .36493 L
.45844 .36708 L
.44043 .36874 L
.42361 .36994 L
.4063 .37084 L
.38957 .37136 L
.37165 .37153 L
.35182 .37122 L
.33437 .3705 L
.31561 .36923 L
.29782 .3675 L
.28167 .36545 L
.26202 .36229 L
.24383 .35861 L
.22251 .35325 L
.20354 .34734 L
.16685 .33196 L
.14829 .32145 L
.13206 .31012 L
.107 .28693 L
.08837 .26253 L
.07285 .23398 L
.06126 .20397 L
.05366 .17677 L
.04858 .15193 L
.04705 .14222 L
.04587 .13311 L
.04515 .12618 L
.04464 .11943 L
.04444 .11567 L
.04434 .11238 L
.04433 .10684 L
.04443 .10405 L
.04457 .10167 L
.04479 .09924 L
.04509 .09688 L
.04573 .09338 L
.04649 .09053 L
.04749 .08781 L
.04875 .08531 L
.05008 .08336 L
.05141 .08183 L
.05313 .08032 L
.05492 .07913 L
.05673 .07819 L
.05853 .07745 L
.06066 .07678 L
.06308 .07622 L
Mistroke
.06575 .07578 L
.06733 .07558 L
.06883 .07544 L
.07193 .07524 L
.07507 .07515 L
.07694 .07514 L
.07901 .07516 L
.08294 .07526 L
.08525 .07535 L
.08749 .07546 L
.09294 .0758 L
.1138 .0776 L
.13835 .0801 L
.21905 .08845 L
Mfstroke
.05967 .07707 m
.06185 .07648 L
.06397 .07605 L
.0666 .07567 L
.06927 .0754 L
.0719 .07524 L
.07449 .07516 L
.0775 .07514 L
.0809 .07519 L
.08455 .07532 L
.08874 .07553 L
.0971 .07611 L
.12041 .07825 L
.29366 .09566 L
.46434 .11164 L
.55782 .12118 L
.64074 .13103 L
.70692 .14077 L
.76463 .15204 L
.79092 .1589 L
.81119 .16564 L
.82575 .17192 L
.83252 .17556 L
.8378 .17895 L
.84193 .18211 L
.84566 .1856 L
.84876 .18934 L
.85095 .19295 L
.85236 .19637 L
.8532 .20005 L
.85341 .20323 L
.85311 .20679 L
.85271 .20884 L
.8521 .211 L
.85056 .21492 L
.84828 .21918 L
.84509 .22391 L
.83759 .23256 L
.82871 .24076 L
.80335 .25921 L
.77381 .27637 L
.73496 .29519 L
.68638 .31478 L
.63898 .33065 L
.5801 .34654 L
.55198 .35273 L
.52016 .35869 L
.48882 .36348 L
.45846 .36708 L
.43955 .36881 L
Mistroke
.41895 .37022 L
.40697 .37081 L
.39556 .37121 L
.38522 .37144 L
.37394 .37153 L
.36379 .37147 L
.35258 .37124 L
.3408 .37082 L
.32974 .37024 L
.30982 .36872 L
.28839 .36636 L
.26746 .36324 L
.24489 .35885 L
.22528 .35402 L
.20494 .34782 L
.18722 .34124 L
.16852 .3328 L
.13828 .31474 L
.12376 .30335 L
.11151 .29175 L
.09855 .27685 L
.08835 .26249 L
.07184 .23174 L
.06503 .21487 L
.05985 .1995 L
.05344 .17585 L
.04899 .15426 L
.04739 .14448 L
.04608 .13491 L
.0453 .12773 L
.04472 .12077 L
.0445 .11697 L
.04437 .1137 L
.04431 .11079 L
.04432 .1079 L
.04446 .10338 L
.04482 .099 L
.0451 .09683 L
.04541 .09498 L
.04579 .09314 L
.04627 .09127 L
.04721 .08848 L
.04839 .08594 L
.04969 .08388 L
.05101 .08225 L
.05272 .08065 L
.0545 .07938 L
.05632 .07838 L
.05813 .0776 L
.06027 .07689 L
Mistroke
.06274 .07629 L
.06522 .07585 L
.06813 .0755 L
.07109 .07528 L
.07404 .07517 L
.07717 .07514 L
.08017 .07518 L
.08387 .07529 L
.08759 .07547 L
.09685 .07609 L
.10657 .07691 L
.13352 .0796 L
.3049 .09672 L
.44225 .10952 L
.60456 .1265 L
.68849 .13781 L
.75155 .14913 L
.77646 .15493 L
.79935 .1615 L
.81699 .16794 L
.82998 .17412 L
.83537 .17732 L
.84024 .18074 L
.84379 .18375 L
.84693 .187 L
.84959 .19057 L
.85142 .19394 L
.85224 .19602 L
.85281 .19801 L
.85337 .20176 L
.85332 .20511 L
.85274 .20871 L
.85183 .21181 L
.8504 .21526 L
.84839 .21901 L
.84569 .22309 L
.8395 .23056 L
.81783 .24931 L
.78946 .26768 L
.71758 .30263 L
.62416 .33503 L
.56156 .35072 L
.5293 .35709 L
.49813 .36217 L
.46702 .36617 L
.45067 .36784 L
.4328 .36932 L
.41447 .37046 L
.39707 .37117 L
.38629 .37142 L
Mistroke
.376 .37152 L
.35653 .37134 L
.33919 .37075 L
.32063 .36962 L
.3047 .36823 L
.28709 .36619 L
.26821 .36337 L
.24803 .35953 L
.21229 .35022 L
.19194 .34311 L
.17422 .33555 L
.15612 .32616 L
.13793 .31449 L
.12252 .30226 L
.10973 .28989 L
.08867 .26299 L
.07922 .24692 L
.07181 .23168 L
.06461 .21374 L
.05938 .19797 L
.05185 .16881 L
.04924 .15566 L
.04721 .1433 L
.04603 .13449 L
.04513 .12591 L
.04462 .11905 L
.04436 .11336 L
.04431 .1104 L
.04432 .1075 L
.04449 .10282 L
.04467 .10047 L
.04489 .09843 L
.04517 .09635 L
.04554 .0943 L
.04629 .09122 L
.04728 .08832 L
.04838 .08597 L
.04954 .08409 L
.0507 .0826 L
.05211 .08117 L
.05374 .07988 L
.0554 .07885 L
.05735 .07791 L
.05961 .07709 L
.06194 .07646 L
.06421 .07601 L
.06568 .07578 L
.0671 .07561 L
.06871 .07545 L
.07049 .07532 L
Mistroke
.07366 .07518 L
.07556 .07515 L
.07741 .07514 L
.08118 .0752 L
.08501 .07534 L
.08867 .07553 L
.09291 .0758 L
.11466 .07768 L
.26338 .09278 L
.56005 .12142 L
.64515 .13161 L
.72414 .14376 L
.75449 .14976 L
.78189 .15636 L
.80328 .1628 L
.81915 .16886 L
.8321 .17532 L
.84132 .1816 L
.84522 .18514 L
.8481 .18845 L
.85052 .19214 L
.85146 .19402 L
.85227 .1961 L
.85313 .19963 L
.85341 .2029 L
.85312 .20671 L
.85229 .21038 L
.85105 .21381 L
.84952 .21701 L
.84473 .22438 L
.83772 .23243 L
.82944 .24014 L
.80498 .25817 L
.73379 .29571 L
.64312 .32938 L
.58825 .34458 L
.55385 .35235 L
.52065 .35861 L
.49058 .36324 L
.45642 .36729 L
.437 .36901 L
.41868 .37023 L
.40083 .37104 L
.38157 .37148 L
.36489 .37148 L
.34673 .37106 L
.32941 .37022 L
.31345 .36905 L
.29472 .36714 L
.27426 .36435 L
Mistroke
.25502 .36096 L
.23732 .3571 L
.2169 .35162 L
.19594 .34463 L
.16068 .32871 L
.14275 .31784 L
.12736 .30637 L
.11122 .29146 L
.09788 .27599 L
.08793 .26184 L
.07867 .24588 L
.06607 .21768 L
.05615 .18663 L
.05037 .16165 L
.04717 .14303 L
.04618 .13568 L
.04539 .12867 L
.04479 .12169 L
.04446 .11599 L
.04431 .11054 L
.04437 .10531 L
.04464 .10083 L
.04504 .09726 L
.04568 .09365 L
.04644 .09069 L
.04729 .08829 L
.04819 .08633 L
.0493 .08444 L
.05061 .0827 L
.05205 .08123 L
.05378 .07985 L
.05558 .07876 L
.05739 .0779 L
.05933 .07718 L
.06122 .07664 L
.06356 .07613 L
.06592 .07575 L
.0687 .07545 L
.07186 .07525 L
.07476 .07516 L
.07815 .07515 L
.08208 .07523 L
.08441 .07531 L
.08662 .07542 L
.09575 .076 L
.11543 .07776 L
.14289 .08058 L
.21395 .08794 L
.48338 .1135 L
.57273 .12282 L
Mistroke
.66265 .13401 L
.73445 .14568 L
.78546 .15733 L
.8049 .16336 L
.82176 .17002 L
.83414 .17654 L
.84256 .18264 L
.84647 .18648 L
.84926 .19007 L
.85052 .19213 L
.85148 .19407 L
.85227 .19611 L
.8529 .19838 L
.85339 .20227 L
.85324 .20587 L
.85292 .20788 L
.85238 .21009 L
.85091 .21414 L
.84903 .21791 L
.84681 .22149 L
.8402 .2298 L
.82074 .24715 L
.79796 .2626 L
.7677 .27956 L
.69032 .31333 L
.63641 .33143 L
.5794 .3467 L
.5455 .35403 L
.51157 .36011 L
.47954 .36469 L
.46094 .36683 L
.44313 .36851 L
.42359 .36994 L
.41306 .37053 L
.4016 .37102 L
.38949 .37136 L
.37787 .37151 L
.36734 .37151 L
.35576 .37133 L
.33462 .37052 L
.32271 .36978 L
.31187 .36891 L
.29068 .36665 L
.27072 .36378 L
.25177 .36031 L
.2317 .35571 L
.19659 .34487 L
.17622 .33648 L
.15795 .3272 L
.12714 .30619 L
Mistroke
.1134 .29368 L
.10045 .27924 L
.08149 .25108 L
.07323 .23482 L
.06681 .21961 L
.05619 .18679 L
.05079 .16377 L
.04724 .14349 L
.04546 .12933 L
.04485 .12248 L
.04449 .1168 L
.04432 .11091 L
.04435 .10604 L
.04454 .10215 L
.04489 .09841 L
.04544 .09483 L
.04578 .0932 L
.0462 .09153 L
.04706 .08888 L
.048 .08671 L
.04917 .08464 L
.05058 .08274 L
.05207 .08121 L
.05356 .08001 L
.05548 .07881 L
.05778 .07774 L
.06016 .07692 L
.06254 .07633 L
.06496 .07589 L
.06737 .07558 L
.07021 .07534 L
.07349 .07519 L
.07523 .07515 L
.07719 .07514 L
.08097 .0752 L
.08493 .07534 L
.08883 .07554 L
.09699 .0761 L
.10559 .07683 L
.12911 .07914 L
.19828 .08635 L
.44077 .10938 L
.60389 .12642 L
.68627 .13747 L
.74833 .14845 L
.7761 .15484 L
.80107 .16206 L
.81987 .16918 L
.83321 .17598 L
.84238 .18249 L
Mistroke
.84629 .18628 L
.84913 .18987 L
.85133 .19373 L
.85263 .1973 L
.85308 .19929 L
.85335 .20148 L
.85328 .2055 L
.85258 .20935 L
.85138 .21301 L
.84949 .21707 L
.8468 .22151 L
.83936 .23071 L
.83036 .23935 L
.80895 .25554 L
.78005 .273 L
.70714 .30686 L
.65754 .32478 L
.60428 .3405 L
.54877 .35338 L
.5172 .35919 L
.482 .36438 L
.45098 .36781 L
.43281 .36932 L
.41546 .37041 L
.39926 .3711 L
.38424 .37145 L
.36667 .3715 L
.34977 .37116 L
.32961 .37023 L
.31818 .36944 L
.30764 .36852 L
.28818 .36634 L
.26766 .36328 L
.23244 .3559 L
.21293 .35041 L
.19521 .34436 L
.17556 .33618 L
.15793 .32719 L
.12809 .30697 L
.11351 .29379 L
.10151 .28055 L
.09011 .26517 L
.07972 .24785 L
.06729 .22085 L
.05893 .19648 L
.05219 .17038 L
.04827 .15009 L
.04593 .13359 L
.04511 .12569 L
.04462 .11919 L
Mistroke
.04436 .1131 L
.04431 .10822 L
.04447 .10326 L
.0448 .09917 L
.04527 .09575 L
.04594 .09253 L
.04671 .08987 L
.04753 .08772 L
.04863 .08551 L
.05001 .08345 L
.05147 .08178 L
.05297 .08045 L
.05466 .07928 L
.05639 .07835 L
.05844 .07748 L
.06086 .07673 L
.06348 .07614 L
.06488 .0759 L
.06647 .07568 L
.06949 .07539 L
.07251 .07522 L
.07555 .07515 L
.07909 .07516 L
.08267 .07525 L
.08618 .07539 L
.08954 .07558 L
.09345 .07584 L
.1021 .07652 L
.15422 .08177 L
.39223 .10483 L
.55762 .12115 L
.63595 .1304 L
.69945 .13954 L
.75495 .14986 L
.80011 .16174 L
.81789 .16832 L
.82568 .17188 L
.83277 .17571 L
.83806 .17913 L
.84291 .18295 L
.84624 .18623 L
.84911 .18984 L
.85124 .19354 L
.85258 .1971 L
.85327 .20062 L
.85339 .20391 L
.85299 .2075 L
.85193 .21152 L
.85116 .21356 L
.85015 .21578 L
Mistroke
.84789 .21982 L
.84232 .22738 L
.83458 .23551 L
.81633 .25041 L
.75863 .28413 L
.71728 .30276 L
.67205 .31989 L
.6243 .33499 L
.56625 .3497 L
.53846 .3554 L
.50759 .36074 L
.47991 .36464 L
.44851 .36804 L
.42903 .36959 L
.4106 .37065 L
.39265 .37129 L
.37323 .37153 L
.35383 .37128 L
.33537 .37056 L
.31865 .36947 L
.30049 .36779 L
.2804 .36527 L
.25846 .36163 L
.23578 .35673 L
.21504 .35106 L
.1795 .33796 L
.16087 .32881 L
.14495 .3193 L
.13086 .30919 L
.11717 .29737 L
.09611 .27366 L
.07854 .24564 L
.07075 .22926 L
.06474 .21408 L
.05668 .1886 L
.05146 .16698 L
.0476 .14589 L
.04638 .1373 L
.04555 .13019 L
.04487 .12273 L
.04462 .11917 L
.04444 .11566 L
.04431 .1103 L
.04438 .10513 L
.04462 .10108 L
.04504 .09725 L
.04559 .09408 L
.0462 .09151 L
.04713 .08871 L
.04813 .08645 L
Mistroke
.04939 .08431 L
.05091 .08236 L
.05239 .08093 L
.05391 .07976 L
.05573 .07867 L
.05789 .0777 L
.05988 .07701 L
.06188 .07648 L
.06423 .07601 L
.06693 .07563 L
.06838 .07548 L
.07001 .07535 L
.07313 .0752 L
.0764 .07514 L
.07963 .07517 L
.08283 .07525 L
.086 .07539 L
.08968 .07559 L
.0939 .07587 L
.11312 .07753 L
.27404 .0938 L
.42456 .10785 L
.51996 .11718 L
.60896 .12703 L
.68684 .13755 L
.72266 .14349 L
.75588 .15006 L
.78001 .15585 L
.80228 .16246 L
.81879 .1687 L
.83107 .17473 L
.83636 .17796 L
.84125 .18154 L
.84483 .18475 L
.84791 .18821 L
.85008 .19136 L
.85182 .19488 L
.85284 .19813 L
.85333 .20122 L
.85333 .20492 L
.8527 .20886 L
.85166 .21227 L
.85002 .21604 L
.84767 .22017 L
.84454 .22463 L
.83735 .2328 L
.81551 .251 L
.78848 .26825 L
.75253 .28709 L
.70509 .30767 L
Mistroke
.66043 .32383 L
.60618 .33999 L
.57333 .34811 L
.54148 .35482 L
.51024 .36032 L
.4739 .36538 L
.45687 .36724 L
.43807 .36892 L
.41993 .37016 L
.40296 .37097 L
.38458 .37145 L
.36411 .37147 L
.35366 .37127 L
.34242 .37089 L
.32198 .36972 L
.30269 .36803 L
.28169 .36546 L
.2619 .36226 L
.24377 .3586 L
.21018 .34955 L
.19382 .34383 L
.17642 .33657 L
.15705 .32669 L
.13991 .31589 L
.11173 .29199 L
.09852 .27681 L
.08791 .26181 L
.0775 .24361 L
.06948 .22626 L
.05876 .19589 L
.05237 .17119 L
.04805 .14872 L
.04648 .13801 L
.04546 .12935 L
.0448 .12188 L
.04444 .11564 L
.04431 .11066 L
.04436 .10586 L
.0446 .10128 L
.0448 .09919 L
.04507 .09705 L
.04568 .09365 L
.04639 .09085 L
.0472 .08851 L
.04818 .08634 L
.04912 .08471 L
.05026 .08312 L
.05162 .08162 L
.05323 .08025 L
.0549 .07914 L
Mistroke
.05654 .07828 L
.05865 .07741 L
.0611 .07667 L
.06336 .07616 L
.06605 .07574 L
.06765 .07555 L
.06917 .07541 L
.071 .07529 L
.07282 .07521 L
.07623 .07514 L
.07827 .07515 L
.08024 .07518 L
.08433 .07531 L
.08845 .07552 L
.09695 .0761 L
.12032 .07824 L
.27562 .09395 L
.42705 .10809 L
.58949 .12473 L
.66631 .13452 L
.72888 .14463 L
.75816 .15057 L
.78536 .15731 L
.80572 .16364 L
.82128 .1698 L
.8342 .17658 L
.83962 .18027 L
.84439 .18432 L
.84808 .18842 L
.84966 .19068 L
.85088 .1928 L
.85243 .19661 L
.85296 .19865 L
.85329 .20084 L
.85334 .20485 L
.85306 .20713 L
.85261 .20924 L
.85131 .21318 L
.85044 .21518 L
.84932 .21739 L
.8439 .22546 L
.83699 .23316 L
.81665 .25018 L
.78673 .26925 L
.71328 .30439 L
.67028 .3205 L
.61853 .33662 L
.56925 .34903 L
.50913 .3605 L
.47679 .36503 L
Mistroke
.45757 .36717 L
.43968 .3688 L
.42031 .37014 L
.40949 .3707 L
.39915 .3711 L
.38052 .37149 L
.35999 .37141 L
.34216 .37088 L
.32233 .36975 L
.30148 .3679 L
.28191 .36549 L
.26366 .36258 L
.24708 .35933 L
.21056 .34967 L
.19094 .34272 L
.17094 .33399 L
.13807 .31459 L
.12038 .30035 L
.10566 .28542 L
.09399 .27077 L
.08343 .25448 L
.06822 .22318 L
.05862 .19541 L
.05184 .16875 L
.04921 .15549 L
.0474 .14457 L
.04619 .13579 L
.04525 .12721 L
.04492 .12344 L
.04465 .11965 L
.04446 .11593 L
.04435 .11269 L
.04432 .10726 L
.04439 .1048 L
.04453 .10229 L
.0449 .09828 L
.04541 .095 L
.04609 .09194 L
.04687 .0894 L
.04768 .08739 L
.04867 .08545 L
.04989 .0836 L
.05134 .08191 L
.0527 .08067 L
.05434 .07948 L
.05643 .07833 L
.0586 .07743 L
.06072 .07677 L
.06321 .07619 L
.06473 .07593 L
Mistroke
.06616 .07572 L
.06788 .07553 L
.06958 .07538 L
.07278 .07521 L
.0747 .07516 L
.07653 .07514 L
.08003 .07517 L
.08352 .07528 L
.08761 .07547 L
.0923 .07576 L
.11426 .07764 L
.27855 .09423 L
.43126 .10848 L
.52711 .11791 L
.6155 .12783 L
.69189 .13834 L
.75012 .14883 L
.77741 .15518 L
.79924 .16146 L
.81799 .16836 L
.82664 .17236 L
.8336 .17621 L
.83862 .17953 L
.84317 .18319 L
.84629 .18628 L
.84903 .18972 L
.85123 .19351 L
.8521 .19561 L
.85271 .19758 L
.85332 .20115 L
.85332 .20504 L
.85273 .20871 L
.85147 .21276 L
.84972 .21664 L
.84761 .22027 L
.84245 .22723 L
.83535 .23477 L
.81487 .25145 L
.79035 .26716 L
.71659 .30304 L
.63071 .33313 L
.57982 .3466 L
.51794 .35906 L
.48334 .3642 L
.46442 .36646 L
.44386 .36845 L
.42546 .36983 L
.41484 .37044 L
.40479 .3709 L
.38692 .37141 L
Mistroke
.3674 .37151 L
.34829 .37111 L
.3272 .37008 L
.30712 .36847 L
.28843 .36637 L
.26991 .36365 L
.25321 .3606 L
.21648 .3515 L
.19619 .34473 L
.17565 .33622 L
.14189 .31726 L
.12521 .30458 L
.11122 .29146 L
.09693 .27474 L
.08545 .25786 L
.0695 .2263 L
.05949 .19833 L
.05239 .17125 L
.04963 .15779 L
.04774 .14677 L
.04651 .13831 L
.04553 .13003 L
.04486 .12267 L
.04445 .11586 L
.04431 .11056 L
.04437 .10557 L
.04459 .10142 L
.04493 .09807 L
.0452 .09617 L
.04554 .09431 L
.04626 .0913 L
.04721 .08848 L
.04845 .08584 L
.04969 .08388 L
.05118 .08207 L
.05276 .08062 L
.05434 .07948 L
.05627 .0784 L
.05852 .07746 L
.06061 .0768 L
.06312 .07621 L
.0646 .07595 L
.06602 .07574 L
.06765 .07555 L
.06944 .07539 L
.07266 .07521 L
.07459 .07516 L
.07646 .07514 L
.07827 .07515 L
.0803 .07518 L
Mistroke
.08421 .07531 L
.08829 .07551 L
.0923 .07576 L
.11473 .07769 L
.28554 .09489 L
.43175 .10853 L
.58364 .12405 L
.65386 .13279 L
.72081 .14316 L
.77189 .15378 L
.80772 .16435 L
.82391 .17102 L
.8357 .17753 L
.84358 .18355 L
.84695 .18702 L
.84939 .19026 L
.85137 .19381 L
.8526 .19717 L
.8533 .20091 L
.85341 .20303 L
.85333 .20498 L
.85268 .20894 L
.85204 .2112 L
.85126 .2133 L
.84942 .2172 L
.84687 .2214 L
.84073 .22921 L
.83233 .2376 L
.81271 .25298 L
.74908 .28873 L
.67377 .31929 L
.62265 .33546 L
.56935 .34901 L
.54098 .35492 L
.51291 .35989 L
.45701 .36723 L
Mfstroke
.5145 .11662 m
.5919 .12501 L
.65926 .13353 L
.72373 .14369 L
.77861 .15549 L
.80027 .1618 L
.8193 .16893 L
.83313 .17593 L
.83837 .17935 L
.84252 .18261 L
.84588 .18583 L
.84839 .18882 L
.85055 .19219 L
.85219 .19586 L
.8531 .19943 L
.8534 .20337 L
.85305 .20715 L
.85219 .21071 L
.85145 .21282 L
.85049 .21506 L
.84832 .21912 L
.8414 .22846 L
.83329 .23672 L
.82229 .24596 L
.76675 .28005 L
.72539 .29935 L
.67304 .31955 L
.61624 .33726 L
.55673 .35175 L
.5241 .35801 L
.49183 .36306 L
.45653 .36728 L
.43711 .369 L
.42607 .36979 L
.41568 .3704 L
.40576 .37086 L
.39505 .37122 L
.38305 .37147 L
.37204 .37153 L
.36043 .37142 L
.34775 .37109 L
.33568 .37057 L
.3245 .3699 L
.30454 .36821 L
.29315 .36696 L
.2825 .36557 L
.26107 .36211 L
.23827 .35733 L
.19782 .34532 L
.17616 .33645 L
Mistroke
.15719 .32677 L
.126 .30525 L
.11095 .29118 L
.09892 .27733 L
.08032 .24897 L
.07215 .23244 L
.06594 .21734 L
.0573 .19084 L
.05126 .16603 L
.0491 .15487 L
.04731 .14398 L
.04614 .13541 L
.04526 .12733 L
.04473 .12087 L
.0444 .11456 L
.04431 .10949 L
.04438 .10526 L
.04464 .10083 L
.04511 .09677 L
.04566 .09373 L
.04641 .09081 L
.04738 .08806 L
.04861 .08555 L
.04995 .08352 L
.05131 .08194 L
.05273 .08064 L
.05438 .07945 L
.05593 .07857 L
.05772 .07776 L
.05981 .07703 L
.0619 .07647 L
.06326 .07618 L
.0646 .07595 L
.06725 .07559 L
.06974 .07537 L
.07257 .07522 L
.07513 .07515 L
.07813 .07515 L
.08155 .07521 L
.08549 .07536 L
.08947 .07558 L
.09336 .07583 L
.11342 .07756 L
.14127 .08041 L
.2135 .08789 L
.50388 .11554 L
.58683 .12442 L
.66833 .13481 L
.70619 .14064 L
.74315 .14739 L
Mistroke
.77237 .1539 L
.79495 .16011 L
.81376 .16663 L
.828 .17306 L
.83937 .18008 L
.84423 .18417 L
.84777 .18803 L
.85029 .19172 L
.85197 .19525 L
.85292 .19847 L
.85338 .20198 L
.85324 .20589 L
.85292 .20787 L
.85238 .21006 L
.85098 .21399 L
.84915 .21769 L
.84335 .22614 L
.83601 .23414 L
.81302 .25276 L
.78606 .26964 L
.75104 .2878 L
.6754 .31872 L
.62368 .33517 L
.56914 .34905 L
.50874 .36056 L
.49113 .36316 L
.47182 .36562 L
.45327 .3676 L
.43579 .3691 L
.41563 .3704 L
.40485 .3709 L
.39331 .37127 L
.37365 .37153 L
.36234 .37145 L
.35169 .37122 L
.33165 .37035 L
.3132 .36903 L
.2918 .36679 L
.27147 .36391 L
.23539 .35663 L
.21568 .35126 L
.19828 .34549 L
.16612 .33158 L
.13875 .31507 L
.12469 .30414 L
.11125 .29149 L
.09095 .26642 L
.08171 .25148 L
.07438 .23727 L
.06173 .20539 L
Mistroke
.05357 .1764 L
.04888 .15362 L
.04711 .14259 L
.04591 .13344 L
.04505 .12504 L
.04474 .12102 L
.04451 .11701 L
.04432 .11102 L
.04431 .10797 L
.04437 .10533 L
.04463 .10097 L
.04509 .09692 L
.04572 .09345 L
.04647 .09061 L
.04727 .08835 L
.04826 .0862 L
.04936 .08434 L
.05052 .08281 L
.05191 .08135 L
.05357 .08 L
.05548 .07881 L
.05746 .07787 L
.05939 .07716 L
.06165 .07653 L
.06375 .07609 L
.06623 .07571 L
.06902 .07542 L
.07183 .07525 L
.07461 .07516 L
.07732 .07514 L
.08048 .07518 L
.08402 .0753 L
.08811 .0755 L
.09287 .0758 L
.10245 .07655 L
.12413 .07863 L
.19599 .08612 L
.43381 .10872 L
.51651 .11682 L
.60462 .12651 L
.67924 .13641 L
.73939 .14664 L
.76641 .15246 L
.79151 .15907 L
.81055 .1654 L
.82455 .17133 L
.83762 .17882 L
.84302 .18305 L
.84702 .18711 L
.84983 .19095 L
Mistroke
.85168 .19453 L
.85237 .19642 L
.85293 .19852 L
.85328 .20073 L
.8534 .2028 L
.85313 .20669 L
.85274 .20867 L
.85214 .21087 L
.85061 .2148 L
.84867 .21853 L
.84258 .22708 L
.83353 .2365 L
.81088 .25424 L
.7838 .27091 L
.71652 .30307 L
.62394 .33509 L
.56576 .34981 L
.50704 .36083 L
.47205 .3656 L
.45156 .36776 L
.43223 .36936 L
.41494 .37043 L
.39558 .37121 L
.37499 .37153 L
.35544 .37132 L
.33713 .37065 L
.317 .36934 L
.29787 .36751 L
.28012 .36523 L
.24676 .35925 L
.23014 .35531 L
.2121 .35016 L
.17657 .33664 L
.15793 .32719 L
.14193 .31728 L
.11573 .29599 L
.10433 .2839 L
.09329 .26978 L
.07526 .23911 L
.06756 .22154 L
.06183 .2057 L
.05412 .1787 L
.04899 .15425 L
.04749 .14518 L
.04627 .13639 L
.04548 .12956 L
.04488 .12286 L
.04446 .11594 L
.04431 .11019 L
.04438 .10528 L
Mistroke
.0446 .10125 L
.04506 .09712 L
.0454 .09504 L
.04576 .09327 L
.04655 .09034 L
.04756 .08766 L
.0486 .08557 L
.0497 .08385 L
.05105 .08222 L
.05265 .08071 L
.05454 .07935 L
.05683 .07814 L
.05922 .07722 L
.06163 .07653 L
.06398 .07605 L
.06678 .07565 L
.06827 .07549 L
.06994 .07535 L
.07315 .0752 L
.07653 .07514 L
.07981 .07517 L
.08387 .07529 L
.08799 .07549 L
.09606 .07603 L
.10598 .07686 L
.16751 .08317 L
.42226 .10763 L
.59335 .12518 L
.67065 .13515 L
.73124 .14507 L
.78198 .15638 L
.80384 .16299 L
.82063 .16951 L
.82794 .17303 L
.83462 .17684 L
.83952 .1802 L
.84393 .18389 L
.848 .18832 L
.84947 .19038 L
.85076 .19257 L
.85169 .19457 L
.85248 .19678 L
.85328 .20071 L
.85335 .2047 L
.8528 .20845 L
.85228 .21042 L
.85153 .21261 L
.84947 .21709 L
.84709 .22108 L
.84393 .22542 L
Mistroke
.83676 .23339 L
.81696 .24995 L
.7931 .26554 L
.75937 .28376 L
.71514 .30363 L
.61458 .33772 L
.58529 .3453 L
.55161 .35281 L
.52019 .35869 L
.48521 .36396 L
.45209 .36771 L
.43265 .36933 L
.4141 .37048 L
.39674 .37118 L
.38065 .37149 L
.36181 .37144 L
.34373 .37094 L
.32429 .36989 L
.31315 .36902 L
.30266 .36802 L
.28152 .36543 L
.25877 .36168 L
.23896 .35749 L
.21843 .35208 L
.18319 .33956 L
.16447 .33073 L
.14573 .31981 L
.11601 .29626 L
.10075 .27961 L
.08846 .26267 L
.07912 .24673 L
.07079 .22933 L
.06019 .2006 L
.0535 .17609 L
.04848 .15131 L
.04587 .13308 L
.04504 .12489 L
.04457 .11821 L
.04441 .11472 L
.04433 .11178 L
.04431 .10862 L
.04436 .10586 L
.0446 .10132 L
.04498 .09766 L
.04557 .09414 L
.04593 .09254 L
.04638 .09091 L
.04728 .08831 L
.04827 .08617 L
.04928 .08447 L
Mistroke
.05049 .08284 L
.05195 .08131 L
.05368 .07992 L
.05529 .07891 L
.05722 .07797 L
.05916 .07724 L
.06107 .07667 L
.06332 .07617 L
.06587 .07576 L
.06826 .07549 L
.07062 .07531 L
.07336 .07519 L
.07649 .07514 L
.08005 .07517 L
.08219 .07523 L
.08426 .07531 L
.08869 .07553 L
.0938 .07586 L
.11491 .07771 L
.18826 .08533 L
.44884 .11015 L
.61728 .12804 L
.70122 .13983 L
.73551 .14589 L
.76377 .15184 L
.78697 .15776 L
.80786 .16441 L
.82317 .17068 L
.83427 .17662 L
.84329 .1833 L
.84707 .18717 L
.84977 .19085 L
.85091 .19287 L
.85179 .1948 L
.85291 .19845 L
.8534 .20243 L
.85335 .20471 L
.85311 .20683 L
.85219 .21071 L
.85077 .21445 L
.84906 .21785 L
.84674 .22159 L
.83991 .23012 L
.83166 .2382 L
.786 .26967 L
.74997 .28831 L
.71149 .30512 L
.66324 .32289 L
.60487 .34034 L
.54739 .35366 L
Mistroke
.51198 .36004 L
.47709 .36499 L
.46002 .36692 L
.4435 .36848 L
.4282 .36965 L
.41165 .3706 L
.39338 .37127 L
.37619 .37152 L
.35743 .37136 L
.33646 .37061 L
.31514 .36919 L
.30436 .3682 L
.29254 .36688 L
.2716 .36393 L
.25221 .3604 L
.22953 .35515 L
.20937 .34929 L
.18662 .34099 L
.16667 .33187 L
.13403 .31163 L
.11893 .29902 L
.1047 .28432 L
.08502 .25716 L
.07614 .24091 L
.06921 .22561 L
.05846 .19489 L
.05199 .16948 L
.04765 .14619 L
.04613 .13533 L
.04521 .12674 L
.04464 .11951 L
.04437 .11366 L
.04431 .10802 L
.04437 .10546 L
.04449 .10285 L
.04483 .09887 L
.04538 .09515 L
.04605 .09208 L
.04679 .08962 L
.04769 .08736 L
.04879 .08525 L
.04984 .08367 L
.05112 .08214 L
.05263 .08072 L
.05444 .07942 L
.0563 .07839 L
.05816 .07759 L
.06006 .07695 L
.06195 .07646 L
.06416 .07602 L
Mistroke
.06669 .07566 L
.06955 .07538 L
.07245 .07522 L
.07522 .07515 L
.07842 .07515 L
.08213 .07523 L
.08574 .07537 L
.0902 .07562 L
.09474 .07593 L
.11448 .07766 L
.18171 .08465 L
.45085 .11035 L
.61113 .12729 L
.68413 .13714 L
.75117 .14905 L
.79464 .16001 L
.8135 .16653 L
.82735 .17273 L
.83693 .17835 L
.84476 .18468 L
.84771 .18795 L
.85016 .1915 L
.85183 .19489 L
.85282 .19802 L
.85336 .20161 L
.85333 .20501 L
.85272 .2088 L
.85141 .21292 L
.85052 .215 L
.84937 .21729 L
.84681 .22149 L
.84046 .22952 L
.82273 .24562 L
.80053 .261 L
.73141 .29675 L
.68194 .31639 L
.63027 .33326 L
.5745 .34784 L
.54132 .35485 L
.5086 .36058 L
.47932 .36472 L
.44659 .36821 L
.42733 .3697 L
.4087 .37073 L
.39168 .37131 L
.37288 .37153 L
.3524 .37124 L
.33294 .37043 L
.32171 .3697 L
.31139 .36887 L
Mistroke
.28805 .36632 L
.26685 .36314 L
.24384 .35861 L
.22023 .3526 L
.19888 .34571 L
.17942 .33792 L
.16194 .32939 L
.13217 .3102 L
.11746 .29764 L
.1053 .28501 L
.09294 .26929 L
.08291 .25359 L
.06834 .22348 L
.05906 .19689 L
.05236 .17113 L
.04787 .14759 L
.04656 .13864 L
.04564 .13108 L
.04491 .12333 L
.04451 .11713 L
.04433 .11191 L
.04432 .10761 L
.04446 .1034 L
.04477 .09946 L
.04529 .09564 L
.04592 .0926 L
.04633 .09108 L
.04682 .08955 L
.04783 .08705 L
.04893 .08502 L
.05024 .08315 L
.05148 .08176 L
.05299 .08043 L
.05494 .07911 L
.0569 .07811 L
.05938 .07716 L
.06198 .07645 L
.06458 .07595 L
.06718 .0756 L
.07026 .07533 L
.07208 .07524 L
.07381 .07518 L
.07707 .07514 L
.08033 .07518 L
.08415 .0753 L
.08855 .07552 L
.09857 .07622 L
.10909 .07715 L
.16332 .08273 L
.40864 .10636 L
Mistroke
.56256 .12169 L
.64363 .13141 L
.71069 .1414 L
.76909 .1531 L
.79367 .15972 L
.8151 .16717 L
.8295 .17386 L
.83583 .17761 L
.84078 .18117 L
.8446 .18452 L
.84744 .18762 L
.84993 .1911 L
.85182 .19489 L
.85291 .19844 L
.85337 .2018 L
.85328 .20555 L
.85251 .20963 L
.85187 .21169 L
.85099 .21395 L
.84891 .21812 L
.8434 .22607 L
.83641 .23374 L
.82717 .24206 L
.80621 .25736 L
.77218 .27723 L
.73297 .29607 L
.69227 .3126 L
.64128 .32994 L
.58869 .34447 L
.52571 .35773 L
.48789 .3636 L
.45159 .36776 L
.4335 .36927 L
.4238 .36993 L
.4134 .37051 L
.39404 .37125 L
.37583 .37152 L
.35774 .37137 L
.34098 .37083 L
.32241 .36975 L
.30274 .36803 L
.28551 .36598 L
.2695 .36358 L
.23356 .35618 L
.21357 .35061 L
.19522 .34436 L
.16282 .32986 L
.14607 .32003 L
.13174 .30987 L
.11659 .29682 L
Mistroke
.10379 .28326 L
.09334 .26986 L
.08349 .25458 L
.06981 .22704 L
.05876 .19591 L
.05214 .17014 L
.04844 .15111 L
.04594 .13373 L
.04517 .12635 L
.04463 .11929 L
.04437 .11342 L
.04431 .10864 L
.04443 .10395 L
.04476 .09956 L
.04524 .09595 L
.04581 .09304 L
.04664 .09005 L
.04774 .08726 L
.04894 .085 L
.05021 .08319 L
.05166 .08159 L
.05317 .0803 L
.05499 .07909 L
.05714 .078 L
.05961 .07709 L
.06219 .07641 L
.0647 .07593 L
.06621 .07571 L
.06767 .07555 L
.0707 .07531 L
.07232 .07523 L
.07416 .07517 L
.07762 .07514 L
.08108 .0752 L
.08329 .07527 L
.08546 .07536 L
.08977 .07559 L
.1006 .07639 L
.15459 .08181 L
.35572 .10144 L
.51191 .11635 L
.59983 .12594 L
.67559 .13587 L
.7309 .14501 L
.77908 .15561 L
.79988 .16167 L
.81782 .16829 L
.83002 .17414 L
.84025 .18075 L
.84453 .18446 L
Mistroke
.84769 .18793 L
.85034 .1918 L
.85135 .19377 L
.85222 .19597 L
.85314 .19969 L
.85337 .2018 L
.8534 .20375 L
.85298 .20756 L
.85203 .21123 L
.85063 .21478 L
.84863 .2186 L
.8438 .22558 L
.8361 .23405 L
.82739 .24187 L
.80237 .25984 L
.76743 .2797 L
.7276 .2984 L
.68438 .31551 L
.63422 .33209 L
.58294 .34586 L
.51945 .35881 L
.48154 .36443 L
.4638 .36652 L
.44376 .36846 L
.42417 .36991 L
.40541 .37087 L
.38522 .37144 L
.37372 .37153 L
.3631 .37146 L
.345 .37099 L
.32503 .36994 L
.30401 .36816 L
.28441 .36583 L
.26101 .3621 L
.23916 .35754 L
.19949 .34592 L
.17837 .33746 L
.15995 .32831 L
.14009 .31601 L
.12301 .30269 L
.11043 .29064 L
.09826 .27648 L
.08078 .2498 L
.07294 .23418 L
.06606 .21765 L
.05691 .18943 L
.05134 .1664 L
.04793 .14796 L
.04666 .13939 L
.04567 .13129 L
Mistroke
.04492 .12343 L
.04451 .11707 L
.04432 .11097 L
.04435 .1061 L
.04445 .10365 L
.04461 .10119 L
.04505 .09716 L
.04563 .09387 L
.0464 .09082 L
.04719 .08854 L
.04819 .08632 L
.04954 .08408 L
.05094 .08233 L
.05276 .08061 L
.05469 .07926 L
.05665 .07822 L
.05863 .07742 L
.06099 .0767 L
.06238 .07636 L
.06373 .0761 L
.06636 .0757 L
.06783 .07553 L
.06948 .07539 L
.07128 .07527 L
.07305 .0752 L
.07658 .07514 L
.08013 .07518 L
.08363 .07528 L
.08774 .07548 L
.09242 .07576 L
.11492 .07771 L
.14831 .08115 L
.36532 .10233 L
.51903 .11708 L
.60427 .12647 L
.67692 .13606 L
.74349 .14746 L
.77236 .1539 L
.79807 .16109 L
.81702 .16796 L
.831 .17469 L
.84049 .18094 L
.84462 .18455 L
.84769 .18792 L
.8502 .19156 L
.85189 .19506 L
.85287 .19825 L
.85337 .20177 L
.85327 .20563 L
.85293 .20782 L
Mistroke
.85246 .20981 L
.85109 .21373 L
.84928 .21746 L
.84439 .22483 L
.8384 .23173 L
.82 .24771 L
.79493 .26445 L
.76068 .28311 L
.71801 .30245 L
.67097 .32026 L
.61989 .33624 L
.55725 .35164 L
.52717 .35747 L
.49361 .36282 L
.46361 .36654 L
.44732 .36815 L
.42916 .36958 L
.41827 .37026 L
.40805 .37076 L
.39818 .37113 L
.38756 .3714 L
.36702 .3715 L
.34812 .37111 L
.33649 .37062 L
.32573 .36998 L
.31386 .36908 L
.30129 .36788 L
.28009 .36523 L
.25689 .36133 L
.23556 .35668 L
.21645 .35149 L
.19643 .34481 L
.17552 .33616 L
.15726 .32681 L
.14145 .31695 L
.1139 .29419 L
.10225 .28144 L
.09145 .26715 L
.07579 .24021 L
.06365 .21103 L
.0548 .18142 L
.04989 .15918 L
.04802 .14852 L
.04667 .13948 L
.04573 .13191 L
.04501 .12457 L
.04459 .11862 L
.04437 .1137 L
.04431 .10846 L
.04445 .10353 L
Mistroke
.04477 .09945 L
.0452 .09616 L
.04588 .09278 L
.04633 .09107 L
.0468 .0896 L
.04777 .08718 L
.04897 .08494 L
.05041 .08294 L
.05217 .08112 L
.05403 .07968 L
.05592 .07858 L
.05778 .07774 L
.05999 .07697 L
.06251 .07634 L
.06505 .07588 L
.06783 .07553 L
.06932 .0754 L
.07102 .07529 L
.0742 .07517 L
.0774 .07514 L
.07933 .07516 L
.08144 .07521 L
.08542 .07536 L
.08777 .07548 L
.09003 .07561 L
.09547 .07598 L
.14563 .08087 L
.33567 .09958 L
.50373 .11553 L
.59014 .1248 L
.66411 .13421 L
.72275 .14351 L
.77321 .15411 L
.79434 .15992 L
.81096 .16555 L
.82579 .17194 L
.83203 .17528 L
.83793 .17904 L
.84234 .18245 L
.84622 .1862 L
.84799 .1883 L
.84938 .19023 L
.85149 .19409 L
.85267 .19746 L
.85333 .2012 L
.85331 .20516 L
.85269 .2089 L
.85208 .21106 L
.85121 .21342 L
.84912 .21775 L
Mistroke
.84346 .22601 L
.83418 .23589 L
.82326 .24521 L
.76782 .2795 L
.73076 .29703 L
.6831 .31597 L
.6305 .33319 L
.574 .34795 L
.51766 .35911 L
.48338 .3642 L
.45003 .3679 L
.43063 .36948 L
.42025 .37014 L
.40916 .37071 L
.39934 .37109 L
.38846 .37138 L
.36908 .37152 L
.34994 .37117 L
.32918 .37021 L
.30942 .36869 L
.29132 .36673 L
.26881 .36347 L
.24811 .35955 L
.22571 .35413 L
.20254 .347 L
.16588 .33146 L
.14675 .32047 L
.13023 .30869 L
.10857 .28864 L
.09184 .26772 L
.07727 .24316 L
.06565 .21656 L
.05708 .19003 L
.05161 .16768 L
.04832 .15037 L
.047 .14185 L
.04605 .13462 L
.04537 .12844 L
.04491 .12328 L
.04456 .11806 L
.04436 .11301 L
.04431 .10866 L
.04441 .10442 L
.04464 .10084 L
.04496 .09785 L
.04538 .09515 L
.04586 .09285 L
.04636 .09097 L
.04697 .08911 L
.04773 .08728 L
Mistroke
.04862 .08554 L
.05045 .0829 L
Mfstroke
.83492 .17703 m
.83961 .18026 L
.84325 .18325 L
.8465 .18652 L
.8493 .19012 L
.85122 .1935 L
.85245 .19666 L
.85315 .19973 L
.85341 .20301 L
.85314 .20659 L
.85226 .21049 L
.85088 .21421 L
.84917 .21766 L
.84327 .22624 L
.83556 .23458 L
.815 .25136 L
.79001 .26736 L
.71397 .30411 L
.66277 .32305 L
.60751 .33964 L
.55182 .35276 L
.51809 .35904 L
.48491 .364 L
.46547 .36634 L
.44731 .36815 L
.42666 .36975 L
.41509 .37043 L
.404 .37093 L
.39315 .37127 L
.38151 .37148 L
.37148 .37153 L
.36032 .37142 L
.34828 .37111 L
.3352 .37055 L
.32278 .36978 L
.31134 .36886 L
.29082 .36667 L
.27171 .36395 L
.25085 .36012 L
.22886 .35498 L
.20627 .34827 L
.18569 .34061 L
.16796 .33252 L
.15 .32251 L
.13418 .31174 L
.12092 .30083 L
.0985 .27679 L
.08811 .26212 L
.07849 .24553 L
.06509 .21505 L
Mistroke
.05578 .18524 L
.04966 .15796 L
.04772 .14667 L
.04637 .13721 L
.0455 .12969 L
.04484 .12236 L
.04447 .11622 L
.04432 .11113 L
.04434 .10635 L
.04456 .10185 L
.04492 .09816 L
.04539 .09507 L
.04592 .09258 L
.04661 .09017 L
.04748 .08784 L
.04859 .08559 L
.04991 .08357 L
.05131 .08194 L
.05274 .08063 L
.05418 .07958 L
.05588 .07859 L
.05783 .07772 L
.05998 .07698 L
.0625 .07634 L
.06509 .07587 L
.06765 .07555 L
.07012 .07534 L
.07301 .0752 L
.07625 .07514 L
.07948 .07516 L
.08353 .07528 L
.08766 .07547 L
.09621 .07604 L
.11991 .0782 L
.27417 .09381 L
.55465 .12083 L
.63512 .1303 L
.71149 .14154 L
.74153 .14707 L
.76927 .15314 L
.80853 .16465 L
.8234 .17078 L
.83577 .17758 L
.84051 .18096 L
.84427 .1842 L
.84704 .18713 L
.84949 .19041 L
.85148 .19407 L
.85227 .19609 L
.85281 .19801 L
Mistroke
.85335 .20146 L
.85331 .20522 L
.85302 .20735 L
.85249 .20969 L
.85179 .21191 L
.85098 .21399 L
.849 .21795 L
.84631 .22222 L
.83891 .23119 L
.8283 .24111 L
.80275 .2596 L
.73528 .29504 L
.64813 .32781 L
.58844 .34453 L
.52569 .35774 L
.48873 .36349 L
.4698 .36586 L
.45186 .36773 L
.43559 .36912 L
.41727 .37031 L
.3985 .37112 L
.37821 .37151 L
.36733 .37151 L
.35579 .37133 L
.33497 .37054 L
.32326 .36981 L
.31232 .36895 L
.28742 .36624 L
.26557 .36292 L
.24586 .35906 L
.22335 .35348 L
.20282 .3471 L
.16865 .33286 L
.15185 .32365 L
.13509 .31241 L
.11914 .29921 L
.10565 .28541 L
.09484 .27195 L
.08486 .25689 L
.07054 .22875 L
.06101 .20317 L
.05334 .17542 L
.04893 .15395 L
.04722 .14334 L
.04591 .13344 L
.04514 .12599 L
.0446 .11877 L
.04442 .11511 L
.04433 .112 L
.04431 .10868 L
Mistroke
.04436 .10578 L
.04461 .10115 L
.04484 .0988 L
.04511 .09679 L
.0457 .09354 L
.04639 .09086 L
.0473 .08828 L
.04843 .08587 L
.04981 .08371 L
.05128 .08197 L
.05275 .08062 L
.05452 .07937 L
.05652 .07828 L
.05852 .07746 L
.06091 .07672 L
.06221 .0764 L
.06367 .07611 L
.06627 .07571 L
.06887 .07544 L
.07056 .07531 L
.07222 .07523 L
.0755 .07515 L
.07868 .07515 L
.08228 .07523 L
.08555 .07536 L
.08939 .07557 L
.09883 .07625 L
.10894 .07713 L
.27823 .0942 L
.56465 .12192 L
.64542 .13165 L
.72039 .14309 L
.75109 .14903 L
.77629 .15489 L
.79556 .1603 L
.81333 .16646 L
.82759 .17285 L
.83356 .17619 L
.83905 .17984 L
.84332 .18332 L
.84653 .18655 L
.84911 .18984 L
.85098 .193 L
.85246 .19671 L
.85299 .19881 L
.85328 .20072 L
.85336 .20449 L
.85288 .20808 L
.85236 .21014 L
.85163 .21234 L
Mistroke
.84988 .21631 L
.84737 .22064 L
.8439 .22545 L
.82589 .24311 L
.79777 .26272 L
.72647 .29889 L
.67931 .31733 L
.62948 .33349 L
.56758 .3494 L
.53294 .35643 L
.49332 .36286 L
.47576 .36515 L
.45682 .36725 L
.43888 .36886 L
.42186 .37005 L
.40555 .37087 L
.38785 .37139 L
.36789 .37151 L
.34952 .37115 L
.33889 .37073 L
.32759 .37011 L
.30722 .36848 L
.29584 .36727 L
.2852 .36594 L
.26105 .36211 L
.24014 .35777 L
.22135 .35292 L
.20011 .34615 L
.18088 .33856 L
.1492 .32202 L
.13393 .31155 L
.11888 .29897 L
.10555 .2853 L
.09328 .26977 L
.07578 .24018 L
.06414 .21244 L
.05654 .18808 L
.05092 .1644 L
.04721 .14328 L
.04589 .1333 L
.04507 .12522 L
.04477 .1214 L
.04453 .11748 L
.04437 .1137 L
.04431 .11043 L
.04432 .10757 L
.04438 .10504 L
.04465 .10074 L
.04512 .0967 L
.04547 .09465 L
Mistroke
.04585 .0929 L
.04668 .08993 L
.04762 .0875 L
.04859 .08559 L
.04977 .08377 L
.0512 .08205 L
.0529 .0805 L
.0545 .07938 L
.05641 .07833 L
.05855 .07745 L
.06069 .07678 L
.06324 .07619 L
.06461 .07595 L
.06618 .07572 L
.06898 .07543 L
.07064 .07531 L
.07222 .07523 L
.0753 .07515 L
.07877 .07515 L
.08211 .07523 L
.08592 .07538 L
.08976 .07559 L
.09345 .07584 L
.11418 .07763 L
.29165 .09547 L
.42943 .10831 L
.59393 .12524 L
.67307 .1355 L
.71029 .14133 L
.74571 .14791 L
.77372 .15424 L
.79542 .16025 L
.81387 .16668 L
.82731 .1727 L
.83308 .17589 L
.83844 .1794 L
.84237 .18248 L
.84595 .18591 L
.84896 .18962 L
.85018 .19153 L
.85127 .1936 L
.85264 .19734 L
.8533 .20088 L
.85336 .20448 L
.8528 .20844 L
.85167 .21223 L
.85015 .21578 L
.84604 .2226 L
.84004 .22997 L
.82067 .2472 L
Mistroke
.79591 .26385 L
.76229 .28231 L
.71797 .30247 L
.66872 .32104 L
.61644 .33721 L
.56036 .35098 L
.52924 .3571 L
.4937 .3628 L
.47602 .36512 L
.45687 .36724 L
.43871 .36887 L
.42139 .37008 L
.40488 .37089 L
.38688 .37141 L
.36656 .3715 L
.34776 .37109 L
.3296 .37023 L
.31266 .36898 L
.29399 .36706 L
.27412 .36433 L
.24105 .35798 L
.22254 .35326 L
.20553 .34802 L
.18774 .34145 L
.16951 .33329 L
.13931 .31547 L
.12289 .30258 L
.109 .28911 L
.08746 .2611 L
.07864 .24582 L
.07082 .22943 L
.06024 .20076 L
.05276 .1729 L
.04988 .1591 L
.04784 .14741 L
.04656 .13865 L
.04554 .13013 L
.04491 .12325 L
.04453 .11755 L
.04432 .11154 L
.04433 .10674 L
.04456 .10189 L
.04495 .0979 L
.04544 .09482 L
.04609 .09193 L
.04675 .08974 L
.04758 .08759 L
.04861 .08556 L
.04985 .08365 L
.05116 .0821 L
Mistroke
.05247 .08086 L
.05394 .07974 L
.05566 .07871 L
.05772 .07776 L
.05983 .07702 L
.06226 .07639 L
.06367 .07611 L
.06503 .07588 L
.06759 .07556 L
.07059 .07531 L
.07362 .07518 L
.07668 .07514 L
.07959 .07517 L
.08295 .07526 L
.08685 .07543 L
.09126 .07569 L
.09999 .07634 L
.25117 .0916 L
.38965 .10459 L
.54925 .12025 L
.68436 .13718 L
.74604 .14798 L
.79057 .15879 L
.81008 .16522 L
.82486 .17148 L
.83533 .17729 L
.84379 .18375 L
.8471 .18721 L
.8499 .19105 L
.85099 .19302 L
.85192 .19514 L
.85303 .199 L
.85341 .20292 L
.85313 .20668 L
.85238 .21009 L
.85104 .21384 L
.84899 .21798 L
.84653 .22189 L
.83911 .23098 L
.82956 .24004 L
.81693 .24997 L
.75604 .28539 L
.71431 .30397 L
.66954 .32076 L
.60851 .33937 L
.57918 .34675 L
.54553 .35403 L
.51142 .36013 L
.47839 .36483 L
.44536 .36832 L
Mistroke
.4282 .36965 L
.40899 .37072 L
.3983 .37113 L
.38807 .37139 L
.36866 .37151 L
.35768 .37137 L
.34744 .37108 L
.33614 .3706 L
.32407 .36987 L
.30406 .36817 L
.28521 .36594 L
.26456 .36274 L
.24248 .35831 L
.20464 .34772 L
.1844 .34007 L
.16683 .33194 L
.1513 .32331 L
.13558 .31278 L
.11046 .29067 L
.09845 .27672 L
.08703 .26043 L
.07766 .24393 L
.06938 .22603 L
.05854 .19514 L
.05197 .16938 L
.04754 .1455 L
.04601 .13431 L
.04548 .12952 L
.04508 .12532 L
.04478 .12157 L
.04455 .1178 L
.04433 .11186 L
.04431 .10882 L
.04436 .10584 L
.04446 .10348 L
.04462 .10107 L
.04508 .09695 L
.04567 .09369 L
.04606 .09206 L
.04653 .09041 L
.04752 .08775 L
.04859 .08558 L
.04989 .0836 L
.05113 .08212 L
.05264 .08071 L
.05429 .07951 L
.05597 .07855 L
.05796 .07767 L
.06028 .07689 L
.06153 .07656 L
Mistroke
.06294 .07625 L
.06567 .07579 L
.06855 .07546 L
.07139 .07527 L
.07425 .07517 L
.07708 .07514 L
.08039 .07518 L
.08418 .0753 L
.08844 .07551 L
.09276 .07579 L
.10168 .07648 L
.25705 .09217 L
.53053 .11827 L
.61261 .12747 L
.69243 .13842 L
.75445 .14975 L
.77857 .15548 L
.79782 .161 L
.815 .16713 L
.82766 .17289 L
.83856 .17949 L
.8432 .18322 L
.84675 .1868 L
.84944 .19033 L
.85151 .19414 L
.85267 .19744 L
.85332 .20112 L
.85332 .20512 L
.85301 .2074 L
.85254 .2095 L
.85114 .21361 L
.84922 .21757 L
.84367 .22575 L
.83547 .23466 L
.81528 .25116 L
.78301 .27136 L
.74656 .28991 L
.7064 .30715 L
.65762 .32476 L
.61002 .33897 L
.55318 .35248 L
.51845 .35898 L
.48507 .36398 L
.46841 .36601 L
.44987 .36792 L
.43196 .36938 L
.41508 .37043 L
.39517 .37122 L
.37616 .37152 L
.36514 .37148 L
Mistroke
.35496 .37131 L
.34372 .37094 L
.33181 .37036 L
.3209 .36964 L
.30921 .36867 L
.28808 .36632 L
.26299 .36246 L
.2404 .35783 L
.20396 .34749 L
.18416 .33997 L
.16647 .33176 L
.134 .3116 L
.11803 .29818 L
.10503 .2847 L
.0858 .25844 L
.07708 .24279 L
.07028 .22815 L
.06063 .20199 L
.0536 .17653 L
.04847 .15127 L
.04666 .13937 L
.04551 .12985 L
.04485 .1225 L
.0446 .11873 L
.04444 .11545 L
.04431 .10947 L
.04434 .10647 L
.04443 .10393 L
.04475 .0996 L
.04521 .0961 L
.04589 .09273 L
.04629 .09121 L
.04678 .08964 L
.04772 .08729 L
.04888 .08509 L
.05013 .08329 L
.05139 .08186 L
.053 .08042 L
.05467 .07927 L
.0563 .07839 L
.05821 .07757 L
.06047 .07684 L
.06307 .07622 L
.06547 .07581 L
.0683 .07549 L
.07115 .07528 L
.07393 .07517 L
.07736 .07514 L
.08085 .07519 L
.08427 .07531 L
Mistroke
.08764 .07547 L
.09599 .07602 L
.11703 .07791 L
.14737 .08105 L
.23941 .09046 L
.3739 .10313 L
.55067 .1204 L
.6229 .12874 L
.69266 .13846 L
.72776 .14442 L
.75597 .15008 L
.80035 .16182 L
.81711 .16799 L
.83114 .17476 L
.84023 .18074 L
.84428 .18421 L
.84736 .18752 L
.84877 .18936 L
.85009 .19138 L
.85191 .19511 L
.85299 .1988 L
.85339 .20227 L
.85337 .20441 L
.85316 .20645 L
.85232 .21028 L
.85159 .21246 L
.85076 .21447 L
.84836 .21906 L
.84314 .2264 L
.83678 .23338 L
.81738 .24965 L
.79242 .26594 L
.75955 .28367 L
.67338 .31943 L
.61325 .33809 L
.54991 .35315 L
.52099 .35855 L
.48831 .36355 L
.46887 .36596 L
.45062 .36785 L
.43279 .36932 L
.41363 .3705 L
.39454 .37124 L
.38371 .37146 L
.37379 .37153 L
.35427 .37129 L
.33563 .37057 L
.32497 .36993 L
.31365 .36906 L
.29329 .36697 L
Mistroke
.27136 .36389 L
.24741 .35939 L
.2266 .35438 L
.20774 .34876 L
.18808 .34159 L
.16736 .33221 L
.13568 .31286 L
.12035 .30032 L
.10741 .28737 L
.0871 .26054 L
.07299 .2343 L
.06185 .20577 L
.05399 .17816 L
.04901 .15439 L
.0472 .14323 L
.04596 .13391 L
.04516 .12622 L
.0446 .11887 L
.04435 .113 L
.04431 .1082 L
.04447 .10319 L
.04481 .0991 L
.04508 .09699 L
.04537 .09519 L
.04577 .09325 L
.04618 .09158 L
.04716 .08862 L
.04844 .08587 L
.04974 .0838 L
.05132 .08193 L
.05287 .08053 L
.05475 .07923 L
.05692 .0781 L
.05914 .07724 L
.0614 .07659 L
.06363 .07611 L
.06639 .07569 L
.06922 .07541 L
.07076 .0753 L
.07252 .07522 L
.07444 .07516 L
.07632 .07514 L
.07986 .07517 L
.08196 .07522 L
.08396 .0753 L
.08844 .07551 L
.09374 .07586 L
.10582 .07685 L
.26018 .09247 L
.41412 .10687 L
Mistroke
.58592 .12432 L
.65639 .13313 L
.72151 .14329 L
.75059 .14893 L
.77828 .1554 L
.79803 .16107 L
.81587 .16748 L
.83046 .17438 L
.83587 .17764 L
.84078 .18117 L
.8448 .18472 L
.84775 .18799 L
.85006 .19133 L
.85167 .19451 L
.85288 .1983 L
.85322 .20023 L
.85339 .20236 L
.8532 .20618 L
.85246 .20978 L
.85176 .212 L
.85093 .2141 L
.84893 .21809 L
.84247 .22721 L
.83532 .2348 L
.82602 .243 L
.80518 .25804 L
.74004 .29291 L
.65551 .32544 L
.59821 .34208 L
.53924 .35525 L
.51214 .36002 L
.48194 .36438 L
.46397 .3665 L
.4473 .36815 L
.43116 .36944 L
.41377 .37049 L
.39523 .37122 L
.37787 .37151 L
.35892 .37139 L
.33782 .37068 L
.31941 .36953 L
.29954 .36769 L
.28073 .36532 L
.26361 .36257 L
.22687 .35445 L
.20653 .34835 L
.18801 .34156 L
.15326 .32448 L
.13559 .31279 L
.12081 .30074 L
Mistroke
.09938 .2779 L
.08098 .25017 L
.07362 .23566 L
.06703 .22018 L
.05804 .19344 L
.05115 .16548 L
.04873 .15277 L
.04686 .14088 L
.04572 .13176 L
.04526 .12737 L
.04489 .12299 L
.04446 .11606 L
.04431 .11037 L
.04438 .10523 L
.04451 .10261 L
.04468 .10036 L
.04513 .09662 L
.04579 .09315 L
.0466 .09019 L
.04751 .08776 L
.04845 .08584 L
.04959 .08401 L
.05095 .08232 L
.05233 .08098 L
.05407 .07966 L
.05588 .0786 L
.0577 .07777 L
.05951 .07712 L
.06164 .07653 L
.06408 .07603 L
.06671 .07565 L
.06828 .07549 L
.06977 .07537 L
.07268 .07521 L
.07595 .07514 L
.07779 .07514 L
.07983 .07517 L
.08371 .07529 L
.08622 .0754 L
.08869 .07553 L
.09359 .07585 L
.11632 .07784 L
.14372 .08067 L
.23638 .09016 L
.36385 .10219 L
.53615 .11886 L
.61987 .12837 L
.69147 .13827 L
.74571 .14791 L
.79203 .15923 L
Mistroke
.81145 .16574 L
.82609 .17209 L
.83638 .17797 L
.84461 .18453 L
.84778 .18803 L
.85041 .19194 L
.85142 .19393 L
.85226 .19608 L
.85319 .2 L
.85339 .20398 L
.85293 .20779 L
.85202 .21125 L
.85049 .21506 L
.84859 .21868 L
.84639 .2221 L
.84 .23002 L
.82157 .24651 L
.80024 .26119 L
.77212 .27726 L
.6913 .31296 L
.63436 .33204 L
.5739 .34798 L
.5412 .35487 L
.50866 .36057 L
.47802 .36488 L
.44336 .36849 L
.42472 .36987 L
.41396 .37048 L
.40381 .37094 L
.39298 .37128 L
.38302 .37147 L
.37142 .37153 L
.36032 .37142 L
.3405 .37081 L
.32196 .36972 L
.30149 .3679 L
.27966 .36516 L
.26112 .36212 L
.24099 .35797 L
.22168 .35301 L
.20154 .34665 L
.16736 .33221 L
.13867 .31502 L
.12317 .30283 L
.10815 .28819 L
.09652 .27421 L
.08587 .25856 L
.07013 .22781 L
.06004 .2001 L
.05356 .17634 L
Mistroke
.049 .15431 L
.04747 .14505 L
.04636 .1371 L
.04553 .13002 L
.04498 .12422 L
.04455 .11794 L
.04433 .11203 L
.04433 .10719 L
.04447 .10315 L
.04482 .09897 L
.0453 .09559 L
.04598 .09234 L
.04639 .09087 L
.04688 .08937 L
.04793 .08685 L
.04905 .08483 L
.05044 .08291 L
.0521 .08118 L
.0537 .07991 L
.05534 .07889 L
.05729 .07794 L
.05959 .0771 L
.06167 .07653 L
.06413 .07603 L
.06689 .07563 L
.06966 .07537 L
.07245 .07522 L
.07514 .07515 L
.07846 .07515 L
.08179 .07522 L
.08565 .07537 L
.0902 .07562 L
.10047 .07638 L
.12306 .07852 L
.20038 .08657 L
.32595 .09868 L
.48762 .11392 L
.63906 .13081 L
.71268 .14174 L
.74088 .14694 L
.76774 .15277 L
.78989 .1586 L
.8071 .16413 L
.8216 .16995 L
.83247 .17554 L
.84164 .18186 L
.84536 .18529 L
.84853 .18902 L
.84981 .19091 L
.85097 .19299 L
Mistroke
.85249 .19681 L
.85327 .20059 L
.85338 .20412 L
.85296 .20768 L
.85192 .21155 L
.85041 .21524 L
.84859 .21867 L
.8425 .22717 L
.83466 .23544 L
.81368 .25229 L
.78329 .2712 L
.70471 .30782 L
.61067 .33879 L
.54865 .35341 L
.51048 .36028 L
.4733 .36545 L
.45697 .36723 L
.43908 .36884 L
.42864 .36962 L
.41902 .37021 L
.3999 .37108 L
.37987 .3715 L
.36841 .37151 L
.35771 .37137 L
.33791 .37069 L
.31665 .36931 L
.29806 .36753 L
.27769 .36487 L
.2565 .36125 L
.23699 .35702 L
.2029 .34712 L
.18461 .34016 L
.16868 .33287 L
.13569 .31286 L
.11936 .29941 L
.10595 .28575 L
.08559 .2581 L
.07739 .2434 L
.06982 .22708 L
.05956 .19857 L
.05322 .17491 L
.04852 .15158 L
.04708 .14238 L
.04593 .13361 L
.04516 .12629 L
.0447 .12036 L
.04442 .11501 L
.04431 .11048 L
.04436 .10575 L
.04456 .10189 L
Mistroke
.04492 .09813 L
.04547 .09464 L
.04608 .09196 L
.04688 .08938 L
.04775 .08723 L
.04866 .08548 L
.05065 .08266 L
.05179 .08147 L
.05316 .0803 L
.05473 .07924 L
.05635 .07836 L
.05838 .07751 L
.06039 .07686 L
.0624 .07636 L
.0644 .07598 L
.06673 .07565 L
.0694 .07539 L
.07205 .07524 L
.07465 .07516 L
.07767 .07514 L
.08108 .0752 L
.08423 .07531 L
.08733 .07545 L
.09502 .07595 L
.11056 .07729 L
.13101 .07934 L
Mfstroke
.85227 .19611 m
.85314 .19963 L
.85341 .20288 L
.85313 .20667 L
.85231 .21031 L
.8511 .21371 L
.84959 .21688 L
.8449 .22416 L
.83846 .23166 L
.82952 .24007 L
.80595 .25753 L
.73795 .29385 L
.65081 .32696 L
.59109 .34388 L
.55875 .35132 L
.52698 .35751 L
.49426 .36272 L
.4632 .36659 L
.44485 .36836 L
.42718 .36971 L
.40815 .37076 L
.39727 .37116 L
.38716 .3714 L
.36726 .3715 L
.35598 .37133 L
.34561 .37102 L
.32531 .36996 L
.30593 .36835 L
.29497 .36717 L
.28332 .36568 L
.26243 .36236 L
.24015 .35777 L
.21602 .35136 L
.19367 .34378 L
.17405 .33548 L
.15414 .32501 L
.13411 .31169 L
.10525 .28496 L
.09237 .26848 L
.08219 .25233 L
.06696 .21999 L
.05749 .19152 L
.05086 .16407 L
.04859 .15198 L
.04681 .14046 L
.0457 .13159 L
.045 .1244 L
.04456 .11799 L
.04434 .11258 L
.04433 .10705 L
Mistroke
.04451 .10256 L
.04491 .09826 L
.04521 .09611 L
.04554 .09431 L
.04622 .09144 L
.04709 .08879 L
.04795 .0868 L
.04902 .08487 L
.05031 .08306 L
.05186 .0814 L
.05348 .08006 L
.0551 .07902 L
.05675 .07818 L
.05864 .07742 L
.06087 .07673 L
.0631 .07621 L
.06532 .07584 L
.06754 .07556 L
.07013 .07534 L
.0731 .0752 L
.07649 .07514 L
.07978 .07517 L
.08386 .07529 L
.08798 .07549 L
.09607 .07603 L
.10599 .07686 L
.16763 .08318 L
.4227 .10768 L
.59416 .12527 L
.67148 .13527 L
.73196 .14521 L
.7826 .15655 L
.80437 .16317 L
.82105 .1697 L
.82832 .17323 L
.83495 .17705 L
.8398 .18041 L
.84416 .1841 L
.84784 .18811 L
.85042 .19195 L
.85154 .1942 L
.85243 .19659 L
.85296 .19865 L
.8533 .20092 L
.85333 .20494 L
.85274 .2087 L
.8522 .21068 L
.85143 .21288 L
.84933 .21737 L
.84689 .22137 L
Mistroke
.84369 .22572 L
.83645 .23371 L
.81647 .25031 L
.79248 .26591 L
.75855 .28417 L
.71414 .30404 L
.61328 .33808 L
.58381 .34565 L
.54996 .35314 L
.51838 .35899 L
.48327 .36421 L
.44998 .36791 L
.43046 .36949 L
.41186 .37059 L
.39443 .37124 L
.3783 .37151 L
.35942 .3714 L
.34132 .37084 L
.32181 .36971 L
.31063 .3688 L
.30013 .36775 L
.27895 .36506 L
.2562 .36119 L
.23639 .35688 L
.2159 .35132 L
.18083 .33854 L
.16221 .32953 L
.14363 .31842 L
.11427 .29456 L
.09925 .27774 L
.08721 .2607 L
.07806 .24472 L
.06994 .22735 L
.05959 .19865 L
.05308 .17431 L
.05026 .1611 L
.04823 .14981 L
.04673 .13989 L
.04573 .13187 L
.04499 .12423 L
.04451 .11709 L
.04432 .1113 L
.04434 .1065 L
.04443 .10401 L
.04458 .10157 L
.04499 .09763 L
.04529 .09566 L
.04561 .09394 L
.04651 .09047 L
.04737 .08811 L
Mistroke
.04844 .08586 L
.04959 .08401 L
.05078 .08251 L
.05334 .08017 L
.0548 .0792 L
.05653 .07828 L
.05856 .07744 L
.06057 .07681 L
.06308 .07622 L
.06566 .07579 L
.06821 .07549 L
.07073 .0753 L
.07369 .07518 L
.07707 .07514 L
.08069 .07519 L
.08285 .07525 L
.08496 .07534 L
.08944 .07557 L
.09463 .07592 L
.11604 .07782 L
.19033 .08554 L
.45298 .11055 L
.62158 .12858 L
.70494 .14044 L
.73883 .14653 L
.76664 .15251 L
.80648 .16391 L
.82235 .17029 L
.82915 .17367 L
.83555 .17743 L
.8405 .18094 L
.84484 .18477 L
.84842 .18887 L
.8497 .19073 L
.85086 .19276 L
.85179 .19481 L
.85246 .19672 L
.85326 .20051 L
.85339 .204 L
.85294 .20774 L
.85193 .21152 L
.85019 .21569 L
.84798 .21969 L
.84544 .22343 L
.83143 .2384 L
.80934 .25528 L
.77875 .27371 L
.70479 .30779 L
.61808 .33675 L
.56076 .35089 L
Mistroke
.52672 .35755 L
.49321 .36287 L
.46324 .36658 L
.44739 .36814 L
.42981 .36954 L
.41017 .37067 L
.39121 .37132 L
.37245 .37153 L
.35486 .3713 L
.33565 .37057 L
.31475 .36916 L
.29492 .36717 L
.27672 .36473 L
.2566 .36127 L
.23484 .3565 L
.21233 .35023 L
.19253 .34334 L
.15414 .32501 L
.13522 .31252 L
.11909 .29917 L
.09494 .27208 L
.08397 .2554 L
.07548 .23958 L
.06316 .20963 L
.05549 .18415 L
.04979 .15861 L
.04801 .14848 L
.04658 .13881 L
.04568 .13145 L
.04498 .12418 L
.04457 .11828 L
.04436 .11331 L
.04431 .10812 L
.04443 .10389 L
.04473 .09979 L
.04523 .09601 L
.04591 .09264 L
.04668 .08996 L
.04773 .08727 L
.04889 .08508 L
.05011 .08332 L
.05135 .0819 L
.05285 .08055 L
.05459 .07932 L
.05651 .07828 L
.05878 .07737 L
.06111 .07666 L
.06342 .07615 L
.0649 .0759 L
.06634 .0757 L
Mistroke
.06798 .07552 L
.06981 .07536 L
.07163 .07526 L
.07342 .07519 L
.07697 .07514 L
.08035 .07518 L
.08422 .07531 L
.08813 .0755 L
.09192 .07573 L
.11338 .07756 L
.17895 .08436 L
.40343 .10587 L
.55731 .12112 L
.6389 .13079 L
.70668 .14073 L
.76606 .15238 L
.79116 .15897 L
.81313 .16638 L
.82799 .17305 L
.83454 .17679 L
.8397 .18033 L
.84371 .18367 L
.84671 .18675 L
.84937 .19023 L
.85145 .19399 L
.8527 .19754 L
.8533 .2009 L
.85335 .20464 L
.85274 .20871 L
.85217 .21077 L
.85137 .21303 L
.84943 .21718 L
.84416 .22512 L
.83737 .23278 L
.82833 .24109 L
.80772 .25637 L
.77406 .27624 L
.7352 .29508 L
.6948 .31164 L
.64419 .32904 L
.59185 .34368 L
.52919 .35711 L
.49153 .36311 L
.45539 .36739 L
.43735 .36898 L
.4277 .36968 L
.41734 .37031 L
.39804 .37114 L
.3799 .3715 L
.36184 .37144 L
Mistroke
.34511 .371 L
.3256 .36998 L
.3069 .36845 L
.28966 .36652 L
.27364 .36425 L
.23761 .35717 L
.21751 .35181 L
.19904 .34577 L
.16632 .33169 L
.14934 .3221 L
.13477 .31218 L
.11932 .29938 L
.10622 .28605 L
.09546 .27279 L
.08528 .25759 L
.0711 .23007 L
.0596 .19868 L
.05267 .17253 L
.04879 .15312 L
.04614 .13535 L
.0453 .12778 L
.04471 .12055 L
.0444 .11453 L
.04431 .10963 L
.04439 .10482 L
.04468 .10031 L
.04513 .0966 L
.04568 .09362 L
.04649 .09055 L
.04755 .08768 L
.04872 .08536 L
.04996 .08351 L
.05139 .08186 L
.05287 .08053 L
.05466 .07928 L
.05677 .07817 L
.05921 .07722 L
.06175 .07651 L
.06423 .07601 L
.06571 .07578 L
.06715 .0756 L
.07015 .07534 L
.07175 .07525 L
.07358 .07518 L
.07699 .07514 L
.08041 .07518 L
.0826 .07524 L
.08475 .07533 L
.089 .07555 L
.09972 .07632 L
Mistroke
.15314 .08166 L
.3527 .10116 L
.50868 .11603 L
.59682 .12558 L
.67295 .13548 L
.72873 .1446 L
.77742 .15518 L
.7985 .16122 L
.81671 .16783 L
.82914 .17367 L
.8396 .18026 L
.84401 .18396 L
.84729 .18743 L
.85004 .1913 L
.85111 .19327 L
.85204 .19546 L
.85306 .19918 L
.85333 .20129 L
.85341 .20323 L
.85307 .20704 L
.85219 .21071 L
.85086 .21425 L
.84894 .21807 L
.84422 .22504 L
.83664 .23351 L
.82805 .24132 L
.80323 .25929 L
.76849 .27915 L
.72885 .29786 L
.68584 .31498 L
.63579 .33162 L
.58463 .34545 L
.52128 .3585 L
.48345 .36419 L
.46575 .36631 L
.44576 .36828 L
.42618 .36978 L
.40745 .37079 L
.38728 .3714 L
.37579 .37152 L
.36519 .37149 L
.34617 .37104 L
.32516 .36995 L
.30517 .36828 L
.28654 .36612 L
.2631 .36248 L
.24121 .35802 L
.20144 .34662 L
.18023 .33828 L
.1617 .32926 L
Mistroke
.14171 .31713 L
.12448 .30396 L
.11173 .29199 L
.09938 .27791 L
.08161 .2513 L
.07362 .23567 L
.06661 .2191 L
.05727 .19074 L
.05157 .16751 L
.04807 .14888 L
.04575 .13202 L
.04497 .12407 L
.04454 .11764 L
.04433 .11186 L
.04434 .10645 L
.04455 .10198 L
.04489 .0984 L
.04546 .09469 L
.04586 .09282 L
.04628 .09123 L
.04717 .08859 L
.04828 .08616 L
.04949 .08416 L
.05096 .08231 L
.05251 .08082 L
.05407 .07965 L
.05608 .0785 L
.05848 .07747 L
.06099 .0767 L
.06351 .07614 L
.06623 .07571 L
.06768 .07555 L
.06933 .0754 L
.07243 .07522 L
.07554 .07515 L
.07753 .07514 L
.07949 .07516 L
.08336 .07527 L
.08565 .07537 L
.08785 .07548 L
.09312 .07581 L
.11362 .07758 L
.142 .08049 L
.32834 .0989 L
.47564 .11274 L
.55856 .12126 L
.64175 .13116 L
.70653 .1407 L
.7364 .14606 L
.76451 .15201 L
Mistroke
.78688 .15773 L
.80419 .16311 L
.81881 .16872 L
.82997 .17411 L
.83986 .18045 L
.84394 .18389 L
.84746 .18764 L
.84891 .18955 L
.85024 .19164 L
.85205 .19549 L
.85308 .1993 L
.8534 .20288 L
.85319 .20623 L
.85256 .20943 L
.85139 .21297 L
.84961 .21684 L
.84437 .22485 L
.83778 .23236 L
.81854 .24879 L
.79007 .26733 L
.75301 .28686 L
.7112 .30524 L
.66544 .32215 L
.60886 .33928 L
.55091 .35295 L
.52308 .35819 L
.49172 .36308 L
.47343 .36543 L
.4563 .3673 L
.4385 .36889 L
.42164 .37006 L
.4017 .37101 L
.39101 .37133 L
.37951 .3715 L
.36844 .37151 L
.35793 .37137 L
.3381 .37069 L
.31681 .36933 L
.30603 .36836 L
.29418 .36708 L
.27319 .36418 L
.2537 .3607 L
.23095 .35552 L
.21065 .3497 L
.1879 .34151 L
.16758 .33232 L
.13728 .31402 L
.12293 .30262 L
.10899 .2891 L
.09682 .2746 L
Mistroke
.08578 .25842 L
.07037 .22838 L
.06033 .20105 L
.05389 .17775 L
.04923 .15559 L
.04624 .13619 L
.04524 .12708 L
.04466 .11974 L
.04447 .11627 L
.04435 .11273 L
.04431 .10932 L
.04434 .10637 L
.04444 .10379 L
.04458 .10151 L
.04499 .09764 L
.0456 .09401 L
.04603 .09217 L
.04647 .0906 L
.04744 .08793 L
.0485 .08576 L
.04957 .08405 L
.05085 .08243 L
.05242 .0809 L
.05425 .07954 L
.05596 .07855 L
.05801 .07765 L
.0603 .07689 L
.06259 .07632 L
.06531 .07584 L
.06677 .07565 L
.06845 .07547 L
.07142 .07527 L
.07319 .0752 L
.07487 .07516 L
.07831 .07515 L
.08181 .07522 L
.08537 .07536 L
.08941 .07557 L
.09739 .07613 L
.11931 .07814 L
.30538 .09676 L
.46245 .11146 L
.55336 .12069 L
.64507 .1316 L
.71504 .14215 L
.7467 .14812 L
.77599 .15481 L
.79852 .16123 L
.81546 .16731 L
.82909 .17364 L
Mistroke
.83904 .17984 L
.84297 .18301 L
.84647 .18648 L
.84909 .18982 L
.85093 .19291 L
.85236 .19639 L
.85323 .20026 L
.85339 .20223 L
.85337 .20435 L
.85285 .20822 L
.85229 .21037 L
.85162 .21237 L
.84956 .21693 L
.84713 .22101 L
.84396 .22538 L
.82759 .24171 L
.80621 .25736 L
.78128 .27232 L
.70789 .30656 L
.66112 .3236 L
.60295 .34085 L
.57376 .34801 L
.54083 .35495 L
.50823 .36064 L
.47678 .36503 L
.46038 .36688 L
.442 .36861 L
.42311 .36997 L
.41263 .37055 L
.40274 .37098 L
.38424 .37145 L
.36713 .3715 L
.34712 .37107 L
.32796 .37013 L
.31063 .3688 L
.29217 .36684 L
.27639 .36468 L
.25905 .36174 L
.24061 .35788 L
.22105 .35284 L
.18697 .34113 L
.1687 .33289 L
.15299 .32433 L
.13717 .31394 L
.1215 .30135 L
.10844 .2885 L
.09773 .27579 L
.08034 .24901 L
.06663 .21914 L
.05653 .18804 L
Mistroke
.05005 .16001 L
.04658 .13881 L
.04552 .12993 L
.04511 .12569 L
.04477 .12149 L
.04456 .11809 L
.0444 .11458 L
.04431 .10899 L
.04442 .10424 L
.04474 .09977 L
.04522 .09608 L
.0458 .0931 L
.04664 .09006 L
.04758 .0876 L
.04878 .08527 L
.05025 .08314 L
.05201 .08126 L
.05389 .07978 L
.05575 .07866 L
.05797 .07766 L
.0601 .07694 L
.0622 .0764 L
.06482 .07591 L
.0675 .07556 L
.07015 .07534 L
.07277 .07521 L
.07584 .07514 L
.07933 .07516 L
.08144 .07521 L
.08346 .07528 L
.08576 .07537 L
.08828 .07551 L
.09808 .07619 L
.12062 .07827 L
.31013 .0972 L
.45505 .11075 L
.54276 .11956 L
.62343 .12881 L
.69109 .13821 L
.75252 .14934 L
.77492 .15454 L
.79545 .16026 L
.8104 .16534 L
.824 .17106 L
.83562 .17748 L
.84034 .18083 L
.84453 .18446 L
.8477 .18793 L
.84994 .19113 L
.85162 .19439 L
Mistroke
.85269 .19751 L
.85333 .2012 L
.85331 .20516 L
.85276 .20859 L
.85161 .21241 L
.84976 .21656 L
.84708 .22108 L
.84056 .22941 L
.8223 .24595 L
.7987 .26214 L
.73949 .29316 L
.65258 .32639 L
.59384 .34319 L
.56346 .35031 L
.534 .35623 L
.50515 .36112 L
.47204 .3656 L
.45541 .36739 L
.43722 .36899 L
.41758 .37029 L
.39891 .37111 L
.38099 .37149 L
.36123 .37143 L
.34232 .37089 L
.32467 .36991 L
.30868 .36862 L
.29099 .36669 L
.27252 .36408 L
.25527 .36101 L
.23621 .35683 L
.21622 .35142 L
.18171 .33892 L
.16192 .32938 L
.14447 .31898 L
.11567 .29593 L
.10304 .28238 L
.09138 .26705 L
.07472 .238 L
.06761 .22164 L
.06216 .2067 L
.05334 .17542 L
.04876 .15295 L
.04723 .14341 L
.04615 .13546 L
.04543 .12907 L
.04486 .1227 L
.0445 .11696 L
.04432 .11153 L
.04434 .10634 L
.04454 .10215 L
Mistroke
.04493 .0981 L
.04552 .09439 L
.04619 .09156 L
.04693 .08922 L
.04787 .08697 L
.04903 .08486 L
.05031 .08307 L
.05188 .08138 L
.05372 .07989 L
.05563 .07873 L
.05758 .07782 L
.05951 .07712 L
.06191 .07647 L
.06439 .07598 L
.06587 .07576 L
.06727 .07559 L
.06895 .07543 L
.0706 .07531 L
.07371 .07518 L
.07556 .07515 L
.07733 .07514 L
.07933 .07516 L
.08127 .0752 L
.08349 .07528 L
.08596 .07538 L
.09134 .07569 L
.09666 .07607 L
.23511 .09004 L
.3654 .10234 L
.53987 .11925 L
.68278 .13694 L
.71602 .14232 L
.74796 .14838 L
.77399 .1543 L
.79469 .16003 L
.8127 .16622 L
.82597 .17203 L
.83744 .1787 L
.84235 .18246 L
.8461 .18607 L
.84898 .18965 L
.85122 .1935 L
.8525 .19683 L
.85326 .20055 L
.8534 .20266 L
.85336 .2046 L
.8531 .20686 L
.85266 .20902 L
.85142 .21289 L
.85047 .21511 L
Mistroke
.84943 .21717 L
.84429 .22495 L
.83772 .23243 L
.82127 .24674 L
.798 .26258 L
.76687 .27999 L
.68938 .31367 L
.63542 .33173 L
.57831 .34696 L
.5444 .35425 L
.51044 .36029 L
.47838 .36483 L
.45977 .36695 L
.44192 .36861 L
.42238 .37002 L
.41184 .37059 L
.40038 .37106 L
.38827 .37138 L
.37663 .37152 L
.36609 .37149 L
.35449 .37129 L
.33335 .37045 L
.32143 .36968 L
.31058 .36879 L
.28937 .36649 L
.26938 .36356 L
.2505 .36005 L
.2305 .3554 L
.19552 .34447 L
.17524 .33603 L
.15706 .32669 L
.1264 .30558 L
.11277 .29305 L
.09991 .27858 L
.0811 .25039 L
.07292 .23415 L
.06656 .21895 L
.05603 .1862 L
.0507 .16331 L
.04719 .14313 L
.04543 .12904 L
.04483 .12223 L
.04448 .11657 L
.04431 .11072 L
.04436 .10587 L
.04455 .102 L
.0449 .09828 L
.04546 .09472 L
.0458 .09309 L
.04622 .09144 L
Mistroke
.04709 .0888 L
.04803 .08663 L
.04921 .08458 L
.05062 .08269 L
.05212 .08117 L
.0536 .07998 L
.05553 .07878 L
.05783 .07772 L
.06021 .07691 L
.06259 .07632 L
.065 .07588 L
.06742 .07557 L
.07026 .07533 L
.07353 .07518 L
.07528 .07515 L
.07724 .07514 L
.08102 .0752 L
.08498 .07534 L
.08889 .07554 L
.09704 .0761 L
.10563 .07683 L
.12915 .07914 L
.19835 .08636 L
.44046 .10935 L
.52543 .11774 L
.61458 .12771 L
.68449 .1372 L
.74801 .14839 L
.77685 .15503 L
.79911 .16142 L
.81655 .16776 L
.83106 .17472 L
.83612 .17781 L
.84079 .18117 L
.84419 .18413 L
.84726 .18739 L
.8488 .1894 L
.85003 .19127 L
.85187 .19501 L
.85291 .19846 L
.85339 .20217 L
.8532 .20615 L
.85244 .20985 L
.85099 .21396 L
.85002 .21605 L
.84877 .21836 L
.84303 .22653 L
.83582 .23431 L
.81323 .25261 L
.78047 .27277 L
Mistroke
.70169 .309 L
.64587 .32852 L
.58676 .34494 L
.52887 .35717 L
.4933 .36286 L
.45825 .3671 L
.43866 .36888 L
.41962 .37018 L
.4022 .371 L
.38285 .37147 L
.37171 .37153 L
.36154 .37144 L
.3497 .37116 L
.33848 .37071 L
.31832 .36945 L
.30691 .36845 L
.29639 .36734 L
.27572 .36458 L
.25622 .3612 L
.22028 .35261 L
.2008 .34639 L
.18338 .33964 L
.16398 .33047 L
.14689 .32056 L
.12156 .30141 L
.1088 .28889 L
.09834 .27659 L
.08073 .24972 L
.06689 .21981 L
.05723 .19059 L
.05136 .16651 L
.04738 .14447 L
.04599 .13414 L
.04513 .12591 L
.04482 .1221 L
.04457 .11834 L
.04434 .11224 L
.04431 .10919 L
.04434 .10653 L
.04444 .10382 L
.04461 .10113 L
.04482 .09899 L
.0451 .09683 L
.04575 .0933 L
.04656 .09032 L
.04745 .08791 L
.04851 .08573 L
.04978 .08375 L
.051 .08227 L
.05246 .08086 L
Mistroke
.05421 .07956 L
.05627 .0784 L
.0584 .0775 L
.06051 .07683 L
.0628 .07627 L
.06508 .07587 L
.06777 .07554 L
.07083 .0753 L
.07368 .07518 L
.07653 .07514 L
.07985 .07517 L
.08368 .07528 L
.08751 .07546 L
.0913 .07569 L
.10078 .07641 L
.12163 .07837 L
.17673 .08413 L
Mfstroke
.85337 .20189 m
.85328 .20549 L
.85271 .2088 L
.85151 .21268 L
.84985 .21638 L
.8457 .22308 L
.83956 .23049 L
.81987 .24781 L
.7952 .26428 L
.7274 .29849 L
.63059 .33316 L
.57354 .34806 L
.53921 .35526 L
.50466 .36119 L
.47098 .36572 L
.45121 .36779 L
.43242 .36935 L
.41469 .37045 L
.39833 .37113 L
.37913 .37151 L
.36077 .37143 L
.34022 .37079 L
.32845 .37016 L
.31741 .36937 L
.29503 .36718 L
.28246 .36556 L
.27101 .36383 L
.25067 .36008 L
.22882 .35497 L
.19052 .34256 L
.17045 .33375 L
.1497 .32233 L
.12991 .30844 L
.11337 .29365 L
.08914 .2637 L
.0785 .24555 L
.07049 .22865 L
.05965 .19885 L
.05308 .17432 L
.04831 .15031 L
.04687 .14094 L
.04575 .13209 L
.04508 .12533 L
.0446 .11871 L
.04436 .11335 L
.04431 .10887 L
.04442 .10417 L
.04468 .10038 L
.04515 .09652 L
.04575 .09332 L
Mistroke
.04658 .09027 L
.04747 .08786 L
.04867 .08545 L
.04996 .0835 L
.05131 .08194 L
.05267 .08069 L
.0543 .07951 L
.05618 .07845 L
.05826 .07755 L
.0607 .07677 L
.0632 .07619 L
.06566 .07579 L
.06725 .07559 L
.06878 .07544 L
.07053 .07532 L
.07247 .07522 L
.07594 .07514 L
.07802 .07514 L
.08006 .07517 L
.08371 .07529 L
.08787 .07548 L
.09613 .07603 L
.11911 .07812 L
.18906 .08541 L
.42346 .10775 L
.5945 .12531 L
.68252 .1369 L
.74937 .14867 L
.79416 .15987 L
.81366 .16659 L
.8281 .17311 L
.83446 .17674 L
.83958 .18024 L
.84349 .18347 L
.84689 .18696 L
.84975 .19081 L
.85164 .19443 L
.85239 .19646 L
.8529 .19839 L
.85326 .20051 L
.8534 .20283 L
.85313 .20668 L
.85234 .21022 L
.85081 .21437 L
.84879 .21833 L
.84386 .22551 L
.8367 .23345 L
.81408 .25201 L
.78604 .26965 L
.7093 .306 L
Mistroke
.66082 .3237 L
.5996 .34172 L
.57013 .34883 L
.53605 .35585 L
.50433 .36124 L
.48626 .36382 L
.46881 .36597 L
.45129 .36778 L
.43192 .36939 L
.41394 .37049 L
.39711 .37116 L
.38096 .37149 L
.363 .37146 L
.344 .37095 L
.32608 .37001 L
.30492 .36825 L
.29293 .36693 L
.28183 .36548 L
.26192 .36227 L
.24014 .35777 L
.2034 .3473 L
.18416 .33997 L
.16689 .33198 L
.14893 .32185 L
.13151 .3097 L
.10471 .28433 L
.09236 .26847 L
.08256 .25297 L
.07353 .23546 L
.06581 .21699 L
.05611 .1865 L
.05044 .16201 L
.04679 .14035 L
.04555 .13017 L
.04514 .12607 L
.0448 .12191 L
.04443 .11523 L
.04431 .10967 L
.04439 .1049 L
.04462 .101 L
.04509 .09692 L
.04567 .0937 L
.04605 .09208 L
.04651 .09046 L
.04748 .08784 L
.04849 .08576 L
.04956 .08406 L
.05085 .08243 L
.0524 .08092 L
.05419 .07958 L
Mistroke
.05606 .07851 L
.05788 .0777 L
.06001 .07697 L
.06201 .07645 L
.06436 .07599 L
.06701 .07562 L
.06967 .07537 L
.07232 .07523 L
.0749 .07516 L
.07805 .07515 L
.08125 .0752 L
.08517 .07535 L
.08751 .07546 L
.08974 .07559 L
.09892 .07625 L
.1197 .07818 L
.18878 .08538 L
.42078 .1075 L
.57231 .12277 L
.65147 .13246 L
.71703 .14249 L
.74871 .14853 L
.77831 .15541 L
.79896 .16137 L
.81763 .16821 L
.83134 .17488 L
.83699 .17838 L
.84207 .18223 L
.84592 .18587 L
.84871 .18927 L
.85075 .19256 L
.85226 .19608 L
.85316 .19977 L
.85337 .20188 L
.85339 .20384 L
.853 .20747 L
.85198 .21137 L
.85057 .2149 L
.84884 .21824 L
.84349 .22597 L
.83565 .23449 L
.82672 .24243 L
.80096 .26073 L
.7372 .29419 L
.65644 .32514 L
.60203 .34109 L
.54692 .35375 L
.51389 .35973 L
.47621 .3651 L
.45822 .36711 L
Mistroke
.43879 .36887 L
.42183 .37005 L
.40289 .37097 L
.38369 .37146 L
.36523 .37149 L
.34845 .37112 L
.33003 .37026 L
.30983 .36872 L
.28829 .36635 L
.2699 .36365 L
.24974 .35989 L
.21458 .35092 L
.19549 .34446 L
.17863 .33757 L
.14958 .32225 L
.12267 .30239 L
.10947 .28962 L
.09686 .27466 L
.08721 .26071 L
.07844 .24545 L
.06556 .21631 L
.0573 .19083 L
.05102 .16486 L
.04741 .14462 L
.04607 .13478 L
.04522 .12686 L
.04488 .12288 L
.0446 .11886 L
.04443 .11533 L
.04434 .11228 L
.04432 .10777 L
.04446 .10343 L
.04473 .09979 L
.0451 .0968 L
.04563 .09385 L
.04635 .09099 L
.04726 .08837 L
.04823 .08625 L
.04941 .08427 L
.05066 .08264 L
.05336 .08015 L
.05508 .07903 L
.05681 .07815 L
.05886 .07734 L
.06122 .07664 L
.06358 .07612 L
.06635 .0757 L
.06918 .07541 L
.072 .07524 L
.07498 .07515 L
Mistroke
.07785 .07514 L
.08139 .07521 L
.08494 .07534 L
.0891 .07555 L
.0938 .07586 L
.10311 .07661 L
.12894 .07912 L
.29436 .09573 L
.44734 .11001 L
.60821 .12694 L
.67221 .13537 L
.73112 .14505 L
.75737 .15039 L
.78252 .15653 L
.80088 .162 L
.81701 .16795 L
.83094 .17465 L
.84058 .18101 L
.84472 .18464 L
.84781 .18807 L
.85039 .19189 L
.85148 .19406 L
.85225 .19605 L
.85314 .19968 L
.85341 .20308 L
.8531 .20685 L
.85213 .21091 L
.85076 .21447 L
.84907 .21784 L
.84375 .22564 L
.83552 .23461 L
.82565 .2433 L
.80212 .26 L
.76657 .28014 L
.72748 .29846 L
.63698 .33126 L
.57728 .3472 L
.54746 .35364 L
.51428 .35967 L
.48418 .36409 L
.46771 .36609 L
.44968 .36793 L
.43272 .36933 L
.417 .37033 L
.40093 .37104 L
.38549 .37143 L
.36729 .3715 L
.34771 .37109 L
.33082 .3703 L
.31206 .36893 L
Mistroke
.29184 .3668 L
.27007 .36368 L
.24964 .35987 L
.23115 .35557 L
.21091 .34978 L
.19239 .34329 L
.15978 .32822 L
.14301 .31801 L
.12872 .30748 L
.11359 .29387 L
.10107 .28 L
.08378 .25507 L
.06956 .22645 L
.05979 .19931 L
.05278 .17298 L
.04805 .14874 L
.04638 .1373 L
.04533 .12807 L
.04474 .12101 L
.04452 .11737 L
.04439 .11418 L
.04431 .10839 L
.04437 .10546 L
.04448 .10298 L
.04482 .09901 L
.04527 .09574 L
.04592 .09259 L
.04678 .08965 L
.04786 .08699 L
.04905 .08482 L
.05025 .08313 L
.05171 .08155 L
.05328 .08021 L
.05485 .07917 L
.05683 .07814 L
.05887 .07733 L
.06091 .07672 L
.06293 .07625 L
.06531 .07584 L
.06803 .07551 L
.06967 .07537 L
.07125 .07528 L
.07305 .0752 L
.07503 .07515 L
.07857 .07515 L
.08069 .07519 L
.08274 .07525 L
.0868 .07543 L
.09075 .07565 L
.10057 .07639 L
Mistroke
.25588 .09206 L
.39419 .10501 L
.57105 .12263 L
.64103 .13107 L
.70801 .14095 L
.74111 .14698 L
.76765 .15275 L
.78937 .15844 L
.80881 .16475 L
.824 .17106 L
.83486 .17699 L
.83914 .17991 L
.8431 .18313 L
.8462 .18618 L
.84857 .18908 L
.85072 .1925 L
.85234 .19632 L
.8532 .2001 L
.85339 .20224 L
.85338 .20421 L
.85294 .20776 L
.85187 .21168 L
.85032 .21542 L
.84844 .21893 L
.84237 .22733 L
.8347 .2354 L
.81571 .25085 L
.7534 .28667 L
.66896 .32096 L
.61738 .33695 L
.55353 .35241 L
.52292 .35822 L
.49255 .36296 L
.47518 .36522 L
.45584 .36735 L
.43939 .36882 L
.4209 .3701 L
.40317 .37096 L
.38628 .37142 L
.36818 .37151 L
.34844 .37112 L
.32993 .37025 L
.3122 .36894 L
.29621 .36732 L
.27874 .36503 L
.25707 .36136 L
.23733 .3571 L
.21645 .35149 L
.19421 .34398 L
.15911 .32785 L
Mistroke
.14161 .31707 L
.12659 .30574 L
.11326 .29354 L
.10193 .28106 L
.08419 .25577 L
.06989 .22723 L
.05911 .19708 L
.05216 .17024 L
.04757 .14568 L
.04614 .13541 L
.04558 .13054 L
.04512 .12578 L
.0448 .12189 L
.04455 .11793 L
.04433 .11169 L
.04435 .10616 L
.04456 .10176 L
.04476 .09956 L
.04503 .09735 L
.04565 .09376 L
.0464 .09082 L
.04736 .08812 L
.04831 .0861 L
.04949 .08416 L
.05089 .08238 L
.05234 .08096 L
.0541 .07963 L
.05617 .07845 L
.05834 .07752 L
.06056 .07681 L
.06271 .07629 L
.06521 .07585 L
.06768 .07555 L
.07058 .07531 L
.07384 .07518 L
.07711 .07514 L
.08038 .07518 L
.08354 .07528 L
.08742 .07546 L
.09133 .07569 L
.11305 .07752 L
.13924 .0802 L
.228 .08934 L
.35122 .10102 L
.52136 .11732 L
.6016 .12615 L
.6789 .13636 L
.73524 .14583 L
.78426 .157 L
.80494 .16337 L
Mistroke
.82082 .1696 L
.8322 .17538 L
.8416 .18183 L
.84534 .18527 L
.84859 .1891 L
.8499 .19106 L
.85107 .19318 L
.85256 .19705 L
.8533 .20097 L
.85335 .20473 L
.85286 .20816 L
.85178 .21193 L
.85029 .21548 L
.84848 .21886 L
.84291 .22668 L
.83567 .23447 L
.82599 .24303 L
.77888 .27364 L
.70545 .30753 L
.65385 .32598 L
.59906 .34186 L
.56642 .34966 L
.5337 .35629 L
.50236 .36154 L
.46748 .36612 L
.44875 .36802 L
.43864 .36888 L
.42763 .36968 L
.40798 .37077 L
.38923 .37136 L
.37785 .37151 L
.36532 .37149 L
.35337 .37127 L
.34221 .37088 L
.32095 .36965 L
.309 .36865 L
.29814 .36754 L
.27845 .36499 L
.26012 .36194 L
.23853 .35739 L
.21917 .35229 L
.18127 .33873 L
.16178 .32931 L
.14451 .31901 L
.11734 .29753 L
.09662 .27434 L
.07893 .24637 L
.07188 .23184 L
.06542 .21594 L
.05567 .18483 L
Mistroke
.05008 .16016 L
.04649 .13812 L
.04542 .12896 L
.04499 .12434 L
.04469 .12029 L
.0445 .11698 L
.04437 .11363 L
.04431 .10833 L
.04436 .10562 L
.04448 .10295 L
.04486 .09866 L
.04537 .0952 L
.04598 .09235 L
.0468 .08959 L
.04785 .08702 L
.04908 .08478 L
.05034 .08302 L
.05198 .08129 L
.0537 .07991 L
.05545 .07883 L
.0572 .07798 L
.05928 .0772 L
.06165 .07653 L
.06427 .076 L
.06584 .07576 L
.06732 .07558 L
.07038 .07533 L
.07349 .07519 L
.07535 .07515 L
.07741 .07514 L
.07924 .07516 L
.08133 .07521 L
.08366 .07528 L
.08628 .0754 L
.09133 .07569 L
.10129 .07645 L
.11388 .0776 L
.14225 .08051 L
.21994 .08854 L
.35729 .10159 L
.52519 .11772 L
.67289 .13547 L
.7406 .14688 L
.76565 .15228 L
.78884 .15829 L
.80795 .16444 L
.82224 .17024 L
.83368 .17626 L
.84197 .18214 L
.84559 .18553 L
Mistroke
.84865 .18918 L
.85064 .19235 L
.8522 .1959 L
.85315 .19975 L
.85338 .20194 L
.85339 .20397 L
.85294 .20774 L
.85184 .21177 L
.85016 .21576 L
.84814 .21943 L
.84197 .2278 L
.83435 .23573 L
.82559 .24335 L
.80102 .26069 L
.76646 .2802 L
.68724 .31447 L
.634 .33215 L
.57754 .34714 L
.54814 .35351 L
.51877 .35893 L
.49086 .3632 L
.45987 .36694 L
.4417 .36863 L
.42489 .36986 L
.40767 .37078 L
.3912 .37132 L
.37161 .37153 L
.35334 .37126 L
.33304 .37043 L
.32275 .36978 L
.31142 .36887 L
.29003 .36657 L
.27026 .36371 L
.24869 .35967 L
.22611 .35424 L
.1896 .34219 L
.16999 .33352 L
.15263 .32411 L
.13797 .31452 L
.12373 .30332 L
.10164 .2807 L
.08286 .2535 L
.07444 .23741 L
.06792 .22244 L
.05716 .19034 L
.05081 .16386 L
.04733 .14409 L
.04605 .13462 L
.04522 .12689 L
.04465 .11956 L
Mistroke
.04437 .11353 L
.04431 .1104 L
.04432 .10774 L
.04439 .10489 L
.04452 .10238 L
.0447 .10013 L
.04495 .0979 L
.04554 .09431 L
.04594 .09253 L
.04636 .09097 L
.04748 .08783 L
.0485 .08575 L
.04974 .0838 L
.05105 .08222 L
.05235 .08096 L
.05404 .07968 L
.05605 .07851 L
.05814 .0776 L
.06023 .0769 L
.06256 .07633 L
.06491 .0759 L
.06768 .07555 L
.06933 .0754 L
.07091 .07529 L
.07424 .07517 L
.07624 .07514 L
.07818 .07515 L
.08192 .07522 L
.08413 .0753 L
.08621 .0754 L
.09468 .07592 L
.10351 .07664 L
.12771 .079 L
.19097 .08561 L
.45846 .11108 L
.54459 .11975 L
.62371 .12884 L
.6931 .13853 L
.74724 .14823 L
.78911 .15837 L
.80602 .16375 L
.82147 .16989 L
.83364 .17623 L
.83878 .17965 L
.84331 .18331 L
.84655 .18657 L
.84936 .1902 L
.85125 .19355 L
.85246 .19671 L
.85324 .2004 L
Mistroke
.8534 .2025 L
.85337 .20446 L
.85287 .20808 L
.85177 .21197 L
.85029 .2155 L
.8485 .21883 L
.84303 .22653 L
.83508 .23503 L
.82609 .24294 L
.80025 .26118 L
.73256 .29625 L
.64837 .32774 L
.59021 .34409 L
.53114 .35676 L
.49566 .36252 L
.47624 .36509 L
.45519 .36741 L
.43625 .36907 L
.42605 .36979 L
.415 .37043 L
.39527 .37122 L
.37655 .37152 L
.35712 .37136 L
.34596 .37103 L
.33543 .37056 L
.31407 .3691 L
.302 .36795 L
.29094 .36669 L
.25197 .36035 L
.23266 .35596 L
.21197 .35011 L
.17042 .33374 L
.14917 .322 L
.13149 .30968 L
.11654 .29677 L
.10223 .28141 L
.09062 .26594 L
.08134 .25082 L
.06732 .22091 L
.05697 .18964 L
.05065 .16305 L
.04847 .15125 L
.04672 .13986 L
.04559 .13062 L
.04489 .12309 L
.04449 .11673 L
.04431 .11079 L
.04435 .10613 L
.04453 .10223 L
.04489 .09843 L
Mistroke
.04543 .09484 L
.04615 .09171 L
.04694 .08921 L
.048 .0867 L
.04916 .08465 L
.05037 .08299 L
.05159 .08166 L
.05306 .08038 L
.05478 .07921 L
.05667 .07821 L
.0586 .07743 L
.06109 .07667 L
.06356 .07613 L
.06634 .0757 L
.06802 .07551 L
.06964 .07538 L
.07279 .07521 L
.07465 .07516 L
.0764 .07514 L
.07819 .07515 L
.08022 .07518 L
.08243 .07524 L
.08457 .07532 L
.08861 .07552 L
.09325 .07582 L
.11777 .07799 L
.18564 .08506 L
.43833 .10915 L
.61211 .12741 L
.69064 .13814 L
.72974 .14479 L
.76092 .15119 L
.78453 .15708 L
.8061 .16378 L
.8234 .17078 L
.83113 .17476 L
.83708 .17845 L
.84156 .1818 L
.84555 .18548 L
.84883 .18944 L
.8511 .19324 L
.85251 .19686 L
.85328 .20074 L
.85338 .20411 L
.85292 .20785 L
.85181 .21185 L
.85019 .2157 L
.84828 .2192 L
.84573 .22304 L
.83832 .23181 L
Mistroke
.82948 .2401 L
.78118 .27237 L
.74521 .29054 L
.69922 .30996 L
.65246 .32643 L
.59663 .34248 L
.54008 .35509 L
.50539 .36108 L
.47137 .36568 L
.45469 .36746 L
.4386 .36888 L
.4239 .36992 L
.40766 .37078 L
.38969 .37136 L
.37031 .37152 L
.35355 .37127 L
.33487 .37053 L
.31395 .36909 L
.29441 .36711 L
.27295 .36414 L
.25019 .35998 L
.22879 .35496 L
.20904 .34918 L
.19161 .34298 L
.17388 .33539 L
.14243 .31762 L
.11733 .29752 L
.09512 .27233 L
.08481 .25681 L
.07662 .24188 L
.06287 .2088 L
.05442 .17992 L
.04959 .15756 L
.04642 .13756 L
.04542 .12893 L
.045 .12444 L
.04471 .12061 L
.0445 .11686 L
.04436 .11313 L
.04431 .11008 L
.04433 .1071 L
.04453 .1023 L
.04489 .0984 L
.04547 .09466 L
.04587 .09279 L
.04629 .09121 L
.04714 .08867 L
.04806 .08658 L
.04921 .08457 L
.05061 .08271 L
Mistroke
.05225 .08105 L
.05398 .07972 L
.05568 .0787 L
.05771 .07777 L
.05979 .07703 L
.06183 .07649 L
.06436 .07599 L
.06693 .07563 L
.06948 .07539 L
.07198 .07524 L
.0749 .07516 L
.07818 .07515 L
.08206 .07523 L
.08584 .07538 L
.09052 .07564 L
.09529 .07597 L
.11619 .07783 L
.18847 .08535 L
.41802 .10724 L
.59091 .12489 L
.66937 .13496 L
.73099 .14502 L
.78012 .15589 L
.79983 .16165 L
.81757 .16819 L
.83159 .17503 L
.83782 .17896 L
.8425 .1826 L
.84608 .18605 L
.84912 .18986 L
.85122 .19351 L
.85252 .19692 L
.85326 .20057 L
.85336 .20454 L
.85282 .20834 L
.85181 .21185 L
.85003 .21601 L
.84739 .22061 L
.8408 .22913 L
.83163 .23823 L
.81947 .2481 L
.79188 .26626 L
.72503 .2995 L
.68132 .31662 L
.62871 .33371 L
.57676 .34732 L
.54702 .35373 L
.51346 .3598 L
.48093 .36451 L
.45001 .3679 L
Mistroke
.43467 .36919 L
.41771 .37029 L
.40142 .37102 L
.38615 .37142 L
.36648 .3715 L
.34753 .37109 L
.33034 .37028 L
.31143 .36887 L
.29085 .36667 L
.26892 .36349 L
.24835 .3596 L
.22993 .35526 L
.19505 .3443 L
.17637 .33655 L
.16 .32834 L
.13247 .31044 L
.10772 .28772 L
.09583 .27328 L
.0864 .25941 L
.07769 .244 L
.06982 .22707 L
.05936 .19789 L
.05277 .17294 L
.04797 .14825 L
.04645 .13781 L
.0453 .12777 L
.0447 .12035 L
.04449 .11659 L
.04437 .11338 L
.04431 .10803 L
.04448 .10311 L
.04482 .09898 L
.04509 .09688 L
.04539 .09509 L
.04605 .0921 L
.04689 .08933 L
.04778 .08715 L
.04873 .08535 L
.04988 .08361 L
.05126 .08199 L
.05289 .08051 L
.05487 .07916 L
.05693 .0781 L
.05901 .07729 L
.06125 .07663 L
.06343 .07615 L
.06615 .07572 L
.0689 .07543 L
.07149 .07526 L
.07451 .07516 L
Mistroke
.07789 .07514 L
.08126 .0752 L
.08462 .07532 L
.08786 .07548 L
.0958 .07601 L
.11744 .07795 L
.14378 .08067 L
.19291 .0858 L
Mfstroke
.06158 .07655 m
.0639 .07607 L
.06616 .07572 L
.06895 .07543 L
.07179 .07525 L
.07459 .07516 L
.07733 .07514 L
.08052 .07518 L
.08413 .0753 L
.08799 .07549 L
.09243 .07577 L
.10127 .07645 L
.12591 .07881 L
.3073 .09694 L
.48165 .11333 L
.57495 .12307 L
.65629 .13312 L
.7201 .14304 L
.77478 .1545 L
.79927 .16147 L
.81787 .16831 L
.831 .17469 L
.83699 .17839 L
.84158 .18182 L
.8451 .18502 L
.84818 .18856 L
.85064 .19235 L
.85223 .196 L
.85311 .19946 L
.85341 .20319 L
.85317 .20641 L
.8524 .21001 L
.85173 .21207 L
.85085 .21427 L
.84885 .21822 L
.84239 .2273 L
.83477 .23533 L
.82442 .24429 L
.7979 .26263 L
.76162 .28264 L
.67656 .31831 L
.62163 .33575 L
.5644 .3501 L
.52903 .35714 L
.49401 .36276 L
.45551 .36738 L
.4343 .36921 L
.42216 .37003 L
.41093 .37063 L
.39177 .37131 L
Mistroke
.38091 .37149 L
.371 .37152 L
.35146 .37121 L
.33287 .37042 L
.32219 .36974 L
.31089 .36882 L
.2906 .36664 L
.26876 .36346 L
.24498 .35887 L
.20617 .34823 L
.18537 .34048 L
.1673 .33218 L
.15137 .32335 L
.13524 .31253 L
.10956 .28971 L
.09798 .27612 L
.08867 .26299 L
.072 .2321 L
.06165 .20514 L
.05421 .17905 L
.04902 .15445 L
.0462 .13586 L
.04522 .12692 L
.04466 .11982 L
.04447 .11625 L
.04435 .11268 L
.04431 .10955 L
.04433 .10687 L
.04452 .10235 L
.04492 .09811 L
.04548 .09462 L
.04612 .09183 L
.04703 .08896 L
.04821 .08628 L
.04952 .08412 L
.05088 .0824 L
.05243 .08089 L
.05404 .07967 L
.05598 .07855 L
.05828 .07755 L
.06078 .07675 L
.06213 .07642 L
.06367 .07611 L
.06505 .07588 L
.0666 .07567 L
.06954 .07538 L
.07258 .07522 L
.0744 .07516 L
.07618 .07514 L
.07996 .07517 L
Mistroke
.08222 .07523 L
.08436 .07531 L
.08837 .07551 L
.09307 .07581 L
.10253 .07656 L
.16618 .08303 L
.40406 .10593 L
.57262 .12281 L
.65137 .13245 L
.71488 .14212 L
.77389 .15428 L
.7981 .16109 L
.81856 .16861 L
.83182 .17515 L
.84115 .18146 L
.84525 .18517 L
.84823 .18861 L
.84957 .19053 L
.85079 .19264 L
.8524 .19652 L
.85321 .20018 L
.8534 .20357 L
.85302 .20735 L
.85197 .21138 L
.85055 .21495 L
.84881 .2183 L
.84344 .22603 L
.83536 .23476 L
.8262 .24285 L
.79981 .26145 L
.76714 .27985 L
.72422 .29985 L
.67695 .31817 L
.62644 .33437 L
.57398 .34796 L
.51135 .36015 L
.49313 .36288 L
.47273 .36552 L
.45427 .3675 L
.43415 .36922 L
.42368 .36994 L
.41374 .3705 L
.39489 .37123 L
.37691 .37152 L
.35721 .37136 L
.336 .37059 L
.31603 .36926 L
.30451 .36821 L
.29399 .36706 L
.27039 .36373 L
Mistroke
.24783 .35949 L
.22372 .35359 L
.20155 .34665 L
.18183 .33898 L
.1494 .32214 L
.13275 .31065 L
.11853 .29865 L
.09435 .27127 L
.08344 .25449 L
.07506 .2387 L
.06268 .20822 L
.05509 .18257 L
.04949 .157 L
.04776 .14693 L
.0464 .1374 L
.04554 .13007 L
.04488 .12289 L
.04451 .11707 L
.04434 .11221 L
.04433 .1071 L
.04448 .10298 L
.04484 .09878 L
.04535 .09531 L
.046 .09227 L
.04689 .08935 L
.04799 .08672 L
.04919 .0846 L
.05045 .08289 L
.05173 .08152 L
.05328 .08021 L
.05506 .07904 L
.05705 .07804 L
.05937 .07717 L
.06176 .0765 L
.06411 .07603 L
.06563 .07579 L
.0671 .07561 L
.06878 .07544 L
.07063 .07531 L
.07395 .07517 L
.07595 .07514 L
.07789 .07514 L
.0816 .07521 L
.08379 .07529 L
.08584 .07538 L
.09431 .0759 L
.1057 .07684 L
.1181 .07802 L
.18323 .08481 L
.41266 .10673 L
Mistroke
.57561 .12314 L
.65953 .13357 L
.7268 .14425 L
.77319 .1541 L
.79436 .15993 L
.81062 .16542 L
.82519 .17164 L
.83155 .175 L
.83735 .17864 L
.84163 .18186 L
.84554 .18547 L
.84838 .18881 L
.85044 .19198 L
.85204 .19546 L
.85307 .19922 L
.8534 .20283 L
.85321 .20614 L
.85238 .21009 L
.85163 .21234 L
.85078 .21443 L
.84615 .22245 L
.83971 .23034 L
.83054 .23918 L
.80592 .25755 L
.74313 .2915 L
.66405 .32262 L
.61118 .33865 L
.58064 .34641 L
.5461 .35392 L
.51428 .35967 L
.47722 .36498 L
.46039 .36688 L
.44181 .36862 L
.42388 .36992 L
.40712 .3708 L
.39046 .37134 L
.37236 .37153 L
.35505 .37131 L
.33913 .37074 L
.32026 .3696 L
.29965 .3677 L
.28013 .36523 L
.26216 .36231 L
.22675 .35441 L
.20715 .34856 L
.18934 .34209 L
.15571 .32592 L
.13853 .31492 L
.1241 .30363 L
.11025 .29045 L
Mistroke
.09868 .27702 L
.0809 .25002 L
.06695 .21996 L
.05681 .18908 L
.05109 .16523 L
.04734 .14418 L
.04548 .12954 L
.04485 .12247 L
.04449 .11661 L
.04431 .11059 L
.04432 .10753 L
.04439 .1049 L
.04466 .10056 L
.04515 .09653 L
.04573 .09339 L
.04641 .09079 L
.0473 .08828 L
.04841 .08592 L
.04968 .08389 L
.05126 .08199 L
.05313 .08033 L
.05506 .07904 L
.05706 .07804 L
.05904 .07728 L
.06152 .07656 L
.06406 .07604 L
.06652 .07568 L
.06935 .0754 L
.07222 .07523 L
.07502 .07515 L
.07851 .07515 L
.0806 .07519 L
.08262 .07525 L
.0865 .07541 L
.09093 .07567 L
.10172 .07649 L
.11347 .07756 L
.1403 .08031 L
.32224 .09833 L
.47504 .11268 L
.56489 .12195 L
.6445 .13153 L
.70958 .14121 L
.75887 .15073 L
.80112 .16207 L
.8187 .16867 L
.83178 .17513 L
.83679 .17825 L
.8414 .18167 L
.84474 .18467 L
Mistroke
.84774 .18799 L
.84923 .19002 L
.85041 .19193 L
.85214 .19573 L
.85307 .19924 L
.85341 .20304 L
.85331 .20517 L
.85305 .20714 L
.85259 .20932 L
.85189 .21164 L
.85025 .21558 L
.8478 .21997 L
.84161 .22822 L
.83397 .23609 L
.8141 .252 L
.79083 .26688 L
.72199 .30079 L
.67892 .31748 L
.6268 .33427 L
.57694 .34727 L
.51592 .3594 L
.47909 .36474 L
.44359 .36847 L
.42435 .3699 L
.41327 .37052 L
.40283 .37097 L
.39167 .37131 L
.38142 .37149 L
.36948 .37152 L
.35811 .37138 L
.33854 .37072 L
.31761 .36939 L
.29962 .3677 L
.27978 .36518 L
.25854 .36164 L
.23594 .35677 L
.19639 .3448 L
.17662 .33666 L
.1596 .32812 L
.14243 .31762 L
.12543 .30477 L
.11125 .29149 L
.09966 .27826 L
.081 .2502 L
.07279 .23386 L
.06645 .21868 L
.056 .18608 L
.04982 .15882 L
.0476 .14588 L
.04616 .13555 L
Mistroke
.04527 .12744 L
.04492 .1234 L
.04467 .11987 L
.04439 .11418 L
.04431 .10863 L
.04435 .10599 L
.04446 .1034 L
.04479 .09923 L
.04506 .09713 L
.04535 .09532 L
.04571 .09349 L
.04616 .09165 L
.04706 .08889 L
.04804 .08662 L
.04914 .08468 L
.05026 .08312 L
.05161 .08164 L
.05324 .08024 L
.05513 .079 L
.05706 .07804 L
.05917 .07723 L
.0616 .07654 L
.0641 .07603 L
.06652 .07568 L
.0681 .0755 L
.06961 .07538 L
.07134 .07527 L
.07324 .07519 L
.07662 .07514 L
.07865 .07515 L
.08061 .07519 L
.08463 .07532 L
.0887 .07553 L
.0971 .07611 L
.1202 .07823 L
.27687 .09407 L
.55965 .12138 L
.64005 .13094 L
.7157 .14226 L
.74678 .14813 L
.77256 .15395 L
.81081 .16549 L
.82534 .17172 L
.83193 .17522 L
.83727 .17858 L
.84152 .18177 L
.84535 .18528 L
.84813 .18849 L
.85018 .19153 L
.85195 .1952 L
Mistroke
.8526 .19717 L
.85308 .1993 L
.85335 .20155 L
.8534 .2037 L
.85294 .20777 L
.85189 .21163 L
.85041 .21524 L
.84824 .21926 L
.84534 .22357 L
.83837 .23175 L
.82872 .24076 L
.80604 .25747 L
.77132 .27768 L
.73172 .29662 L
.64295 .32943 L
.58657 .34499 L
.51872 .35893 L
.48145 .36445 L
.45953 .36697 L
.43876 .36887 L
.42017 .37015 L
.40944 .3707 L
.39929 .3711 L
.38849 .37138 L
.37853 .37151 L
.36694 .3715 L
.35585 .37133 L
.33642 .37061 L
.31554 .36922 L
.29571 .36726 L
.27773 .36488 L
.25658 .36127 L
.23397 .35628 L
.21296 .35042 L
.19437 .34404 L
.15997 .32832 L
.14266 .31777 L
.12756 .30654 L
.10421 .28375 L
.09311 .26954 L
.08419 .25578 L
.06942 .2261 L
.0631 .20947 L
.05835 .1945 L
.05152 .16725 L
.04895 .15406 L
.04719 .14317 L
.04592 .13354 L
.04512 .12582 L
.04482 .12208 L
Mistroke
.04457 .11829 L
.0444 .11459 L
.04432 .11135 L
.04431 .10843 L
.04437 .10546 L
.04451 .1026 L
.0447 .10014 L
.0452 .09619 L
.04556 .0942 L
.04594 .09253 L
.04679 .08963 L
.04772 .08729 L
.04891 .08505 L
.05035 .08302 L
.05174 .08151 L
.05318 .08029 L
.05491 .07913 L
.05695 .07808 L
.05905 .07727 L
.0611 .07667 L
.06367 .07611 L
.06629 .0757 L
.06889 .07543 L
.07145 .07527 L
.07446 .07516 L
.07786 .07514 L
.08153 .07521 L
.08371 .07529 L
.08577 .07538 L
.09428 .0759 L
.10573 .07684 L
.11834 .07804 L
.30496 .09672 L
.45056 .11032 L
.53901 .11916 L
.62016 .1284 L
.68881 .13786 L
.75087 .14899 L
.7736 .15421 L
.79433 .15992 L
.80944 .16498 L
.82315 .17066 L
.83012 .1742 L
.83569 .17752 L
.84017 .18069 L
.84431 .18424 L
.84713 .18724 L
.84957 .19053 L
.85147 .19405 L
.85266 .1974 L
Mistroke
.85332 .20111 L
.85341 .20324 L
.85331 .20524 L
.85259 .20931 L
.85189 .21162 L
.85109 .21373 L
.84923 .21755 L
.84664 .22175 L
.84048 .22949 L
.82335 .24513 L
.79861 .2622 L
.73884 .29345 L
.65348 .3261 L
.59567 .34272 L
.56567 .34982 L
.53633 .3558 L
.50506 .36113 L
.47545 .36519 L
.45912 .36702 L
.44109 .36868 L
.42164 .37006 L
.40296 .37097 L
.38621 .37142 L
.36758 .37151 L
.34785 .3711 L
.32926 .37021 L
.31168 .36889 L
.29562 .36725 L
.27706 .36478 L
.25955 .36183 L
.24101 .35797 L
.22136 .35292 L
.18712 .3412 L
.16744 .33226 L
.14984 .32242 L
.1204 .30036 L
.10751 .28748 L
.09539 .27269 L
.0778 .2442 L
.06951 .22632 L
.06321 .20976 L
.05467 .18091 L
.04985 .15893 L
.04801 .14845 L
.04669 .13964 L
.04578 .13229 L
.04516 .12622 L
.04468 .12014 L
.04439 .11433 L
.04431 .10886 L
Mistroke
.04441 .1044 L
.04471 .10009 L
.04521 .09609 L
.04581 .09308 L
.04648 .09056 L
.04735 .08813 L
.04845 .08584 L
.04968 .08389 L
.05093 .08234 L
.05253 .0808 L
.05421 .07957 L
.0559 .07859 L
.05758 .07782 L
.05957 .0771 L
.06185 .07648 L
.06432 .07599 L
.0658 .07577 L
.0672 .0756 L
.07007 .07535 L
.073 .0752 L
.07474 .07516 L
.07666 .07514 L
.08031 .07518 L
.08268 .07525 L
.08501 .07534 L
.08961 .07558 L
.09931 .07628 L
.11113 .07734 L
.13705 .07997 L
.2251 .08905 L
.3537 .10125 L
.50988 .11615 L
.65083 .13237 L
.71859 .14277 L
.74634 .14804 L
.7694 .15317 L
.80754 .16429 L
.82281 .1705 L
.82936 .17378 L
.83555 .17743 L
.84038 .18085 L
.84464 .18456 L
.84817 .18854 L
.85062 .19231 L
.85228 .19614 L
.85316 .1998 L
.85341 .20314 L
.85311 .2068 L
.85214 .21086 L
.85066 .21471 L
Mistroke
.84841 .21898 L
.8453 .22363 L
.83685 .2333 L
.82684 .24233 L
.80343 .25916 L
.77174 .27746 L
.69272 .31243 L
.59779 .34218 L
.56876 .34914 L
.53561 .35594 L
.50541 .36108 L
.47071 .36575 L
.45005 .3679 L
.43033 .3695 L
.41943 .37019 L
.40901 .37072 L
.39687 .37117 L
.38571 .37143 L
.36521 .37149 L
.34602 .37103 L
.32471 .36992 L
.31389 .36908 L
.30194 .36795 L
.28086 .36534 L
.26133 .36216 L
.24008 .35776 L
.21783 .3519 L
.19721 .3451 L
.17851 .33752 L
.1623 .32958 L
.14615 .32008 L
.11846 .29858 L
.09743 .2754 L
.07975 .24792 L
.07187 .23182 L
.06578 .2169 L
.05587 .18559 L
.05004 .15996 L
.04688 .14097 L
.04573 .13188 L
.045 .12445 L
.04453 .11746 L
.04433 .1117 L
.04435 .10616 L
.04446 .10338 L
.04462 .10101 L
.04508 .09697 L
.04542 .09492 L
.04579 .09316 L
.04667 .08997 L
Mistroke
.04725 .08839 L
.04783 .08707 L
.04884 .08517 L
.05006 .08338 L
.05155 .0817 L
.05311 .08034 L
.05503 .07906 L
.05704 .07805 L
.059 .07729 L
.06131 .07661 L
.06369 .0761 L
.066 .07574 L
.06887 .07544 L
.07176 .07525 L
.07464 .07516 L
.07745 .07514 L
.08073 .07519 L
.08442 .07531 L
.08876 .07553 L
.093 .0758 L
.10357 .07665 L
.1269 .07891 L
.20696 .08723 L
.325 .09859 L
.49321 .11447 L
.64244 .13125 L
.71513 .14216 L
.74308 .14738 L
.76995 .15331 L
.79069 .15883 L
.80932 .16494 L
.82516 .17162 L
.8365 .17806 L
.84085 .18123 L
.84479 .18471 L
.84762 .18783 L
.84997 .19117 L
.85155 .19423 L
.85272 .19764 L
.85329 .20077 L
.8534 .20373 L
.85298 .20754 L
.85248 .20971 L
.85185 .21174 L
.85029 .21548 L
.84808 .21952 L
.84297 .22661 L
.83554 .23459 L
.81304 .25275 L
.78492 .27028 L
Mistroke
.71143 .30514 L
.66552 .32213 L
.60818 .33946 L
.55293 .35254 L
.52007 .35871 L
.48739 .36367 L
.45552 .36738 L
.43695 .36901 L
.41946 .37019 L
.40448 .37091 L
.38773 .37139 L
.36999 .37152 L
.35315 .37126 L
.33304 .37043 L
.32172 .3697 L
.31141 .36887 L
.29127 .36673 L
.27229 .36404 L
.25021 .35999 L
.23016 .35532 L
.20727 .3486 L
.18665 .341 L
.15422 .32505 L
.13854 .31493 L
.12313 .30279 L
.10863 .28872 L
.09658 .27428 L
.07834 .24524 L
.06608 .21771 L
.05705 .18996 L
.05184 .16877 L
.04805 .14875 L
.04671 .13973 L
.04566 .13125 L
.04525 .1272 L
.04489 .12307 L
.04448 .11649 L
.04432 .11099 L
.04436 .10583 L
.04458 .10155 L
.04492 .09811 L
.04546 .09472 L
.04609 .09192 L
.04693 .08922 L
.048 .0867 L
.0493 .08444 L
.05069 .08261 L
.05209 .08119 L
.05377 .07986 L
.05552 .07879 L
Mistroke
.05724 .07796 L
.05939 .07716 L
.06157 .07655 L
.06376 .07609 L
.0659 .07576 L
.06841 .07548 L
.07124 .07528 L
.07459 .07516 L
.07786 .07514 L
.07977 .07517 L
.08192 .07522 L
.08605 .07539 L
.0902 .07562 L
.09491 .07594 L
.10423 .0767 L
.16754 .08317 L
.40066 .10561 L
.54408 .1197 L
.61874 .12822 L
.69077 .13816 L
.72581 .14406 L
.75399 .14965 L
.79849 .16122 L
.81514 .16718 L
.82951 .17387 L
.8349 .17701 L
.83978 .18039 L
.84358 .18355 L
.84657 .18659 L
.84944 .19033 L
.85136 .1938 L
.85271 .19758 L
.85315 .19975 L
.85337 .20177 L
.85331 .20515 L
.85268 .20894 L
.8514 .21295 L
.84965 .21676 L
.8471 .22105 L
.84375 .22564 L
.83617 .23398 L
.81216 .25335 L
.78377 .27093 L
.75249 .28711 L
.71317 .30444 L
.66388 .32268 L
.61186 .33847 L
.55824 .35143 L
.50175 .36163 L
.47132 .36568 L
Mistroke
.45457 .36747 L
.43635 .36906 L
.41693 .37033 L
.39855 .37112 L
.38713 .3714 L
.37629 .37152 L
.35577 .37133 L
.33584 .37058 L
.31735 .36937 L
.29693 .3674 L
.27534 .36452 L
.2573 .36141 L
.23816 .3573 L
.2045 .34767 L
.18479 .34024 L
.16698 .33202 L
.13642 .3134 L
.1223 .30207 L
.1083 .28835 L
.09629 .27389 L
.08518 .25742 L
.06974 .22689 L
.0597 .199 L
.05197 .16935 L
.04938 .15642 L
.0473 .14389 L
.04603 .13444 L
.0455 .12973 L
.0451 .12559 L
.04457 .11831 L
.04434 .11251 L
.04432 .10753 L
.04449 .10283 L
.04483 .09893 L
.04527 .09578 L
.04594 .09253 L
.04639 .09088 L
.04685 .08946 L
.0478 .08712 L
.04897 .08495 L
.05022 .08317 L
.05174 .08152 L
.05332 .08018 L
.05491 .07913 L
.05683 .07814 L
.05913 .07725 L
.06176 .0765 L
.06312 .07621 L
.06443 .07597 L
.06691 .07563 L
Mistroke
.0698 .07536 L
.07252 .07522 L
.07561 .07515 L
.07855 .07515 L
.08147 .07521 L
.08485 .07533 L
.08873 .07553 L
.09824 .0762 L
.10858 .0771 L
.13203 .07944 L
.32512 .0986 L
.46066 .11129 L
.61736 .12805 L
.69516 .13885 L
.75423 .1497 L
.79752 .16091 L
.81433 .16686 L
.82907 .17362 L
.83556 .17744 L
.84072 .18112 L
.8446 .18452 L
.8479 .18819 L
.84929 .19011 L
.85058 .19225 L
.85225 .19606 L
.85286 .19823 L
.85326 .20058 L
.8534 .20283 L
.85333 .2049 L
.85274 .20868 L
.85167 .21224 L
.84994 .21619 L
.84748 .22047 L
.84059 .22937 L
.83228 .23764 L
.81078 .2543 L
.78115 .27239 L
.71158 .30508 L
.66729 .32152 L
.61329 .33808 L
.57922 .34674 L
.54605 .35393 L
.51315 .35985 L
.47531 .36521 L
.44189 .36861 L
Mfstroke
.42962 .10833 m
.57957 .12359 L
.66021 .13366 L
.72371 .14368 L
.77745 .15519 L
.80061 .16191 L
.81836 .16852 L
.8313 .17486 L
.84043 .18089 L
.84418 .18412 L
.84753 .18773 L
.8502 .19156 L
.85195 .1952 L
.85259 .19714 L
.85307 .19922 L
.85341 .20302 L
.85329 .20537 L
.85297 .2076 L
.85251 .20961 L
.85183 .21181 L
.85006 .21596 L
.84753 .2204 L
.84137 .22849 L
.82471 .24405 L
.79944 .26168 L
.76485 .28102 L
.71963 .30178 L
.66965 .32072 L
.61667 .33714 L
.55861 .35135 L
.52637 .35761 L
.48966 .36336 L
.46974 .36586 L
.45101 .36781 L
.43269 .36933 L
.41299 .37053 L
.40234 .37099 L
.39085 .37133 L
.3799 .3715 L
.36986 .37152 L
.35795 .37137 L
.34494 .37099 L
.33256 .3704 L
.32109 .36966 L
.30217 .36797 L
.28179 .36547 L
.2626 .36239 L
.24518 .35891 L
.22508 .35396 L
.20368 .34739 L
Mistroke
.1669 .33198 L
.14838 .32151 L
.13287 .31074 L
.11765 .29783 L
.1031 .28246 L
.09139 .26707 L
.08216 .25227 L
.06796 .22254 L
.05802 .19336 L
.05202 .16961 L
.04966 .15796 L
.04771 .14657 L
.04645 .13778 L
.04544 .12916 L
.04482 .12214 L
.04447 .11629 L
.04431 .11081 L
.04436 .10562 L
.04458 .1016 L
.04496 .09786 L
.0454 .09502 L
.04601 .09225 L
.04696 .08915 L
.04803 .08664 L
.04914 .08468 L
.05049 .08285 L
.05215 .08114 L
.05411 .07963 L
.05597 .07855 L
.0582 .07757 L
.06049 .07683 L
.06274 .07629 L
.06406 .07604 L
.06556 .0758 L
.06845 .07547 L
.07136 .07527 L
.07468 .07516 L
.07772 .07514 L
.08131 .0752 L
.08514 .07535 L
.08895 .07554 L
.09853 .07622 L
.12239 .07845 L
.18491 .08498 L
.45375 .11062 L
.53844 .1191 L
.6276 .12933 L
.69776 .13927 L
.73124 .14507 L
.75894 .15074 L
Mistroke
.80064 .16192 L
.81753 .16817 L
.83179 .17514 L
.83679 .17825 L
.84145 .18171 L
.84488 .1848 L
.84787 .18814 L
.85016 .1915 L
.8517 .19459 L
.85275 .19773 L
.85328 .20072 L
.85338 .20427 L
.85287 .20812 L
.85183 .2118 L
.85043 .2152 L
.84826 .21923 L
.84527 .22366 L
.83827 .23186 L
.81677 .25009 L
.78984 .26746 L
.72544 .29933 L
.68128 .31663 L
.63541 .33173 L
.58499 .34537 L
.52369 .35808 L
.48915 .36343 L
.45543 .36739 L
.43613 .36907 L
.41822 .37026 L
.40815 .37076 L
.39713 .37116 L
.37684 .37152 L
.35879 .37139 L
.34171 .37086 L
.3228 .36978 L
.30235 .36799 L
.28088 .36534 L
.26056 .36202 L
.24224 .35825 L
.22302 .35339 L
.18946 .34214 L
.16046 .32859 L
.14404 .3187 L
.12973 .3083 L
.1063 .28614 L
.09557 .27294 L
.08558 .25808 L
.07123 .23035 L
.05944 .19815 L
.05252 .17185 L
Mistroke
.04806 .14877 L
.04645 .1378 L
.04542 .12892 L
.04482 .12207 L
.04443 .11541 L
.04434 .11238 L
.04431 .10934 L
.04441 .10438 L
.0447 .10012 L
.04513 .09664 L
.04576 .09329 L
.04618 .0916 L
.0466 .09018 L
.04748 .08782 L
.04859 .0856 L
.04977 .08377 L
.05098 .08229 L
.05355 .08001 L
.0552 .07896 L
.05687 .07812 L
.05878 .07737 L
.06064 .07679 L
.06295 .07625 L
.0653 .07584 L
.06781 .07553 L
.07071 .07531 L
.07364 .07518 L
.07651 .07514 L
.0799 .07517 L
.08388 .07529 L
.086 .07539 L
.08834 .07551 L
.09281 .07579 L
.11582 .07779 L
.14327 .08062 L
.32834 .0989 L
.4743 .11261 L
.63669 .1305 L
.70986 .14126 L
.74304 .14737 L
.77376 .15425 L
.7973 .16084 L
.81495 .16711 L
.82909 .17364 L
.83932 .18005 L
.84356 .18354 L
.84724 .18737 L
.84989 .19105 L
.85166 .19449 L
.85272 .19764 L
Mistroke
.85332 .20113 L
.85334 .20484 L
.85282 .20834 L
.85231 .21032 L
.85158 .2125 L
.84979 .21649 L
.84751 .22042 L
.84495 .2241 L
.82752 .24177 L
.80763 .25642 L
.78017 .27293 L
.70792 .30655 L
.6616 .32344 L
.60623 .33998 L
.55333 .35245 L
.52123 .35851 L
.4894 .3634 L
.47088 .36573 L
.45031 .36788 L
.43116 .36944 L
.41314 .37053 L
.39324 .37127 L
.38178 .37148 L
.37096 .37152 L
.35946 .3714 L
.34889 .37113 L
.3366 .37062 L
.32487 .36993 L
.30514 .36827 L
.28407 .36579 L
.26611 .36301 L
.24639 .35918 L
.22559 .3541 L
.20369 .3474 L
.18366 .33976 L
.16626 .33166 L
.13488 .31226 L
.11965 .29968 L
.10675 .28664 L
.08752 .2612 L
.07186 .2318 L
.06559 .2164 L
.06 .19999 L
.05209 .16989 L
.0497 .15816 L
.04774 .14681 L
.04647 .13794 L
.04548 .12952 L
.04505 .12504 L
.04476 .12126 L
Mistroke
.0444 .11459 L
.04432 .11123 L
.04432 .10788 L
.04439 .10496 L
.04452 .10247 L
.04489 .09839 L
.04518 .09631 L
.0455 .09451 L
.04628 .09125 L
.04679 .08961 L
.04731 .08824 L
.04841 .08591 L
.04958 .08403 L
.05101 .08226 L
.05271 .08065 L
.05435 .07948 L
.05601 .07853 L
.058 .07765 L
.06033 .07688 L
.06271 .07629 L
.06504 .07588 L
.06795 .07552 L
.0709 .07529 L
.07383 .07518 L
.07671 .07514 L
.08008 .07517 L
.0839 .07529 L
.08801 .07549 L
.09276 .07579 L
.10226 .07653 L
.12906 .07913 L
.33276 .09931 L
.49336 .11449 L
.58293 .12397 L
.67115 .13522 L
.7097 .14123 L
.74202 .14716 L
.76948 .15319 L
.79111 .15895 L
.8082 .16453 L
.82354 .17085 L
.83554 .17743 L
.84071 .18111 L
.84468 .18461 L
.84793 .18823 L
.84937 .19023 L
.85052 .19213 L
.85206 .19551 L
.85308 .19929 L
.85334 .20142 L
Mistroke
.8534 .20346 L
.85302 .20732 L
.85254 .20951 L
.85192 .21155 L
.84993 .21623 L
.84754 .22039 L
.84475 .22436 L
.83824 .23189 L
.81788 .24928 L
.79314 .26552 L
.76548 .2807 L
.68648 .31474 L
.63975 .33041 L
.58331 .34577 L
.55352 .35241 L
.52378 .35807 L
.49605 .36247 L
.46408 .36649 L
.44542 .36832 L
.4275 .36969 L
.40819 .37076 L
.39716 .37116 L
.38695 .37141 L
.36955 .37152 L
.35026 .37118 L
.32987 .37025 L
.31073 .36881 L
.29974 .36771 L
.28781 .36629 L
.26617 .36302 L
.24525 .35893 L
.22622 .35427 L
.18469 .34019 L
.1651 .33106 L
.14498 .31932 L
.11566 .29592 L
.10164 .2807 L
.09037 .26557 L
.07394 .23635 L
.06692 .21989 L
.06171 .20533 L
.05436 .17965 L
.04925 .15573 L
.04765 .14624 L
.04637 .13722 L
.04551 .12979 L
.04492 .12348 L
.04448 .11652 L
.04432 .11095 L
.04436 .10569 L
Mistroke
.04448 .10302 L
.04465 .10073 L
.04504 .09727 L
.04562 .09391 L
.0464 .09084 L
.04727 .08833 L
.04841 .0859 L
.0498 .08372 L
.05114 .08212 L
.05276 .08062 L
.05471 .07925 L
.05702 .07805 L
.05944 .07715 L
.06183 .07649 L
.06421 .07601 L
.06659 .07567 L
.0694 .07539 L
.07265 .07521 L
.07438 .07516 L
.07633 .07514 L
.08009 .07518 L
.08403 .0753 L
.08794 .07549 L
.0965 .07606 L
.10525 .07679 L
.12884 .07911 L
.328 .09887 L
.47531 .11271 L
.6383 .13071 L
.71166 .14157 L
.74477 .14772 L
.77522 .15461 L
.7986 .16125 L
.816 .16753 L
.8299 .17408 L
.83988 .18047 L
.84372 .18368 L
.84709 .18719 L
.84958 .19055 L
.8513 .19367 L
.85265 .19737 L
.85311 .19948 L
.85335 .20146 L
.85332 .20513 L
.85265 .20908 L
.85202 .21126 L
.85127 .21327 L
.84905 .21787 L
.84648 .22197 L
.84317 .22636 L
Mistroke
.82633 .24274 L
.80449 .25848 L
.77918 .27347 L
.70502 .3077 L
.65753 .32478 L
.59862 .34197 L
.56903 .34908 L
.53574 .35591 L
.50541 .36108 L
.4711 .36571 L
.45447 .36748 L
.43658 .36904 L
.42101 .3701 L
.40367 .37094 L
.38709 .37141 L
.36911 .37152 L
.35191 .37123 L
.33613 .3706 L
.31583 .36925 L
.29699 .36741 L
.27629 .36466 L
.25446 .36085 L
.21843 .35208 L
.19862 .34561 L
.18073 .3385 L
.16291 .32991 L
.1451 .3194 L
.11677 .29699 L
.10206 .28121 L
.09015 .26523 L
.08091 .25004 L
.07272 .23371 L
.06118 .20372 L
.05406 .17845 L
.04913 .15504 L
.04728 .14376 L
.04601 .13433 L
.04522 .12687 L
.04465 .11969 L
.04438 .11394 L
.04431 .1092 L
.0444 .10465 L
.04469 .10025 L
.04519 .09624 L
.04583 .09298 L
.04652 .09043 L
.04739 .08806 L
.04822 .08627 L
.04924 .08452 L
.05047 .08287 L
Mistroke
.05193 .08133 L
.05345 .08009 L
.05494 .07911 L
.05677 .07817 L
.05862 .07742 L
.0608 .07674 L
.06335 .07617 L
.06471 .07593 L
.06625 .07571 L
.06922 .07541 L
.07235 .07523 L
.07546 .07515 L
.07853 .07515 L
.0816 .07521 L
.08517 .07535 L
.08928 .07556 L
.09856 .07622 L
.10824 .07707 L
.27436 .09383 L
.41661 .1071 L
.50708 .11586 L
.59287 .12512 L
.66694 .13461 L
.73548 .14588 L
.76086 .15117 L
.78426 .157 L
.80257 .16256 L
.81716 .16801 L
.83023 .17426 L
.83945 .18014 L
.84352 .18351 L
.84664 .18667 L
.84935 .1902 L
.85146 .19402 L
.85266 .1974 L
.85332 .2011 L
.85335 .20465 L
.8529 .20794 L
.85211 .21096 L
.85084 .21431 L
.84907 .21784 L
.84702 .22117 L
.84033 .22965 L
.83204 .23786 L
.81178 .25362 L
.74602 .29016 L
.66064 .32376 L
.60861 .33935 L
.57582 .34754 L
.54389 .35435 L
Mistroke
.51536 .35949 L
.48265 .36429 L
.44822 .36807 L
.4288 .3696 L
.41036 .37066 L
.39244 .37129 L
.37525 .37153 L
.35962 .37141 L
.34249 .37089 L
.32363 .36984 L
.30353 .36811 L
.28632 .36609 L
.26741 .36323 L
.24636 .35917 L
.22712 .35451 L
.20476 .34776 L
.18523 .34042 L
.15149 .32343 L
.13476 .31218 L
.12039 .30036 L
.09728 .2752 L
.0807 .24966 L
.06725 .22074 L
.05752 .19162 L
.0512 .16572 L
.04883 .15334 L
.04715 .14287 L
.046 .1342 L
.04513 .12586 L
.04462 .11918 L
.04437 .1137 L
.04431 .10799 L
.04446 .10331 L
.04463 .10089 L
.04484 .09883 L
.04513 .09663 L
.04546 .09469 L
.04583 .09296 L
.04628 .09125 L
.0472 .0885 L
.04852 .08571 L
.04991 .08357 L
.05126 .08199 L
.05265 .08071 L
.05431 .0795 L
.05627 .0784 L
.05852 .07746 L
.06085 .07673 L
.06312 .07621 L
.06578 .07577 L
Mistroke
.06824 .07549 L
.07115 .07528 L
.07442 .07516 L
.07771 .07514 L
.08099 .0752 L
.08417 .0753 L
.08789 .07548 L
.09205 .07574 L
.11373 .07759 L
.14001 .08028 L
.22927 .08946 L
.497 .11485 L
.58285 .12396 L
.66729 .13466 L
.72906 .14466 L
.7828 .1566 L
.80533 .16351 L
.82186 .17007 L
.82938 .1738 L
.83633 .17794 L
.84178 .18199 L
.84577 .18572 L
.84891 .18955 L
.85108 .19321 L
.85197 .19525 L
.85259 .19714 L
.85307 .19923 L
.85335 .20146 L
.85331 .2052 L
.85273 .20874 L
.85151 .21267 L
.85057 .2149 L
.84956 .21694 L
.84403 .22528 L
.83698 .23317 L
.81473 .25155 L
.78852 .26823 L
.75442 .28618 L
.67437 .31908 L
.61971 .3363 L
.56323 .35036 L
.50821 .36064 L
.47484 .36526 L
.44241 .36857 L
.42417 .36991 L
.40663 .37082 L
.39062 .37133 L
.37301 .37153 L
.35353 .37127 L
.33266 .37041 L
Mistroke
.31469 .36915 L
.29483 .36716 L
.27359 .36425 L
.254 .36076 L
.23275 .35598 L
.21061 .34968 L
.17525 .33603 L
.15651 .32638 L
.14007 .316 L
.12641 .30559 L
.11327 .29355 L
.09322 .26969 L
.07658 .24179 L
.06924 .22568 L
.0636 .21091 L
.05448 .18015 L
.04919 .15539 L
.04637 .13721 L
.04538 .12856 L
.04478 .12151 L
.04441 .11487 L
.04431 .10941 L
.04434 .10658 L
.04442 .10417 L
.04458 .10158 L
.04479 .09931 L
.04504 .09727 L
.04536 .09526 L
.04607 .09201 L
.04658 .09024 L
.04713 .0887 L
.04828 .08615 L
.0494 .08429 L
.05074 .08256 L
.05214 .08114 L
.05354 .08002 L
.05533 .07889 L
.05747 .07786 L
.05968 .07707 L
.06189 .07647 L
.06434 .07599 L
.06681 .07564 L
.06972 .07537 L
.07145 .07527 L
.07311 .0752 L
.07643 .07514 L
.07841 .07515 L
.08033 .07518 L
.08443 .07531 L
.08686 .07543 L
Mistroke
.08916 .07556 L
.10723 .07698 L
.13252 .07949 L
.1985 .08638 L
.45694 .11093 L
.5467 .11998 L
.63933 .13084 L
.71544 .14222 L
.77101 .15357 L
.79289 .15948 L
.81221 .16603 L
.82678 .17243 L
.83704 .17842 L
.84204 .1822 L
.84578 .18573 L
.849 .18967 L
.85027 .19168 L
.85141 .1939 L
.85274 .1977 L
.85317 .19985 L
.85337 .20182 L
.85326 .2057 L
.85256 .20942 L
.85143 .21289 L
.84965 .21676 L
.84448 .22472 L
.83789 .23225 L
.83025 .23944 L
.80843 .25589 L
.77767 .2743 L
.70107 .30924 L
.64925 .32746 L
.59447 .34303 L
.53685 .3557 L
.50753 .36075 L
.47933 .36471 L
.44533 .36832 L
.42685 .36973 L
.4069 .37081 L
.38922 .37136 L
.37246 .37153 L
.35382 .37128 L
.33358 .37046 L
.31383 .36908 L
.30253 .36801 L
.2919 .3668 L
.27051 .36375 L
.24759 .35943 L
.2277 .35467 L
.2072 .34858 L
Mistroke
.17234 .33467 L
.15405 .32495 L
.13592 .31303 L
.10768 .28768 L
.09349 .27007 L
.08225 .25242 L
.07391 .23628 L
.0664 .21856 L
.05708 .19006 L
.05075 .16356 L
.04881 .15325 L
.0472 .14324 L
.04607 .13483 L
.04531 .12784 L
.04494 .12366 L
.04468 .12012 L
.04448 .11646 L
.04435 .11284 L
.04431 .10991 L
.04433 .10696 L
.04454 .10216 L
.04493 .09805 L
.0452 .09619 L
.04554 .09429 L
.04627 .09126 L
.04709 .08879 L
.04814 .08642 L
.04942 .08426 L
.05065 .08266 L
.05216 .08113 L
.05394 .07974 L
.05608 .0785 L
.05831 .07753 L
.06053 .07682 L
.06281 .07627 L
.06508 .07587 L
.06776 .07554 L
.07084 .0753 L
.07249 .07522 L
.07435 .07517 L
.07792 .07514 L
.08165 .07521 L
.08533 .07535 L
.08895 .07554 L
.09307 .07581 L
.10122 .07644 L
.12352 .07857 L
.18926 .08543 L
.44427 .10972 L
.61747 .12807 L
Mistroke
.70258 .14005 L
.73683 .14614 L
.7644 .15199 L
.78736 .15787 L
.80832 .16457 L
.82506 .17158 L
.83252 .17556 L
.83825 .17926 L
.84251 .1826 L
.8463 .18629 L
.84939 .19025 L
.85148 .19406 L
.85273 .19768 L
.85335 .20157 L
.85333 .20494 L
.85274 .2087 L
.8515 .2127 L
.84977 .21654 L
.84511 .22389 L
.83817 .23196 L
.82847 .24097 L
.77954 .27328 L
.74162 .29219 L
.69958 .30982 L
.60421 .34052 L
.57426 .3479 L
.54069 .35497 L
.51006 .36035 L
.47557 .36518 L
.45543 .36739 L
.4366 .36904 L
.41726 .37031 L
.39857 .37112 L
.38788 .37139 L
.37642 .37152 L
.35557 .37132 L
.34388 .37095 L
.33283 .37042 L
.32064 .36962 L
.30745 .3685 L
.28692 .36617 L
.26827 .36338 L
.24689 .35928 L
.22697 .35447 L
.19268 .3434 L
.17431 .33559 L
.1582 .32733 L
.12755 .30653 L
.11243 .2927 L
.09992 .27859 L
Mistroke
.07963 .24769 L
.07094 .2297 L
.06451 .21344 L
.05513 .18274 L
.04972 .15824 L
.04767 .14636 L
.04628 .13648 L
.04569 .13152 L
.04519 .12654 L
.04484 .12239 L
.0446 .11877 L
.04435 .11268 L
.04431 .10976 L
.04433 .10686 L
.04443 .10404 L
.04458 .10156 L
.04502 .09741 L
.0456 .09402 L
.04627 .09127 L
.04716 .08862 L
.04827 .08618 L
.04936 .08434 L
.0507 .0826 L
.05226 .08104 L
.05386 .0798 L
.05547 .07881 L
.05711 .07802 L
.05915 .07724 L
.06115 .07666 L
.06354 .07613 L
.06628 .07571 L
.06879 .07544 L
.07174 .07525 L
.07516 .07515 L
.07719 .07514 L
.07912 .07516 L
.08309 .07526 L
.08712 .07544 L
.09076 .07566 L
.09503 .07595 L
.10456 .07673 L
.125 .07872 L
.19158 .08567 L
.46824 .11202 L
.62037 .12843 L
.69669 .1391 L
.75532 .14994 L
.77964 .15576 L
.79925 .16146 L
.81424 .16682 L
Mistroke
.82727 .17268 L
.8329 .17579 L
.83826 .17927 L
.84561 .18555 L
.84863 .18916 L
.84997 .19117 L
.85103 .1931 L
.85251 .19689 L
.85324 .2004 L
.85338 .2042 L
.85295 .20769 L
.85184 .21178 L
.8502 .21567 L
.84819 .21934 L
.84594 .22274 L
.83952 .23054 L
.82017 .24758 L
.79207 .26615 L
.72419 .29986 L
.67741 .31801 L
.62681 .33427 L
.57407 .34794 L
.54396 .35434 L
.51022 .36033 L
.4805 .36457 L
.4642 .36648 L
.44625 .36824 L
.42947 .36956 L
.41382 .37049 L
.39861 .37112 L
.38236 .37147 L
.36284 .37146 L
.35171 .37122 L
.34138 .37085 L
.32225 .36974 L
.30187 .36794 L
.28356 .36572 L
.26647 .36307 L
.22805 .35476 L
.20736 .34863 L
.18834 .34169 L
.15497 .32549 L
.13801 .31455 L
.12359 .30319 L
.10943 .28957 L
.09606 .27358 L
.07802 .24463 L
.06573 .21679 L
.05735 .19102 L
.05205 .16974 L
Mistroke
.04824 .14987 L
.04575 .13207 L
.04501 .12454 L
.04453 .11745 L
.04433 .11159 L
.04433 .10688 L
.04452 .10245 L
.04484 .09884 L
.04534 .09534 L
.04605 .0921 L
Mfstroke
.80025 .16179 m
.81599 .16753 L
.82954 .17388 L
.83935 .18007 L
.84591 .18587 L
.84886 .18948 L
.85091 .19287 L
.85244 .19665 L
.85294 .19858 L
.85328 .20072 L
.85337 .20434 L
.85283 .20829 L
.85173 .21207 L
.85025 .21557 L
.84811 .21948 L
.84525 .22369 L
.8387 .23141 L
.81769 .24942 L
.79035 .26717 L
.75989 .2835 L
.6716 .32005 L
.60989 .339 L
.57735 .34718 L
.54508 .35412 L
.51268 .35993 L
.48166 .36442 L
.4646 .36644 L
.4456 .3683 L
.43498 .36916 L
.42504 .36985 L
.40513 .37088 L
.38578 .37143 L
.36732 .37151 L
.34678 .37106 L
.33512 .37054 L
.32437 .36989 L
.30385 .36814 L
.29218 .36684 L
.28133 .3654 L
.25944 .36181 L
.23629 .35685 L
.19582 .34459 L
.17649 .3366 L
.15639 .32631 L
.14042 .31624 L
.12466 .30411 L
.10026 .27901 L
.08827 .26237 L
.07741 .24344 L
.0696 .22655 L
Mistroke
.0629 .20887 L
.05396 .17803 L
.04891 .1538 L
.04723 .14346 L
.04595 .13378 L
.04545 .1292 L
.04501 .12454 L
.04471 .12055 L
.04451 .11717 L
.04432 .11111 L
.04431 .1081 L
.04437 .10546 L
.04461 .10121 L
.04505 .09716 L
.0456 .094 L
.04636 .09095 L
.04733 .08819 L
.04839 .08594 L
.04952 .08412 L
.05066 .08265 L
.05202 .08125 L
.05363 .07995 L
.05547 .07881 L
.05737 .07791 L
.05936 .07717 L
.06134 .07661 L
.06364 .07611 L
.06637 .07569 L
.06782 .07553 L
.06945 .07539 L
.07255 .07522 L
.07566 .07515 L
.07928 .07516 L
.08295 .07526 L
.08658 .07541 L
.09004 .07561 L
.09408 .07588 L
.10306 .0766 L
.25907 .09237 L
.40091 .10564 L
.57936 .12357 L
.64943 .13218 L
.71537 .1422 L
.74779 .14834 L
.77343 .15416 L
.79391 .15979 L
.8127 .16622 L
.82699 .17254 L
.833 .17585 L
.83853 .17947 L
Mistroke
.84286 .18291 L
.84613 .1861 L
.84878 .18936 L
.85072 .1925 L
.85229 .19617 L
.85287 .19824 L
.85321 .20014 L
.85339 .20387 L
.853 .20742 L
.85255 .20947 L
.85188 .21164 L
.85025 .21558 L
.84787 .21986 L
.84454 .22463 L
.82928 .24028 L
.80581 .25762 L
.74685 .28977 L
.65647 .32513 L
.59384 .34319 L
.56086 .35087 L
.52805 .35732 L
.49554 .36254 L
.46433 .36647 L
.44689 .36819 L
.42814 .36965 L
.40891 .37072 L
.39785 .37114 L
.38747 .3714 L
.37729 .37152 L
.36618 .3715 L
.34579 .37102 L
.32571 .36998 L
.30706 .36846 L
.2868 .36615 L
.26455 .36274 L
.2415 .35808 L
.22032 .35262 L
.20084 .34641 L
.18087 .33856 L
.14761 .32102 L
.12938 .30802 L
.11399 .29428 L
.10159 .28064 L
.09019 .26529 L
.07333 .23503 L
.06237 .20732 L
.0544 .17982 L
.04897 .15413 L
.04731 .14396 L
.04614 .13536 L
Mistroke
.04536 .12834 L
.04479 .12168 L
.04443 .11526 L
.04431 .11003 L
.04438 .10507 L
.04451 .10253 L
.04469 .10031 L
.04511 .09677 L
.04565 .09379 L
.04623 .0914 L
.04699 .08907 L
.04793 .08685 L
.04908 .08478 L
.0503 .08308 L
.05152 .08173 L
.05293 .08048 L
.05458 .07933 L
.05656 .07826 L
.05858 .07743 L
.06106 .07668 L
.06361 .07612 L
.06608 .07573 L
.06897 .07543 L
.07165 .07526 L
.07481 .07516 L
.07836 .07515 L
.08193 .07522 L
.08547 .07536 L
.08892 .07554 L
.09744 .07613 L
.15048 .08138 L
.24459 .09096 L
.382 .10388 L
.54174 .11945 L
.67866 .13632 L
.74157 .14708 L
.78711 .1578 L
.80573 .16365 L
.82017 .16931 L
.83279 .17572 L
.8428 .18286 L
.84651 .18652 L
.84812 .18848 L
.8496 .19058 L
.85078 .19262 L
.85166 .19448 L
.85285 .19816 L
.85337 .20176 L
.85326 .2057 L
.85255 .20947 L
Mistroke
.85139 .21299 L
.84961 .21685 L
.84712 .22103 L
.84117 .22871 L
.83183 .23804 L
.82131 .24671 L
.79415 .26492 L
.75767 .2846 L
.7206 .30138 L
.67337 .31943 L
.62391 .3351 L
.57334 .34811 L
.54264 .35459 L
.50719 .3608 L
.46955 .36588 L
.4482 .36807 L
.43849 .36889 L
.42785 .36967 L
.40795 .37077 L
.38883 .37137 L
.36989 .37152 L
.35221 .37123 L
.33285 .37042 L
.31137 .36886 L
.3005 .36779 L
.28882 .36642 L
.26775 .36329 L
.24804 .35953 L
.22655 .35436 L
.20609 .34821 L
.18478 .34023 L
.16589 .33146 L
.14954 .32223 L
.12083 .30076 L
.10693 .28685 L
.09553 .27288 L
.08393 .25533 L
.07514 .23886 L
.06176 .20549 L
.05659 .18828 L
.05284 .17325 L
.0484 .15084 L
.0468 .14039 L
.04571 .13171 L
.04506 .12513 L
.0446 .11879 L
.04434 .11259 L
.04432 .10759 L
.04438 .10507 L
.04451 .10257 L
Mistroke
.04488 .09851 L
.04518 .09628 L
.04553 .09434 L
.04632 .09109 L
.04725 .0884 L
.04823 .08624 L
.04947 .08418 L
.05096 .08231 L
.05244 .08088 L
.05422 .07956 L
.05607 .0785 L
.05793 .07768 L
.05973 .07705 L
.06186 .07648 L
.06425 .076 L
.06667 .07566 L
.06952 .07538 L
.07276 .07521 L
.07572 .07515 L
.07919 .07516 L
.08321 .07527 L
.0856 .07537 L
.08785 .07548 L
.09717 .07611 L
.11731 .07794 L
.14536 .08084 L
.21774 .08832 L
.4909 .11424 L
.58036 .12368 L
.66948 .13498 L
.73998 .14676 L
.78951 .15849 L
.80837 .16459 L
.82456 .17133 L
.8363 .17792 L
.84414 .18408 L
.84772 .18796 L
.85021 .19159 L
.85122 .19351 L
.8521 .19563 L
.85278 .19786 L
.85319 .19997 L
.85339 .2039 L
.85299 .20752 L
.85253 .20955 L
.85184 .21177 L
.85012 .21584 L
.848 .21965 L
.84557 .22326 L
.83849 .23162 L
Mistroke
.81818 .24906 L
.79472 .26457 L
.76382 .28154 L
.6801 .31705 L
.62146 .3358 L
.55932 .3512 L
.52579 .35772 L
.49246 .36298 L
.46111 .36681 L
.44286 .36853 L
.4257 .36981 L
.40684 .37081 L
.3889 .37137 L
.36889 .37152 L
.35753 .37136 L
.34709 .37107 L
.32592 .37 L
.31387 .36908 L
.30268 .36802 L
.28212 .36552 L
.26031 .36197 L
.24194 .35818 L
.22213 .35314 L
.20327 .34725 L
.18379 .33981 L
.15126 .32329 L
.12461 .30408 L
.11055 .29075 L
.09715 .27504 L
.08697 .26032 L
.07779 .24419 L
.06452 .21349 L
.05621 .18688 L
.051 .16476 L
.04742 .14471 L
.04627 .13639 L
.04545 .12929 L
.04493 .12352 L
.04455 .11784 L
.04433 .11178 L
.04433 .10694 L
.04454 .10204 L
.04494 .09803 L
.04545 .09475 L
.04605 .09208 L
.04684 .08949 L
.04781 .0871 L
.04892 .08502 L
.0503 .08308 L
.05176 .0815 L
Mistroke
.05324 .08024 L
.05642 .07833 L
.05822 .07757 L
.06037 .07686 L
.06288 .07626 L
.06536 .07583 L
.06674 .07565 L
.06831 .07549 L
.07001 .07535 L
.07167 .07526 L
.07491 .07516 L
.07806 .07515 L
.08196 .07522 L
.0859 .07538 L
.08952 .07558 L
.09374 .07586 L
.10315 .07661 L
.1233 .07854 L
.18885 .08539 L
.46565 .11177 L
.54719 .12003 L
.63085 .12975 L
.69998 .13963 L
.75415 .14969 L
.77828 .1554 L
.80032 .16181 L
.81553 .16734 L
.82902 .1736 L
.84032 .18081 L
.84493 .18485 L
.84829 .18869 L
.85064 .19235 L
.85214 .19573 L
.85314 .19968 L
.8534 .20348 L
.85311 .20683 L
.85223 .21057 L
.85074 .21452 L
.84882 .21827 L
.8442 .22507 L
.83761 .23253 L
.81686 .25003 L
.79149 .2665 L
.72036 .30148 L
.63294 .33247 L
.57289 .34821 L
.51197 .36005 L
.47549 .36519 L
.45411 .36752 L
.43392 .36924 L
Mistroke
.41582 .37039 L
.39556 .37121 L
.3852 .37144 L
.37399 .37153 L
.35352 .37127 L
.33391 .37048 L
.32267 .36977 L
.31206 .36893 L
.29065 .36665 L
.26757 .36326 L
.24739 .35939 L
.22643 .35433 L
.19029 .34247 L
.17095 .33399 L
.15151 .32344 L
.12047 .30043 L
.10441 .28398 L
.09142 .26711 L
.08161 .2513 L
.07264 .23353 L
.06126 .20395 L
.05335 .17546 L
.04877 .15303 L
.04619 .13577 L
.04523 .12699 L
.04465 .11968 L
.04438 .1139 L
.04431 .10835 L
.04437 .10551 L
.04448 .10312 L
.04466 .10055 L
.0449 .09832 L
.04545 .09475 L
.04584 .09294 L
.04624 .09139 L
.04714 .08868 L
.04813 .08644 L
.04914 .08467 L
.05037 .08299 L
.05186 .0814 L
.05361 .07997 L
.05525 .07894 L
.05722 .07797 L
.05921 .07722 L
.06117 .07665 L
.06348 .07614 L
.0661 .07573 L
.06855 .07546 L
.07098 .07529 L
.07382 .07518 L
Mistroke
.07705 .07514 L
.07899 .07516 L
.08113 .0752 L
.08518 .07535 L
.08756 .07547 L
.08988 .0756 L
.09547 .07598 L
.11881 .07809 L
.18406 .08489 L
.41547 .107 L
.57909 .12354 L
.66324 .13409 L
.73077 .14498 L
.7852 .15726 L
.80731 .16421 L
.82597 .17203 L
.83794 .17905 L
.84259 .18267 L
.84668 .18671 L
.84937 .19023 L
.85147 .19405 L
.85274 .19771 L
.85332 .20109 L
.85333 .20491 L
.8531 .20686 L
.85266 .20902 L
.85143 .21288 L
.84977 .21654 L
.84721 .2209 L
.84431 .22493 L
.83598 .23417 L
.81514 .25127 L
.78897 .26796 L
.71896 .30206 L
.67093 .32027 L
.61933 .3364 L
.56525 .34992 L
.53448 .35615 L
.50021 .36186 L
.46988 .36585 L
.4533 .36759 L
.43515 .36915 L
.41812 .37026 L
.40233 .37099 L
.38621 .37142 L
.37074 .37152 L
.35257 .37124 L
.33276 .37042 L
.3139 .36909 L
.29652 .36735 L
Mistroke
.27722 .3648 L
.2562 .36119 L
.23448 .35641 L
.21466 .35095 L
.19409 .34394 L
.17545 .33613 L
.14328 .31819 L
.12716 .30621 L
.1137 .29399 L
.10066 .27951 L
.08859 .26287 L
.07374 .23592 L
.06355 .21074 L
.05516 .18285 L
.05017 .16062 L
.04693 .14133 L
.04576 .13211 L
.04501 .12456 L
.04456 .11812 L
.04435 .11294 L
.04432 .10763 L
.04447 .10324 L
.04479 .0993 L
.0453 .09561 L
.04593 .09256 L
.04663 .0901 L
.0476 .08756 L
.04882 .08519 L
.05015 .08327 L
.05151 .08173 L
.05307 .08037 L
.05467 .07928 L
.05658 .07826 L
.05883 .07735 L
.0614 .07659 L
.06275 .07628 L
.06407 .07604 L
.06666 .07566 L
.06811 .0755 L
.06971 .07537 L
.07281 .07521 L
.07586 .07514 L
.07946 .07516 L
.08136 .07521 L
.08354 .07528 L
.08739 .07546 L
.09181 .07572 L
.10061 .07639 L
.14677 .08099 L
.35618 .10148 L
Mistroke
.52576 .11777 L
.61983 .12836 L
.69858 .1394 L
.75559 .15 L
.78181 .15634 L
.80204 .16238 L
.81916 .16887 L
.83365 .17624 L
.83935 .18007 L
.84431 .18424 L
.84795 .18825 L
.85043 .19196 L
.85205 .19548 L
.85307 .19925 L
.8534 .20252 L
.8532 .20617 L
.85236 .21013 L
.85162 .21238 L
.85077 .21445 L
.84618 .22241 L
.8401 .2299 L
.83161 .23824 L
.81152 .2538 L
.74551 .2904 L
.66296 .32299 L
.60765 .3396 L
.57573 .34756 L
.53984 .35514 L
.50649 .36091 L
.48811 .36357 L
.46789 .36607 L
.4488 .36801 L
.43102 .36945 L
.41278 .37054 L
.39519 .37122 L
.37734 .37152 L
.35782 .37137 L
.33915 .37074 L
.3219 .36972 L
.30263 .36802 L
.28151 .36543 L
.25952 .36182 L
.23926 .35756 L
.21797 .35194 L
.19842 .34554 L
.16391 .33044 L
.14613 .32007 L
.13099 .30929 L
.11598 .29623 L
.10175 .28084 L
Mistroke
.08368 .2549 L
.07086 .22951 L
.06001 .20003 L
.05337 .17555 L
.04888 .15366 L
.04727 .14369 L
.046 .13424 L
.04522 .12694 L
.04466 .11979 L
.04438 .11405 L
.04431 .10924 L
.0444 .10459 L
.04469 .10022 L
.04513 .09661 L
.04567 .0937 L
.04644 .09069 L
.04747 .08787 L
.0486 .08557 L
.04979 .08374 L
.05116 .08209 L
.05258 .08076 L
.05429 .07951 L
.05632 .07838 L
.05865 .07741 L
.06107 .07667 L
.06344 .07615 L
.06475 .07592 L
.06622 .07571 L
.06907 .07542 L
.07195 .07524 L
.07494 .07515 L
.07788 .07514 L
.08127 .0752 L
.08526 .07535 L
.08972 .07559 L
.09419 .07589 L
.1372 .07998 L
.31779 .09792 L
.47027 .11222 L
.64188 .13118 L
.71542 .14221 L
.74852 .14849 L
.77899 .15559 L
.80203 .16238 L
.81912 .16885 L
.832 .17526 L
.83772 .17889 L
.84209 .18224 L
.84557 .1855 L
.84858 .18909 L
Mistroke
.85095 .19295 L
.85244 .19664 L
.85321 .20015 L
.85339 .20392 L
.85305 .20718 L
.85216 .21081 L
.85137 .21302 L
.85046 .21514 L
.84831 .21914 L
.84152 .22831 L
.83361 .23643 L
.82296 .24544 L
.79565 .26401 L
.76327 .28182 L
.68621 .31484 L
.63342 .33232 L
.57861 .34689 L
.51117 .36017 L
.47431 .36533 L
.45254 .36767 L
.43171 .3694 L
.41258 .37055 L
.40278 .37097 L
.39188 .37131 L
.37235 .37153 L
.35377 .37128 L
.34303 .37092 L
.33166 .37035 L
.31123 .36885 L
.29978 .36772 L
.28912 .36646 L
.26498 .36281 L
.24399 .35865 L
.22448 .3538 L
.18928 .34207 L
.17062 .33383 L
.15435 .32513 L
.13779 .31439 L
.12158 .30142 L
.09915 .27762 L
.08257 .25298 L
.06797 .22256 L
.05873 .19579 L
.05227 .17075 L
.04987 .15904 L
.0479 .14782 L
.04661 .13905 L
.04557 .13042 L
.04492 .12345 L
.04454 .11761 L
Mistroke
.04433 .11197 L
.04434 .10667 L
.04453 .10228 L
.04485 .09874 L
.04539 .09508 L
.04577 .09323 L
.04617 .09164 L
.04701 .08901 L
.04806 .08658 L
.04921 .08457 L
.05061 .0827 L
.05209 .08119 L
.05357 .08 L
.05547 .07881 L
.05776 .07775 L
.06013 .07693 L
.06253 .07633 L
.06489 .0759 L
.06764 .07555 L
.07043 .07532 L
.07318 .0752 L
.07581 .07514 L
.07888 .07515 L
.08228 .07523 L
.08566 .07537 L
.08989 .0756 L
.09416 .07589 L
.10295 .07659 L
.12691 .07891 L
.28881 .0952 L
.44313 .10961 L
.52835 .11804 L
.60531 .12659 L
.67454 .13571 L
.739 .14656 L
.78926 .15841 L
.81021 .16527 L
.82571 .1719 L
.83229 .17543 L
.83834 .17933 L
.84277 .18283 L
.84657 .18659 L
.84925 .19005 L
.85141 .1939 L
.85268 .19746 L
.85329 .20083 L
.85341 .20288 L
.85332 .20512 L
.85303 .20725 L
.8526 .20925 L
Mistroke
.85136 .21305 L
.84945 .21714 L
.84643 .22204 L
.84288 .22672 L
.83449 .23559 L
.81469 .25158 L
.78617 .26957 L
.70866 .30626 L
.66548 .32214 L
.61329 .33808 L
.55811 .35145 L
.50274 .36148 L
.47072 .36575 L
.45166 .36775 L
.43382 .36925 L
.41464 .37045 L
.40389 .37093 L
.39357 .37126 L
.37503 .37153 L
.35448 .37129 L
.33501 .37054 L
.3172 .36936 L
.29652 .36735 L
.277 .36477 L
.24247 .3583 L
.22335 .35348 L
.20612 .34822 L
.18789 .34151 L
.16917 .33312 L
.1382 .31468 L
.12146 .30132 L
.10733 .2873 L
.08561 .25814 L
.07686 .24237 L
.06916 .22548 L
.05885 .19619 L
.05171 .16816 L
.049 .1543 L
.04715 .14289 L
.04598 .13406 L
.04522 .1269 L
.04466 .11984 L
.04447 .11632 L
.04436 .11323 L
.04432 .10762 L
.04448 .10309 L
.04485 .09874 L
.04511 .09677 L
.04545 .09476 L
.04614 .09175 L
Mistroke
.04689 .08933 L
.04791 .08688 L
.04902 .08486 L
.05017 .08324 L
.05134 .08191 L
.05286 .08054 L
.05438 .07945 L
.05634 .07837 L
.05866 .07741 L
.0609 .07672 L
.06345 .07615 L
.06593 .07575 L
.06841 .07548 L
.07132 .07527 L
.07467 .07516 L
.07664 .07514 L
.07853 .07515 L
.08069 .07519 L
.08309 .07526 L
.08734 .07545 L
.0924 .07576 L
.11409 .07762 L
.29256 .09556 L
.42848 .10822 L
.59588 .12547 L
.66874 .13487 L
.73517 .14582 L
.76221 .15148 L
.78436 .15703 L
.80133 .16214 L
.817 .16795 L
.83037 .17434 L
.83593 .17768 L
.84098 .18133 L
.84488 .1848 L
.84777 .18802 L
.85005 .1913 L
.85165 .19446 L
.85285 .19816 L
.85339 .20215 L
.85327 .20561 L
.85254 .20948 L
.85188 .21166 L
.85111 .21368 L
.84882 .21827 L
.84286 .22674 L
.83514 .23497 L
.82651 .2426 L
.80193 .26012 L
.741 .29247 L
Mistroke
.69797 .31044 L
.64399 .32911 L
.58577 .34518 L
.55511 .35209 L
.52553 .35776 L
.49555 .36254 L
.46127 .36679 L
.44182 .36862 L
.42336 .36996 L
.40537 .37087 L
.38583 .37143 L
.36731 .3715 L
.34699 .37107 L
.32759 .37011 L
.30961 .3687 L
.29327 .36697 L
.27534 .36452 L
.23942 .3576 L
.21743 .35178 L
.19718 .34509 L
.1615 .32915 L
.14326 .31818 L
.12775 .3067 L
.1115 .29175 L
.09817 .27637 L
.08032 .24897 L
.07282 .23392 L
.06611 .21779 L
.05617 .18672 L
.05043 .16194 L
.04838 .15072 L
.04691 .14121 L
.04591 .13345 L
.04515 .12609 L
.04461 .119 L
.04436 .11324 L
.04432 .10778 L
.04439 .10498 L
.04451 .10256 L
.04486 .09867 L
.04533 .09541 L
.04587 .09281 L
.04657 .09028 L
.04747 .08786 L
.04857 .08562 L
.04976 .08378 L
.05095 .08233 L
.05253 .0808 L
.05439 .07945 L
.05613 .07847 L
Mistroke
.0582 .07757 L
.06064 .07679 L
.06208 .07643 L
.0635 .07614 L
.06489 .0759 L
.06646 .07568 L
.06937 .0754 L
.07232 .07523 L
.0741 .07517 L
.07583 .07514 L
.07952 .07516 L
.08171 .07522 L
.08379 .07529 L
.08769 .07547 L
.09224 .07575 L
.10141 .07646 L
.10234 .07654 L
Mfstroke
.84505 .18497 m
.84801 .18833 L
.85012 .19143 L
.85189 .19506 L
.85293 .19854 L
.85337 .20181 L
.85334 .20485 L
.85284 .20823 L
.85181 .21186 L
.85026 .21555 L
.84806 .21956 L
.8427 .22693 L
.83418 .23589 L
.82447 .24425 L
.80033 .26113 L
.76697 .27994 L
.68838 .31404 L
.63282 .3325 L
.57555 .3476 L
.54085 .35494 L
.50092 .36176 L
.48175 .36441 L
.46093 .36683 L
.44091 .3687 L
.42223 .37003 L
.40334 .37095 L
.38511 .37144 L
.36557 .37149 L
.3544 .37129 L
.344 .37095 L
.32659 .37004 L
.30723 .36848 L
.28694 .36617 L
.2679 .36332 L
.24682 .35927 L
.22494 .35392 L
.18731 .34127 L
.16758 .33232 L
.1503 .3227 L
.13268 .3106 L
.11589 .29614 L
.10331 .28271 L
.09126 .26687 L
.07442 .23736 L
.06718 .22057 L
.06096 .20303 L
.05302 .17403 L
.05038 .16169 L
.04819 .14959 L
.04675 .14007 L
Mistroke
.04564 .13107 L
.0449 .12322 L
.0445 .11696 L
.04432 .11139 L
.04433 .10674 L
.0445 .1027 L
.04484 .09878 L
.04537 .09519 L
.04601 .09225 L
.04673 .08981 L
.04748 .08783 L
.04847 .08581 L
.04952 .08412 L
.05078 .08251 L
.05227 .08103 L
.05366 .07994 L
.05532 .07889 L
.05727 .07795 L
.05955 .07711 L
.0619 .07647 L
.06421 .07601 L
.06697 .07562 L
.06977 .07537 L
.07245 .07522 L
.07556 .07515 L
.07919 .07516 L
.08112 .0752 L
.08333 .07527 L
.08746 .07546 L
.09158 .07571 L
.10962 .0772 L
.13434 .07968 L
.34034 .10002 L
.50266 .11542 L
.59208 .12503 L
.67917 .1364 L
.74259 .14728 L
.77233 .15389 L
.79582 .16038 L
.81245 .16612 L
.82668 .17238 L
.83283 .17574 L
.83856 .17949 L
.84267 .18274 L
.84625 .18624 L
.84923 .19002 L
.85125 .19357 L
.85267 .19745 L
.85314 .19968 L
.85337 .20178 L
Mistroke
.85327 .20562 L
.85262 .20918 L
.85205 .21116 L
.85125 .21334 L
.84934 .21735 L
.84431 .22493 L
.83696 .23319 L
.81899 .24846 L
.78845 .26827 L
.75224 .28723 L
.71411 .30405 L
.66591 .32199 L
.61633 .33724 L
.55671 .35175 L
.52078 .35858 L
.48617 .36383 L
.46887 .36596 L
.44961 .36794 L
.43099 .36945 L
.41342 .37051 L
.39717 .37116 L
.37938 .3715 L
.36235 .37145 L
.34656 .37105 L
.32888 .37019 L
.3094 .36868 L
.28897 .36644 L
.26998 .36366 L
.2498 .3599 L
.23099 .35553 L
.19683 .34496 L
.17858 .33755 L
.16252 .3297 L
.14501 .31934 L
.12967 .30824 L
.11649 .29672 L
.10361 .28306 L
.0849 .25697 L
.07642 .24147 L
.06891 .22488 L
.05882 .1961 L
.0521 .16994 L
.04812 .14914 L
.04594 .13372 L
.04516 .12629 L
.04469 .12021 L
.04439 .11415 L
.04431 .10846 L
.04444 .10375 L
.04472 .09997 L
Mistroke
.04522 .09607 L
.04558 .0941 L
.04597 .09241 L
.04679 .08962 L
.04783 .08706 L
.04898 .08494 L
.05038 .08298 L
.05187 .08139 L
.05337 .08014 L
.0553 .07891 L
.05763 .0778 L
.06005 .07696 L
.06251 .07634 L
.06512 .07587 L
.06652 .07568 L
.06812 .0755 L
.07112 .07528 L
.07413 .07517 L
.07605 .07514 L
.07794 .07514 L
.08169 .07522 L
.08391 .07529 L
.08604 .07539 L
.09116 .07568 L
.09995 .07634 L
.11102 .07733 L
.13857 .08013 L
.32043 .09817 L
.46658 .11186 L
.63045 .1297 L
.70516 .14047 L
.73909 .14658 L
.77043 .15342 L
.79465 .16002 L
.81279 .16625 L
.8274 .17275 L
.83801 .17909 L
.84215 .1823 L
.84584 .18579 L
.84862 .18914 L
.85059 .19225 L
.85221 .19593 L
.85282 .19804 L
.85319 .20001 L
.8534 .20366 L
.85297 .2076 L
.85247 .20977 L
.85184 .21178 L
.84986 .21636 L
.84749 .22045 L
Mistroke
.84439 .22483 L
.82824 .24116 L
.80694 .25688 L
.78211 .27186 L
.70901 .30612 L
.66195 .32332 L
.60356 .34069 L
.57419 .34791 L
.54117 .35488 L
.51107 .36019 L
.47704 .365 L
.4605 .36687 L
.44271 .36855 L
.42721 .36971 L
.40998 .37068 L
.39347 .37127 L
.37557 .37152 L
.35845 .37138 L
.34273 .3709 L
.32245 .36976 L
.30364 .36812 L
.28292 .36563 L
.26106 .36211 L
.22483 .35389 L
.20485 .34779 L
.18676 .34105 L
.16855 .33281 L
.15031 .3227 L
.12108 .30098 L
.10714 .28708 L
.09561 .27299 L
.0846 .25646 L
.07495 .23848 L
.06267 .2082 L
.05505 .18243 L
.04974 .15835 L
.04772 .14669 L
.04633 .13692 L
.04544 .12916 L
.04479 .1217 L
.04445 .1157 L
.04431 .11078 L
.04435 .10604 L
.04459 .10146 L
.04503 .09729 L
.04562 .09389 L
.04632 .09111 L
.0471 .08877 L
.0479 .0869 L
.04889 .08509 L
Mistroke
.05008 .08336 L
.05149 .08176 L
.05296 .08046 L
.05442 .07943 L
.05608 .0785 L
.05801 .07765 L
.06032 .07688 L
.06265 .07631 L
.06398 .07605 L
.0655 .07581 L
.06842 .07548 L
.07149 .07526 L
.07454 .07516 L
.07756 .07514 L
.08057 .07519 L
.08409 .0753 L
.08813 .0755 L
.09724 .07612 L
.10676 .07693 L
.27046 .09346 L
.41183 .10666 L
.58822 .12458 L
.66793 .13475 L
.73224 .14526 L
.77846 .15545 L
.79939 .16151 L
.81543 .1673 L
.82806 .17309 L
.83859 .17951 L
.84262 .1827 L
.84581 .18576 L
.84839 .18882 L
.85024 .19163 L
.85189 .19506 L
.85298 .19877 L
.85339 .20225 L
.85327 .20556 L
.85254 .20949 L
.85132 .21315 L
.84941 .21722 L
.84676 .22156 L
.84072 .22922 L
.83233 .23759 L
.81257 .25307 L
.78219 .27181 L
.74778 .28934 L
.65749 .3248 L
.59934 .34178 L
.56668 .3496 L
.52924 .3571 L
Mistroke
.49459 .36268 L
.46127 .36679 L
.44473 .36837 L
.42629 .36977 L
.40852 .37074 L
.39172 .37131 L
.38138 .37149 L
.37008 .37152 L
.34935 .37115 L
.32893 .37019 L
.30997 .36874 L
.28932 .36648 L
.26666 .36311 L
.24318 .35846 L
.2216 .35299 L
.20202 .34682 L
.18195 .33903 L
.14851 .32159 L
.13182 .30994 L
.11756 .29774 L
.10347 .28288 L
.09067 .26601 L
.07364 .23571 L
.06259 .20795 L
.05453 .18035 L
.04904 .15457 L
.04736 .14433 L
.04618 .13567 L
.04539 .12862 L
.04481 .12192 L
.04444 .11547 L
.04431 .11021 L
.04438 .10522 L
.0445 .10267 L
.04467 .10044 L
.04509 .09688 L
.04563 .09389 L
.04621 .09149 L
.04696 .08915 L
.0479 .08692 L
.04904 .08484 L
.05025 .08313 L
.05147 .08178 L
.05288 .08052 L
.05453 .07936 L
.05651 .07829 L
.05853 .07745 L
.06101 .07669 L
.06356 .07613 L
.06603 .07574 L
Mistroke
.06892 .07543 L
.0716 .07526 L
.07477 .07516 L
.07831 .07515 L
.08188 .07522 L
.08543 .07536 L
.08888 .07554 L
.09739 .07613 L
.11923 .07813 L
.15047 .08138 L
.24457 .09096 L
.3926 .10486 L
.5637 .12182 L
.63609 .13042 L
.70435 .14034 L
.73537 .14586 L
.76528 .15219 L
.78693 .15775 L
.80681 .16403 L
.82346 .17081 L
.83562 .17748 L
.84019 .18071 L
.84426 .18419 L
.84736 .18751 L
.84962 .1906 L
.85072 .1925 L
.8517 .19459 L
.85246 .19671 L
.85302 .19897 L
.85331 .20098 L
.85341 .20315 L
.85306 .20709 L
.85265 .20908 L
.85201 .21126 L
.8504 .21526 L
.84828 .2192 L
.84585 .22288 L
.83261 .23734 L
.81148 .25382 L
.75017 .28821 L
.70781 .30659 L
.66138 .32351 L
.61383 .33793 L
.55728 .35163 L
.52244 .3583 L
.48908 .36344 L
.47238 .36556 L
.45389 .36754 L
.43616 .36907 L
.41927 .3702 L
Mistroke
.39914 .3711 L
.38832 .37138 L
.37661 .37152 L
.36421 .37147 L
.35237 .37124 L
.34166 .37086 L
.32994 .37025 L
.30853 .3686 L
.29767 .36748 L
.28568 .36601 L
.26453 .36274 L
.24482 .35883 L
.22601 .35421 L
.20634 .34829 L
.17261 .33479 L
.15346 .3246 L
.13668 .31359 L
.1093 .28943 L
.09747 .27546 L
.08663 .25978 L
.0713 .23052 L
.0599 .19968 L
.05198 .16941 L
.04792 .1479 L
.04573 .13185 L
.045 .12435 L
.04471 .1205 L
.04451 .11717 L
.04433 .11161 L
.04434 .10639 L
.04454 .10211 L
.04493 .09804 L
.04547 .09468 L
.04608 .09195 L
.04675 .08975 L
.04758 .08759 L
.04858 .08561 L
.04962 .08397 L
.05101 .08226 L
.05266 .0807 L
.05421 .07957 L
.05607 .0785 L
.05826 .07755 L
.06085 .07673 L
.06212 .07642 L
.06352 .07613 L
.06617 .07572 L
.06885 .07544 L
.07194 .07524 L
.07506 .07515 L
Mistroke
.07808 .07515 L
.08189 .07522 L
.08416 .0753 L
.08634 .0754 L
.09532 .07597 L
.11385 .0776 L
.13976 .08025 L
.21533 .08808 L
.34853 .10078 L
.5142 .11659 L
.66267 .13401 L
.73217 .14525 L
.75823 .15058 L
.78267 .15657 L
.8025 .16253 L
.81761 .1682 L
.82938 .17379 L
.83907 .17986 L
.84314 .18316 L
.8467 .18674 L
.84934 .19018 L
.85115 .19335 L
.85258 .19712 L
.85308 .19928 L
.85333 .20129 L
.85333 .20501 L
.85266 .20901 L
.85142 .2129 L
.84979 .2165 L
.84733 .22071 L
.84445 .22475 L
.82945 .24014 L
.80606 .25746 L
.77295 .27683 L
.73366 .29576 L
.69034 .31332 L
.64556 .32862 L
.59249 .34352 L
.56242 .35053 L
.52745 .35742 L
.49346 .36284 L
.46097 .36682 L
.44055 .36873 L
.42076 .37011 L
.40972 .37069 L
.3994 .37109 L
.38796 .37139 L
.37569 .37152 L
.35519 .37131 L
.33571 .37058 L
Mistroke
.32447 .3699 L
.31412 .3691 L
.29073 .36666 L
.26981 .36364 L
.25018 .35998 L
.21418 .3508 L
.19472 .34418 L
.17745 .33704 L
.15829 .32739 L
.14156 .31703 L
.11684 .29705 L
.10452 .28411 L
.09452 .2715 L
.0778 .2442 L
.06484 .21437 L
.05547 .18407 L
.05001 .15977 L
.04648 .13803 L
.04533 .12806 L
.04498 .12411 L
.04469 .12023 L
.04437 .11368 L
.04431 .10841 L
.04446 .10343 L
.04463 .1009 L
.04485 .09872 L
.04538 .09514 L
.046 .09228 L
.04687 .08938 L
.04785 .087 L
.0489 .08506 L
.05017 .08324 L
.0515 .08175 L
.05284 .08056 L
.05454 .07935 L
.05658 .07825 L
.0587 .07739 L
.06083 .07674 L
.06205 .07644 L
.06342 .07615 L
.06607 .07573 L
.06885 .07544 L
.0716 .07526 L
.07478 .07516 L
.0767 .07514 L
.07855 .07515 L
.08251 .07524 L
.08486 .07533 L
.08708 .07544 L
.09557 .07599 L
Mistroke
.10445 .07672 L
.12885 .07911 L
.19276 .08579 L
.45879 .11111 L
.54 .11926 L
.6231 .12877 L
.6924 .13842 L
.74683 .14814 L
.78822 .15811 L
.80669 .16398 L
.8206 .1695 L
.83284 .17575 L
.83805 .17912 L
.84269 .18276 L
.84602 .18599 L
.84894 .1896 L
.85094 .19292 L
.85226 .19608 L
.85315 .19971 L
.8534 .20371 L
.85298 .20755 L
.85205 .21116 L
.85062 .21478 L
.84892 .21809 L
.84375 .22564 L
.83618 .23396 L
.82584 .24315 L
.80181 .2602 L
.73758 .29402 L
.64147 .32989 L
.58248 .34597 L
.54686 .35377 L
.51102 .3602 L
.47583 .36515 L
.45518 .36741 L
.4356 .36912 L
.41881 .37023 L
.39994 .37107 L
.37988 .3715 L
.36075 .37143 L
.34183 .37086 L
.32143 .36968 L
.30204 .36796 L
.28439 .36583 L
.26363 .36258 L
.24133 .35805 L
.20201 .34682 L
.18324 .33958 L
.1636 .33027 L
.14568 .31978 L
Mistroke
.12803 .30693 L
.1132 .29349 L
.10118 .28014 L
.09113 .26668 L
.08187 .25176 L
.06801 .22267 L
.05899 .19666 L
.05243 .17144 L
.04793 .148 L
.04571 .13171 L
.04496 .12399 L
.04454 .11771 L
.04435 .11279 L
.04431 .10797 L
.04445 .1035 L
.04473 .09982 L
.04523 .09601 L
.04555 .09427 L
.04594 .0925 L
.04677 .08968 L
.04768 .08737 L
.04893 .08502 L
.05022 .08317 L
.05191 .08135 L
.05371 .0799 L
.05542 .07884 L
.0574 .07789 L
.05944 .07715 L
.06142 .07659 L
.06395 .07606 L
.06546 .07582 L
.06691 .07563 L
.06973 .07537 L
.07293 .0752 L
.07602 .07514 L
.07901 .07516 L
.0827 .07525 L
.08642 .07541 L
.09008 .07561 L
.09366 .07585 L
.10252 .07655 L
.15616 .08198 L
.38416 .10408 L
.54788 .1201 L
.61881 .12823 L
.68922 .13792 L
.74648 .14807 L
.7886 .15822 L
.80711 .16413 L
.82102 .16969 L
Mistroke
.83377 .17631 L
.84271 .18278 L
.84601 .18598 L
.84891 .18955 L
.85114 .19334 L
.85253 .19694 L
.85324 .20035 L
.8534 .20351 L
.85304 .2072 L
.85218 .21074 L
.8507 .21461 L
.84853 .21878 L
.84314 .2264 L
.83441 .23568 L
.82447 .24425 L
.76776 .27953 L
.6934 .31217 L
.64605 .32847 L
.58723 .34482 L
.55472 .35217 L
.51776 .3591 L
.48081 .36453 L
.46275 .36664 L
.44544 .36831 L
.42904 .36959 L
.41104 .37063 L
.39068 .37133 L
.3717 .37153 L
.35272 .37125 L
.33173 .37036 L
.32104 .36965 L
.3096 .3687 L
.28894 .36643 L
.26948 .36358 L
.24854 .35964 L
.2303 .35535 L
.21138 .34993 L
.17711 .33689 L
.14821 .32139 L
.13204 .31011 L
.11856 .29868 L
.10552 .28526 L
.09311 .26954 L
.07557 .23975 L
.06373 .21126 L
.05451 .18026 L
.05109 .16522 L
.04869 .15256 L
.04594 .13371 L
.04508 .12538 L
Mistroke
.04475 .12116 L
.04453 .11755 L
.04432 .11147 L
.04434 .10643 L
.04452 .10243 L
.04487 .09858 L
.04542 .0949 L
.04577 .09324 L
.0462 .09153 L
.04708 .08883 L
.04804 .08661 L
.04914 .08467 L
.05031 .08306 L
.05284 .08055 L
.05444 .07942 L
.05605 .07851 L
.05796 .07767 L
.06017 .07692 L
.06144 .07658 L
.06283 .07627 L
.06548 .07581 L
.06705 .07561 L
.06857 .07546 L
.07031 .07533 L
.07227 .07523 L
.07402 .07517 L
.07601 .07514 L
.07797 .07514 L
.07984 .07517 L
.08359 .07528 L
.08785 .07548 L
.09195 .07573 L
.09667 .07607 L
.10607 .07687 L
.13227 .07947 L
.32048 .09817 L
.48305 .11347 L
.57881 .1235 L
.66307 .13406 L
.73193 .1452 L
.76413 .15192 L
.78922 .1584 L
.80829 .16456 L
.82286 .17053 L
.83481 .17696 L
.83986 .18046 L
.84434 .18428 L
.84768 .1879 L
.85006 .19132 L
.85192 .19512 L
Mistroke
.85263 .19727 L
.85307 .19924 L
.85341 .20289 L
.8531 .20689 L
.85219 .21071 L
.85085 .21427 L
.84911 .21777 L
.8471 .22106 L
.84122 .22866 L
.82426 .24442 L
.79909 .2619 L
.76435 .28127 L
.72761 .2984 L
.68245 .31621 L
.63625 .33148 L
.57901 .34679 L
.55177 .35277 L
.52095 .35856 L
.49029 .36328 L
.46128 .36679 L
.44224 .36859 L
.4239 .36992 L
.40414 .37092 L
.39283 .37128 L
.38232 .37148 L
.36452 .37148 L
.34472 .37098 L
.32381 .36985 L
.30413 .36817 L
.29294 .36693 L
.28075 .36532 L
.25866 .36166 L
.23736 .35711 L
.21798 .35194 L
.17611 .33643 L
.15656 .32641 L
.13661 .31354 L
.12174 .30157 L
.1077 .2877 L
.08692 .26024 L
.0777 .244 L
.07052 .22872 L
.05855 .1952 L
.05191 .16907 L
.04809 .14899 L
.04666 .13942 L
.04555 .13023 L
.04486 .12261 L
.04448 .11641 L
.04431 .11057 L
Mistroke
.04436 .10569 L
.04456 .10182 L
.04493 .09807 L
.0455 .0945 L
.04589 .09272 L
.04629 .09121 L
.04718 .08857 L
.04816 .08639 L
.0492 .08459 L
.05043 .08292 L
.05296 .08046 L
.05456 .07934 L
.05617 .07845 L
.05809 .07762 L
.06032 .07688 L
.06157 .07655 L
.06295 .07624 L
.06559 .0758 L
.06715 .0756 L
.06867 .07545 L
.07041 .07532 L
.07236 .07522 L
.07402 .07517 L
.0759 .07514 L
.07794 .07514 L
.07992 .07517 L
.08366 .07528 L
.08794 .07549 L
.09246 .07577 L
.09772 .07616 L
.10833 .07708 L
.13242 .07948 L
.31879 .09801 L
.4801 .11318 L
.57569 .12315 L
.6605 .1337 L
.72905 .14466 L
.75937 .15084 L
.78679 .15771 L
.80589 .1637 L
.82296 .17058 L
.83496 .17706 L
.84335 .18334 L
.84648 .18649 L
.84922 .18999 L
.85132 .19371 L
.85261 .19721 L
.85326 .20055 L
.8534 .20362 L
.85304 .20721 L
Mistroke
.85221 .21065 L
.85078 .21442 L
.8487 .21848 L
.84357 .22588 L
.83615 .234 L
.82586 .24313 L
.80026 .26117 L
.7694 .27868 L
.6952 .31149 L
.64453 .32894 L
.59134 .34381 L
.52584 .35771 L
.48589 .36387 L
.46634 .36625 L
.44764 .36812 L
.43102 .36945 L
.41285 .37054 L
.40234 .37099 L
.39229 .3713 L
.37321 .37153 L
.35281 .37125 L
.33371 .37047 L
.31254 .36897 L
.30181 .36793 L
.28994 .36656 L
.25258 .36047 L
.23185 .35575 L
.21321 .3505 L
.18026 .33829 L
.16464 .33082 L
.14847 .32156 L
.13091 .30923 L
.11593 .29619 L
.09247 .26862 L
.08194 .25188 L
.07382 .23608 L
.06032 .20102 L
.05337 .17556 L
.04855 .15175 L
.04696 .14155 L
.04573 .13187 L
.04495 .12386 L
.04453 .11742 L
.04432 .11126 L
.04435 .1062 L
.04453 .10217 L
.0449 .09833 L
.04547 .09465 L
.04583 .09299 L
.04626 .09129 L
Mistroke
.04717 .0886 L
.04815 .08641 L
.04927 .08448 L
.05046 .08288 L
.05303 .08041 L
.05466 .07928 L
.05629 .07839 L
.05823 .07756 L
.06046 .07684 L
.0629 .07625 L
.06531 .07584 L
.06672 .07565 L
.06831 .07548 L
.0714 .07527 L
.07449 .07516 L
.07803 .07514 L
.08161 .07521 L
.08507 .07534 L
.08733 .07545 L
.08982 .0756 L
.09453 .07591 L
.10646 .0769 L
.13345 .07959 L
.14864 .08119 L
Mfstroke
.85137 .19383 m
.85264 .19732 L
.85326 .20054 L
.85337 .2043 L
.85291 .2079 L
.85201 .21127 L
.85079 .21442 L
.84903 .21791 L
.8467 .22165 L
.8404 .22958 L
.83283 .23714 L
.80999 .25484 L
.7492 .28867 L
.65867 .32441 L
.60051 .34148 L
.56667 .3496 L
.52817 .35729 L
.48882 .36348 L
.45114 .3678 L
.43228 .36936 L
.4222 .37003 L
.41142 .37061 L
.39132 .37132 L
.37249 .37153 L
.35254 .37124 L
.33414 .37049 L
.3127 .36898 L
.29228 .36685 L
.27342 .36422 L
.25604 .36116 L
.2174 .35177 L
.19803 .3454 L
.18049 .33839 L
.16065 .32869 L
.14364 .31844 L
.11328 .29357 L
.09991 .27857 L
.08782 .26167 L
.07907 .24664 L
.07113 .23012 L
.06027 .20086 L
.05324 .175 L
.04902 .15446 L
.04623 .13609 L
.04526 .12734 L
.04468 .12016 L
.04437 .11353 L
.04431 .10823 L
.04437 .10558 L
.04449 .1029 L
Mistroke
.04487 .09853 L
.04542 .09494 L
.04608 .09198 L
.04679 .08963 L
.04768 .08738 L
.0488 .08523 L
.05014 .08328 L
.05142 .08183 L
.05296 .08045 L
.05452 .07936 L
.05612 .07848 L
.05811 .07761 L
.06008 .07695 L
.06206 .07643 L
.06402 .07604 L
.0663 .0757 L
.06889 .07543 L
.07166 .07526 L
.07491 .07516 L
.07855 .07515 L
.08218 .07523 L
.08583 .07538 L
.08935 .07557 L
.098 .07618 L
.15128 .08146 L
.34399 .10036 L
.4932 .11447 L
.65394 .1328 L
.72439 .14381 L
.75578 .15004 L
.78444 .15705 L
.80609 .16377 L
.82204 .17015 L
.83453 .17678 L
.84328 .18328 L
.84649 .1865 L
.84924 .19003 L
.85118 .19341 L
.85241 .19655 L
.8532 .20008 L
.85339 .204 L
.85322 .20599 L
.85286 .20815 L
.85174 .21206 L
.85087 .21424 L
.84991 .21626 L
.84722 .22088 L
.84055 .22942 L
.82237 .2459 L
.80103 .26069 L
Mistroke
.77208 .27728 L
.69699 .31081 L
.64634 .32838 L
.59177 .34371 L
.53722 .35563 L
.50396 .3613 L
.47155 .36565 L
.45264 .36766 L
.4317 .3694 L
.42191 .37005 L
.41146 .37061 L
.39247 .37129 L
.37389 .37153 L
.35631 .37134 L
.33678 .37063 L
.31566 .36923 L
.30389 .36815 L
.29299 .36694 L
.26833 .36339 L
.24674 .35925 L
.22415 .3537 L
.18658 .34098 L
.1665 .33178 L
.14881 .32177 L
.13395 .31157 L
.11943 .29948 L
.09706 .27492 L
.08585 .25852 L
.07694 .24251 L
.06417 .21251 L
.05519 .18297 L
.04993 .15939 L
.0465 .13822 L
.04546 .12934 L
.04506 .12512 L
.04473 .12084 L
.0444 .11452 L
.04431 .10924 L
.0444 .1047 L
.04463 .10095 L
.04507 .09703 L
.04562 .0939 L
.04642 .09075 L
.04733 .08818 L
.04826 .08619 L
.04936 .08434 L
.05165 .0816 L
.05311 .08034 L
.05459 .07932 L
.05635 .07836 L
Mistroke
.05839 .0775 L
.06056 .07681 L
.06315 .07621 L
.06453 .07596 L
.06609 .07573 L
.06908 .07542 L
.0723 .07523 L
.07559 .07515 L
.07874 .07515 L
.08243 .07524 L
.08482 .07533 L
.08716 .07544 L
.0918 .07572 L
.10351 .07664 L
.1299 .07922 L
.32131 .09825 L
.47331 .11251 L
.56294 .12174 L
.64264 .13128 L
.70783 .14092 L
.75741 .1504 L
.80002 .16171 L
.81782 .16829 L
.83112 .17475 L
.83619 .17785 L
.84087 .18124 L
.84429 .18422 L
.84737 .18753 L
.85001 .19125 L
.85112 .1933 L
.85196 .19523 L
.85297 .19872 L
.8534 .20251 L
.85335 .20462 L
.85314 .20658 L
.85273 .20874 L
.85208 .21106 L
.85053 .21498 L
.84818 .21936 L
.84216 .22758 L
.83466 .23544 L
.81511 .25128 L
.7921 .26614 L
.72375 .30005 L
.68114 .31668 L
.62948 .33349 L
.57941 .3467 L
.51943 .35881 L
.50029 .36185 L
.47949 .36469 L
Mistroke
.45968 .36696 L
.44075 .36871 L
.4226 .37 L
.40276 .37098 L
.39128 .37132 L
.3803 .3715 L
.35947 .3714 L
.34037 .3708 L
.31988 .36957 L
.30227 .36798 L
.28281 .36561 L
.26198 .36228 L
.23976 .35768 L
.21905 .35226 L
.20071 .34636 L
.16542 .33122 L
.14759 .321 L
.13202 .31009 L
.10773 .28774 L
.09614 .2737 L
.08681 .26008 L
.0712 .23028 L
.06451 .21345 L
.05947 .19826 L
.05219 .17038 L
.04945 .15684 L
.04756 .14565 L
.04623 .13611 L
.04522 .12685 L
.04485 .12255 L
.0446 .11879 L
.04442 .11511 L
.04432 .11144 L
.04431 .10863 L
.04436 .10578 L
.04448 .10302 L
.04465 .10064 L
.0451 .0968 L
.04543 .09487 L
.04577 .09323 L
.04659 .09023 L
.04749 .08781 L
.04864 .0855 L
.05004 .0834 L
.05141 .08184 L
.05281 .08057 L
.0545 .07938 L
.0565 .07829 L
.05868 .0774 L
.06084 .07674 L
Mistroke
.06211 .07642 L
.06354 .07613 L
.0663 .0757 L
.0691 .07542 L
.07229 .07523 L
.07521 .07515 L
.07863 .07515 L
.08083 .07519 L
.08299 .07526 L
.08728 .07545 L
.09226 .07575 L
.09813 .07619 L
.12269 .07848 L
.30284 .09652 L
.45804 .11104 L
.61707 .12802 L
.68847 .13781 L
.75244 .14932 L
.78043 .15597 L
.80469 .16328 L
.82125 .16979 L
.82901 .1736 L
.83515 .17718 L
.8443 .18423 L
.84778 .18804 L
.84923 .19001 L
.85053 .19214 L
.85215 .19577 L
.85306 .1992 L
.85334 .20132 L
.8534 .20334 L
.85305 .20719 L
.8522 .21069 L
.85077 .21446 L
.84894 .21806 L
.8469 .22136 L
.8404 .22958 L
.83246 .23748 L
.80898 .25552 L
.78091 .27253 L
.74369 .29124 L
.69636 .31105 L
.64656 .32831 L
.59539 .3428 L
.53812 .35546 L
.51039 .3603 L
.47843 .36483 L
.46126 .36679 L
.44235 .36858 L
.43174 .3694 L
Mistroke
.42191 .37005 L
.40233 .37099 L
.38422 .37145 L
.36412 .37147 L
.34486 .37099 L
.32679 .37005 L
.3158 .36924 L
.30387 .36815 L
.28218 .36553 L
.26112 .36212 L
.24188 .35817 L
.1994 .34589 L
.1791 .33778 L
.15802 .32724 L
.12642 .3056 L
.11101 .29124 L
.09847 .27675 L
.07982 .24804 L
.07243 .23305 L
.06567 .2166 L
.05699 .18971 L
.05087 .16415 L
.04732 .14404 L
.04619 .13578 L
.04543 .129 L
.0448 .12183 L
.04442 .11508 L
.04431 .1096 L
.04438 .10503 L
.0445 .10268 L
.04468 .10036 L
.04513 .09661 L
.0458 .09309 L
.04626 .0913 L
.04674 .08976 L
.04783 .08705 L
.04904 .08483 L
.05027 .08311 L
.05176 .08149 L
.05357 .08 L
.0557 .07869 L
.05794 .07768 L
.06015 .07693 L
.06242 .07636 L
.06469 .07593 L
.06737 .07558 L
.07047 .07532 L
.07212 .07523 L
.07398 .07517 L
.07758 .07514 L
Mistroke
.08134 .07521 L
.08507 .07534 L
.08877 .07553 L
.09245 .07577 L
.10164 .07648 L
.12423 .07864 L
.31665 .09781 L
.46914 .11211 L
.55939 .12135 L
.63956 .13087 L
.7056 .14055 L
.75569 .15002 L
.79885 .16134 L
.81689 .1679 L
.83034 .17432 L
.83559 .17746 L
.84042 .18089 L
.84394 .18389 L
.84711 .18722 L
.8487 .18926 L
.84997 .19117 L
.85186 .19498 L
.85292 .19849 L
.85339 .20229 L
.85337 .20442 L
.85317 .2064 L
.85277 .20858 L
.85213 .2109 L
.85059 .21485 L
.84825 .21924 L
.84223 .22749 L
.83475 .23535 L
.81509 .2513 L
.79201 .26619 L
.72362 .3001 L
.68048 .31692 L
.62836 .33382 L
.57781 .34707 L
.51751 .35914 L
.48103 .3645 L
.44597 .36827 L
.42857 .36962 L
.40919 .37071 L
.39052 .37134 L
.37291 .37153 L
.36206 .37145 L
.35023 .37118 L
.33899 .37074 L
.32858 .37017 L
.30873 .36862 L
Mistroke
.28766 .36627 L
.26501 .36282 L
.24403 .35866 L
.22137 .35293 L
.19777 .34531 L
.16058 .32865 L
.14343 .3183 L
.12609 .30532 L
.1128 .29308 L
.10007 .27876 L
.08126 .25067 L
.07291 .23412 L
.06548 .2161 L
.05974 .19915 L
.05498 .18216 L
.04922 .15554 L
.04617 .13562 L
.04522 .12685 L
.04466 .11976 L
.04448 .1164 L
.04435 .11295 L
.04431 .10963 L
.04433 .10675 L
.04455 .10198 L
.04492 .09816 L
.04519 .09626 L
.04553 .09433 L
.0463 .09118 L
.04721 .0885 L
.04816 .08638 L
.04943 .08425 L
.05077 .08253 L
.05215 .08114 L
.05353 .08003 L
.05519 .07897 L
.05708 .07803 L
.05914 .07724 L
.06156 .07655 L
.06405 .07604 L
.06652 .07568 L
.0689 .07543 L
.07169 .07525 L
.07481 .07516 L
.07795 .07514 L
.08164 .07521 L
.08582 .07538 L
.08964 .07559 L
.09409 .07588 L
.11704 .07791 L
.2669 .09312 L
Mistroke
.42366 .10777 L
.5957 .12545 L
.66533 .13438 L
.72899 .14465 L
.7572 .15035 L
.78386 .15689 L
.80274 .16262 L
.81964 .16908 L
.83335 .17606 L
.83838 .17936 L
.84287 .18292 L
.84619 .18617 L
.84909 .18981 L
.85107 .19318 L
.85236 .19638 L
.85322 .20021 L
.85339 .20216 L
.85337 .20431 L
.85286 .20816 L
.85183 .2118 L
.85096 .21403 L
.84996 .21615 L
.84768 .22016 L
.84061 .22934 L
.83299 .23699 L
.82322 .24523 L
.80159 .26034 L
.73485 .29524 L
.64857 .32767 L
.59023 .34409 L
.55995 .35106 L
.53031 .35691 L
.49883 .36207 L
.46898 .36595 L
.45255 .36767 L
.4344 .36921 L
.41481 .37044 L
.39599 .3712 L
.37917 .37151 L
.36045 .37142 L
.34065 .37081 L
.32198 .36972 L
.30438 .3682 L
.28829 .36635 L
.26972 .36362 L
.25223 .3604 L
.23387 .35626 L
.21443 .35088 L
.1807 .33849 L
.16236 .32961 L
Mistroke
.14428 .31886 L
.11579 .29604 L
.10344 .28285 L
.09189 .26779 L
.07524 .23907 L
.06746 .22127 L
.06156 .20489 L
.05362 .17662 L
.04918 .15535 L
.0475 .14525 L
.04631 .13676 L
.0455 .12971 L
.04496 .12388 L
.04456 .11805 L
.04434 .11247 L
.04432 .10724 L
.04448 .10296 L
.04484 .09883 L
.0454 .09501 L
.04612 .09183 L
.04693 .08923 L
.04778 .08716 L
.04882 .08519 L
.0501 .08333 L
.05139 .08186 L
.05304 .0804 L
.05475 .07922 L
.05648 .0783 L
.05821 .07757 L
.06024 .0769 L
.06257 .07632 L
.0651 .07587 L
.0666 .07567 L
.06803 .07551 L
.07096 .07529 L
.07395 .07517 L
.07572 .07515 L
.07768 .07514 L
.0814 .07521 L
.08382 .07529 L
.08619 .0754 L
.09089 .07566 L
.10075 .0764 L
.11278 .0775 L
.13917 .08019 L
.22869 .0894 L
.35844 .10169 L
.51506 .11667 L
.65523 .13297 L
.72222 .14341 L
Mistroke
.74957 .14871 L
.77228 .15388 L
.8095 .165 L
.82433 .17122 L
.83069 .17451 L
.83667 .17817 L
.8413 .18159 L
.84537 .1853 L
.84873 .18929 L
.85101 .19307 L
.85252 .1969 L
.85326 .20058 L
.85339 .20392 L
.85297 .20759 L
.85188 .21165 L
.85029 .2155 L
.84792 .21978 L
.84469 .22443 L
.83603 .23411 L
.82583 .24315 L
.80212 .26 L
.77009 .27833 L
.69073 .31317 L
.64761 .32797 L
.59543 .34279 L
.56038 .35097 L
.52612 .35766 L
.49151 .36311 L
.47317 .36546 L
.45303 .36762 L
.43428 .36921 L
.41684 .37033 L
.39899 .37111 L
.38181 .37148 L
.36152 .37144 L
.3425 .37089 L
.3214 .36968 L
.31068 .3688 L
.29884 .36761 L
.27887 .36505 L
.26036 .36198 L
.23855 .3574 L
.21908 .35227 L
.1809 .33857 L
.16132 .32905 L
.14405 .31871 L
.11676 .29698 L
.09608 .27362 L
.07846 .24549 L
.07148 .23092 L
Mistroke
.0651 .21506 L
.05541 .18382 L
.0499 .15922 L
.04786 .14753 L
.04626 .13632 L
.04524 .12711 L
.04465 .11967 L
.04437 .11369 L
.04431 .10871 L
.04443 .1039 L
.04459 .10145 L
.04478 .09937 L
.04527 .09578 L
.04598 .09237 L
.0464 .09082 L
.04691 .08929 L
.04794 .08682 L
.04908 .08477 L
.0505 .08283 L
.05218 .08111 L
.05392 .07975 L
.05572 .07868 L
.0575 .07785 L
.05973 .07705 L
.06202 .07644 L
.0647 .07593 L
.0663 .0757 L
.0678 .07553 L
.07092 .07529 L
.07408 .07517 L
.07598 .07514 L
.07807 .07515 L
.07993 .07517 L
.08205 .07523 L
.08442 .07531 L
.08708 .07544 L
.09218 .07575 L
.10236 .07654 L
.11517 .07773 L
.14399 .0807 L
.22268 .08881 L
.49741 .11489 L
.58623 .12435 L
.67446 .1357 L
.71026 .14133 L
.74385 .14753 L
.77118 .15361 L
.79244 .15935 L
.80956 .16503 L
.8247 .1714 L
Mistroke
.83155 .175 L
.83697 .17838 L
.84164 .18187 L
.84526 .18519 L
.848 .18831 L
.84999 .1912 L
.85165 .19446 L
.85281 .198 L
.85335 .20144 L
.85331 .20525 L
.85269 .20888 L
.85165 .2123 L
.84984 .2164 L
.84721 .22088 L
.84078 .22916 L
.82341 .24508 L
.79519 .26429 L
.76235 .28228 L
.7261 .29905 L
.68126 .31664 L
.63738 .33113 L
.58413 .34557 L
.54869 .3534 L
.51392 .35973 L
.47884 .36478 L
.46023 .3669 L
.4397 .36879 L
.42081 .37011 L
.40316 .37096 L
.38601 .37142 L
.3677 .37151 L
.34725 .37108 L
.32803 .37013 L
.30677 .36844 L
.29483 .36716 L
.28399 .36578 L
.24623 .35914 L
.22516 .35398 L
.20591 .34815 L
.1691 .33308 L
.15007 .32256 L
.13401 .31161 L
.10891 .28901 L
.09691 .27471 L
.08722 .26073 L
.07289 .23407 L
.06192 .20598 L
.0541 .17859 L
.04885 .15345 L
.04725 .14359 L
Mistroke
.04601 .13433 L
.0452 .12664 L
.0447 .1204 L
.04438 .11382 L
.04431 .11056 L
.04432 .10771 L
.04448 .10311 L
.04485 .09876 L
.04512 .09671 L
.04548 .09462 L
.04588 .09275 L
.04638 .0909 L
.04743 .08796 L
.04858 .08561 L
.04991 .08357 L
.05127 .08198 L
.05301 .08042 L
.05483 .07918 L
.05668 .07821 L
.05853 .07745 L
.06071 .07677 L
.06321 .07619 L
.06596 .07575 L
.06759 .07556 L
.06914 .07541 L
.07234 .07523 L
.0756 .07515 L
.07754 .07514 L
.07969 .07517 L
.0816 .07521 L
.08378 .07529 L
.08621 .0754 L
.08895 .07554 L
.09422 .07589 L
.11641 .07785 L
.14724 .08104 L
.22787 .08932 L
.35863 .10171 L
.516 .11677 L
.65666 .13317 L
.72354 .14365 L
.77322 .15411 L
.79407 .15984 L
.81052 .16539 L
.82527 .17168 L
.83741 .17868 L
.84213 .18227 L
.84628 .18626 L
.84929 .1901 L
.85132 .19371 L
Mistroke
.85264 .19734 L
.85328 .20068 L
.85336 .20458 L
.85283 .2083 L
.85172 .21212 L
.85084 .21431 L
.84986 .21636 L
.84419 .22508 L
.83736 .23279 L
.82819 .2412 L
.80065 .26093 L
.7682 .2793 L
.73199 .2965 L
.68736 .31442 L
.64352 .32925 L
.59072 .34396 L
.55854 .35136 L
.52738 .35744 L
.49402 .36276 L
.46154 .36676 L
.4427 .36855 L
.42214 .37003 L
.41019 .37067 L
.39879 .37111 L
.38845 .37138 L
.37716 .37152 L
.36703 .3715 L
.35582 .37133 L
.34403 .37096 L
.33295 .37043 L
.31298 .36901 L
.29146 .36675 L
.27155 .36392 L
.2497 .35988 L
.22719 .35453 L
.20654 .34836 L
.17152 .33427 L
.15325 .32448 L
.13765 .31428 L
.1088 .28889 L
.09527 .27252 L
.08454 .25637 L
.06799 .22261 L
.06132 .20416 L
.05659 .18826 L
.05045 .16204 L
.04703 .14207 L
.04588 .13322 L
.04502 .12466 L
.04473 .12078 L
Mistroke
.0445 .1169 L
.04437 .11351 L
.04431 .11062 L
.04437 .10553 L
.04459 .10137 L
.04502 .09737 L
.04534 .09536 L
.04567 .09367 L
.04639 .09086 L
.04733 .0882 L
.04835 .08602 L
.04942 .08426 L
.05079 .0825 L
.05223 .08107 L
.05366 .07994 L
.05531 .0789 L
.05726 .07795 L
.05922 .07722 L
.0615 .07657 L
.0628 .07627 L
.06423 .07601 L
.06676 .07565 L
.06923 .07541 L
.07208 .07524 L
.07541 .07515 L
.07851 .07515 L
.08204 .07523 L
.08559 .07537 L
.08901 .07555 L
.09898 .07626 L
.10953 .07719 L
.13907 .08018 L
.2191 .08845 L
.33948 .09994 L
.50836 .11599 L
.59357 .1252 L
.66836 .13482 L
.7265 .14419 L
.7545 .14976 L
.77753 .15521 L
.79786 .16102 L
.81352 .16654 L
.82764 .17287 L
.83408 .17651 L
.83919 .17995 L
.84341 .1834 L
.84657 .18659 L
.84934 .19018 L
.85056 .19221 L
.85149 .19409 L
Mistroke
.85279 .19791 L
.85318 .19994 L
.85338 .20211 L
.85325 .2058 L
.85291 .20792 L
.85242 .20992 L
.8512 .21346 L
.84932 .21737 L
.84455 .22462 L
.83832 .2318 L
.83121 .23859 L
.78278 .27148 L
.74728 .28957 L
.70178 .30897 L
.65549 .32545 L
.6001 .34159 L
.54406 .35432 L
.50966 .36041 L
.47584 .36514 L
.4593 .367 L
.44332 .3685 L
.42852 .36962 L
.41254 .37056 L
.39488 .37123 L
.37829 .37151 L
.36019 .37142 L
.33996 .37078 L
.32022 .36959 L
.30174 .36793 L
.2814 .36541 L
.25974 .36187 L
.23718 .35707 L
.21628 .35144 L
.19778 .34531 L
.17891 .33769 L
.14699 .32062 L
.12126 .30114 L
.09828 .27651 L
.08752 .2612 L
.07892 .24635 L
.07125 .23041 L
.06443 .21324 L
.05543 .18391 L
.0499 .15921 L
.04678 .1403 L
.04559 .13056 L
.04516 .12625 L
.04485 .12255 L
.04447 .11624 L
.04431 .11025 L
Mistroke
.04439 .10501 L
.04452 .10235 L
.04471 .10005 L
.04496 .0978 L
.04525 .0959 L
.0456 .09399 L
.04605 .09209 L
.04681 .08956 L
.04764 .08747 L
.04877 .08528 L
.04994 .08353 L
.05129 .08196 L
.05292 .08049 L
.05463 .0793 L
.05635 .07836 L
.05821 .07757 L
.0601 .07694 L
.06191 .07647 L
.064 .07605 L
.06644 .07569 L
.06921 .07541 L
.07173 .07525 L
.07468 .07516 L
.07642 .07514 L
.07839 .07515 L
.08217 .07523 L
.08611 .07539 L
.09001 .07561 L
.0998 .07632 L
.11182 .07741 L
.17064 .0835 L
Mfstroke
0 0 m
1 0 L
1 .4424 L
0 .4424 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{494.563, 218.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;U0001B2000`400?l00000o`00003oo`3ooooo
0?ooonL0oooo003o0?ooool0ooooi`3oool00?l0ooooo`3ooooW0?ooo`00o`3ooon50?ooo`030?oo
g`2LB00000000080000000<0M;oo0?ooo`3oool04@3oool0103OW4P000000018W03Ooooo0?ooodD0
oooo003o0?ooohL0oooo00<0okmd0000M02oool0503oool01@3o_g@004RL0=oOW018B9`0gooo0?l0
ooooA03oool00?l0ooooQ`3oool00`3ookl0M00007Boo`0G0?ooo`030?oOW018M;l0oooo0?l0oooo
@`3oool00?l0ooooQ`3oool00`3ooml0W4P004RLg`0H0?ooo`030?noM01d_ol0oooo0?l0oooo@P3o
ool00?l0ooooR03oool00`3OW4P00000000000020000000607Boo`3oool0oooo0?ooo`2oM00007Bo
1P3oool01@3OW4P00000000000000000M;oo00@0oooo00<0okmd0000001d_ol0o`3ooom20?ooo`00
o`3ooon80?ooo`070?noM00004P0W=oo0?ooo`3ooml0W4P0001d_`020?ooo`030?noM00007@0_ooo
00@0oooo00<0omnL04P0001d_ol00P3oool00`2oM00007Bo0?ooo`020?ooo`040=nLB00007@0M7A8
09cOool0oooo@@3oool00?l0ooooR03oool00`3ookl0M00007Boo`020?ooo`070?oog`2LB000B9cO
0?ooo`3ogi`0B00007Boo`040?ooo`030=nLB000B9`0gooo00<0oooo00T0gibL0;ooo`3oool0oooo
0=nLB000B9`0gooO09adW03Oool0o`3ooom00?ooo`00o`3ooon80?ooo`030?oog`2LB000B9cO00<0
oooo00L0omnL04P0B02Lgol0oooO09a80000B9`0gooo00<0oooo00D0okmd000000000000000004RL
g`050?ooo`050;md0000B9`0gooo0?oOW01dW=l0o`3ooom00?ooo`00o`3ooon90?ooo`030=nLB000
07@0_ooo0080oooo00L0oooO09a80018W=l0oooo0;md0018M7@0M9cO00<0oooo00L0oono07@0B02L
gol0oooo0=nLB0000000B9cO0080oooo00<0oooO09a80000M;l00P3oool00`3OW9`0_ooo0?ooo`3o
0?oooch0oooo003o0?ooohT0oooo00@0okmd00000000B9`0gooo0P3oool01`3OW4P007Bo0?ooo`3o
_g@004RL0;nLB01d_ol00`3oool02`3o_g@004RL0=ooo`3oool0oono07@00018W=l0oooo0?oog`2L
B00007Bo0080oooo00<0oono07Ad_`3oool0o`3oooln0?ooo`00o`3ooon90?ooo`0K0?oo_`1d0000
M9bL04P0M02oool0oooO09a80000M;l0oooo0?oo_`1d04P0W=oo0;md001dM7@004RL0=ooo`3oool0
gia80000M02oool0oooo0=nLB000B9`0gooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0M02oool0
o`3oooln0?ooo`00o`3ooon80?ooo`0A0?oOW0180000000004RLg`3ookl0M0000000000007@0_ooo
0?oOW0180000000007Boo`3oool0_g@00000M02oool00P3oool02@3ogi`0B000000000000000M;oo
0;md00000000001809cOo`020?ooo`030=nLB000B9`0gooo0?l0oooo?P3oool00?l0ooooo`3ooooW
0?ooo`00o`3ooooo0?ooonL0oooo003o0?ooool0ooooi`3oool00?l0ooooo`3ooooW0?ooo`00o`3o
oooo0?ooonL0oooo003o0?ooool0ooooi`3oool00?l0ooooo`3ooooW0?ooo`00o`3ooooo0?ooonL0
oooo003o0?ooool0ooooi`3oool00?l0ooooo`3ooooW0?ooo`00o`3ooooo0?ooonL0oooo003o0?oo
ool0ooooi`3oool00?l0ooooo`3ooooW0?ooo`00o`3ooooo0?ooonL0oooo003o0?ooool0ooooi`3o
ool00?l0ooooo`3ooooW0?ooo`00Q`3oool0102oM00000000000001d_omi0?ooo`040;md00000000
000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P00000000000030000000304RLg`3o
ool0oooo0700oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`050?ooo`030?oo
g`2LB000B9cO0740oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`030?ooo`05
0?oog`2LB000000000000000M;l0L`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000
M;oo00<0oooo00H0oono07@00000000000000018W03Ooom10?ooo`00QP3oool01P3OW4P007Bo0?oo
o`3ogi`0B00004RLggL0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`1_0?ooo`060=nLB000M;l0
oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`060?ooo`030=nLB000B9`0gooo06l0oooo
00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00L0gia8001d
_`3oool0oono07@00000B9`0gooo0700oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`03
0?oOW0180000M;oo0080oooo00<0oono07@00018W=l00P3oool00`3OW4P0001d0;ooo`100?ooo`00
Q@3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo07D0oooo00<0oooO09a80018W=l0
0P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo0780oooo00<0oooO09a80018W=l0
0P3oool00`3o_g@0001809cOo`0:0?ooo`030?oOW01804P0W=oo06h0oooo00<0oooO09a80018W=l0
0P3oool00`3o_g@0001809cOo`060?ooo`030?oog`2LB000M;oo0080oooo00<0omnL04P00018W=l0
K`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0okmd0018W03Oool0
0`3oool00`2oM000B9cO0?ooo`0o0?ooo`00Q@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2L
B00004RL0=ooog@0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`03
0?noM000M;l0oooo0740oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?oo
o`030?noM0000000000000@0000000<004RL0=ooo`3oool0J`3oool00`3ooml0W4P004RLg`020?oo
o`040?oog`2LB00004RL0=ooo`D0oooo00<0oono07@0001d_ol00`3oool00`2oM000001d0;ooo`1^
0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3o_g@004RL0=oo
o`030?ooo`030;md0000M;l0oooo03l0oooo00250?ooo`030?oog`2LB00007Bo00<0oooo00<0gia8
0000B02Lgol0M03oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00T0oooo00<0okmd
04RLg`3oool0L03oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO
09a8B02Lgol00P3oool00`2oM00007Bo0?ooo`1]0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia8
0000B02Lgol01@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo06h0oooo00<0oooO
09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB000M;oo0080oooo00<0oono
07@00018W=l0@03oool008H0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`1e0?oo
o`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`1`0?oo
o`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3oool01`3ookl0M01d0;ooo`3oool0
okmd0018W03Oool0KP3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0
_g@00000M02oool00P3oool00`3OW4P0001809cOo`1_0?ooo`030;md0000B9`0gooo0080oooo00<0
omnL04P00018W=l01`3oool01P2oM000001809cOg`2LB000001d0;oood00oooo00260?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l0M@3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00/0oooo00<0_g@007Boo`3oool0K`3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00L0oooo00H0omnL04Q8W03Oool0omnL04P0B02Lgom^0?ooo`030=nLB00004P0W=oo
0080oooo00<0oooO09a80000M;l01P3oool0203o_g@0000004RLg`3oool0oooO09a80000B9`0gooo
K`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00P0oooo00D0oooO09a800000000
04RL0=ooo`100?ooo`00QP3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo07@0oooo
00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0:0?ooo`030?oOW01807@0_ooo06l0oooo
00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`050?noM000M;l0oooO09a80018
W=l0KP3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00D0oooo00<0oooO09a80000
00000P0000000`0007@0_ooo0?ooo`1_0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03O
ool01`3oool01P2oM000001809cOo`3ogi`0B4RL0=ooocl0oooo00260?ooo`040?oog`2LB00004RL
0=ooo`80oooo00<0gia80018W03Oool0M03oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000
B9`0gooo00X0oooo00<0oooO09a8001d_ol0K`3oool0103ooml0W4P00018W03Oool20?ooo`030=nL
B000B9`0gooo00P0oooo00@0gia804RLg`2oM00007BoKP3oool0103ooml0W4P00018W03Oool20?oo
o`030=nLB000B9`0gooo00H0oooo00<0oono07@00000M;l0L`3oool0103ooml0W4P00018W03Oool2
0?ooo`030=nLB000B9`0gooo00H0oooo00<0omnL04P0001d_ol00P3oool00`3o_g@0B9cO0?ooo`0n
0?ooo`00Q`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo07D0oooo00<0omnL04P0
001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo_`1d0000B9cO0700oooo00<0omnL04P0
001d_ol00P3oool00`3OW4P007Bo0?ooo`090?ooo`040=nLB01dM7@0001d0;ooofh0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030?oOW0180000B9cO07<0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`060?ooo`030?oOW01804P0W=oo0080oooo00<0okmd
0018W03Oool0?P3oool008P0oooo00H0gia80000M02oool0oooO09a80018W=mg0?ooo`060=nLB000
07@0_ooo0?oog`2LB000B9cO1`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol0L@3oool0
1P3OW4P0001d0;ooo`3ooml0W4P004RLg`/0oooo00<0_g@00000B02Lgol0K`3oool01P3OW4P0001d
0;ooo`3ooml0W4P004RLg`T0oooo00@0oooO09a8000007@0_oooLP3oool01P3OW4P0001d0;ooo`3o
oml0W4P004RLg`L0oooo00<0oooO09a80018W=l00P3oool00`2oM00007Bo0?ooo`0n0?ooo`00R@3o
ool0103OW4P0000000000000M;mi0?ooo`040=nLB00000000000001d_`T0oooo00D0omnL04P00000
0000000007Boo`1c0?ooo`040=nLB00000000000001d_``0oooo00<0oooO09a80018W=l0L03oool0
103OW4P0000000000000M;l<0?ooo`040?oo_`1d0000000004RLgg40oooo00@0gia8000000000000
07Bo2@3oool01@3ooml0W4P000000000000007Bo0400oooo003o0?ooool0ooooi`3oool00?l0oooo
o`3ooooW0?ooo`00o`3ooooo0?ooonL0oooo003o0?ooool0ooooi`3oool00?l0ooooo`3ooooW0?oo
o`00o`3ooooo0?ooonL0oooo003o0?ooool0ooooi`3oool00?l0ooooo`3ooooW0?ooo`00o`3ooooo
0?ooonL0oooo003o0?ooool0ooooi`3oool00?l0ooooo`3ooooW0?ooo`00P`3ooooo00000?l00000
:000000l0?ooo`00LP3oool0102oM00000000000001d_ol=0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03X0oooo
001a0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO303oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0j0?ooo`00
L03oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00/0oooo00@000000?ooo`000000
00000`3oool00`000000oooo0?ooo`0N0?ooo`800000903oool2000002<0oooo0P00000F0?ooo`03
0000003oool0oooo00/0oooo0P00000S0?ooo`8000008`3oool2000002@0oooo0P0000040?ooo`03
0000003oool0oooo01`0oooo0P00000S0?ooo`8000008`3oool2000001T0oooo00<000000?ooo`3o
ool0203oool2000002<0oooo0P00000S0?ooo`8000008`3oool2000000P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0j0?ooo`00L03oool00`3ooml0W4P004RLg`020?ooo`040?oo
g`2LB00004RL0=ooo`X0oooo00<000000?ooo`0000001@00000P0?ooo`H00000803oool6000001l0
oooo1P00000B0?ooo`030000003oool0oooo00/0oooo1P00000O0?ooo`H000007`3oool600000200
oooo1`00000N0?ooo`H000007`3oool6000001l0oooo1P00000E0?ooo`030000003oool0oooo00P0
oooo1P00000O0?ooo`H000007`3oool6000001l0oooo1P0000040?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0>P3oool00700oooo00<0oooO09a80000M;l00`3oool00`3OW4P00018
09cOo`0:0?ooo`030000003oool0000000T00000703oool:000001`0oooo2P00000K0?ooo`X00000
703oool:000001/0oooo2P00000K0?ooo`X00000703oool:000001/0oooo2P00000K0?ooo`X00000
6`3oool:000001`0oooo2P00000K0?ooo`X000006`3oool:000001/0oooo2P00000>0?ooo`030000
003oool0oooo03X0oooo001a0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3o
ool>000001X0oooo3000000J0?ooo``000006@3oool<000001X0oooo3000000I0?ooo``000006@3o
ool<000001X0oooo3000000I0?ooo``000006@3oool<000001T0oooo3000000J0?ooo``000006@3o
ool<000001T0oooo3000000I0?ooo``000002@3oool4000003`0oooo001a0?ooo`030=nLB00004P0
W=oo0080oooo00<0oooO09a80000M;l02P3oool00`000000oooo00000009000001`0oooo2P00000L
0?ooo`X000006`3oool:000001`0oooo2P00000K0?ooo`X000006`3oool:000001`0oooo2P00000K
0?ooo`X000006`3oool:000001/0oooo2P00000L0?ooo`X000006`3oool:000001/0oooo2P00000K
0?ooo`X000003P3oool00`000000oooo0?ooo`0j0?ooo`00L@3oool00`3ogi`0B00004RLg`030?oo
o`030;md0000B9`0gooo00T0oooo00<000000?ooo`0000001@00000P0?ooo`H00000803oool60000
01l0oooo1P00000P0?ooo`H000007`3oool6000001l0oooo1P00000P0?ooo`H000007`3oool60000
01l0oooo1P00000O0?ooo`H00000803oool6000001l0oooo1P00000O0?ooo`H000007`3oool60000
0180oooo00<000000?ooo`3oool0>P3oool00740oooo00@0oooO09a80000B9`0gooo0P3oool00`3O
W4P004RL0=ooo`090?ooo`040000003oool00000000002@0oooo0P00000T0?ooo`8000008`3oool2
000002@0oooo0P00000S0?ooo`8000008`3oool2000002@0oooo0P00000S0?ooo`8000008`3oool2
000002<0oooo0P00000T0?ooo`8000008`3oool2000002<0oooo0P00000S0?ooo`8000005P3oool0
0`000000oooo0?ooo`0j0?ooo`00LP3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo
00T0oooo00<000000?ooo`3oool0o`3ooooo0?ooob@0oooo00<000000?ooo`3oool0>P3oool007<0
oooo00H0gia80000M02oool0oooO09a80018W=l:0?ooo`030000003oool0oooo0?l0ooooo`3ooolT
0?ooo`030000003oool0oooo03X0oooo001d0?ooo`040=nLB00000000000001d_`/0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooob@0oooo00<000000?ooo`3oool0>P3oool008<0oooo0`00003o0?oo
ool0oooo8P3oool3000003`0oooo00230?ooo`030000003oool0oooo0?l0ooooo`3ooolT0?ooo`03
0000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo0?l0ooooo`3ooolT0?ooo`030000
003oool0oooo03X0oooo00230?ooo`030000003oool0oooo0?l0ooooo`3ooolT0?ooo`030000003o
ool0oooo03X0oooo00230?ooo`030000003oool0oooo0?l0ooooo`3ooolT0?ooo`030000003oool0
oooo03X0oooo00230?ooo`030000003oool0oooo0?l0ooooo`3ooolT0?ooo`030000003oool0oooo
03X0oooo00230?ooo`<00000o`3ooooo0?ooob80oooo0`00000l0?ooo`00P`3oool00`000000oooo
0?ooo`0U0?ooo`8000008`3oool2000002@0oooo0P00000S0?ooo`800000903oool2000002<0oooo
0P00000T0?ooo`8000008`3oool2000002<0oooo0P00000S0?ooo`8000008`3oool2000002@0oooo
0P00000S0?ooo`8000008`3oool2000001H0oooo00<000000?ooo`3oool0>P3oool008<0oooo00<0
00000?ooo`3oool09@3oool6000001l0oooo1P00000P0?ooo`H000007`3oool600000200oooo1P00
000O0?ooo`H00000803oool6000001l0oooo1P00000O0?ooo`H000007`3oool6000001l0oooo1P00
000P0?ooo`H000007`3oool6000001l0oooo1P00000B0?ooo`030000003oool0oooo03X0oooo0023
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0603oool:000001/0oooo2P00000L
0?ooo`X000006`3oool:000001`0oooo2P00000K0?ooo`X00000703oool:000001/0oooo2P00000K
0?ooo`X000006`3oool:000001/0oooo2P00000L0?ooo`X000006`3oool:000001/0oooo2P00000>
0?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0603oool<000001T0oooo3000000J0?ooo``000006@3oool<000001X0oooo3000000I0?oo
o``000006P3oool<000001T0oooo3000000I0?ooo``000006@3oool<000001T0oooo3000000J0?oo
o``000006@3oool<000001T0oooo3000000<0?ooo`030000003oool0oooo03X0oooo00230?ooo`03
0000003oool0oooo00X0oooo0P00000I0?ooo`T00000703oool9000001d0oooo2@00000L0?ooo`T0
00007@3oool9000001`0oooo2@00000M0?ooo`T00000703oool9000001`0oooo2@00000L0?ooo`T0
0000703oool9000001d0oooo2@00000L0?ooo`T00000703oool9000000l0oooo00<000000?ooo`3o
ool0>P3oool008<0oooo00<000000?ooo`3oool02@3oool3000001T0oooo0`00000R0?ooo`<00000
8`3oool300000280oooo0`00000S0?ooo`<000008P3oool3000002<0oooo0`00000R0?ooo`<00000
8P3oool300000280oooo0`00000R0?ooo`<000008`3oool300000280oooo0`00000R0?ooo`<00000
5@3oool00`000000oooo0?ooo`0j0?ooo`00P`3oool3000000T0oooo0`00003o0?ooool0oooo5P3o
ool3000003`0oooo00230?ooo`030000003oool0oooo00T0oooo0`00003o0?ooool0oooo603oool0
0`000000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?ooo`090?ooo`@00000o`3ooooo0?oo
oaL0oooo00<000000?ooo`3oool0>P3oool008<0oooo00<000000?ooo`3oool02@3oool400000?l0
ooooo`3ooolG0?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00T0oooo
1000003o0?ooool0oooo5`3oool00`000000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?oo
o`080?ooo`D00000o`3ooooo0?oooaL0oooo00<000000?ooo`3oool0>P3oool008<0oooo0`000008
0?ooo`H00000o`3ooooo0?oooa@0oooo0`00000l0?ooo`00P`3oool00`000000oooo0?ooo`080?oo
o`H00000o`3ooooo0?oooaH0oooo00<000000?ooo`3oool0>P3oool005`0oooo00@0_g@000000000
0000M;oo0`3oool00`3ogi`0B00007Boo`040?ooo`040;md00000000000007Boo`<0oooo00H0omnL
04P00000000000000018W03Oool<0?ooo`030000003oool0oooo0?l0ooooo`3ooolT0?ooo`030000
003oool0oooo03X0oooo001K0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0
B00007Boo`030?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool01P3o_g@0000007Boo`3o
ool0omnL04Qd_``0oooo00<000000?ooo`3oool0B`3oool2000002<0oooo0P00003o0?oooiT0oooo
0P00000F0?ooo`030000003oool0oooo03X0oooo001J0?ooo`030?oog`2LB000B9cO0080oooo00<0
okmd0000B02Lgol01P3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0
okmd04RLg`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`800000903oool400000240oooo1@00
000P0?ooo`800000903oool2000002<0oooo0P00000S0?ooo`800000903oool2000002<0oooo0P00
000S0?ooo`8000008`3oool2000002@0oooo0P00000S0?ooo`8000008`3oool4000001@0oooo00<0
00000?ooo`3oool0>P3oool005X0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03O
ool50?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ookl0M01d
0;ooo`0:0?ooo`030000003oool0oooo02D0oooo1P00000P0?ooo`L000007P3oool7000001h0oooo
1P00000P0?ooo`H000007`3oool6000001l0oooo1P00000P0?ooo`H000007`3oool6000001l0oooo
1P00000O0?ooo`H00000803oool500000200oooo1@00000P0?ooo`L000004@3oool00`000000oooo
0?ooo`0j0?ooo`00FP3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0
oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB000M;oo00X0oooo00<0
00000?ooo`3oool09@3oool:000001/0oooo2P00000K0?ooo`/000006`3oool:000001`0oooo2P00
000K0?ooo`X000006`3oool:000001`0oooo2P00000K0?ooo`X000006`3oool:000001/0oooo2P00
000L0?ooo`T00000703oool9000001/0oooo2P00000?0?ooo`030000003oool0oooo03X0oooo001K
0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3oool00`2oM00004RL0=ooo`02
0?ooo`030?oOW0180000B9cO00D0oooo00<0oono07@00018W=l02P3oool4000000T0oooo00<00000
0?ooo`3oool0603oool<000001T0oooo3000000I0?ooo`d000006@3oool<000001T0oooo3@00000I
0?ooo``000006@3oool<000001T0oooo3@00000I0?ooo``000006@3oool<000001T0oooo3000000I
0?ooo``000006@3oool<000001T0oooo3000000:0?ooo`@00000?03oool005/0oooo00<0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8
0000M;l01@3oool00`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0603oool:000001/0oooo1P00000O0?ooo`X00000703oool9000001`0oooo2P00000L0?oo
o`T00000703oool9000001`0oooo2P00000L0?ooo`T00000703oool9000001`0oooo2@00000L0?oo
o`T00000703oool9000001`0oooo2@00000@0?ooo`030000003oool0oooo03X0oooo001K0?ooo`03
0?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01@3oool00`3ogi`0B00004RLg`030?ooo`0:
0;md0000B9`0gooo0?ooo`3ogml0gooo0?noM0000000001d0;ooo`X0oooo00<000000?ooo`3oool0
2P3oool2000001T0oooo1P0000140?ooo`@000008P3oool300000280oooo1000000R0?ooo`<00000
8P3oool300000280oooo1000000R0?ooo`<000008P3oool300000280oooo0`00000R0?ooo`<00000
8P3oool300000280oooo0`00000F0?ooo`030000003oool0oooo03X0oooo001K0?ooo`040?oog`2L
B00004RL0=ooo`80oooo00<0gia80018W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`09
0=nLB000B9`0gooo0?ooo`3ookl0M0000000000004P0W=oo00/0oooo00<000000?ooo`3oool02@3o
ool300000180oooo7`00003o0?ooonH0oooo00<000000?ooo`3oool0>P3oool005`0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`060?ooo`030?oOW0180000M;oo0080oooo00<0gia8
001d_`3oool00P3oool00`3OW9`0_ooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo0`00000?
0?ooo`@00000503ooolD00000?l0oooog03oool00`000000oooo0?ooo`0j0?ooo`00G@3oool01P3O
W4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000M02oool0oooO09a80018W=l30?ooo`03
0?oOW01dW=l0oooo00`0oooo00<000000?ooo`3oool02@3oool3000000h0oooo0`00000Q0?oooa<0
0000o`3ooooB0?ooo`030000003oool0oooo03X0oooo001N0?ooo`040=nLB00000000000001d_`X0
oooo00@0gia800000000000007Bo1@3oool01@2oM0000000000000000000B9cO00T0oooo00<00000
0?ooo`3oool02@3oool4000000`0oooo0P00000/0?oooa@00000o`3oooo80?ooo`030000003oool0
oooo03X0oooo00230?ooo`<000002@3oool4000000/0oooo0P00000g0?oooa@00000o`3ooonl0?oo
o`<00000?03oool008<0oooo00<000000?ooo`3oool02@3oool4000000X0oooo0P0000120?oooa@0
0000o`3ooond0?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00P0oooo
1@00000:0?ooo`800000C03ooolE00000?l0ooooZ@3oool00`000000oooo0?ooo`0j0?ooo`00P`3o
ool00`000000oooo0?ooo`080?ooo`H00000203oool2000005H0oooo5P00003o0?oooil0oooo00<0
00000?ooo`3oool0>P3oool008<0oooo00<000000?ooo`3oool0203oool6000000P0oooo0P00001P
0?oooaH00000o`3ooonE0?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0d0?oooaH00000o`3ooomc0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>P3oool008<0oooo0`00000F0?ooo`03
0000003oool0oooo0380oooo0`00000R0?ooo`8000006`3ooolF000001P0oooo0P00000S0?ooo`80
00008`3oool2000002@0oooo0P00000S0?ooo`8000008`3oool2000002<0oooo0P00000S0?ooo`80
00008`3oool2000002@0oooo0`00000C0?ooo`<00000?03oool008<0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0<0?ooo`800000903oool500000200oooo1@00000P0?oooaT00000
3@3oool400000240oooo1@00000P0?ooo`D000008@3oool400000240oooo1@00000P0?ooo`D00000
803oool500000200oooo1@00000P0?ooo`D000008@3oool5000001<0oooo00<000000?ooo`3oool0
>P3oool008<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`H000007`3o
ool8000001h0oooo1`00000N0?ooo`L000001@3ooolG000000<0oooo1`00000N0?ooo`L000007P3o
ool7000001l0oooo1`00000N0?ooo`L000007P3oool7000001h0oooo1`00000N0?ooo`L000007P3o
ool7000001h0oooo2000000A0?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0203oool2000000h0oooo2P00000K0?ooo`X000006`3oool;
000001/0oooo2P00000=0?oooaP00000703oool:000001/0oooo2P00000K0?ooo`X000006`3oool;
000001/0oooo2P00000K0?ooo`X000006`3oool:000001/0oooo2P00000K0?ooo`X000003`3oool0
0`000000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00P0oooo0P00000>0?ooo``000006@3oool<000001T0oooo3@00000I0?ooo``000005P3ooolF0000
01<0oooo3000000I0?ooo``000006@3oool<000001T0oooo3@00000I0?ooo``000006@3oool<0000
01T0oooo3000000I0?ooo``000006@3oool<000000d0oooo00<000000?ooo`3oool0>P3oool008<0
oooo00<000000?ooo`3oool02P3oool2000000T0oooo00<000000?ooo`3oool03@3oool900000440
oooo1`00000O0?ooo`H000007`3ooolN000000P0oooo2@00000L0?ooo`T00000703oool9000001`0
oooo2P00000L0?ooo`T00000703oool9000001`0oooo2@00000L0?ooo`H000007`3oool6000001<0
oooo00<000000?ooo`3oool0>P3oool008<0oooo00<000000?ooo`3oool02@3oool3000000T0oooo
00<000000?ooo`3oool03@3oool300000980oooo0`00000?0?oooaL000008P3oool300000280oooo
0`00000R0?ooo`@000008P3oool300000280oooo0`00000R0?ooo`<00000H03oool00`000000oooo
0?ooo`0j0?ooo`00P`3oool3000000T0oooo0`0000090?ooo`030000003oool0oooo0;h0oooo5P00
003o0?ooocD0oooo0`00000l0?ooo`00P`3oool00`000000oooo0?ooo`090?ooo`<000002@3oool0
0`000000oooo0?ooo`390?oooaD00000o`3oool]0?ooo`030000003oool0oooo03X0oooo00230?oo
o`030000003oool0oooo00T0oooo100000080?ooo`030000003oool0oooo0=<0oooo5P00003o0?oo
ob80oooo00<000000?ooo`3oool0>P3oool008<0oooo00<000000?ooo`3oool02@3oool4000000P0
oooo00<000000?ooo`3oool0g@3ooolF00000?l0oooo603oool00`000000oooo0?ooo`0j0?ooo`00
P`3oool00`000000oooo0?ooo`090?ooo`@00000203oool00`000000oooo0?ooo`3X0?oooa@00000
o`3oool?0?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00P0oooo1@00
00080?ooo`030000003oool0oooo0?80oooo5000003^0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0>P3oool008<0oooo0`0000080?ooo`H000001`3oool200000?d0oooo5000003S
0?ooo`<000004P3oool3000003`0oooo00230?ooo`030000003oool0oooo00P0oooo1P0000070?oo
o`800000o`3oool70?oooaD00000f03oool5000001<0oooo00<000000?ooo`3oool0>P3oool006D0
oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d00000000
0080000000<0B9cO0?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`800000F@3oool00`00
0000oooo0?ooo`2d0?oooa@00000Q@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0280oooo1P00000B0?ooo`030000003oool0oooo03X0oooo001T0?ooo`060=nLB000M;l0oooo0?oO
W0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030?noM0000000M;oo00d0oooo00<00000
0?ooo`3oool05@3oool2000005T0oooo0`00000R0?ooo`800000903oool2000002<0oooo0P00000S
0?ooo`800000903oool2000000<0oooo4`00000=0?ooo`8000008`3oool2000002<0oooo0P00000T
0?ooo`<000008P3oool300000240oooo2000000A0?ooo`030000003oool0oooo03X0oooo001S0?oo
o`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3ooml0W4P0001d_`0=0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0<@3oool2000002@0oooo1@00000P0?oo
o`D000008@3oool400000240oooo1@00000P0?ooo`D000008@3oool4000000X0oooo4P0000050?oo
o`@000008@3oool500000200oooo1@00000Q0?ooo`D00000803oool500000240oooo1`00000@0?oo
o`030000003oool0oooo03X0oooo001S0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000
B9`0gooo203oool00`3OW4P004RL0=ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0<@3oool6000001l0oooo2000000N0?ooo`L000007`3oool7000001h0oooo1`00000N0?oo
o`L000007`3oool7000000l0oooo5P00000N0?ooo`L000007P3oool7000001h0oooo2000000M0?oo
o`P000008P3oool5000000l0oooo00<000000?ooo`3oool0>P3oool006<0oooo00<0oooO09a80000
M;l00`3oool00`3OW4P0001809cOo`080?ooo`030?oOW01804P0W=oo00`0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0340oooo2P00000K0?ooo`X0
0000703oool:000001/0oooo2P00000K0?ooo`/000006`3oool:000001/0oooo2P00000F0?oooa40
00006@3oool;000001X0oooo2`00000K0?ooo`X000006`3oool:00000280oooo1000000>0?ooo`03
0000003oool0oooo03X0oooo001T0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0
203oool00`3ookl0M00007Boo`0<0?ooo`@000002@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool<000001T0oooo3000000J0?ooo``00000
6@3oool<000001T0oooo3@00000I0?ooo``000006@3oool<000001T0oooo5000000A0?ooo`d00000
603oool=000001T0oooo3000000I0?ooo``000008`3oool2000000X0oooo1000000l0?ooo`00I03o
ool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00T0oooo00<0_g@0001d_`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`8000002P3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01L0oooo2P00000K0?ooo`H00000803oool9000001`0oooo2@00000L0?ooo`L000007`3o
ool6000001l0oooo1P00000O0?ooo`H000001@3oool@000000X0oooo1`00000N0?ooo`L00000PP3o
ool00`000000oooo0?ooo`0j0?ooo`00I03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0
gooo00P0oooo00<0gia80018W03Oool02`3oool00`000000oooo0?ooo`090?ooo`<000002P3oool2
000001L0oooo0P00000I0?ooo`H00000A@3oool300000280oooo0`00002U0?ooo`l00000/@3oool0
0`000000oooo0?ooo`0j0?ooo`00I03oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0
gooo00P0oooo00<0omnL04P0B02Lgol02`3oool00`000000oooo0?ooo`090?ooo`<000002P3oool2
000001L0oooo0`00000H0?ooo`800000o`3ooolO0?ooo`h00000ZP3oool00`000000oooo0?ooo`0j
0?ooo`00I@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00P0oooo00<0oono07@0
001d_ol02`3oool00`000000oooo0?ooo`090?ooo`@000002@3oool2000001L0oooo0`00003o0?oo
od00oooo3@00002T0?ooo`030000003oool0oooo03X0oooo001V0?ooo`060=nLB00007@0_ooo0?oo
g`2LB000B9cO2P3oool00`2oM00007Bo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo10000009
0?ooo`8000005`3oool300000?l0ooooAP3oool=000009h0oooo00<000000?ooo`3oool0>P3oool0
06L0oooo00@0gia800000000000007Bo2@3oool01@3ookl0M0000000000007@0_ooo00X0oooo00<0
00000?ooo`3oool02@3oool5000000P0oooo0P00000F0?ooo`@00000o`3ooom=0?ooo``00000S03o
ool2000000X0oooo00<000000?ooo`3oool0>P3oool008<0oooo0`0000090?ooo`D00000203oool2
000001H0oooo1000003o0?oooe<0oooo300000260?ooo`@000001P3oool3000003`0oooo00230?oo
o`030000003oool0oooo00P0oooo1P0000090?ooo`8000005@3oool400000?l0ooooF03oool;0000
05<0oooo00<000000?ooo`3oool0;03oool6000000H0oooo00<000000?ooo`3oool0>P3oool008<0
oooo00<000000?ooo`3oool0203oool7000000P0oooo0P00000E0?ooo`D00000?`3oool00`000000
oooo0?ooo`3o0?oooa/0oooo2P00001=0?ooo`<00000;03oool6000000L0oooo00<000000?ooo`3o
ool0>P3oool008<0oooo00<000000?ooo`3oool0203oool7000000P0oooo0P00000D0?ooo`H00000
?P3oool300000?l0oooo8@3oool:000004P0oooo1000000[0?ooo`D00000203oool00`000000oooo
0?ooo`0j0?ooo`00P`3oool00`000000oooo0?ooo`0G0?ooo`800000503oool6000003h0oooo1000
00160?ooo`030000003oool0oooo0=/0oooo2@00000N0?ooo`030000003oool0oooo0280oooo1P00
000Z0?ooo`D00000203oool00`000000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?ooo`0G
0?ooo`800000E`3oool6000001l0oooo0P00000T0?ooo`<000008P3oool00`000000oooo0?ooo`0R
0?ooo`800000903oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool08`3oool;000001X0oooo0`00000R0?ooo`L00000:@3oool4000000T0oooo00<00000
0?ooo`3oool0>P3oool008<0oooo0`00000G0?ooo`800000E`3oool7000001h0oooo1000000R0?oo
o`D00000803oool300000280oooo1000000R0?ooo`<000008P3oool300000280oooo0`00000R0?oo
o`H000000P3oool8000001D0oooo1P00000O0?ooo`P00000:@3oool3000000P0oooo0`00000l0?oo
o`00P`3oool00`000000oooo0?ooo`0H0?ooo`800000E@3oool9000001d0oooo1P00000O0?ooo`L0
00007`3oool500000200oooo1P00000P0?ooo`D00000803oool500000200oooo1@00000P0?ooo`L0
00001@3oool800000140oooo1`00000P0?ooo`L00000:03oool2000000/0oooo00<000000?ooo`3o
ool0>P3oool008<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`800000
E`3oool8000001/0oooo2@00000M0?ooo`T00000703oool8000001d0oooo2@00000M0?ooo`P00000
7@3oool8000001d0oooo2000000N0?ooo`T000001`3oool7000000d0oooo2P00000Q0?ooo`D00000
9P3oool3000000/0oooo00<000000?ooo`3oool0>P3oool008<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0;0?ooo`8000005@3oool00`000000oooo0?ooo`130?ooo`D000006P3o
ool;000001/0oooo2`00000J0?ooo`X000006`3oool;000001/0oooo2P00000K0?ooo`X000006`3o
ool:000001/0oooo300000090?ooo`L000002@3oool<00000240oooo1000000U0?ooo`800000303o
ool00`000000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?ooo`0:0?ooo`800000303oool2
000001H0oooo0P00000S0?ooo`030000003oool0oooo0240oooo0P00000I0?ooo`d000006@3oool<
000001T0oooo3000000I0?ooo`d000006@3oool<000001T0oooo3000000I0?ooo``000006@3oool=
000000/0oooo1`00000<0?ooo`L000008`3oool2000002@0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0j0?ooo`00D03oool00`2oW9`0gooo0?ooo`0`0?ooo`030000003oool0oooo
00T0oooo0`00000<0?ooo`8000005P3oool400000600oooo1`00003o0?oooaX0oooo1`00001W0?oo
o`030000003oool0oooo03X0oooo001>0?ooo`040?oo_`1d000004RL0=oooc40oooo00<000000?oo
o`3oool02@3oool3000000d0oooo0P00000F0?ooo`@00000o`3ooon30?ooo`H00000I@3oool00`00
0000oooo0?ooo`0j0?ooo`00BP3oool00`3ookl0M00000000003000000030018W03Oool0oooo0300
oooo0`0000090?ooo`<000003@3oool2000001H0oooo1P00003o0?oooh@0oooo1@00001Q0?ooo`<0
0000?03oool004@0oooo00@0oono09bLg`3ookl0M000100000001P00M;l0oooo0?ooo`3oool0_ibL
0=oooc40oooo00<000000?ooo`3oool02@3oool4000000`0oooo0P00000G0?ooo`L00000o`3ooon5
0?ooo`@00000H@3oool00`000000oooo0?ooo`0j0?ooo`00A03oool01@3ogi`0B000000000000000
07Bo00<0oooo00<0_gAd0;ooo`3oool0=03oool00`000000oooo0?ooo`090?ooo`@00000303oool2
000001P0oooo1`00000m0?ooo`L00000o`3ooom20?ooo`@00000;03oool200000340oooo00<00000
0?ooo`3oool0>P3oool004D0oooo00<0oono07A8W03Oool0103oool00`3OW9`0_ooo0?ooo`0d0?oo
o`030000003oool0oooo00T0oooo1000000<0?ooo`800000603oool6000003h0oooo1`00003o0?oo
od@0oooo100000000`3oool000000?ooo`0W0?ooo`D00000;P3oool00`000000oooo0?ooo`0j0?oo
o`00A03oool00`3ooml0W4Qd0;ooo`040?ooo`030?oo_`1dM;l0oooo03D0oooo00<000000?ooo`3o
ool0203oool6000000`0oooo0P00000H0?ooo`@00000@03oool500000?l0oooo8@3oool00`000000
oooo0?ooo`0S0?ooo`@00000:03oool7000002D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0j0?ooo`00A03oool00`3ogi`0M9cO0?ooo`030?ooo`030?oo_`1d07@0_ooo03H0oooo
00<000000?ooo`3oool0203oool6000000`0oooo0P00000H0?ooo`<00000@@3oool500000?l0oooo
803oool3000002<0oooo1`00000V0?ooo`H000009@3oool3000000D0oooo00<000000?ooo`3oool0
>P3oool004@0oooo00P0okmd001d_`3oool0oooo0?oog`2LB000001d0;ooocL0oooo0`0000080?oo
o`<000003`3oool2000001T0oooo00<000000?ooo`3oool0@03oool500000?l0oooo803oool40000
0240oooo2@00000U0?ooo`D000009@3oool4000000<0oooo0`00000l0?ooo`00A@3oool01@2oM000
00000000000004P0W=oo03T0oooo00<000000?ooo`3oool06P3oool2000005`0oooo1@00000I0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo0280oooo1@00000R0?ooo`X000008`3oool5000002D0oooo1@0000040?oo
o`030000003oool0oooo03X0oooo001L0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0
001d_ol00P3oool00`3ookl0M000000000020000000604RLg`3oool0oooo0?ooo`3ogi`0B0000P00
00000`00B9`0gooo0?ooo`0;0?ooo`030000003oool0oooo01/0oooo0P00001L0?ooo`<000006P3o
ool3000002<0oooo0`00000R0?ooo`<000008P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool08`3oool300000280oooo1P00000R0?ooo`D000000P3o
ool300000240oooo1@00000U0?ooo`H00000103oool00`000000oooo0?ooo`0j0?ooo`00F`3oool0
1P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol0103oool00`3o_g@00000
07Boo`040?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo303oool00`000000oooo0?ooo`0K0?oo
o`800000G03oool3000001T0oooo1@00000Q0?ooo`D00000803oool500000240oooo0`00000R0?oo
o`<000008P3oool300000280oooo1@00000P0?ooo`P000008P3oool500000080oooo0`00000P0?oo
o`@000009@3oool8000000<0oooo00<000000?ooo`3oool0>P3oool004X0oooo00@0oono07@00000
07@0_ooo303oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0oooO09a8
0000M;l02@3oool00`3o_g@0B9cO0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03P3oool2000005`0oooo0`00000I0?ooo`L000007`3oool7000001h0oooo1`00000N0?oo
o`H000007`3oool600000200oooo1@00000P0?ooo`L00000803oool700000280oooo100000040?oo
o`8000007`3oool3000002D0oooo1`0000050?ooo`030000003oool0oooo03X0oooo00140?ooo`04
0?oo_`2LW=l0oono07@000@0000000<0M;oo0?ooo`3oool02`3oool00`3ooml0W4P004RLg`020?oo
o`040?oog`2LB00004RL0=ooo`P0oooo00<0gia80018W03Oool0203oool00`3ookl0M01d0;ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool2000005`0oooo0`00000H
0?ooo`T000007@3oool9000001`0oooo2@00000M0?ooo`P000007@3oool8000001d0oooo2000000M
0?ooo`T000008@3oool5000002@0oooo0P0000040?ooo`8000007`3oool3000002D0oooo1@000007
0?ooo`030000003oool0oooo03X0oooo00140?ooo`060?oOW018000000000000000004P0W=oo403o
ool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00P0oooo00<0omnL04P0B02Lgol0203o
ool00`3ooml0W4P007Boo`0:0?ooo`030000003oool0oooo00X0oooo0P00000@0?ooo`800000G03o
ool00`000000oooo0?ooo`0G0?ooo`/000006`3oool;000001X0oooo2`00000J0?ooo`/000006P3o
ool;000001/0oooo2P00000K0?ooo`/000008P3oool3000002@0oooo0P0000040?ooo`8000007P3o
ool2000002D0oooo0`00000:0?ooo`030000003oool0oooo03X0oooo00150?ooo`030?oo_`1d0000
M;oo01<0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`080?ooo`030?oo_`1d0000
M;oo00P0oooo00<0oono07@00018W=l02P3oool4000000P0oooo0`00000@0?ooo`8000004@3oool2
000002@0oooo0`00000R0?ooo`030000003oool0oooo01d0oooo1P00000P0?ooo`H000007`3oool6
000001T0oooo3000000I0?ooo`d000006@3oool<000001l0oooo1P00000S0?ooo`800000903oool0
0`000000oooo0?ooo`030?ooo`8000007@3oool2000002@0oooo0P0000090?ooo`@00000?03oool0
04D0oooo00<0_gAd0;ooo`3oool04`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo
00T0oooo00<0_g@0001d_`3oool01`3oool00`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo
00T0oooo0`00000@0?ooo`8000004@3oool2000002D0oooo2000003o0?ooog80oooo0P00001A0?oo
o`030000003oool0oooo03X0oooo00140?ooo`040?noM000000004RL0=oooa<0oooo00<0omnL04P0
0018W=l00`3oool00`2oM00004RL0=ooo`080?ooo`030=nLB000B9`0gooo00@0oooo00H0omoO0=oo
o`3o_g@000000000M02oool:0?ooo`030000003oool0oooo00T0oooo0`00000A0?ooo`8000004@3o
ool3000002@0oooo2P00003o0?ooog00oooo0P00001@0?ooo`030000003oool0oooo03X0oooo001K
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0203oool00`3ogi`0B01809cO
o`040?ooo`050?oo_`1d000000000000B02Lgol02`3oool00`000000oooo0?ooo`090?ooo`@00000
403oool200000140oooo1000000T0?ooo`P00000o`3oooma0?ooo`800000D03oool00`000000oooo
0?ooo`0j0?ooo`00A`3oool01P3OW4P00000000000000000001809cOo`l0oooo00<0omnL04P0001d
_ol00P3oool00`3OW4P007Bo0?ooo`080?ooo`030?oo_`1d0000M;oo00D0oooo00<0gibL0;ooo`3o
ool0303oool00`000000oooo0?ooo`090?ooo`@00000403oool200000180oooo1000000T0?ooo`L0
0000o`3ooomb0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0>P3oool004D0oooo
00T0oono07@00018W=l0omnL09boo`3oool0gia80018W03Oool03`3oool01P3OW4P0001d0;ooo`3o
oml0W4P004RLg`X0oooo00<0_g@0001d_`3oool0103oool00`3ogi`0M9cO0?ooo`0<0?ooo`030000
003oool0oooo00T0oooo1000000@0?ooo`<000004@3oool6000002@0oooo1000003o0?oood@0oooo
0P00000V0?ooo`8000001@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03X0oooo
00150?ooo`090;mdM02oool0oooo0?noW02Lgol0oooo0?oo_`1d07@0_ooo0100oooo00@0gia80000
0000000007Bo2@3oool01@3ookl0M0000000000007@0_ooo00D0oooo00D0_g@00000000000000000
04RLg`090?ooo`030000003oool0oooo00P0oooo1@00000A0?ooo`8000004P3oool6000002@0oooo
0`00000n0?ooo`H00000o@3oool4000002H0oooo100000030?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0>P3oool004@0oooo00T0omnL09boo`3oool0oooO09adW03Oool0oooo0?oO
W018M;l0=P3oool3000000P0oooo1P00000@0?ooo`8000004P3oool7000002@0oooo00<000000?oo
o`3oool0?@3oool6000001`0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0R0?oo
o`H000009P3oool6000000030?ooo`000000oooo04d0oooo0`00000l0?ooo`00A03oool02@3o_i`0
W=oo0?ooo`2oM000M;oo0?ooo`3OW4P0001d0;ooo`0f0?ooo`030000003oool0oooo00P0oooo1P00
000@0?ooo`<000004P3oool5000006D0oooo1@00000L0?ooo`<000008@3oool00`000000oooo0?oo
o`1^0?ooo`030000003oool0oooo0280oooo0`00000T0?ooo`D000009P3oool500000080oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03X0oooo0014
0?ooo`040?oo_`1d0000000007Booc/0oooo00<000000?ooo`3oool07`3oool200000180oooo1000
001W0?ooo`@000006`3oool400000200oooo0`00000S0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool08`3oool300000280oooo1000000T0?ooo`D000009P3oool500000080oooo00<0
00000?ooo`3oool0803oool3000002/0oooo00<000000?ooo`3oool0>P3oool008<0oooo00<00000
0?ooo`3oool07`3oool2000001<0oooo00<000000?ooo`3oool0I`3oool4000001X0oooo1P00000O
0?ooo`@000008@3oool300000280oooo0`00000S0?ooo`D00000803oool6000002@0oooo1000000V
0?ooo`@000000`3oool00`000000oooo0?ooo`0O0?ooo`D000009@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo03X0oooo00180?ooo`050=nLB000000000000000001d_ol0=P3oool0
0`000000oooo0?ooo`0O0?ooo`<00000O03oool4000001T0oooo1`00000N0?ooo`H00000803oool4
00000240oooo1000000Q0?ooo`H000007`3oool7000002@0oooo1000000U0?ooo`D000000P3oool2
00000240oooo1P00000R0?ooo`<00000103oool00`000000oooo0?ooo`0j0?ooo`00AP3oool00`3o
gi`0B00004RLg`020?ooo`030?oOW01807@0_ooo03D0oooo00<000000?ooo`3oool0803oool20000
07`0oooo0`00000K0?ooo`L000007@3oool7000001h0oooo1P00000O0?ooo`H000007`3oool80000
01l0oooo1`00000T0?ooo`@00000903oool4000000<0oooo0P00000P0?ooo`P00000803oool40000
00@0oooo00<000000?ooo`3oool0>P3oool004D0oooo00<0omnL04Q8W03Oool00`3oool00`3ookl0
M4RL0=ooo`0e0?ooo`<000002P3oool00`000000oooo0?ooo`0C0?ooo`800000O03oool3000001d0
oooo1P00000K0?ooo`P000007P3oool7000001h0oooo2000000O0?ooo`L00000803oool6000002@0
oooo0`00000T0?ooo`<000000`3oool200000200oooo1`00000Q0?ooo`H0000000@0oooo00000000
00000000?03oool004@0oooo00<0oooO09adW03Oool0103oool00`2oM000M;oo0?ooo`0e0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool300000640oooo0P00000H0?ooo`<0
00007`3oool4000001d0oooo1`00000L0?ooo`T00000703oool:00000200oooo1P00000Q0?ooo`@0
0000903oool3000002@0oooo0`0000030?ooo`8000007`3oool600000240oooo200000030?ooo`03
0000003oool0oooo03X0oooo00140?ooo`030?oO_`2ogol0oooo0080oooo00<0oooO09a8001d_ol0
=`3oool00`000000oooo0?ooo`0:0?ooo`8000005@3oool2000005d0oooo1P00000I0?ooo`800000
803oool4000001l0oooo1@00000M0?ooo`P000007@3oool900000240oooo1000000R0?ooo`@00000
903oool2000002@0oooo0P0000030?ooo`800000803oool400000280oooo2@0000030?ooo`030000
003oool0oooo03X0oooo00140?ooo`0:0?noM01d_ol0oooo0?ooo`3ogi`0B01809cO_`1d000004RL
0=ooocD0oooo00<000000?ooo`3oool02@3oool3000001D0oooo0P00000<0?ooo`030000003oool0
oooo02<0oooo0`00000T0?ooo`X000006@3oool00`000000oooo0?ooo`0Q0?ooo`8000008@3oool4
00000200oooo1@00000P0?ooo`H000008P3oool3000002<0oooo0P00000T0?ooo`800000903oool2
000000<0oooo0P00000O0?ooo`<000008P3oool8000000H0oooo00<000000?ooo`3oool0>P3oool0
04@0oooo00<0oooO09a8000000001@0000000`00B9`0gooo0?ooo`0d0?ooo`030000003oool0oooo
00T0oooo0`00000F0?ooo`8000002`3oool2000002@0oooo2@00000L0?ooo``000006@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0240oooo0P00000S0?ooo`8000008`3oool30000
02<0oooo0P00000T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08P3oool01000
0000oooo0?ooo`3oool2000001l0oooo0P00000S0?ooo`<00000303oool00`000000oooo0?ooo`0j
0?ooo`00@03oool0102oW9`0gooo0?oo_`1d00040000000507Boo`3oool0oooo0;mdM02oool0=P3o
ool00`000000oooo0?ooo`090?ooo`<000005P3oool2000000`0oooo0`00000T0?ooo`X00000703o
ool900000?l0ooooA`3oool2000005@0oooo00<000000?ooo`3oool0>P3oool003l0oooo00<0oooO
09a8000000000P0000000`1d_ol0oooo0?ooo`0l0?ooo`030000003oool0oooo00T0oooo1000000E
0?ooo`<000002`3oool4000002D0oooo2000000R0?ooo`<00000o`3ooom60?ooo`<00000E03oool0
0`000000oooo0?ooo`0j0?ooo`00?`3oool00`3ookl0W9cO0?ooo`110?ooo`<000002@3oool40000
01H0oooo0P00000<0?ooo`@000009@3oool600000?l0ooooK03oool2000005<0oooo0`00000l0?oo
o`00B03oool01@2oM0000000000000000000B9cO03H0oooo00<000000?ooo`3oool02@3oool40000
01H0oooo0`00000;0?ooo`H00000903oool500000?l0ooooJ`3oool2000005H0oooo00<000000?oo
o`3oool0>P3oool004H0oooo00<0gia80000001d_ol00P3oool00`3ogi`0B01d0;ooo`0e0?ooo`03
0000003oool0oooo00P0oooo1P00000F0?ooo`800000303oool6000002D0oooo0P0000280?ooo`H0
00007`3oool7000001l0oooo0P00000S0?ooo`H000008`3oool2000004L0oooo0P00001G0?ooo`03
0000003oool0oooo03X0oooo00150?ooo`030=nLB018W=l0oooo00<0oooo00<0omnL04Qd_`3oool0
=@3oool00`000000oooo0?ooo`080?ooo`H000005P3oool2000000`0oooo1`00000U0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool06P3oool6000001l0oooo1`00000M0?ooo`@00000
8`3oool6000002<0oooo100000140?ooo`800000F03oool00`000000oooo0?ooo`0j0?ooo`00A03o
ool00`3ogi`0M9cO0?ooo`030?ooo`030?noW018M9`0gooo03H0oooo00<000000?ooo`3oool0203o
ool3000001X0oooo0P00000<0?ooo`D00000T@3oool3000001`0oooo1@00000P0?ooo`D00000703o
ool6000002@0oooo1@00000S0?ooo`H00000903oool00`000000oooo0?ooo`0J0?ooo`800000F@3o
ool00`000000oooo0?ooo`0j0?ooo`00A03oool00`3o_g@007Bo0?ooo`020?ooo`050?oOW018M7@0
M0000018W03Oool0=@3oool00`000000oooo0?ooo`0U0?ooo`800000303oool400000980oooo1000
000K0?ooo`@000008@3oool5000001d0oooo1@00000T0?ooo`@00000903oool5000002@0oooo0`00
000I0?ooo`<000002@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03X0oooo0015
0?ooo`030?noM0000000000000@0000000<004RL0=ooo`3oool0=03oool3000002D0oooo0`00000<
0?ooo`030000003oool0oooo0940oooo1P00000J0?ooo`@000008@3oool5000001d0oooo1@00000T
0?ooo`@00000903oool5000002@0oooo1@00000F0?ooo`<000002@3oool3000004d0oooo0`00000l
0?ooo`00A03oool01@3ogi`0B000000000000000B9cO0080oooo00<0_gA809cOo`3oool0=@3oool0
0`000000oooo0?ooo`0V0?ooo`800000P@3oool00`000000oooo0?ooo`0L0?ooo`L000006@3oool4
00000240oooo1@00000N0?ooo`@00000903oool4000002@0oooo1000000T0?ooo`L00000503oool3
000000T0oooo1000000T0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0>P3oool0
06D0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB0000000
000000<0000000<0B9cO0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01T0oooo0`00001n0?ooo`<000007@3oool7000001/0oooo0`00000R0?ooo`<00000803oool4
000002@0oooo0`00000S0?ooo`@00000903oool7000001@0oooo0`0000090?ooo`H000008@3oool3
000002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`00I03oool01P3O
W4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?oo
o`020?ooo`030;mdM02oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0J0?ooo`800000O03oool5000001`0oooo1P00000M0?ooo`<000008P3oool300000200oooo1000
000T0?ooo`<000008`3oool4000002@0oooo1@00000D0?ooo`@000002@3oool700000200oooo1@00
000R0?ooo`<00000103oool00`000000oooo0?ooo`0j0?ooo`00A03oool01@3ogkl0_moo0?ooo`3o
ool0_g@000<0000000<0001d0;ooo`3oool0503oool00`3ooml0W4P004RLg`020?ooo`030?noM000
04P0W=oo00P0oooo00<0okmd001d_`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`8000006`3o
ool3000005X0oooo0P00000N0?ooo`L000006`3oool4000001l0oooo0`00000R0?ooo`<000008@3o
ool3000002@0oooo0`00000S0?ooo`<00000903oool4000001D0oooo100000090?ooo`T000007@3o
ool700000200oooo1@0000040?ooo`030000003oool0oooo03X0oooo00140?ooo`030;md00000000
00000080000000D0001d0;ooo`3oool0_ibL0=ooo`0E0?ooo`030?oog`2LB000B9cO0080oooo00@0
oooO09a80000B9`0gooo203oool00`3o_g@007Bo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo
0`00000L0?ooo`800000EP3oool6000001`0oooo2@00000J0?ooo`@00000803oool2000002<0oooo
0`00000R0?ooo`800000903oool2000002@0oooo0P00000T0?ooo`@000005@3oool3000000X0oooo
2000000N0?ooo`T000007@3oool8000000<0oooo00<000000?ooo`3oool0>P3oool00480oooo00D0
_g@000000000000004RL0=ooo`030?ooo`030?oog`2LB000M;oo01H0oooo00<0oooO09a80000M;l0
0`3oool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo00/0oooo00<000000?ooo`3oool0
2@3oool3000001`0oooo0`0000040?ooo`030000003oool0oooo04X0oooo2P00000J0?ooo`/00000
6P3oool2000002<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`800000
9@3oool00`000000oooo0?ooo`0R0?ooo`800000903oool2000001D0oooo1000000:0?ooo`D00000
803oool;000001/0oooo2P0000030?ooo`030000003oool0oooo03X0oooo00140?ooo`030?noW02L
gol0oooo01d0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018
W=l0oooo00X0oooo100000080?ooo`<000007@3oool2000000@0oooo0P00000S0?ooo`<000008`3o
ool<000001T0oooo1P00000O0?ooo`800000903oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0503oool4000000X0oooo0P00000S0?ooo`H000007`3o
ool@000003`0oooo001T0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l02`3oool0
0`2oM000M;oo0?ooo`090?ooo`030000003oool0oooo00T0oooo1000000M0?ooo`800000103oool3
00000280oooo2000000O0?ooo`X00000o`3ooold0?ooo`@00000I@3oool00`000000oooo0?ooo`0j
0?ooo`00A`3oool01P3ogi`0B000000000000000001809cOoaL0oooo00<0omnL04P00018W=l00`3o
ool00`2oM00004RL0=ooo`0:0?ooo`030?oOW01807@0_ooo00T0oooo00<000000?ooo`3oool02@3o
ool4000001d0oooo0`0000030?ooo`@000008P3oool;000001l0oooo1P00003o0?oooc<0oooo1000
001V0?ooo`030000003oool0oooo03X0oooo00160?ooo`030;md00000000M;oo0080oooo00<0oooO
09adW03Oool05P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00X0oooo00<0
oooO09a8001d_ol02@3oool00`000000oooo0?ooo`090?ooo`@000007P3oool2000000@0oooo1000
000S0?ooo`P00000903oool200000?l0oooo<@3oool5000006L0oooo00<000000?ooo`3oool0>P3o
ool004D0oooo00<0gia804RLg`3oool0103oool00`3OW9`0_ooo0?ooo`0F0?ooo`030?oOW0180000
M;oo0080oooo00<0gia8001d_`3oool02P3oool00`3ookl0M00004RLg`090?ooo`030000003oool0
oooo00P0oooo1@00000N0?ooo`<000000`3oool600000280oooo1`00003o0?oooeD0oooo1@00001Y
0?ooo`030000003oool0oooo03X0oooo00140?ooo`030?oOW01dW=l0oooo00@0oooo00<0oooO09ad
W03Oool0603oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00L0okmd0018W03Oool0oooo
0=nLB00004P0W=oo00T0oooo00<000000?ooo`3oool0203oool6000001h0oooo0`0000030?ooo`H0
00008P3oool500000?l0ooooE@3oool5000006X0oooo00<000000?ooo`3oool0>P3oool004@0oooo
00<0oknL09cOo`3oool00`3oool00`3ooml0W4P007Boo`0J0?ooo`040=nLB00000000000001d_`T0
oooo00D0omnL04P000000000000007Boo`0:0?ooo`030000003oool0oooo00P0oooo1P00000O0?oo
o`8000000`3oool7000002<0oooo0`00003o0?oooe<0oooo1@00001/0?ooo`030000003oool0oooo
03X0oooo00140?ooo`030?oOW018M;l0oooo0080oooo00<0gia800000018W=l0=`3oool3000002d0
oooo0`0000030?ooo`D000009@3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0C@3oool5000006`0oooo0`00000l0?ooo`00A@3oool01P3o_g@00000
00000000000004RL0=ooocP0oooo00<000000?ooo`3oool0;P3oool300000080oooo1000003O0?oo
o`030000003oool0oooo0200oooo0`00000R0?ooo`<00000C@3oool5000006l0oooo00<000000?oo
o`3oool0>P3oool008<0oooo00<000000?ooo`3oool0;`3oool2000000<0oooo0P00002l0?ooo`03
0000003oool0oooo0200oooo0`00000Q0?ooo`@000008@3oool4000002@0oooo00<000000?ooo`3o
ool08`3oool500000740oooo00<000000?ooo`3oool0>P3oool008<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0R0?ooo`<000000P3oool00`000000oooo0?ooo`2j0?ooo`<00000
803oool400000200oooo1P00000O0?ooo`H000008P3oool300000280oooo1@00001c0?ooo`030000
003oool0oooo03X0oooo001:0?ooo`040?oo_`1d0000001d0;ooocD0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0S0?ooo`<00000_@3oool400000200oooo1@00000O0?ooo`L00000
7P3oool700000200oooo1000000Q0?ooo`D00000903oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`00A03o
ool0103ookl0W9cO0?oo_`1d00040000000307Boo`3oool0oooo03@0oooo00<000000?ooo`3oool0
2P3oool2000002D0oooo0P00002K0?ooo`030000003oool0oooo01h0oooo1P00000N0?ooo`H00000
7P3oool7000001h0oooo1`00000P0?ooo`H000007P3oool800000240oooo0`00000R0?ooo`<00000
8`3oool3000000@0oooo00<000000?ooo`3oool0>P3oool004@0oooo00H0omnL04P0000000000000
0000B02Lgoli0?ooo`<000002@3oool3000002H0oooo0P00002H0?ooo`<000007`3oool7000001d0
oooo2000000L0?ooo`H000007`3oool600000240oooo2000000K0?ooo`X00000803oool500000200
oooo1@00000P0?ooo`D000000P3oool3000003`0oooo00150?ooo`030?oo_`1d0000M;oo03/0oooo
00<000000?ooo`3oool02@3oool3000002H0oooo0`00001d0?ooo`8000007`3oool5000001h0oooo
2@00000K0?ooo`L000007P3oool400000240oooo1000000R0?ooo`L000006`3oool=000001d0oooo
1`00000N0?ooo`L000007`3oool6000000@0oooo00<000000?ooo`3oool0>P3oool004D0oooo00<0
_gAd0;ooo`3oool0>`3oool00`000000oooo0?ooo`090?ooo`<000009`3oool3000004X0oooo1P00
000O0?ooo`H000007@3oool8000001`0oooo2000000M0?ooo`D000007`3oool400000240oooo1000
000R0?ooo`D00000703oool=000001h0oooo2@00000L0?ooo`T00000703oool9000000<0oooo00<0
00000?ooo`3oool0>P3oool004@0oooo00@0okmd00000000B9`0gooo>`3oool00`000000oooo0?oo
o`090?ooo`@000008P3oool00`000000oooo0?ooo`020?ooo`8000007P3oool3000002<0oooo3000
000K0?ooo`X000006`3oool:000001/0oooo1@00000P0?ooo`<000008P3oool2000002<0oooo0P00
000S0?ooo`@00000703oool5000000030?ooo`000000000000<00000803oool;000001X0oooo2`00
000J0?ooo`/000000`3oool00`000000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?ooo`09
0?ooo`@000008P3oool2000000@0oooo0P00000N0?ooo`P000007@3oool<000001T0oooo3000000I
0?ooo``000006P3oool2000002<0oooo0P00000S0?ooo`030000003oool0oooo0280oooo0P00000S
0?ooo`8000007@3oool500000080oooo0P00000S0?ooo`H000007`3oool6000001l0oooo30000003
0?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00T0oooo1000000S0?oo
o`800000103oool2000001h0oooo2P00000M0?ooo`P000007@3oool900000?00oooo1@0000220?oo
o`030000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00P0oooo1@00000S0?ooo`<0
00000`3oool3000001l0oooo2000000O0?ooo`H000008`3oool300000>h0oooo1@0000240?ooo`03
0000003oool0oooo03X0oooo00230?ooo`<00000203oool6000002<0oooo100000020?ooo`<00000
7`3oool600000280oooo1000003o0?oooa<0oooo1@0000240?ooo`<00000?03oool008<0oooo00<0
00000?ooo`3oool0203oool6000002<0oooo1@0000020?ooo`<000007`3oool5000002@0oooo0P00
003o0?oooa00oooo1P0000280?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0
oooo0340oooo1P0000020?ooo`<00000803oool200000?l0oooo=@3oool6000008X0oooo00<00000
0?ooo`3oool0>P3oool008<0oooo00<000000?ooo`3oool0<P3oool600000080oooo0`00000P0?oo
o`030000003oool0oooo0?l0oooo<@3oool6000008`0oooo00<000000?ooo`3oool0>P3oool008<0
oooo00<000000?ooo`3oool0<P3oool5000000@0oooo0`00003o0?oooe40oooo1P00002>0?ooo`03
0000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
9P3oool3000000H0oooo0`00003o0?ooodh0oooo1@00002A0?ooo`030000003oool0oooo03X0oooo
00230?ooo`<000002P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00L0oooo0`00
003l0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0903oool600000940oooo0`00
000l0?ooo`00P`3oool00`000000oooo0?ooo`0:0?ooo`800000<P3oool300000=L0oooo00<00000
0?ooo`3oool0803oool3000002<0oooo0P00000T0?ooo`H00000803oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0>P3oool005`0oooo00@0_g@00000
00000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB0000000000000<0000000D0B9cO
0?ooo`3oool0omnL04P00002000000030018W03Oool0oooo00/0oooo00<000000?ooo`3oool02@3o
ool3000003<0oooo0`00002a0?ooo`030000003oool0oooo0200oooo0`00000Q0?ooo`@000008@3o
ool500000200oooo1`00000P0?ooo`<000008P3oool3000002@0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo001K0?ooo`060=nLB000M;l0
oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`030?noM000M;l0oooo0080oooo
00T0_gAd0;ooo`3oool0okmd0000001d_ol0oooo0?oOW018M;l0303oool00`000000oooo0?ooo`09
0?ooo`<00000=03oool3000008/0oooo0P00000Q0?ooo`<000008@3oool5000001l0oooo1P00000O
0?ooo`H000007P3oool700000200oooo1P00000P0?ooo`D000008@3oool3000002<0oooo0`000004
0?ooo`030000003oool0oooo03X0oooo001J0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000
B02Lgol0203oool00`3o_g@007Bo0?ooo`090?ooo`030?noM018W=l0oooo00X0oooo00<000000?oo
o`3oool02@3oool3000003H0oooo0`00001T0?ooo`800000803oool5000001l0oooo1P00000N0?oo
o`L000007@3oool8000001h0oooo2000000J0?ooo`/000007P3oool7000001h0oooo1`00000O0?oo
o`H00000803oool5000000@0oooo00<000000?ooo`3oool0>P3oool005X0oooo00<0oooO09a80018
W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030?noM000M;l0oooo00P0oooo00<0oono07@0
M02oool02P3oool00`000000oooo0?ooo`090?ooo`@00000=P3oool3000005l0oooo1P00000N0?oo
o`L000007@3oool8000001d0oooo2@00000K0?ooo`X000006`3oool:000001P0oooo3@00000L0?oo
o`T000007@3oool9000001`0oooo2000000N0?ooo`L00000103oool00`000000oooo0?ooo`0j0?oo
o`00FP3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00T0oooo00<0okmd04RLg`3o
ool01`3oool00`3ooml0W4P007Boo`0:0?ooo`030000003oool0oooo00T0oooo1000000R0?ooo`03
0000003oool0oooo0180oooo0`00000i0?ooo`H000006`3oool:000001/0oooo2P00000K0?ooo`/0
00006P3oool;000001X0oooo2000000M0?ooo`P00000603oool@000001X0oooo3000000J0?ooo`/0
00006P3oool;000001/0oooo2P0000030?ooo`030000003oool0oooo03X0oooo001K0?ooo`030;md
0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`060?ooo`030?oo
_`1d0000B9cO00X0oooo100000080?ooo`@000008P3oool2000001@0oooo1000000;0?ooo`800000
8`3oool=000001T0oooo3000000I0?ooo``000006@3oool=000001T0oooo1P00000O0?ooo`<00000
8P3oool3000001/0oooo3@00000O0?ooo`d000006@3oool6000001l0oooo3000000I0?oooa000000
?03oool005/0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d
_ol0oooo00D0oooo00<0okmd0000001d_ol02P3oool00`000000oooo0?ooo`080?ooo`D000008`3o
ool2000001D0oooo0`00000;0?ooo`D000008@3oool;000001/0oooo2P00000O0?ooo`H00000Y03o
ool8000009d0oooo1P0000030?ooo`030000003oool0oooo03X0oooo001K0?ooo`030?oOW0180000
B9cO00<0oooo00<0_g@00018W03Oool02P3oool00`3ogi`0B01d0;ooo`020?ooo`060?oOg`3Oool0
okmd0000000007@0_ooo2P3oool00`000000oooo0?ooo`080?ooo`H000008P3oool3000001D0oooo
1000000:0?ooo`P000007`3oool800000200oooo1P0000370?ooo`L00000Z@3oool00`000000oooo
0?ooo`0j0?ooo`00F`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00X0oooo
00<0oooO09a8001d_ol00P3oool01@3ookl0M0000000000004P0W=oo00/0oooo00<000000?ooo`3o
ool0203oool600000280oooo1000000E0?ooo`@000002P3oool9000001l0oooo1P00000T0?ooo`80
0000a03oool700000:`0oooo00<000000?ooo`3oool0>P3oool005`0oooo00<0omnL04P0001d_ol0
0P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gibL0;ooo`3oool0
303oool00`000000oooo0?ooo`0a0?ooo`@000005P3oool4000000T0oooo1`00000R0?ooo`@00000
i`3oool800000:h0oooo00<000000?ooo`3oool0>P3oool005d0oooo00H0gia80000M02oool0oooO
09a80018W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`030?ooo`030?oOW01dW=l0
oooo00`0oooo00<000000?ooo`3oool0<@3oool5000001H0oooo1000000:0?ooo`@000009@3oool2
00000>@0oooo2000002a0?ooo`030000003oool0oooo03X0oooo001N0?ooo`040=nLB00000000000
001d_`T0oooo00D0omnL04P000000000000007Boo`050?ooo`050;md00000000000000000018W=l0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo1@00000G0?ooo`@00000
2@3oool300000?l0oooo2@3oool800000;@0oooo00<000000?ooo`3oool0>P3oool008<0oooo0`00
000:0?ooo`030000003oool0oooo02D0oooo1P00000G0?ooo`D00000203oool00`000000oooo0?oo
o`3o0?ooo`D0oooo2000002e0?ooo`<00000?03oool008<0oooo00<000000?ooo`3oool02P3oool2
000002H0oooo1@00000J0?ooo`@00000o`3oool<0?ooo`P00000^P3oool00`000000oooo0?ooo`0j
0?ooo`00P`3oool00`000000oooo0?ooo`090?ooo`<000009`3oool3000001`0oooo1@00003o0?oo
o`L0oooo2000002m0?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00T0
oooo0`00000W0?ooo`030000003oool0oooo01h0oooo1@00003o0?ooo`80oooo200000300?ooo`03
0000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00T0oooo0`00001:0?ooo`D00000
hP3oool00`000000oooo0?ooo`0F0?ooo`T00000103oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00T0oooo1000001;0?ooo`D00000^`3o
ool200000240oooo0`00000E0?ooo`P000001P3oool300000280oooo0`00000R0?ooo`<000008P3o
ool3000002@0oooo00<000000?ooo`3oool08P3oool2000000@0oooo00<000000?ooo`3oool0>P3o
ool008<0oooo0`0000090?ooo`@00000C@3oool6000006h0oooo0P00000S0?ooo`8000008@3oool4
00000200oooo1@00000@0?ooo`T000001`3oool500000200oooo1@00000P0?ooo`D00000803oool6
00000240oooo0`00000R0?ooo`@000000P3oool3000003`0oooo00230?ooo`030000003oool0oooo
00T0oooo1000001?0?ooo`H00000J@3oool500000200oooo1@00000O0?ooo`H000007P3oool70000
00`0oooo2@00000:0?ooo`L000007P3oool6000001l0oooo1`00000N0?ooo`L000007`3oool60000
01l0oooo1P0000040?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00P0
oooo1@00000R0?ooo`030000003oool0oooo02`0oooo1P0000110?ooo`H000007P3oool7000001h0
oooo1`00000M0?ooo`T00000703oool9000000L0oooo2P00000;0?ooo`T00000703oool9000001`0
oooo2@00000L0?ooo`T000007@3oool8000001d0oooo200000040?ooo`030000003oool0oooo03X0
oooo00230?ooo`030000003oool0oooo00P0oooo1P00000Q0?ooo`8000008`3oool2000000/0oooo
1@00000C0?ooo`d000006@3oool<000001/0oooo2P00000K0?ooo`X000006`3oool;000001X0oooo
2`0000040?ooo`T000003@3oool;000001X0oooo2`00000J0?ooo`/000006P3oool<000001X0oooo
2`00000J0?ooo`/000000`3oool00`000000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?oo
o`080?ooo`H000008P3oool2000002<0oooo1@0000090?ooo`H000004@3oool<000001T0oooo00<0
00000?ooo`0000002@00000I0?ooo``000006@3oool<000001T0oooo3@00000I0?ooo`H000001P3o
ool:000000l0oooo1P00000O0?ooo``000006@3oool6000001l0oooo3@00000H0?ooo`d00000603o
ool=000000<0oooo00<000000?ooo`3oool0>P3oool008<0oooo00<000000?ooo`3oool0<03oool3
000002<0oooo200000070?ooo`L00000403oool9000001h0oooo1`00000P0?ooo`H000007`3oool6
000004L0oooo2P00003B0?ooo`L000000`3oool00`000000oooo0?ooo`0j0?ooo`00P`3oool00`00
0000oooo0?ooo`0`0?ooo`@00000903oool8000000P0oooo1P00000@0?ooo`L000008@3oool40000
08h0oooo2P00003P0?ooo`030000003oool0oooo03X0oooo00230?ooo`<00000<03oool5000002@0
oooo1P00000<0?ooo`H000003`3oool4000002@0oooo0P00002:0?ooo`X00000hP3oool3000003`0
oooo00230?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0903oool5000002@0oooo
1@00000>0?ooo`P000003@3oool200000:`0oooo2@00003Y0?ooo`030000003oool0oooo03X0oooo
00230?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0903oool6000002D0oooo0P00
000B0?ooo`P00000/`3oool:00000>d0oooo00<000000?ooo`3oool0>P3oool008<0oooo00<00000
0?ooo`3oool02P3oool2000002D0oooo1`00000U0?ooo`030000003oool0oooo01@0oooo1`00002[
0?ooo`/00000l@3oool00`000000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?ooo`090?oo
o`<000009@3oool600000400oooo2000002R0?ooo`/00000mP3oool00`000000oooo0?ooo`0j0?oo
o`00P`3oool00`000000oooo0?ooo`090?ooo`<000009P3oool3000004H0oooo2000002I0?ooo`/0
0000n`3oool00`000000oooo0?ooo`0j0?ooo`00P`3oool3000000T0oooo0`00000V0?ooo`030000
003oool0oooo04X0oooo2@00002>0?ooo`/00000o`3oool3000003`0oooo00230?ooo`030000003o
ool0oooo00T0oooo1000001f0?ooo`X00000PP3oool<00000?l0oooo203oool00`000000oooo0?oo
o`0j0?ooo`00I@3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0
oono07@0000000000P0000000`1d_ol0oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo1000
001k0?ooo`/00000M@3oool=000002P0oooo0P00000T0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0>P3oool006@0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oO
W0180000M;oo0080oooo00<0okmd00000000M;l00P3oool00`2oM4P0W=oo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo100000200?ooo``00000I`3oool?000000T0oooo0P00000Q0?ooo`@00000
8P3oool300000280oooo0`00000R0?ooo`<000008P3oool3000002<0oooo0P00000T0?ooo`800000
103oool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`3ooml0W4P004RLg`020?ooo`030?noM000
04P0W=oo00/0oooo00<0omnL04Q8W03Oool02P3oool00`000000oooo0?ooo`080?ooo`D00000QP3o
ool>000002d0oooo0P00000S0?ooo`80000000<0oooo0000000000004000000=0?ooo`D000007`3o
ool600000200oooo1@00000P0?ooo`D00000803oool500000200oooo1@00000Q0?ooo`@000008@3o
ool5000000@0oooo00<000000?ooo`3oool0>P3oool006<0oooo00<0oooO09a80018W=l00P3oool0
103ooml0W4P00018W03Oool:0?ooo`030?oo_`1d0000M;oo00X0oooo00<000000?ooo`3oool0203o
ool6000008`0oooo4@00000O0?ooo`H000007@3ooolC000001<0oooo1`00000M0?ooo`T000007@3o
ool7000001h0oooo1`00000N0?ooo`P000007@3oool7000001h0oooo1`00000O0?ooo`L00000103o
ool00`000000oooo0?ooo`0j0?ooo`00H`3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0
W=oo00X0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`080?ooo`H000008@3oool0
0`000000oooo0?ooo`0R0?ooo`800000C03ooolF000000h0oooo2P00000>0?oooaT000006@3oool:
000001/0oooo2`00000K0?ooo`X000006`3oool:000001/0oooo2P00000K0?ooo`X000006`3oool:
000001/0oooo2P0000040?ooo`030000003oool0oooo03X0oooo001T0?ooo`030;md0000B9`0gooo
0080oooo00<0omnL04P00018W=l02@3oool0103ogi`0B0000000B02Lgol:0?ooo`@000002@3oool0
0`000000oooo0?ooo`0R0?ooo`800000903oool5000001l0oooo3000000I0?ooo`d000000P3ooom8
000001T0oooo3000000I0?ooo`d000006@3oool<000001T0oooo3000000I0?ooo``000006@3oool<
000001T0oooo3000000I0?ooo``0000000<0oooo0000000000000P00000l0?ooo`00I03oool00`3O
W4P0001809cOo`020?ooo`030?oog`2LB00007Bo00L0oooo00D0omnL04P000000000000007Boo`0;
0?ooo`030000003oool0oooo0300oooo0P00000T0?ooo`P00000703oool;000001/0oooo2`00000K
0?ooo`X00000703oool9000001l0oooo1P0000150?ooo`H000007`3oool6000004@0oooo1P00000O
0?ooo`H000007`3oool6000000@0oooo00<000000?ooo`3oool0>P3oool006@0oooo00<0omnL04P0
0018W=l00`3oool00`2oM00004RL0=ooo`080?ooo`030?oo_`1d000007Bo00/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0S0?ooo`<00000903oool9000001`0oooo2@00000N0?oo
o`L00000803oool600000280oooo0`00003o0?ooobh0oooo00<000000?ooo`3oool0>P3oool006@0
oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030=nLB000M;l0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0S0?ooo`@00000903oool70000
01l0oooo1P00000Q0?ooo`D00000903oool200000?l0ooooD`3oool00`000000oooo0?ooo`0j0?oo
o`00I@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00X0oooo00<0omnL04P0B02L
gol02@3oool00`000000oooo0?ooo`0:0?ooo`800000903oool5000002@0oooo1P00000Q0?ooo`@0
0000903oool200000?l0ooooN@3oool00`000000oooo0?ooo`0j0?ooo`00IP3oool01P3OW4P0001d
0;ooo`3ooml0W4P004RLg`P0oooo00H0_g@007Boo`3oool0gia80000B02Lgol90?ooo`030000003o
ool0oooo00T0oooo0`00000U0?ooo`D00000903oool4000002@0oooo0P00003o0?oooil0oooo00<0
00000?ooo`3oool0>P3oool006L0oooo00@0gia800000000000007Bo2P3oool0102oM00000000000
0018W=l:0?ooo`030000003oool0oooo00T0oooo0`00000U0?ooo`H00000903oool300000?l0oooo
a@3oool00`000000oooo0?ooo`0j0?ooo`00P`3oool3000000T0oooo0`00000U0?ooo`L00000903o
ool00`000000oooo0?ooo`3o0?oool80oooo0`00000l0?ooo`00P`3oool00`000000oooo0?ooo`09
0?ooo`@00000903oool600000?l0ooook03oool00`000000oooo0?ooo`0j0?ooo`00P`3oool00`00
0000oooo0?ooo`090?ooo`@000009@3oool300000?l0ooookP3oool00`000000oooo0?ooo`0j0?oo
o`00P`3oool00`000000oooo0?ooo`090?ooo`@000009@3oool00`000000oooo0?ooo`3o0?ooonh0
oooo00<000000?ooo`3oool0>P3oool008<0oooo00<000000?ooo`3oool0203oool500000?l0oooo
o`3ooolG0?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00P0oooo1P00
003o0?oooeD0oooo0P00000T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0>P3o
ool008<0oooo0`0000080?ooo`H00000i@3oool2000002<0oooo0P00000S0?ooo`8000008@3oool4
00000280oooo0`00000R0?ooo`<000008P3oool300000280oooo0`00000S0?ooo`8000000`3oool3
000003`0oooo00230?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0`03oool30000
0200oooo1@00000P0?ooo`D00000803oool5000001l0oooo1P00000P0?ooo`D00000803oool50000
0200oooo1@00000P0?ooo`D000008@3oool4000000D0oooo00<000000?ooo`3oool0>P3oool008<0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0780
oooo1P00000M0?ooo`T000007P3oool7000001h0oooo1`00000N0?ooo`L000007@3oool8000001h0
oooo1`00000N0?ooo`P000007@3oool7000001h0oooo1`00000N0?ooo`L000001@3oool00`000000
oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo
0P00000S0?ooo`8000008`3oool6000001l0oooo3000000I0?ooo`d000006`3oool:000001/0oooo
2P00000K0?ooo`X000006`3oool;000001/0oooo2P00000K0?ooo`X000006`3oool:000001/0oooo
2P00000K0?ooo`X00000103oool00`000000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0280oooo0`00000S0?ooo`<000008P3oool;000001X0oooo2`00
000J0?ooo`/000006P3oool<000001T0oooo3000000I0?ooo``000006@3oool=000001T0oooo3000
000I0?ooo``000006@3oool<000001T0oooo3000000I0?ooo``00000103oool00`000000oooo0?oo
o`0j0?ooo`00P`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo0`00000S
0?ooo`D000008@3oool9000001d0oooo2000000N0?ooo`L000007@3oool9000001l0oooo1P00000O
0?ooo`H000007`3oool7000001l0oooo1P0000140?ooo`H000007`3oool6000001l0oooo1P000004
0?ooo`030000003oool0oooo03X0oooo00230?ooo`030000003oool0oooo00T0oooo0`00000T0?oo
o`<00000903oool600000240oooo1`00000O0?ooo`H00000803oool5000002<0oooo0`00003o0?oo
obh0oooo00<000000?ooo`3oool0>P3oool008<0oooo0`0000090?ooo`<00000903oool4000002<0
oooo2000000P0?ooo`D000008P3oool4000002<0oooo0P00003o0?oooe80oooo0`00000l0?ooo`00
P`3oool00`000000oooo0?ooo`090?ooo`<00000903oool5000002<0oooo1P00000S0?ooo`<00000
903oool200000?l0ooooN@3oool00`000000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?oo
o`090?ooo`<00000903oool6000002<0oooo1000000V0?ooo`030000003oool0oooo0?l0ooooW@3o
ool00`000000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?ooo`080?ooo`D000008`3oool7
000002<0oooo0`00003o0?ooolH0oooo00<000000?ooo`3oool0>P3oool008<0oooo00<000000?oo
o`3oool0203oool5000002@0oooo1@00000U0?ooo`030000003oool0oooo0?l0ooooa@3oool00`00
0000oooo0?ooo`0j0?ooo`00P`3oool00`000000oooo0?ooo`080?ooo`D00000903oool300000?l0
ooook`3oool00`000000oooo0?ooo`0j0?ooo`00P`3oool3000000P0oooo1P00000S0?ooo`030000
003oool0oooo0?l0ooook@3oool3000003`0oooo00230?ooo`030000003oool0oooo00L0oooo1`00
003o0?ooool0oooo5P3oool00`000000oooo0?ooo`0j0?ooo`00G03oool0102oM00000000000001d
_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0000000000P0000001P1d_ol0oooo0?oo
o`3oool0omnL04P00080000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`@0
0000o`3ooooo0?oooaT0oooo00<000000?ooo`3oool0>P3oool005/0oooo00H0gia8001d_`3oool0
omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo00<0okmd00000000M;l00P3oool02P2o
M4P0W=oo0?ooo`3oool0okmd0000001d_ol0oooo0?oOW018M;l<0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0o`3ooola0?ooo`8000008`3oool2000002<0oooo0P00000S0?ooo`80
00008`3oool2000002<0oooo0P00000S0?ooo`8000001@3oool00`000000oooo0?ooo`0j0?ooo`00
FP3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00/0oooo00<0omnL04Q8W03Oool0
1P3oool00`3o_g@0B9cO0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
i@3oool2000002@0oooo0P00000P0?ooo`D00000803oool500000200oooo1@00000Q0?ooo`@00000
8@3oool400000240oooo1000000Q0?ooo`@000001@3oool00`000000oooo0?ooo`0j0?ooo`00FP3o
ool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`X0oooo00<0oono07@0001d_ol0
1P3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`2J0?ooo`<00000803oool500000200oooo1P00000N0?ooo`L00000
7P3oool7000001h0oooo1`00000N0?ooo`L000007P3oool7000001h0oooo1`00000N0?ooo`L00000
1@3oool00`000000oooo0?ooo`0j0?ooo`00FP3oool00`3ooml0W4P0001d_`030?ooo`030=nLB000
04P0W=oo00X0oooo00<0omnL04P0001d_ol01P3oool00`3ooml0W4P007Boo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool08P3oool2000002<0oooo0P00001>0?ooo`H00000703o
ool9000001`0oooo2@00000L0?ooo`X000006`3oool:000001/0oooo2P00000K0?ooo`/000006`3o
ool:000001/0oooo2P00000K0?ooo`T00000703oool:000000@0oooo00<000000?ooo`3oool0>P3o
ool005/0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`090?ooo`040?oOW0180000
001809cOo`H0oooo00<0oono07@00018W=l02P3oool4000000T0oooo00<000000?ooo`3oool08P3o
ool3000002<0oooo0`00000Q0?ooo``000006@3oool<000001T0oooo3000000J0?ooo`/000006P3o
ool<000001T0oooo3000000I0?ooo``000006@3oool=000001T0oooo3000000I0?ooo``000006@3o
ool<000001T0oooo300000000`3oool0000000000002000003`0oooo001K0?ooo`030=nLB00004P0
W=oo0080oooo00<0oooO09a80000M;l01`3oool01@3ogi`0B000000000000000M;oo00L0oooo00<0
okmd0000001d_ol02P3oool00`000000oooo0?ooo`0`0?ooo`800000903oool5000001l0oooo2`00
000J0?ooo`/000006`3oool:000001`0oooo2@00000M0?ooo`T00000703oool9000001l0oooo1P00
000O0?ooo`L000007`3oool6000001l0oooo1P00000L0?ooo`T000007`3oool6000000@0oooo00<0
00000?ooo`3oool0>P3oool005/0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`08
0?ooo`030?oo_`1d000007Bo00@0oooo00H0omoO0=ooo`3o_g@000000000M02oool:0?ooo`030000
003oool0oooo0300oooo0`00000S0?ooo`L000007`3oool8000001d0oooo2000000P0?ooo`H00000
7`3oool6000002<0oooo0`00000R0?ooo`<00000]`3oool3000002T0oooo00<000000?ooo`3oool0
>P3oool005/0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030=nL
B000M;l0oooo0080oooo00D0oono07@000000000001809cOo`0;0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0:@3oool4000002<0oooo2000000N0?ooo`L00000103oool00`000000
oooo0?ooo`0H0?ooo`H00000903oool2000002<0oooo0P00000H0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03X0
oooo001L0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLW02oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00P0oooo1@00000A0?ooo`030000003oool0oooo00l0oooo
1P0000090?ooo`030000003oool0oooo01D0oooo1@0000040?ooo`030000003oool0oooo01X0oooo
1@00000P0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0j0?ooo`00G@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0_g@007Boo`3o
ool0gia80000B02Lgol30?ooo`030?oOW01dW=l0oooo00`0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo1@00000A0?ooo`030000003oool0
oooo0100oooo1@0000090?ooo`030000003oool0oooo01H0oooo0`0000050?ooo`030000003oool0
oooo01`0oooo0`00000P0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0j0?ooo`00GP3oool0103OW4P0000000000000M;l:0?ooo`040;md00000000
000004RLg`D0oooo00D0_g@0000000000000000004RLg`090?ooool00000o`00000X000003`0oooo
002g0?ooo`H000008`3oool300000?l0ooooo`3oool40?ooo`00]`3oool4000002H0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`<0oooo002g0?ooo`800000o`3ooooo0?ooobh0oooo003o0?ooool0
ooooi`3oool00?l0ooooo`3ooooW0?ooo`00o`3ooooo0?ooonL0oooo003o0?ooool0ooooi`3oool0
0?l0ooooo`3ooooW0?ooo`00o`3ooooo0?ooonL0oooo003a0?ooo`030?oog`2LB000000000800000
00<0M;oo0?ooo`3oool0A@3oool00`3ooml0W4P0000000020000000307Boo`3oool0oooo0140oooo
00@0gia800000000B9`0gooo@`3oool00`2oM000001809cOo`0S0?ooo`040?oOW018000004RL0=oo
oa80oooo00<0_g@00000B02Lgol0EP3oool0103ogi`0B0000018W03Ooon^0?ooo`00l`3oool00`3o
_g@0001d0;ooo`1:0?ooo`030?noM00007@0_ooo01@0oooo00D0okmd0018W03Ogi`0B4RL0=ooo`11
0?ooo`030=nLB00007@0_ooo02D0oooo00<0oono07@00000M;l04@3oool00`3OW4P0001d0;ooo`1H
0?ooo`030?oo_`1d000007Bo0:h0oooo003c0?ooo`030?oo_`1d0000M;oo04X0oooo00<0oono07@0
001d_ol05`3oool00`3ogi`0B7Bo0?ooo`0d0?ooo`030?oo_`1d07@0_ooo00P0oooo00<0oooO09a8
0018W=l02P3oool00`3ookl0M01d0;ooo`0;0?ooo`030?oo_`1d07@0_ooo00`0oooo00<0gia80018
W03Oool03`3oool00`3ooml0W4P004RLg`0H0?ooo`030?oo_`1d07@0_ooo01`0oooo00<0oono07@0
M02oool0803oool00`3OW4P004RL0=ooo`2]0?ooo`00l`3oool00`3ooml0W4P004RLg`1:0?ooo`03
0?oog`2LB000B9cO01P0oooo00<0okmd07Boo`3oool0=03oool00`3ogi`0B01d0;ooo`070?ooo`03
0?oog`2LB000B9cO00/0oooo00<0omnL04P0M02oool02`3oool00`3ogi`0B01d0;ooo`0;0?ooo`03
0=nLB000B9`0gooo00l0oooo00<0oooO09a80018W=l06@3oool00`3ogi`0B01d0;ooo`0L0?ooo`03
0?oOW01807@0_ooo01l0oooo00<0gia80018W03Oool0[@3oool00?@0oooo00<0gia8000000000000
0P0000001P1d_ol0oooo0?ooo`3oool0_g@0001d_`H0oooo00D0gia8000000000000000007Boo`02
0?ooo`0;0?oo_`1d000000000000M02oool0gia800000018W=l0oooo0?oOW01800000P0000002@1d
_ol0gia800000000B9`0gooo0?noM0000000001809cOo`020?ooo`050?noM000000000000000B02L
gol00`3oool00`2oM00007Bo0?ooo`0B0?ooo`030=nLB000000000000080000000H0M;oo0?ooo`3o
ool0oooo0;md0000M;l60?ooo`050=nLB000000000000000001d_ol0103oool00`3o_g@0000007Bo
o`080?ooo`0<0=nLB000B9`0gooo0?ooo`3o_g@0001d0;ooo`3oool0oooO09a800000000M;oo0P3o
ool01@3o_g@000000000000004P0W=oo00<0oooo00P0oono07@000000000001d0;ooo`3OW4P00000
04RLg`80oooo00D0gia8000000000000000007Boo`020?ooo`040?noM0000000001d0;ooo`80oooo
00<0_g@007Boo`3oool01P3oool00`3ooml0W4P004RLg`020?ooo`0<0?oOW018000000000000001d
_ol0gia800000000B9`0gooo0?ooo`2oM000M;oo0`3oool01@3OW4P000000000000004P0W=oo00@0
oooo00D0_g@007Boo`3oool0oooo0=nLB002000000030000B02Lgol0oooo00<0oooo00<0gia80018
W03Oool03`3oool00`3ooml0W4P004RLg`020?ooo`030?oo_`1d000000000080000000L0B9cO0?oo
o`3oool0oooo0?oOW0180000M;oo0080oooo00H0omnL04P00000000000000018W03Oool40?ooo`03
0;md001d_ol0oooo00L0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?oo
o`030?oo_`1d000000000080000000H0B9cO0?ooo`3oool0oooo0;md001d_ol80?ooo`040;md0000
0000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P00000000000030000000304RL
g`3oool0oooo0080oooo00<0gia80018W03Oool0[@3oool00?@0oooo00L0okmd0000B02Lgol0oooo
0?oog`2LB00007Bo0080oooo00<0okmd0000M02oool0103oool00`3ogi`0B00007Boo`020?ooo`0Q
0;md0000M;l0oooo0=nLB000B9`0gooo0?oo_`1d07@0_kmd0000M02LW7@0W=oo0;md0000B9`0gooo
0?ooo`2oM000M7Ad0000M02ogi`0W;oo0?noM00004P0W=oO09adW03Oool0omnL04P0B02Lgol0oooo
0?oOW018000007Bo0080oooo00<0okmd0000M02oool04P3oool01`3o_g@0001809cOo`3oool0oooO
09a80000M;l00P3oool00`3o_g@0001d0;ooo`040?ooo`030?oOW0180000M;oo0080oooo00<0_g@0
001d_`3oool00P3oool0103OW4P0001d07AdB02Lgol70?ooo`070?noM00004P0W=oo0?ooo`3ookl0
M00007Boo`020?ooo`0;0;md0000M;l0_gAd0;ooo`3ogi`0B01809cOo`3oool0omnL04P00000M;l0
0P3oool0303OW4P004RL0=ooo`3ookl0M01d0;noM00007@0W9ad09cOo`3ogi`0B00007Boo`80oooo
00/0_g@0001d_`3oool0omnL04P0M02ookl0W9cO0?ooo`3ogi`0B00007Boo`070?ooo`030?oog`2L
B000B9cO0080oooo00`0_g@00018W03Oool0oooo0;md001dM7@0001d0;oOW02L_ol0omnL04P0001d
_ol20?ooo`070?oOW01807@0_ooo0?ooo`3ookl0M00004RLg`020?ooo`0;0?oOW0180000M;oo0?oo
o`3o_g@0000007Boo`3oool0oooO09a80018W=l00`3oool00`3OW4P004RL0=ooo`0?0?ooo`030?oo
g`2LB000B9cO00@0oooo00<0okmd0000001d_ol0103oool00`3ogi`0B00007Boo`020?ooo`060?no
M0000000M;oo0?ooo`3ogi`0B7Bo0`3oool00`3ogi`0B00007Boo`070?ooo`060=nLB000M;l0oooo
0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030?noM0000000M;oo00<0oooo00<0
omnL04P0001d_ol01`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo0080oooo00<0gia80018W03O
ool0[@3oool00?@0oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0omnL04P0
001d_ol0103oool00`3OW4P004RL0=ooo`030?ooo`040=nLW02oool0_g@0001d_`80oooo00L0oono
07A8B01804P0W=oo0?ooo`2oM00007Bo00<0oooo00L0_g@00000001d_ol0oooo0?oo_`1d0000M;oo
0080oooo00<0gia80018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0omnL04P0001d_ol04P3o
ool00`3ookl0M00007Boo`020?ooo`070?oog`2LB000B9cO0?ooo`3ogi`0B00007Boo`040?ooo`03
0=nLB000B9`0gooo00<0oooo00T0gibL0;ooo`3oool0oooo0=nLB000B9`0gooO09adW03Oool01P3o
ool01`3ookl0M00004RLg`3oool0oooO09a80000M;l00P3oool01`3OW4P004RL0=ooo`3oool0gia8
0018W03Oool00P3oool01P3ogi`0B00004RLg`3oool0_g@0001d_`80oooo00P0oono07A8B01804P0
W=oo0?ooo`3OW4P004RL0=ooo`<0oooo00L0gibL0;ooo`3ookl0M00007Boo`3OW9`0_ooo00X0oooo
00<0oooO09a80018W=l00P3oool00`2oM00007Bo0?ooo`020?ooo`030;md00000000M;oo00H0oooo
00<0oono07@0001d_ol00P3oool00`3ookl0M00007Boo`050?ooo`030=nLB000B9`0gooo00<0oooo
00X0gmoO0?ooo`3oool0oooo0=nLB000B9`0gooo0?ooo`3ooml0W4P0200000001`18W=l0oooo0?oo
o`3oool0oooO09a80018W=l0103oool00`3ooml0W4P0001d_`0>0?ooo`030?noM018W=l0oooo00X0
oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?oog`2LB00007Bo00`0
oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo00H0
oooo00<0gia80018W03Oool0[@3oool00?@0oooo00<0oooO09a80018W=l00`3oool01`3ogi`0B018
09cOo`3ooml0W4P00018W03Oool00`3oool01@3o_g@00000000000000000B9cO00<0oooo00<0okmd
0018W03Oool00P3oool01`3o_g@0000004RLg`3oool0okmd0000M02oool00P3oool00`3ookl0M000
04RLg`020?ooo`070;md0000M;l0oooo0?ooo`3o_g@0001d0;ooo`030?ooo`070=nLB00007@0_ooo
0?oog`2LB00004RL0=ooo`0A0?ooo`030?oog`2LB000B9cO00<0oooo00L0omnL04P0B02Lgol0oooO
09a80000B9`0gooo00<0oooo00D0okmd000000000000000004RLg`050?ooo`050;md0000B9`0gooo
0?oOW01dW=l01P3oool0403ooml0W4P00018W03Oool0oooo0=nLB0000000M;oo0?ooo`3ogi`0B018
09cOo`3oool0okmd0000M02oool30?ooo`060=nLB00007@0_ooo0?noM000B9`0gooo0P3oool01@3o
_g@0000004RLg`3oool0okmd00<0000000<0B9cO0?ooo`3oool00P3oool00`2oM000B9cO0?ooo`0;
0?ooo`030?oo_`1d0000M;oo0080oooo00<0okmd0000M02oool00P3oool00`3ookl0M00004RLg`07
0?ooo`030;md0018W=l0oooo0080oooo00<0gia80018W03Oool0103oool00`3o_g@0001d0;ooo`07
0?ooo`030?noM00007@0_ooo00l0oooo00<0oono07@0001d_ol01@3oool00`3OW4P004RL0=ooo`0=
0?ooo`030?oo_`1d07@0_ooo00X0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03O
ool80?ooo`030=nLB000B9`0gooo00/0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018
W03Oool80?ooo`030?noM000M;l0oooo00D0oooo00<0okmd0000M02oool0[@3oool00?D0oooo00<0
gia80000M02oool00P3oool01`3ooml0W4P004RLg`3oool0_g@004QdM01dW=l00`3oool02`3ookl0
M01809cOo`3oool0gia800000018W=l0oooo0?oo_`1d0000M;oo0080oooo00L0oooO09a80000M;l0
oooo0?oo_`1d0000M;oo00<0oooo00/0_g@00018W03Oool0oooo0=nLB000B9`0gooo0?ooo`3ookl0
M00007Boo`030?ooo`070?oOW01804P0W=oo0?ooo`2oM000B7Ad07BLg`030?ooo`030?oog`2LB000
000000L0000000<0B9cO0?ooo`3oool00P3oool00`3OW4P0001d0;ooo`020?ooo`070?oog`2LB000
B9cO0?ooo`2oM000B7Ad07BLg`030?ooo`070?oo_`1d04P0W=oo0?ooo`3OW4P0000004RLg`020?oo
o`030?oog`2LB00007Bo0080oooo00<0gibL0;ooo`3oool01@3oool03`3OW4P004Q807BLg`3oool0
okmd0000M01dM7@0_ooo0?oog`2LB000B9cO0?ooo`3ookl0M00007Boo`030?ooo`060?oOW01804P0
W=oo0?oo_`1d0000M;oo0P3oool02`3ooml0W4P0001d_`3oool0oono07@0B02Lgol0oooo0=nLB000
0000B9cO0080oooo00<0gia80018W03Oool02P3oool00`3ogi`0B01809cOo`030?ooo`030?oo_`1d
0000M;oo00<0oooo00<0_g@00018W03Oool01P3oool00`3OW4P004RL0=ooo`020?ooo`030?oOW018
04P0W=oo00@0oooo00<0oono07@0001d_ol0203oool00`3ogi`0B01809cOo`0=0?ooo`030?oOW018
04P0W=oo00H0oooo00<0omnL04P0B02Lgol03@3oool00`3ooml0W4P007Boo`0:0?ooo`030?oog`2L
B00007Bo00<0oooo00<0gia80000B02Lgol0203oool00`3ogi`0B01809cOo`0;0?ooo`030?oog`2L
B00007Bo00<0oooo00<0gia80000B02Lgol02@3oool00`3o_g@0B9cO0?ooo`050?ooo`030?oOW018
04P0W=oo0:`0oooo003e0?ooo`040?noM000000004RL0=ooo`80oooo00L0gia8001d_`3oool0okmd
0018W02oW4P0M;oo00<0oooo00/0okmd0018W03Oool0oooo0?oo_`1d0000B9cO0?ooo`3o_g@0001d
0;ooo`020?ooo`070=nLB00007@0_ooo0?ooo`3o_g@0001d0;ooo`020?ooo`070=nLB00007@0_ooo
0?ooo`3ogi`0B01809cOo`020?ooo`030=nLB00007@0_ooo0080oooo00P0oono07@0001d_ol0oooo
0?noM000B9`0_ia807Booa40oooo00@0okmd00000000B9`0gooo0P3oool01`3OW4P007Bo0?ooo`3o
_g@004RL0;nLB01d_ol00`3oool02`3o_g@004RL0=ooo`3oool0oono07@00018W=l0oooo0?oog`2L
B00007Bo0080oooo00<0oono07Ad_`3oool01@3oool0403o_g@0001d09bLM02Lgol0oono07@0001d
_kl0M7Bo0?ooo`2oM00004RL0=ooo`3oool0gia80000M02oool20?ooo`070?oo_`1d0000M;oo0?oo
o`3o_g@0001d0;ooo`020?ooo`0?0=nLB00007@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0
0018W=l0oooo0?oOW01807@0_ooo00/0oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001d0;oo
o`020?ooo`030=nLB00007@0_ooo00H0oooo00<0omnL04P0B01d_ml00P3oool00`3ookl0M00007Bo
o`050?ooo`070=nLB00007@0_ooo0?ooo`3ookl0M00007Boo`020?ooo`030?noM00007@0_ooo00l0
oooo00<0oono07@0001d_ol01@3oool00`3ookl0M00007Boo`0=0?ooo`030?oo_`1d0000B9cO00/0
oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`080?ooo`030?oo_`1d0000M;oo00`0
oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0oooo00<0
oooo00<0okmd0000M02oool0[@3oool00?D0oooo0200oono07@0001dW9`0B01d0;ooo`3ooml0W4P0
001d_`3oool0oono07@0B02Lgol0_g@007AdM000B9`0gooo0?ooo`3OW4P0001d0;ooo`3oool0gia8
0018W03Oool0oooo0=nLB00007@0_ooo0?ooo`2oM000001809cOo`80oooo00/0gia80000M02oool0
oooo0;md000004P0W=oo0?ooo`3ooml0W4P004RLg`030?ooo`0?0;md000007@0_ooo0?ooo`3o_g@0
001d0;ooo`3oool0oono07@0B02Lgol0_g@007AdM000B9`0gooo00h0oooo01/0oono07@0001dW9`0
B01d0;ooo`3ooml0W4P0001d_`3oool0oono07@0B02Lgol0_g@007AdM000B9`0gooo0?ooo`3OW4P0
001d0;ooo`3oool0gia80018W03Oool0oono07@00018W=l00P3oool00`3ogi`0B01d0;ooo`050?oo
o`0<0?oo_`1d04P0W=oO09a8B02Lgml0W4P004RLg`3o_g@007Bo0?noM00007@0_ooo0P3oool01`2o
M000001d0;ooo`3oool0okmd0000M02oool00P3oool01`3OW4P0001d0;ooo`3oool0_g@00000B02L
gol00P3oool02P3OW4P0001d0;ooo`3oool0gia80018W03Oool0oono07@0001d_ol;0?ooo`030?oo
g`2LB000B9cO00@0oooo00L0gia80000M02oool0oooo0;md000004P0W=oo00H0oooo00P0oono07@0
0018B4P0B9cO0?ooo`3o_g@0001809cOo`H0oooo00H0_g@00000M02oool0oooo0=nLB018W=l20?oo
o`060=nLB000B9`0gooo0?ooo`3ooml0W4P0200000001`18W=l0oooo0?ooo`3oool0oooO09a80018
W=l01P3oool00`2oM00007Bo0?ooo`0<0?ooo`030?noM0000000M;oo00/0oooo00<0gia80000B02L
gol00P3oool00`3ooml0W4P0001d_`090?ooo`030;md0000M;l0oooo00/0oooo00<0gia80000B02L
gol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo0080oooo00<0gia80018W03O
ool0[@3oool00?@0oooo0140omnL04P000000000B9cO0?oo_`1d000000000000M02oool0omnL04P0
00000000M;oo0?ooo`2oM000001d0;ooo`020?ooo`050?oOW018000000000000001d_ol00`3oool0
1P3ogi`0B00000000018W;l0W4P004RLg`<0oooo00P0omnL04P000000000B9bL07@00018W=l0oono
07@000<0000000@0M;oo0?ooo`3oool0okmd0`0000002P1d_ol0oooo0?oOW0180000000007Boo`3o
ool0_g@00000M02oool=0?ooo`0A0?oOW0180000000004RLg`3ookl0M0000000000007@0_ooo0?oO
W0180000000007Boo`3oool0_g@00000M02oool00P3oool02@3ogi`0B000000000000000M;oo0;md
00000000001809cOo`020?ooo`030=nLB000B9`0gooo00@0oooo00d0oono07@000000000B9cO0?oo
g`2LB000000004RLg`3oool0okmd00000000B9`0gooo00<0oooo00D0okmd000000000000000007Bo
o`040?ooo`060?oOW0180000000004RL_`2LB000B9cO0`3oool01@3ogi`0B000000000000000M;oo
0080oooo00<0_g@004RLg`3oool02P3oool00`3ooml0W4P004RLg`050?ooo`060?oOW01800000000
04RLW01d0000B9cO1`3oool00`2oM00007Bo0=nLB0020000000304RLg`3oool0oooo00H0oooo00D0
omnL04P000000000001809cOo`020?ooo`030=nLB000B9`0gooo00l0oooo00<0oooO09a80018W=l0
1P3oool00`3OW4P004RL0=ooo`090?ooo`060?oOg`3Oool0okmd0000000007@0_ooo2`3oool00`3o
gi`0B00004RLg`030?ooo`030;md0000B9`0gooo00P0oooo00<0gia80018W03Oool02`3oool00`3o
gi`0B00004RLg`030?ooo`030;md0000B9`0gooo00X0oooo00<0omnL04P0M02oool00P3oool00`3O
W4P004RL0=ooo`2]0?ooo`00o`3ooolD0?ooo`030;md0000M;l0oooo00X0oooo00<0okmd0000M02o
ool0H03oool00`2oM00007Bo0?ooo`090?ooo`030=nLB000B9`0gooo00X0oooo00<0oooO09a80018
W=l04P3oool00`3OW4P004RL0=ooo`0B0?ooo`030=nLB000B9`0gooo00l0oooo00<0oooO09a80018
W=l01P3oool00`3ogi`0B01809cOo`090?ooo`050?oo_`1d000000000000B02Lgol0303oool0103o
oml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00<0omnL04P0B02Lgol02`3oool0
103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00X0oooo00<0oooO09a8001d_ol00P3o
ool00`3OW4P004RL0=ooo`2]0?ooo`00o`3ooolD0?ooo`030?noM00007@0_ooo00/0oooo00<0giad
09cOo`3oool0G`3oool00`3o_g@0001d0;ooo`090?ooo`030?oOW01807@0_ooo00X0oooo00<0oooO
09a80018W=l04P3oool00`3ogi`0B01809cOo`0B0?ooo`030=nLB000B9`0gooo00l0oooo00<0oooO
09a80018W=l01P3oool00`3ookl0M00007Boo`0:0?ooo`030=nLW02oool0oooo00h0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`080?ooo`030?oo_`1d0000M;oo00`0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo_`1d0000B9cO0080oooo00<0gia8
0018W03Oool0[@3oool00?l0oooo503oool00`3ogi`0B01809cOo`1]0?ooo`030?oOW01804P0W=oo
00T0oooo00<0oooO09a8001d_ol02P3oool00`3ooml0W4P004RLg`0B0?ooo`030?oo_`1d0000B9cO
0180oooo00<0gia80018W03Oool03`3oool00`3ooml0W4P004RLg`070?ooo`030;md0000M;l0oooo
00T0oooo00<0omnL07BLg`3oool03`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`X0oooo00<0
_g@0001d_`3oool0303oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00L0okmd0018W03O
ool0oooo0=nLB00004P0W=oo0080oooo00<0gia80018W03Oool0[@3oool00?l0oooo503oool00`3o
oml0W4P004RLg`1]0?ooo`030?oog`2LB000B9cO00X0oooo00<0gia804RLg`3oool02P3oool00`3O
W4P0001d0;ooo`0B0?ooo`030=nLB000M;l0oooo0100oooo00<0oono07@00000M;l04@3oool00`3O
W4P0001d0;ooo`040?ooo`050?oo_`1d000000000000M02oool02P3oool01@2oM000000000000000
0000B9cO00d0oooo00@0gia800000000000007Bo2@3oool01@3ookl0M0000000000007@0_ooo00d0
oooo00@0gia800000000000007Bo2@3oool01@3ogi`0B000000000000000M;oo0080oooo00<0oono
07@00000M;l0[P3oool00?l0oooo4`3oool0103ookl0M00000000000M;m/0?ooo`040?oo_`1d0000
0000001d_`P0oooo00@0oooO09a80000000007Bo2`3oool0103ooml0W4P00000B02Lgol?0?ooo`05
0?oog`2LB00000000000M02oool03`3oool0103ogi`0B0000018W03OoolA0?ooo`040?oog`2LB000
001809cOoeH0oooo00@0omnL04P00000B9`0gooo[P3oool00?l0ooooo`3ooooW0?ooo`00o`3ooooo
0?ooonL0oooo003o0?ooool0ooooi`3oool00?l0ooooo`3ooooW0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 740.813}, {327.188, 0}} -> {-0.209399, -0.0904568, \
0.00227246, 0.00227246}}]
}, Closed]],

Cell[TextData[{
  "Finally, the figure below shows the time dependence of both population \
densities for a particular choice of initial conditions.  The greater \
amplitude of the oscillation of prey population and the approximately \
quarter-cycle relative phase between the two populations both make sense \
intuitively \[LongDash] the predator population peaks after the prey that it \
relies on for food, but increasing predator population drives down the prey \
population.  The relative scarcity of prey then drives down the predator \
population.  When the predator population is small, the prey population tends \
to increase.  For this system, the two populations eventually settle upon a \
periodic oscillation known as a ",
  StyleBox["limit cycle",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[trajectory[{1.5, 0.1, 0.2}, {0.2, 0.2}, 200]], {t, 0, 80}, 
        PlotRange \[Rule] {Automatic, {0, 0.8}}, 
        PlotStyle \[Rule] {{}, Dashing[{0.02, 0.02}]}, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<population density\>"}, 
        PlotLegend \[Rule] {"\<prey\>", "\<predator\>"}, 
        LegendPosition \[Rule] {\(-0.7\), 0.35}, 
        LegendSize \[Rule] {0.7, 0.2}, 
        LegendShadow \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.0119048 1.61546e-017 0.772542 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.2619 -0.0125 -8 -15.6875 ]
[.2619 -0.0125 8 0 ]
[.5 -0.0125 -8 -15.6875 ]
[.5 -0.0125 8 0 ]
[.7381 -0.0125 -8 -15.6875 ]
[.7381 -0.0125 8 0 ]
[.97619 -0.0125 -8 -15.6875 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -3.78125 -31.375 ]
[.5 -0.0125 3.78125 -15.6875 ]
[-0.0125 .07725 -19 -7.84375 ]
[-0.0125 .07725 0 7.84375 ]
[-0.0125 .15451 -19 -7.84375 ]
[-0.0125 .15451 0 7.84375 ]
[-0.0125 .23176 -19 -7.84375 ]
[-0.0125 .23176 0 7.84375 ]
[-0.0125 .30902 -19 -7.84375 ]
[-0.0125 .30902 0 7.84375 ]
[-0.0125 .38627 -19 -7.84375 ]
[-0.0125 .38627 0 7.84375 ]
[-0.0125 .46353 -19.25 -7.84375 ]
[-0.0125 .46353 0 7.84375 ]
[-0.0125 .54078 -19.25 -7.84375 ]
[-0.0125 .54078 0 7.84375 ]
[-0.0125 .61803 -19 -7.84375 ]
[-0.0125 .61803 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.9375 -47.0313 ]
[-0.01875 .30902 -19.25 47.0313 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -64.7813 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
66.563 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
gsave
-0.0125 .07725 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .15451 m
.00625 .15451 L
s
gsave
-0.0125 .15451 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .23176 m
.00625 .23176 L
s
gsave
-0.0125 .23176 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .38627 m
.00625 .38627 L
s
gsave
-0.0125 .38627 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .46353 m
.00625 .46353 L
s
gsave
-0.0125 .46353 -80.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .54078 m
.00625 .54078 L
s
gsave
-0.0125 .54078 -80.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.125 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
108.031 11.8438 translate
90 rotate
-108.031 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(population) show
119.250 15.813 moveto
(density) show
153.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .15451 m
.04262 .09936 L
.0522 .07277 L
.05746 .06094 L
.06244 .0521 L
.06506 .0484 L
.0679 .04506 L
.07026 .04281 L
.07286 .04082 L
.0753 .03939 L
.07655 .03881 L
.0779 .03829 L
.07915 .03791 L
.0803 .03763 L
.08146 .03743 L
.08255 .0373 L
.08327 .03725 L
.08394 .03722 L
.0852 .03723 L
.0859 .03727 L
.08655 .03732 L
.08726 .0374 L
.08801 .03751 L
.08926 .03775 L
.09043 .03804 L
.09308 .03889 L
.09599 .04016 L
.09863 .04162 L
.10458 .04597 L
.10939 .05062 L
.11449 .0568 L
.12366 .07167 L
.12875 .08241 L
.13353 .09443 L
.14443 .13014 L
.15426 .1738 L
.16461 .23125 L
.18311 .34544 L
.19266 .39475 L
.198 .41591 L
.20053 .42405 L
.20285 .43045 L
.20501 .43544 L
.20739 .43987 L
.20977 .44322 L
.21108 .44459 L
.2123 .44558 L
.21345 .44626 L
.21455 .44668 L
.21553 .44687 L
Mistroke
.2166 .44688 L
.21776 .44667 L
.219 .44618 L
.22016 .44547 L
.22122 .44464 L
.22355 .44214 L
.22611 .4384 L
.23127 .42777 L
.23605 .41443 L
.24051 .39911 L
.25057 .35469 L
.26134 .29243 L
.28119 .14509 L
.28659 .10463 L
.29165 .07232 L
.29441 .05824 L
.29693 .04782 L
.29974 .0389 L
.3012 .03526 L
.30275 .03203 L
.30526 .02806 L
.30758 .02546 L
.30901 .02428 L
.31035 .0234 L
.31156 .02279 L
.31286 .02228 L
.31414 .02193 L
.31487 .02178 L
.31555 .02168 L
.31627 .02161 L
.31692 .02157 L
.31768 .02156 L
.31839 .02158 L
.31966 .02169 L
.32083 .02186 L
.32212 .02212 L
.32349 .02248 L
.32575 .02326 L
.32818 .02435 L
.33259 .02693 L
.33784 .03111 L
.34265 .03612 L
.34738 .04233 L
.35244 .05064 L
.36155 .07121 L
.36712 .08835 L
.37239 .10859 L
.38224 .15916 L
.39195 .2266 L
.40223 .31252 L
Mistroke
.41187 .39405 L
.42068 .45703 L
.42551 .484 L
.4301 .50407 L
.43494 .51945 L
.43768 .52565 L
.4389 .52786 L
.44023 .52988 L
.44147 .53144 L
.44262 .53259 L
.44372 .53345 L
.44488 .5341 L
.44591 .53447 L
.44688 .53463 L
.44795 .53461 L
.44909 .53437 L
.4503 .53387 L
.45163 .53306 L
.45287 .53203 L
.45403 .53087 L
.45853 .52449 L
.46095 .51992 L
.46317 .51506 L
.46817 .50195 L
.47721 .47104 L
.48725 .4264 L
.49782 .36752 L
.5178 .22118 L
.52651 .14715 L
.53109 .10993 L
.53595 .07589 L
.53845 .0616 L
.5412 .04889 L
.5437 .04 L
.54604 .03375 L
.54844 .02905 L
.55064 .02596 L
.55185 .02466 L
.55317 .0235 L
.55432 .02269 L
.55557 .022 L
.55631 .02167 L
.557 .02141 L
.55764 .0212 L
.55834 .02101 L
.55956 .02078 L
.56084 .02065 L
.56157 .02063 L
.56224 .02063 L
.56301 .02066 L
Mistroke
.56374 .02073 L
.56504 .02091 L
.56577 .02105 L
.56645 .0212 L
.56878 .02187 L
.57134 .02289 L
.57653 .02577 L
.58172 .02982 L
.58666 .03487 L
.59593 .0483 L
.6011 .05866 L
.60591 .07065 L
.61114 .08685 L
.6168 .10885 L
.62736 .16495 L
.63731 .23721 L
.65592 .3972 L
.66542 .46556 L
.67081 .49477 L
.67585 .51518 L
.67858 .52354 L
.68116 .52978 L
.68349 .53407 L
.68479 .53595 L
.68601 .5374 L
.68732 .5386 L
.68807 .53913 L
.68876 .53953 L
.68944 .53984 L
.69016 .54006 L
.69088 .54019 L
.69167 .54023 L
.69298 .54005 L
.69372 .53982 L
.69439 .53953 L
.69568 .53876 L
.69691 .5378 L
.6993 .53526 L
.70154 .53214 L
.70663 .52254 L
.71159 .51013 L
.71691 .49368 L
.73536 .41344 L
.74549 .35375 L
.75653 .27511 L
.76708 .18818 L
.77663 .10853 L
.78151 .07454 L
.78407 .06013 L
.78678 .04789 L
Mistroke
.78915 .03961 L
.79176 .03285 L
.79412 .02845 L
.79633 .0255 L
.79764 .02419 L
.79906 .02305 L
.8004 .02222 L
.80163 .02163 L
.80275 .02123 L
.80398 .02091 L
.80526 .0207 L
.80646 .0206 L
.8071 .02059 L
.80779 .0206 L
.80852 .02064 L
.80919 .02071 L
.8104 .02088 L
.81169 .02115 L
.81321 .02155 L
.81464 .02203 L
.81731 .02316 L
.82196 .02581 L
.82706 .0298 L
.83238 .03531 L
.83736 .04192 L
.84626 .05828 L
.85126 .07072 L
.85582 .08466 L
.86571 .12557 L
.87487 .17932 L
.89562 .34972 L
.90458 .42361 L
.90929 .45666 L
.91425 .48568 L
.91689 .49851 L
.91979 .51046 L
.92487 .52628 L
.92736 .53176 L
.92873 .53417 L
.93003 .53606 L
.93124 .53751 L
.93255 .53874 L
.93374 .53956 L
.93484 .54007 L
.93609 .54038 L
.93728 .54042 L
.93834 .54024 L
.9395 .53983 L
.94076 .53913 L
.9421 .53811 L
Mistroke
.94451 .53559 L
.94696 .53217 L
.94927 .52821 L
.95357 .51899 L
.96348 .4896 L
.9742 .44596 L
.97619 .43654 L
Mfstroke
[ .02 .02 ] 0 setdash
.02381 .15451 m
.06244 .11076 L
.07216 .0912 L
.0775 .08205 L
.08255 .07489 L
.08852 .06833 L
.09396 .06396 L
.09905 .06105 L
.10193 .05985 L
.10458 .059 L
.10685 .05844 L
.10811 .05819 L
.1093 .058 L
.1104 .05786 L
.11161 .05774 L
.1127 .05766 L
.11372 .05762 L
.11504 .05759 L
.11628 .05761 L
.11739 .05766 L
.11859 .05773 L
.11991 .05786 L
.1213 .05802 L
.12379 .05842 L
.12621 .05892 L
.12881 .05958 L
.1335 .06109 L
.14415 .06591 L
.15433 .07228 L
.16539 .08115 L
.18551 .10255 L
.20529 .12996 L
.22629 .16456 L
.24599 .1979 L
.25461 .21044 L
.2595 .21622 L
.26184 .2185 L
.26405 .22031 L
.26519 .22109 L
.26643 .22181 L
.26747 .22229 L
.2686 .22271 L
.26983 .223 L
.27113 .22311 L
.27234 .22302 L
.27347 .22276 L
.27475 .22224 L
.27597 .2215 L
.27706 .22063 L
.27825 .21942 L
Mistroke
.28092 .2157 L
.28339 .2108 L
.28612 .20356 L
.28869 .19481 L
.29349 .17326 L
.30425 .11232 L
.30931 .08866 L
.31404 .07265 L
.31642 .06654 L
.31897 .0612 L
.32155 .05682 L
.32437 .05305 L
.32695 .05031 L
.32934 .04828 L
.33158 .04675 L
.33404 .04541 L
.33625 .04448 L
.33832 .0438 L
.3405 .04327 L
.34173 .04304 L
.34285 .04288 L
.34413 .04274 L
.34534 .04265 L
.34643 .0426 L
.34761 .04258 L
.34889 .04261 L
.34954 .04263 L
.35025 .04267 L
.35151 .04277 L
.35268 .04289 L
.35498 .04321 L
.35709 .04359 L
.36181 .04474 L
.3669 .0464 L
.37245 .04867 L
.38253 .05399 L
.39191 .0603 L
.40228 .06882 L
.42328 .09125 L
.4426 .11816 L
.46345 .15334 L
.48307 .18962 L
.49346 .20785 L
.49916 .21671 L
.50456 .22378 L
.50706 .22646 L
.50971 .22879 L
.51109 .22976 L
.51261 .23061 L
.51328 .23091 L
Mistroke
.514 .23118 L
.51529 .2315 L
.51654 .2316 L
.51725 .23157 L
.51791 .23147 L
.51911 .23112 L
.52039 .23048 L
.52165 .22957 L
.52284 .22844 L
.52506 .22552 L
.52738 .22119 L
.52984 .21503 L
.53193 .20832 L
.53423 .1993 L
.53936 .17288 L
.54415 .14278 L
.54916 .11191 L
.5518 .09797 L
.55461 .08549 L
.55706 .07653 L
.55976 .06851 L
.56224 .06259 L
.56452 .05817 L
.56913 .05154 L
.57154 .04901 L
.57409 .0469 L
.57617 .04552 L
.57838 .04433 L
.58082 .04332 L
.58308 .04262 L
.58431 .04232 L
.58567 .04205 L
.58709 .04184 L
.58777 .04176 L
.58841 .0417 L
.58965 .04161 L
.59078 .04156 L
.592 .04155 L
.59269 .04156 L
.59333 .04158 L
.59403 .04161 L
.59479 .04166 L
.59615 .04178 L
.59749 .04193 L
.59871 .0421 L
.6015 .04259 L
.60444 .04327 L
.60942 .04475 L
.61406 .04648 L
.62459 .05161 L
Mistroke
.63508 .05835 L
.645 .06623 L
.66358 .08506 L
.68354 .11145 L
.70198 .14129 L
.72228 .17841 L
.73222 .19671 L
.74132 .21215 L
.74578 .21878 L
.75065 .22492 L
.75288 .22722 L
.75526 .22925 L
.75641 .23006 L
.7575 .2307 L
.75855 .2312 L
.75953 .23156 L
.76067 .23183 L
.76192 .23193 L
.76313 .23182 L
.76444 .23146 L
.76565 .23087 L
.7668 .23007 L
.76783 .22914 L
.76895 .22788 L
.77151 .22394 L
.77281 .22133 L
.77424 .21791 L
.77914 .20141 L
.78935 .14377 L
.79492 .10956 L
.79763 .09557 L
.8001 .08482 L
.80454 .06995 L
.80698 .06384 L
.80928 .05914 L
.8141 .05191 L
.81682 .04902 L
.81933 .04692 L
.82156 .04544 L
.82395 .04418 L
.82621 .04326 L
.82827 .04261 L
.83069 .04207 L
.83205 .04185 L
.83332 .0417 L
.83454 .04159 L
.83564 .04154 L
.83691 .04151 L
.83811 .04152 L
.83927 .04157 L
Mistroke
.84054 .04165 L
.84117 .04171 L
.84186 .04178 L
.84309 .04193 L
.84549 .0423 L
.84767 .04274 L
.85298 .04414 L
.858 .04589 L
.86768 .05035 L
.87794 .05658 L
.89637 .07172 L
.91587 .0935 L
.93416 .11947 L
.97289 .18818 L
.97619 .19422 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.166667 0.475684 0.5 0.570922 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0113379 0.113379 [
[ 0 0 0 0 ]
[ 1 .28571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .28571 L
0 .28571 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0204082 0.35119 0.133787 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ .13333 .13333 ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .0771 -61 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(predator) show
106.250 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.151927 0.35119 0.265306 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20862 -61 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(prey) show
85.500 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{326.688, 201.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007Z0001;R000`400?l00000o`00003oo`3oooo[
0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[
0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[
0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oool>0?ooo`040?noM000
0000001809cOomT0oooo003o0?ooo`h0oooo00D0okmd0000B02Lgml0W7BL0=ooo`3H0?ooo`00o`3o
ool>0?ooo`030?oo_`1d0000M;oo0=X0oooo003o0?ooo`l0oooo00<0_g@0001d_`3oool0f@3oool0
0?l0oooo3`3oool00`3OW4P004RL0=ooo`3I0?ooo`00o`3oool?0?ooo`030?oOW01804P0W=oo0=T0
oooo003o0?ooo`l0oooo00<0oooO09a80018W=l0f@3oool00?l0oooo3P3oool00`3ookl0M0000000
00020000000307Boo`3oool0oooo0=D0oooo003o0?oooa00oooo00<0okmd0000M02oool0f03oool0
0?l0oooo4@3oool00`3OW7@0W=oo0?ooo`3G0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3o
ooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3o
ooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3o
ooo[0?ooo`00H@3oool0102oM00000000000001d_om<0?ooo`030=nLB0000000000000<0000000<0
B9cO0?ooo`3oool00P3oool0102oM00000000000001d_om:0?ooo`030?oog`2LB000B9cO00D0oooo
00@0_g@0000000000000M;ooB03oool01@3ooml0W4P000000000000007Bo00D0oooo00@0_g@00000
00000000M;ooB@3oool01P3ookl0M00000000000000004RL0=ooo`@0oooo00@0_g@0000000000000
M;oo9`3oool00600oooo00H0gia8001d_`3oool0omnL04P00018W=m<0?ooo`030?noM000M;l0oooo
0080oooo00X0_gAd0;ooo`3oool0oooo0=nLB000M;l0oooo0?oOW0180000B9cOBP3oool00`3OW4P0
04RL0=ooo`030?ooo`060=nLB000M;l0oooo0?oOW0180000B9cOA`3oool01`3OW4P007Bo0?ooo`3o
okl0M0000018W03Oool00P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgdL0oooo00<0oono07@0
0018W=l00P3oool00`3OW4P0001d0;ooo`020?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO9P3o
ool005l0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`1<0?ooo`030?noM000M;l0
oooo00@0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`190?ooo`030?oOW01804P0
W=oo0080oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`150?ooo`030?oog`2LB000
M;oo0080oooo00L0omnL04P00018W=l0oooo0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0
AP3oool00`3o_g@004RL0=ooo`030?ooo`060;md0018W=l0oooo0?oog`2LB000B9cO0P3oool00`3o
_g@0001809cOo`0U0?ooo`00G`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oo
od`0oooo00<0okmd001d_`3oool00`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL
0=oood@0oooo00<0okmd000000000000100000001@00B9`0gooo0?oog`2LB000B9cO0080oooo00@0
oooO09a80000B9`0goooA03oool00`3ookl0M00007Boo`030?ooo`060;md000007@0_ooo0?oog`2L
B000B9cO0P3oool0103ooml0W4P00018W03Ooom50?ooo`030?noM000B9`0gooo00<0oooo00H0_g@0
001d_`3oool0oooO09a80018W=l20?ooo`040?oog`2LB00004RL0=ooob@0oooo001O0?ooo`030?oo
g`2LB00007Bo00<0oooo00<0gia80000B02Lgol0C@3oool00`3o_g@0B9cO0?ooo`020?ooo`030?oo
g`2LB00007Bo00<0oooo00<0gia80000B02Lgol0A03oool00`3ooml0W4Q809cOo`020?ooo`070;md
0000M;l0oooo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo04@0oooo00<0oooO09a8
0000M;l00`3oool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol0A@3o
ool00`3ooml0W4P007Boo`020?ooo`070?oo_`1d0000B9cO0?ooo`3ooml0W4P0001d_`030?ooo`03
0=nLB00004P0W=oo02@0oooo001P0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0
CP3oool00`3OW4P0B9cO0?ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0
A@3oool01`3ookl0M01d0;ooo`3oool0okmd0018W03Oool00P3oool00`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO04D0oooo00<0_g@00000M02oool00P3oool01`3OW4P0001809cOo`3oool0
_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`170?ooo`060;md000004P0W=oO09a8000007@0
_ooo0P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO02@0oooo001P0?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l0C`3oool01`2oM000M;oo0?ooo`3oool0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`160?ooo`060?oOW018B9`0gooo0?oOW01804P0W=oo0P3o
ool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo04D0oooo00`0okmd00000018W=l0oooo
0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol20?ooo`030?oog`2LB00007Bo04P0oooo00D0
oooO09a80000000004RL0=ooo`020?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0
903oool00600oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`1>0?ooo`070?oOW018
07@0_ooo0?ooo`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo04H0oooo00D0okmd001d_`3o
oml0W4P004RLg`020?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0A03oool00`3o
oml0W4P000000002000000070000M02oool0oooo0?ooo`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo04L0oooo00X0_g@00000B02Lgol0omnL04Q8W03Oool0oooo0?oOW0180000B9cO0`3oool0
0`2oM00004RL0=ooo`0S0?ooo`00H03oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0
gooo04h0oooo00P0oooO09a8001d_ol0oooo0?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03O
ool0A`3oool0103OW4P0B9cO0;md0000M;l20?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool0A@3oool00`3ookl0M000001d_`050?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool0AP3oool00`3ogi`0B00007Boo`020?ooo`070?noM018W=l0oooo0?oog`2LB000
04RL0=ooo`020?ooo`030=nLB000B9`0gooo02<0oooo001Q0?ooo`030?oOW0180000M;oo0080oooo
00<0gia8001d_`3oool0CP3oool00`3ookl0M00004RLg`020?ooo`030?oOW0180000M;oo0080oooo
00<0gia8001d_`3oool0B03oool0103OW4P0M7Ad0000M02oool20?ooo`030?oOW0180000M;oo0080
oooo00<0gia8001d_`3oool0AP3oool00`3ogi`0B00004RLg`050?ooo`030?oOW0180000M;oo0080
oooo00<0gia8001d_`3oool0AP3oool00`3ogi`0B01809cOo`020?ooo`070?noM000B9`0gooo0?oo
o`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo02<0oooo001R0?ooo`060=nLB00007@0_ooo
0?oog`2LB000B9cOB`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol00`3oool01P3OW4P0
001d0;ooo`3ooml0W4P004RLgdX0oooo00<0_g@00000B02Lgol00`3oool01P3OW4P0001d0;ooo`3o
oml0W4P004RLgdP0oooo00@0oooO09a8000007@0_ooo103oool01P3OW4P0001d0;ooo`3ooml0W4P0
04RLgdL0oooo00<0oooO09a80018W=l00P3oool00`2oM00007Bo0?ooo`020?ooo`060=nLB00007@0
_ooo0?oog`2LB000B9cO903oool006<0oooo00@0gia800000000000007BoC@3oool01@3ogi`0B000
000000000000M;oo00D0oooo00@0gia800000000000007BoB`3oool00`3ooml0W4P004RLg`040?oo
o`040=nLB00000000000001d_d/0oooo00@0oono07@000000000B9cO0`3oool0103OW4P000000000
0000M;m90?ooo`050?oog`2LB000000000000000M;l01@3oool0103OW4P0000000000000M;lU0?oo
o`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?oo
o`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00o`3oooo[0?ooo`00F`3ooooo0000
06`00000903oool005/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool005/0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
8P3oool005/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool08P3oool005/0oooo00<000000?ooo`3oool0o`3ooomX
0?ooo`030000003oool0oooo0280oooo001K0?ooo`030000003oool0oooo0?l0ooooJ03oool00`00
0000oooo0?ooo`0R0?ooo`00F`3oool200000?l0ooooJ03oool2000002@0oooo001K0?ooo`030000
003oool0oooo0?l0ooooJ03oool00`000000oooo0?ooo`0R0?ooo`00F`3oool00`000000oooo0?oo
o`1^0?ooo`@00000E03oool6000005<0oooo1P0000120?ooo`030000003oool0oooo0280oooo001K
0?ooo`030000003oool0oooo06d0oooo0P0000030?ooo`<00000D03oool2000000D0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool08P3oool005/0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool01P3oool2000004h0oooo00<000000?oo
o`3oool01P3oool2000003l0oooo00<000000?ooo`3oool08P3oool005/0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool02@3oool2000004`0oooo00<000000?ooo`3oool0203oool2000003d0oooo00<000000?ooo`3o
ool08P3oool005/0oooo0P00001[0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0j0?ooo`800000903oool005/0oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0R0?ooo`00F`3oool00`000000oooo0?ooo`0H0?ooo`H00000B`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0R0?ooo`00F`3oool00`000000oooo0?ooo`0G0?ooo`8000001@3oool20000
04T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00h0oooo0P0000160?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0R0?ooo`00F`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0>0?ooo`D00000@`3oool00`000000
oooo0?ooo`0>0?ooo`H00000@P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080
oooo0P00000d0?ooo`030000003oool0oooo0280oooo001K0?ooo`8000005P3oool00`000000oooo
0?ooo`090?ooo`800000A@3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0?ooo`<0
0000?`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool3000003h0oooo00<000000?ooo`3oool02@3oool2000000@0oooo00<000000?ooo`3o
ool0103oool200000340oooo0P00000T0?ooo`00F`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo0P00000`0?ooo`030000003oool0oooo0280oooo001K0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`800000;P3o
ool00`000000oooo0?ooo`0R0?ooo`00F`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo0280oooo001K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool40000
03d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo0P00000f0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo0280oooo001K0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04`3oool00`000000oooo00000002000003/0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo0P00000d0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool08P3oool003l0oooo00@0_g@0000000000000
M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3o
ool0203oool200000180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo0P00000i0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo0P00000c0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`80
0000903oool003h0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo
00@0oooo00<0okmd0000001d_ol02`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool08P3oool003d0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0
001809cOo`080?ooo`030?oog`2LB00007Bo00/0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0:0?ooo`8000002@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool03@3oool2000002D0oooo00<000000?ooo`3oool08P3oool003d0oooo
00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030=nLB000B9`0gooo00X0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`00?@3oool00`3ooml0W4P0
001d_`030?ooo`030=nLB00004P0W=oo00P0oooo00<0omnL04P0B02Lgol02P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0R0?ooo`00?P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00P0oooo00<0
oono07@0001d_ol02P3oool3000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0O0?ooo`<00000903oool003h0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`09
0?ooo`030;md0000M;l0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00X0oooo0P00000]0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0R0?ooo`00?P3oool00`3ogi`0B00004RLg`030?oo
o`030;md0000B9`0gooo00P0oooo00<0gia80018W03Oool02@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0280oooo000n0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018
W03Oool0203oool00`3ogi`0B01809cOo`090?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool08P3oool003l0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`080?ooo`03
0?oo_`1d0000M;oo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo0280oooo00100?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO2P3oool00`2o
M00007Bo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0R0?ooo`00@@3oool0103OW4P0000000000000M;l90?ooo`050?oo_`1d00000000
0000M02oool0203oool2000000h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A
0?ooo`800000703oool2000002@0oooo001K0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool08P3oool005/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0R0?ooo`00
F`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0R0?ooo`00F`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0280oooo001K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08P3oool0
05/0oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05`3oool20000
02@0oooo001K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo0280oooo001K0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0R0?ooo`00F`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0R0?ooo`00F`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0280oooo001K0?oo
o`8000002P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0;03oool2000002@0oooo000d0?ooo`030;nLW03Oool0oooo02@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0R0?ooo`00<P3oool0103ookl0M0000018W03OoolU0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool08P3oool002h0oooo00<0oono07@000000000
0`0000000`00B9`0gooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8P3oool002P0oooo00@0oono09bLg`3ookl0M000100000001P00M;l0oooo0?ooo`3oool0_ibL0=oo
obD0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0R0?ooo`00:03oool01@3ogi`0
B00000000000000007Bo00<0oooo00<0_gAd0;ooo`3oool0:03oool00`000000oooo0?ooo`070?oo
o`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0R0?ooo`00:@3oool00`3o
okl0M4RL0=ooo`040?ooo`030=nLW02oool0oooo00`0oooo00@0_g@0000000000000M;oo0`3oool0
0`3ogi`0B00007Boo`020?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool01`3oool2
000000P0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0403oool2000002@0oooo000X0?ooo`030?oog`2LB7@0_ooo00@0oooo00<0oono
07Ad_`3oool0303oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol0
0`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000002L0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0R0?ooo`00:03oool00`3ogi`0M9cO0?ooo`030?ooo`030?oo_`1d07@0_ooo00`0oooo
00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo00/0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool08P3oool002P0oooo00P0okmd001d_`3oool0oooo0?oog`2LB000001d0;oo
o`d0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030?noM000M;l0
oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo0280oooo000Y0?ooo`050;md0000000000000000B02Lgol03`3oool00`3ooml0W4P0001d_`03
0?ooo`030=nLB00004P0W=oo00T0oooo00<0okmd04RLg`3oool02@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo0280oooo000n0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P0
0018W=l02P3oool00`3OW4P0B9cO0?ooo`080?ooo`<000001@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Y0?oo
o`<00000903oool003h0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`03
0;md001d_ol0oooo00L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0280oooo000[0?ooo`060?oOW018000000000000000004P0W=oo3@3oool00`3o
gi`0B00004RLg`030?ooo`030;md0000B9`0gooo00X0oooo00<0omnL04P0M02oool01`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo000Z0?ooo`030;md00000000M;oo0080
oooo00<0oooO09adW03Oool0303oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo
00X0oooo00<0oooO09a8001d_ol01`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0280oooo000Y0?ooo`030=nLB018W=l0oooo00@0oooo00<0gibL0;ooo`3oool0303oool00`3ogi`0
B00007Boo`020?ooo`030=nLB000M;l0oooo00X0oooo00<0oono07@00018W=l01`3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08P3oool002P0oooo
00<0omnL07BLg`3oool0103oool00`3ooml0W7BL0=ooo`0>0?ooo`060=nLB00007@0_ooo0?oog`2L
B000B9cO1`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol01`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08P3oool002P0oooo00<0oknL
09cOo`3oool00`3oool00`3ooml0W4P007Boo`0@0?ooo`040=nLB00000000000001d_`T0oooo00D0
omnL04P000000000000007Boo`080?ooo`800000=P3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:0?ooo`800000
903oool002P0oooo00<0omnL04Qd_`3oool00P3oool00`3OW4P0000004RLg`0[0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool08P3oool002T0oooo00H0okmd00000000000000000018
W03Oool50?ooo`030;nLW03Oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0R0?ooo`00<P3oool0103ookl0M0000018W03OoolU0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo
000^0?ooo`030?oo_`1d0000000000<0000000<004RL0=ooo`3oool0903oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool08P3oool002P0oooo00@0oono
09bLg`3ookl0M000100000001P00M;l0oooo0?ooo`3oool0_ibL0=ooobD0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0R0?ooo`00:03oool01@3ogi`0B00000000000000007Bo00<0
oooo00<0_gAd0;ooo`3oool0:03oool2000003L0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo02T0oooo0P00000T0?ooo`00:@3oool00`3ookl0M4RL
0=ooo`040?ooo`030=nLW02oool0oooo02P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0R0?ooo`00:03oool00`3ooml0W4Qd0;ooo`040?ooo`030?oo_`1dM;l0oooo02T0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0R0?ooo`00:03oool00`3ogi`0M9cO0?ooo`03
0?ooo`030?oo_`1d07@0_ooo02X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0280oooo000X0?ooo`080?noM000M;l0oooo0?ooo`3ooml0W4P00000
M02oool[0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02P3oool01@000000oooo
0?ooo`3oool0000002<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0R0?ooo`00
:@3oool01@2oM00000000000000004P0W=oo02d0oooo0P00000g0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0:03oool2000002@0oooo001K0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`00
00009@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool08P3oool005/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo02`0
oooo00D000000?ooo`3oool0oooo0000000T0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0R0?ooo`00:@3oool01@2oM00004RL0=ooo`3ookl0M000
0080000000<0001d0;ooo`3oool0:03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00000V0?ooo`030000003oool0
oooo02`0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`030000003oool0oooo02d0oooo00D0
00000?ooo`3oool0oooo0000000T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
8P3oool002P0oooo00<0omnL04P0000000000`0000001018W=l0oooo0;nLW03OoolY0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`0/0?ooo`050000003oool0oooo0?oo
o`0000009@3oool00`000000oooo0?ooo`0/0?ooo`050000003oool0oooo0?ooo`000000903oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0280oooo000X0?ooo`040?oog`2LB000001d
0;ooo`<0oooo00<0okmd04RLg`3oool0:@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000W0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0;03oool01@000000oooo0?ooo`3oool0000002@0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0R0?ooo`00;P3oool00`3o_g@007Bo0?oo
o`0Z0?ooo`800000>03oool00`000000oooo0?ooo`0U0?ooo`040000003oool0oooo000002L0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00009P3oool00`000000oooo0?ooo`0/0?ooo`050000003oool0oooo0?ooo`0000009@3oool00`00
0000oooo0?ooo`0W0?ooo`800000903oool002`0oooo00<0oooO0;no_`2LW;l0403oool0102oM000
00000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0000000000P0000000`1d
_ol0oooo0?ooo`080?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0000000Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool08P3oool002`0oooo00H0omno09ad
B000000000000000M02oool<0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0
B00007Boo`020?ooo`030?noM000000007Bo0080oooo00<0_gA809cOo`3oool0203oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo02@0oooo0`00000Y0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool08P3oool002P0oooo00<0omnL04P0000000000P0000001@0004P0W=oo
0?ooo`2oW9`0gooo00/0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`03
0?oOW018B9`0gooo00P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool09P3oool01@000000oooo0?ooo`3oool00000
02X0oooo00<000000?ooo`3oool09`3oool01@000000oooo0?ooo`3oool0000002X0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0R0?ooo`00:03oool00`3o_g@0001d0;ooo`040?oo
o`030;md001d_ol0oooo00/0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:
0?ooo`030?oo_`1d0000M;oo00P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool09P3oool200000080oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo000002X0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0R0?ooo`00;`3oool00`3Ogml0oooo0?ooo`0;
0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol02P3oool00`3ogi`0B00007Boo`08
0?ooo`<00000>03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0:03oool3000002/0oooo00<000000?ooo`3oool09`3oool5000002T0oooo00<00000
0?ooo`3oool09P3oool3000002@0oooo000/0?ooo`060?noM000000000000000000007@0_ooo303o
ool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00T0oooo00@0omnL04P0000004P0W=oo
203oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
8P3oool002@0oooo00H0_ibL0=ooo`3oool0oooo0?oOW0180003000000040018W03Oool0oono07Ad
_`d0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`050?oOW01800000000
0000001d_ol02@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool08P3oool002<0oooo00<0oooO09a8000000000`0000000`00M;l0oooo0?ooo`020?oo
o`030?noM00007@0_ooo00d0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`080?oo
o`030?oo_`1d000007Bo00T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0280oooo000S0?ooo`030?oo_`1d0000B9cO01P0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030=nLB000M;l0oooo00L0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0280oooo000o0?ooo`03
0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02P3oool00`3ogi`0B01809cOo`070?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0R0?ooo`00
;03oool01@2oM0000000000000000000B9cO00l0oooo00H0gia80000M02oool0oooO09a80018W=l8
0?ooo`060;md001d_ol0oooo0=nLB00004P0W=oo1`3oool2000003X0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
9P3oool2000002@0oooo000Z0?ooo`030=nLB0000000M;oo0080oooo00<0omnL04P0M02oool03`3o
ool0103OW4P0000000000000M;l:0?ooo`040;md00000000000004RLg`P0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0280oooo000Y0?ooo`030=nL
B018W=l0oooo00<0oooo00<0omnL04Qd_`3oool0:@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool08P3oool002P0oooo00<0omnL07BLg`3oool00`3o
ool00`3o_i`0B7BL0=ooo`0Z0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0R0?ooo`00:03oool00`3o_g@007Bo0?ooo`020?ooo`050?oOW018M7@0
M0000018W03Oool0:@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool08P3oool002T0oooo00<0okmd000000000000100000000`00B9`0gooo0?ooo`0X
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0R
0?ooo`00:03oool01@3ogi`0B000000000000000B9cO0080oooo00<0_gA809cOo`3oool0:@3oool2
000003/0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool09P3oool2000002@0oooo001K0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0R0?ooo`00F`3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool08P3oool002P0oooo
00D0omno0;oOo`3oool0oooo0;md0003000000030000M02oool0oooo02P0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0280oooo000X0?ooo`030;md
0000000000000080000000D0001d0;ooo`3oool0_ibL0=ooo`0Y0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0R0?ooo`009P3oool01@2oM0000000
00000000B9`0gooo00<0oooo00<0oooO09a8001d_ol0:P3oool2000003`0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool09@3oool2000002@0oooo000X0?ooo`030?noW02Lgol0oooo0300oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0280oooo001K0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0R0?ooo`00:03oool0
0`3ookl0W9cO0?ooo`030?ooo`040?noM0000000001d0;ooobT0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0280oooo000X0?ooo`040?oo_`2LW=l0
oono07@000@0000000<004RL0=ooo`3oool0:03oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool08P3oool002P0oooo00T0omnL04P000000000001809cO
o`3oool0oooO09a8M02oool0:P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool08P3oool002@0oooo00@0oooO09a8000007@0_ooo<`3oool2000003d0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0903oool2000002@0oooo000o0?ooo`040;md00000000000007Boo`<0
oooo00<0omnL04P0001d_ol01@3oool00`3ooml0W4P004RLg`0:0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0R0?ooo`00:`3oool01P3ogi`0B000
000000000000001809cOo`d0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW018
0000M;oo00H0oooo00<0gia80018W03Oool02@3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool08P3oool002X0oooo00<0_g@00000001d_ol00P3oool0
0`3ooml0W7BL0=ooo`0;0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol02P3oool0
0`3ogi`0B01809cOo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0R0?ooo`00:@3oool00`3OW4P0B9cO0?ooo`040?ooo`030=nLW02oool0oooo
00X0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?noM0000000
000000@0000000<004RL0=ooo`3oool01P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool08P3oool002P0oooo00<0omnL07BLg`3oool0103oool00`3o
oml0W7BL0=ooo`0;0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3o
oml0W4Q809cOo`020?ooo`030;md0000M;l0oooo00P0oooo0`00000m0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02<0oooo0`00000T0?ooo`00:03oool00`3o_i`0W=oo0?ooo`030?ooo`030?oog`2LB000M;oo00d0
oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`070?oo_`1d07@0_ooo0?oo
o`3o_g@004RL0=ooo`080?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0R0?ooo`00:03oool00`3ogi`0B7Bo0?ooo`020?ooo`030=nLB0000000B9cO
00h0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`060?oOW018B9`0gooo
0?oOW01804P0W=oo203oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool08P3oool002T0oooo00H0okmd00000000000000000018W03Oool?0?ooo`030?oO
W0180000B9cO00<0oooo00<0_g@00018W03Oool01`3oool01@3o_g@007Bo0?oog`2LB000B9cO00P0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0280
oooo000n0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0203oool0103OW4P0
B9cO0;md0000M;l80?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0R0?ooo`00;P3oool0103ookl0M0000000M02oool=0?ooo`030?oOW0180000M;oo
0080oooo00<0gia8001d_`3oool02@3oool0103OW4P0M7Ad0000M02oool70?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0R0?ooo`00:03oool0103o
okl0W9cO0?oo_`1d0003000000030000B02Lgol0oooo00h0oooo00H0gia80000M02oool0oooO09a8
0018W=l;0?ooo`030;md000004P0W=oo00L0oooo0P00000o0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02<0oooo
0P00000T0?ooo`00:03oool00`3ogi`0B0000000000200000003001d_`3oool0oooo0140oooo00@0
gia800000000000007Bo303oool00`3ooml0W4P004RLg`070?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0R0?ooo`00:P3oool00`3ogi`0B01d0;oo
o`0^0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0R0?ooo`00:@3oool00`3ookl0M4RL0=ooo`0_0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0R0?ooo`00:03oool00`3ooml0W4Qd0;ooo`030?oo
o`040?noM0000000001d0;ooobT0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0280oooo000X0?ooo`040?noM000B9`0gono07@000@0000000<004RL
0=ooo`3oool0:03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool08P3oool002P0oooo00T0omnL04P000000000000004RLg`3oool0oooO09a8M02oool0
:P3oool200000400oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool08P3oool2000002@0oooo001K0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`00F`3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool0
05/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0280oooo001K0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0R0?ooo`00F`3oool200000400oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool08P3oool2000002@0oooo
000/0?ooo`050=nLB000000000000000001d_ol0:P3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool002X0oooo00<0omnL04P00018W=l00P3o
ool00`3ogi`0B01d0;ooo`0Y0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0R0?ooo`00:@3oool00`3ogi`0B4RL0=ooo`030?ooo`030?oo_`1dB9`0
gooo02T0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0280oooo000X0?ooo`030?oog`2LM9`0gooo00@0oooo00<0_g@007Boo`3oool0:@3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08P3oool002P0
oooo00<0omno0;oOo`3oool00P3oool00`3ooml0W4P007Boo`0[0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`00:03oool02P3o_g@0M;oo
0?ooo`3oool0omnL04P0B02Lgkl0M0000018W03OoolY0?ooo`800000@@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0Q0?ooo`800000903oool002P0oooo00<0oooO09a8000000001@0000000`00B9`0gooo0?ooo`0<
0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool01P3ogi`0B0000000
0000000004RL0=ooo`X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0280oooo000T0?ooo`040;nLW03Oool0oono07@000@0000000D0M;oo0?ooo`3o
ool0_gAd0;ooo`0=0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Bo
o`020?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo2P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool08P3oool002<0oooo00<0oooO09a800000000
0P0000000`1d_ol0oooo0?ooo`0B0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0
2`3oool00`3o_g@0B9cO0?ooo`080?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0R0?ooo`008`3oool00`3ookl0W9cO0?ooo`0G0?ooo`030?oog`2L
B000B9cO0080oooo00@0oooO09a80000B9`0gooo2P3oool00`3ookl0M01d0;ooo`080?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`00:`3o
ool01P3OW4P00000000000000000001809cOo``0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0
001809cOo`0:0?ooo`030?oog`2LB000M;oo00P0oooo0`0000110?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01l0
oooo0`00000T0?ooo`00:@3oool02@3ookl0M00004RLg`3ogi`0W;oo0?ooo`3OW4P004RL0=ooo`0<
0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3ookl0M00004RLg`08
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R
0?ooo`00:@3oool02@2oM7@0_ooo0?ooo`3o_i`0W=oo0?ooo`3ookl0M01d0;ooo`0<0?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l02P3oool00`3o_g@0000007Boo`080?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`00:03o
ool02@3ogi`0W;oo0?ooo`3ooml0W7BL0=ooo`3oool0omnL04Qd_`0=0?ooo`030?oOW0180000B9cO
00<0oooo00<0_g@00018W03Oool01P3oool01P3ogml0gooo0?noM0000000001d0;ooo`P0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo000X
0?ooo`090?noW02Lgol0oooo0;md001d_ol0oooo0=nLB00007@0_ooo00d0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3OW4P004RL0=ooo`060?ooo`050?oo_`1d000000000000B02Lgol02@3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08P3oool0
02P0oooo00@0oono07@000000000M;oo4`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0
oooo00L0oooo00<0gibL0;ooo`3oool02P3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool08P3oool00400oooo00H0gia80000M02oool0oooO09a80018
W=l80?ooo`030?oOW01dW=l0oooo00X0oooo0P0000140?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01l0oooo0P00
000T0?ooo`00;P3oool0103ookl0M0000000M02oool?0?ooo`040=nLB00000000000001d_`X0oooo
00D0_g@0000000000000000004RLg`070?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0R0?ooo`00:03oool0103ookl0W9cO0?oo_`1d000300000003
0000B02Lgol0oooo02T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0280oooo000X0?ooo`030?oOW018000000000080000000<007Bo0?ooo`3oool0
:`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
8P3oool002X0oooo00<0omnL04P0M02oool0;P3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool08P3oool002T0oooo00<0oono07A8W03Oool0;`3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool0
02P0oooo00<0oooO09a8M02oool00`3oool0103o_g@000000000M02ooolY0?ooo`800000A@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0N0?ooo`800000903oool002P0oooo00@0okmd0018W03Ookl0M00010000000
0`00B9`0gooo0?ooo`0X0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0R0?ooo`00:03oool02@3ogi`0B000000000000000B9cO0?ooo`3ooml0W4Qd
0;ooo`0Z0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0R0?ooo`00F`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool08P3oool002d0oooo00D0oooO09a80000000004RL0=ooo`0Y0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0R0?ooo`00:@3oool0
102oM00000000000M02oool20?ooo`030?oo_`1dM;l0oooo02T0oooo0P0000170?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo01h0oooo0P00000T0?ooo`00:03oool01P3ogi`0W;oo0?oog`2LB000001d0;ooo`80oooo
00<0gibL0;ooo`3oool0:03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool08P3oool002P0oooo00X0oknL09cOo`3oool0oooO09a8000004P0W=oo0?oo
_`1dB9`0gooo:@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`00:03oool00`3ookl0M7Bo0?ooo`020?oo
o`040;md00000000001d0;ooobX0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool002P0oooo00@0omnL04P0
00000000M;oo;`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`00F`3oool00`000000oooo0?ooo`190?oo
o`D00000AP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`00F`3oool2000009H0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo0P00000T0?ooo`00
:03oool00`3ookl0W9cO0?ooo`030?ooo`040?noM0000000001d0;ooo``0oooo00@0_g@000000000
0000M;oo0`3oool00`3ogi`0B00007Boo`030?ooo`050?oog`2LB000000000000000M;l02`3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0280oooo000X0?ooo`040?oo_`2LW=l0oono
07@000@0000000<004RL0=ooo`3oool02P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo
00<0omnL04P0001d_ol00`3oool01`3OW4P007Bo0?ooo`3ookl0M0000018W03Oool02@3oool00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0280oooo000X0?ooo`090?oOW018000000000000
B02Lgol0oooo0?oog`2LB7@0_ooo00/0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cO
o`060?ooo`030?oog`2LB000M;oo0080oooo00<0omnL04P00018W=l02@3oool00`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0280oooo000T0?ooo`040?oog`2LB000001d0;oooa@0oooo00<0
oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?oo_`1d0000M;oo00<0oooo
00<0_g@00000M02oool0203oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0280oooo
000l0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P0001d
_`030?ooo`030=nLB00004P0W=oo00P0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0R0?ooo`00:03oool01@3ogkl0_moo0?ooo`3oool0_g@000<0000000<0001d0;ooo`3oool02P3o
ool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0_g@00000M02oool00P3o
ool00`3OW4P0001809cOo`080?ooo`<00000UP3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool01P3oool3000002@0oooo000X0?ooo`030;md00000000
00000080000000D0001d0;ooo`3oool0_ibL0=ooo`0;0?ooo`030=nLB00004P0W=oo0080oooo00<0
oooO09a80000M;l01P3oool0203o_g@0000004RLg`3oool0oooO09a80000B9`0gooo203oool00`00
0000oooo0?ooo`2F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0280oooo000V0?ooo`050;md0000000000000018
W03Oool00`3oool00`3ooml0W4P007Boo`020?ooo`030;md0000B9`0gooo00L0oooo00<0omnL04P0
0018W=l00`3oool00`2oM00004RL0=ooo`050?ooo`030?oog`2LB00000000080000000<0001d0;oo
o`3oool0203oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0280oooo000X0?ooo`03
0?noW02Lgol0oooo00P0oooo00<0omnL04Qd_`3oool01`3oool0103ooml0W4P00018W03Oool20?oo
o`030=nLB000B9`0gooo00H0oooo00<0oono07@00000M;l0303oool00`000000oooo0?ooo`2F0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0280oooo000X0?ooo`030?oo_`1dM;l0oooo00L0oooo00<0okmd0018W03O
ool02@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00L0oooo00<0omnL04P00018
W=l02`3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo000X0?ooo`040?oO
W0180000001d0;ooo`D0oooo00<0gia8001d_`3oool02`3oool01P3OW4P0001d0;ooo`3ooml0W4P0
04RLg`T0oooo00@0oooO09a8000007@0_ooo2@3oool2000009P0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo0P00000T0?ooo`00:@3oool0
0`3ogi`0B000000000050000000304RLg`3oool0oooo00`0oooo00@0gia800000000000007Bo303o
ool0103ookl0M00000000018W=l70?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
8P3oool002h0oooo00<0okmd0000B02Lgol0:P3oool00`000000oooo0?ooo`2G0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0280oooo000]0?ooo`030;md0000M;l0oooo02/0oooo00<000000?ooo`3oool0U`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0R0?ooo`00:03oool01P3ogi`0B00007Boo`3o_g@0000007Boobd0oooo00<0
00000?ooo`3oool0=@3oool00`3ooml0W4P0000000020000000307Boo`3oool0oooo05/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool08P3oool002P0oooo00@0omnL04P00000000007Bo;`3oool00`000000oooo0?oo
o`0g0?ooo`030?noM00007@0_ooo05h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08P3oool005/0oooo0P00000h
0?ooo`030?oo_`1d0000M;oo05h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00X0oooo0P00000T0?ooo`00F`3oool00`000000oooo0?ooo`0g0?oo
o`030?oog`2LB000B9cO05h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool08P3oool005/0oooo00<000000?ooo`3o
ool0>03oool00`3OW4P00000000000020000000607Boo`3oool0oooo0?ooo`2oM00007Bo1P3oool0
1@3OW4P00000000000000000M;oo0080oooo00/0oono07@000000000001d0;ooo`3OW4P0000004RL
g`3oool0omnL04P000020000000907Boo`3OW4P000000018W03Oool0okmd0000000004P0W=oo0080
oooo00D0okmd000000000000001809cOo`030?ooo`030;md0000M;l0oooo02H0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool08P3oool005/0oooo00<000000?ooo`3oool0>03oool01`3o_g@0001809cOo`3oool0oooO
09a80000M;l00P3oool00`3o_g@0001d0;ooo`040?ooo`030?oOW0180000M;oo0080oooo0240_g@0
001d_`3oool0gia80018W03Oool0oono07@0M02o_g@0001d09bLM02Lgol0_g@00018W03Oool0oooo
0;md001dM7@0001d0;oOW02L_ol0okmd0000B02Lgml0W7BL0=ooo`3ogi`0B01809cOo`3oool0omnL
04P00000M;l00P3oool00`3o_g@0001d0;ooo`0V0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0280oooo001K0?oo
o`030000003oool0oooo03P0oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0
omnL04P0001d_ol0103oool00`3OW4P004RL0=ooo`030?ooo`040=nLW02oool0_g@0001d_`80oooo
00L0oono07A8B01804P0W=oo0?ooo`2oM00007Bo00<0oooo00L0_g@00000001d_ol0oooo0?oo_`1d
0000M;oo0080oooo00<0gia80018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0omnL04P0001d
_ol09P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0R0?ooo`00F`3oool2000003T0oooo00<0oooO09a80018W=l0
0`3oool01`3ogi`0B01809cOo`3ooml0W4P00018W03Oool00`3oool01@3o_g@00000000000000000
B9cO00<0oooo00<0okmd0018W03Oool00P3oool01`3o_g@0000004RLg`3oool0okmd0000M02oool0
0P3oool00`3ookl0M00004RLg`020?ooo`070;md0000M;l0oooo0?ooo`3o_g@0001d0;ooo`030?oo
o`070=nLB00007@0_ooo0?oog`2LB00004RL0=ooo`0U0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`800000903oool005/0oooo00<00000
0?ooo`3oool0>@3oool00`3OW4P0001d0;ooo`020?ooo`070?oog`2LB000B9cO0?ooo`2oM000B7Ad
07BLg`030?ooo`0;0?oo_`1d04P0W=oo0?ooo`3OW4P0000004RLg`3oool0oono07@0001d_ol00P3o
ool01`3ooml0W4P0001d_`3oool0oono07@0001d_ol00`3oool02`2oM00004RL0=ooo`3oool0gia8
0018W03Oool0oooo0?oo_`1d0000M;oo00<0oooo00L0omnL04P0B02Lgol0oooo0;md0018M7@0M9cO
02D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool08P3oool005/0oooo00<000000?ooo`3oool01P3oool5000000<0
oooo1@0000030?ooo`D000000`3oool5000001H0oooo00@0okmd00000000B9`0gooo0P3oool01`3O
W4P007Bo0?ooo`3o_g@004RL0;nLB01d_ol00`3oool02`3o_g@004RL0=ooo`3oool0oono07@00018
W=l0oooo0?noM00007@0_ooo0080oooo00L0gia80000M02oool0oooo0?noM00007@0_ooo0080oooo
00L0gia80000M02oool0oooo0?oOW01804P0W=oo0080oooo00<0gia80000M02oool00P3oool0203o
okl0M00007Boo`3oool0okmd0018W02oW4P0M;oo9@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0R0?ooo`00F`3o
ool00`000000oooo0?ooo`0i0?ooo`0P0?oo_`1d0000M9bL04P0M02oool0oooO09a80000M;l0oooo
0?oo_`1d04P0W=oo0;md001dM7@004RL0=ooo`3oool0gia80000M02oool0oooo0=nLB000B9`0gooo
0?ooo`3OW4P0001d0;ooo`3oool0_g@00000B02Lgol20?ooo`0;0=nLB00007@0_ooo0?ooo`2oM000
001809cOo`3oool0oooO09a80018W=l00`3oool03`2oM000001d0;ooo`3oool0okmd0000M02oool0
oooo0?oo_`1d04P0W=oo0;md001dM7@004RL0=ooo`0R0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0280oooo001K
0?ooo`030000003oool0oooo03P0oooo0140omnL04P000000000B9cO0?oo_`1d000000000000M02o
ool0omnL04P000000000M;oo0?ooo`2oM000001d0;ooo`020?ooo`050?oOW018000000000000001d
_ol00`3oool01P3ogi`0B00000000018W;l0W4P004RLg`<0oooo00P0omnL04P000000000B9bL07@0
0018W=l0oono07@000<0000000@0M;oo0?ooo`3oool0okmd0`0000002P1d_ol0oooo0?oOW0180000
000007Boo`3oool0_g@00000M02ooolR0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0280oooo001K0?ooo`030000
003oool0oooo05L0oooo00<0_g@0001d_`3oool02P3oool00`3o_g@0001d0;ooo`0c0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0280oooo001K0?ooo`800000F03oool00`3o_g@0001d0;ooo`0;0?ooo`030=nLM02L
gol0oooo03<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo0P00000T0?ooo`00?P3oool0102oM00000000000001d_ol30?ooo`030?oOW018
0000M;oo00<0oooo00<0oono07A8W03Oool03@3oool00`000000oooo0?ooo`1G0?ooo`030?oOW018
04P0W=oo0480oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool08P3oool003d0oooo00H0gia8001d_`3oool0omnL04P0
0018W=l20?ooo`030?oOW0180000M;oo00@0oooo00<0gia804RLg`3oool0303oool00`000000oooo
0?ooo`1G0?ooo`030?oog`2LB000B9cO0480oooo0P0000030?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0R0?ooo`00?03oool00`3ooml0W4P004RL
g`020?ooo`030?noM00004P0W=oo00P0oooo00<0oono07@0M02oool0303oool00`000000oooo0?oo
o`1F0?ooo`040?oo_`1d00000000001d_d<0oooo1000001C0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool08P3oool003`0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018
W03Oool80?ooo`030?noM000M;l0oooo00/0oooo00<000000?ooo`3oool0m@3oool010000000oooo
0?ooo`3oool2000005<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0280oooo000l0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol0
203oool00`3ooml0W4Q809cOo`0;0?ooo`030000003oool0oooo0?H0oooo1000001E0?ooo`@00000
503oool00`000000oooo0?ooo`0R0?ooo`00?@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW018
0000B9cO00T0oooo00<0omnL04Qd_`3oool02P3oool300000?l0ooooIP3oool3000002@0oooo000m
0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l02P3oool00`2oM000M;oo0?ooo`09
0?ooo`030000003oool0oooo0?l0ooooJ03oool00`000000oooo0?ooo`0R0?ooo`00?@3oool00`3o
gi`0B00004RLg`030?ooo`030;md0000B9`0gooo00T0oooo00<0omnL04Q8W03Oool02@3oool00`00
0000oooo0?ooo`0e0?ooo`030?oog`2LB00000000080000000<0M;oo0?ooo`3oool04@3oool0103O
W4P000000018W03Ooooo0?oooaH0oooo00<000000?ooo`3oool08P3oool003d0oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030=nLB018W=l0oooo00P0oooo00<00000
0?ooo`3oool0=`3oool00`3o_g@0001d0;ooo`0D0?ooo`050?noM000B9`0gmnL04Q8W03Oool0o`3o
oolE0?ooo`030000003oool0oooo0280oooo000n0?ooo`030?oOW0180000M;oo0080oooo00<0gia8
001d_`3oool01@3oool00`3ooml0gmoo0?ooo`020?ooo`030?oo_`1d07@0_ooo00P0oooo00<00000
0?ooo`3oool0=`3oool00`3ookl0M00007Boo`0G0?ooo`030?oOW018M;l0oooo0?l0oooo503oool0
0`000000oooo0?ooo`0R0?ooo`00?`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00<0
_gAd0;ooo`3oool00P3oool00`3o_g@007Bo0?ooo`070?ooo`800000>03oool00`3ooml0W4P004RL
g`0H0?ooo`030?noM01d_ol0oooo0?l0oooo4P3oool2000002@0oooo00100?ooo`040=nLB0000000
0000001d_`P0oooo00<0oono07@0000000000`0000000`0004P0W=oo0?ooo`060?ooo`030000003o
ool0oooo03P0oooo00<0gia80000000000000P0000001P1d_ol0oooo0?ooo`3oool0_g@0001d_`H0
oooo00D0gia8000000000000000007Boo`040?ooo`030?noM0000000M;oo0?l0oooo4`3oool00`00
0000oooo0?ooo`0R0?ooo`00F`3oool00`000000oooo0?ooo`0h0?ooo`070?noM00004P0W=oo0?oo
o`3ooml0W4P0001d_`020?ooo`030?noM00007@0_ooo00@0oooo00<0omnL04P0001d_ol00P3oool0
0`2oM00007Bo0?ooo`020?ooo`040=nLB00007@0M7A809cOool0oooo4P3oool00`000000oooo0?oo
o`0R0?ooo`00F`3oool00`000000oooo0?ooo`0h0?ooo`030?oo_`1d0000M;oo0080oooo00L0oooO
09a80018W=l0oooo0?oOW0180000M;oo00@0oooo00<0gia80018W03Oool00`3oool02@3OW9`0_ooo
0?ooo`3oool0gia80018W03Ooml0W7BL0=ooo`3o0?oooa40oooo00<000000?ooo`3oool08P3oool0
05/0oooo00<000000?ooo`3oool0>03oool00`3ooml0W4P004RLg`030?ooo`070?oOW01804P0W=oo
0?oog`2LB00004RL0=ooo`030?ooo`050?noM0000000000000000018W=l01@3oool01@2oM00004RL
0=ooo`3ogi`0M9cO0?l0oooo4@3oool00`000000oooo0?ooo`0R0?ooo`00F`3oool00`000000oooo
0?ooo`0i0?ooo`030=nLB00007@0_ooo0080oooo00L0oooO09a80018W=l0oooo0;md0018M7@0M9cO
00<0oooo00L0oono07@0B02Lgol0oooo0=nLB0000000B9cO0080oooo00<0oooO09a80000M;l00P3o
ool00`3OW9`0_ooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool08P3oool005/0oooo0P000007
0?oooad000005P3oool0103o_g@000000018W03Oool20?ooo`070=nLB000M;l0oooo0?noM000B9`0
_ia807Boo`030?ooo`0;0?noM000B9`0gooo0?ooo`3ookl0M00004RLg`3oool0oooO09a80000M;l0
0P3oool00`3ookl0M7Bo0?ooo`3o0?ooo`h0oooo0P00000T0?ooo`00F`3oool00`000000oooo0?oo
o`0i0?ooo`0K0?oo_`1d0000M9bL04P0M02oool0oooO09a80000M;l0oooo0?oo_`1d04P0W=oo0;md
001dM7@004RL0=ooo`3oool0gia80000M02oool0oooo0=nLB000B9`0gooo0?oo_`1d0000B9cO0080
oooo00<0omnL04P0M02oool0o`3oool?0?ooo`030000003oool0oooo0280oooo001K0?ooo`030000
003oool0oooo03P0oooo0140omnL04P000000000B9cO0?oo_`1d000000000000M02oool0omnL04P0
00000000M;oo0?ooo`2oM000001d0;ooo`020?ooo`090?oOW018000000000000001d_ol0_g@00000
000004P0W=oo0080oooo00<0gia80018W03Oool0o`3oool?0?ooo`030000003oool0oooo0280oooo
001K0?ooo`030000003oool0oooo0?l0ooooJ03oool00`000000oooo0?ooo`0R0?ooo`00F`3oool0
0`000000oooo0?ooo`3o0?ooofP0oooo00<000000?ooo`3oool08P3oool005/0oooo0P00003o0?oo
ofP0oooo0P00000T0?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooofP0oooo00<000000?ooo`3o
ool08P3oool005/0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`030000003oool0oooo0280oooo
001K0?ooo`030000003oool0oooo0?l0ooooJ03oool00`000000oooo0?ooo`0R0?ooo`00F`3oool0
0`000000oooo0?ooo`3o0?ooofP0oooo00<000000?ooo`3oool08P3oool005/0oooo00<000000?oo
o`3oool0o`3ooomX0?ooo`030000003oool0oooo0280oooo001K0?ooo`800000o`3ooomX0?ooo`80
0000903oool003l0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`030?ooo`06
0?oo_`1d0000000000000000B9`0gooo2@3oool00`000000oooo0?ooo`3o0?ooofP0oooo00<00000
0?ooo`3oool08P3oool003h0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW018
0000M;oo0080oooo00<0oono07@00018W=l00P3oool00`3OW4P0001d0;ooo`080?ooo`030000003o
ool0oooo0?l0ooooJ03oool00`000000oooo0?ooo`0R0?ooo`00?@3oool00`3ooml0W4P004RLg`02
0?ooo`030?noM00004P0W=oo00H0oooo00<0okmd0018W03Oool00`3oool00`2oM000B9cO0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0280oooo000m0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a8
0000B9`0gooo1@3oool00`3o_g@004RL0=ooo`030?ooo`030;md0000M;l0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool08P3oool003d0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?oo
o`030?oog`2LB000M;oo0080oooo00<0oono07@00018W=l0203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?oo
o`00?P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00L0oooo00H0_g@00000B02L
gml0W4P00000M02oool80?ooool00000K000000T0?ooo`00?P3oool00`3OW4P0001809cOo`020?oo
o`030?oog`2LB00007Bo00P0oooo00D0oooO09a80000000004RL0=ooo`3o0?oooiP0oooo000n0?oo
o`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01`3oool01P2oM000001809cOo`3ogi`0
B4RL0=ooool0ooooU`3oool003h0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=oo
o`060?ooo`030?oOW0180000M;oo0080oooo00<0okmd04RLg`3oool0o`3ooonF0?ooo`00?`3oool0
0`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00H0oooo00<0omnL04P0B02Lgol00P3oool0
0`3o_g@004RL0=ooo`3o0?oooiH0oooo00100?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3o
ool00`3ooml0W4P004RLg`020?ooo`030;md0000M;l0oooo0?l0ooooUP3oool00440oooo00@0gia8
00000000000007Bo2@3oool01@3ooml0W4P000000000000007Bo0?l0ooooV03oool00?l0ooooj`3o
ool00?l0ooooj`3oool00?l0ooooj`3oool00?l0ooooj`3oool00?l0ooooj`3oool00?l0ooooj`3o
ool00?l0ooooj`3oool00?l0ooooj`3oool00?l0ooooj`3oool00?l0ooooj`3oool00?l0ooooj`3o
ool00?l0ooooj`3oool00001\
\>"],
  ImageRangeCache->{{{0, 489}, {301.875, 0}} -> {-1.0512, -0.648943, \
0.00644908, 0.00644908}, {{11.875, 477.063}, {294.688, 7.1875}} -> {-23.0908, \
-0.209815, 0.347429, 0.00535385}, {{81.6875, 244.5}, {69.5, 23}} -> \
{-1.78708, -12.6931, 0.0309676, 0.0812897}, {{90.4375, 138.875}, {66.125, \
47.6875}} -> {-3.53551, -27.9016, 0.052795, 0.170848}, {{90.4375, 138.875}, \
{44.75, 26.3125}} -> {-3.53551, -30.3362, 0.052795, 0.170848}}]
}, Closed]],

Cell["\<\
\tLimit cycles require two conditions.  First, the fixed point must be \
unstable such that points inside the cycle are driven outward.  Second, there \
must be a closed surface in phase space on which the velocity field is \
everywhere inward.  When these conditions are satisfied, a limit cycle around \
the fixed point exists within that surface.  Thus, points inside the limit \
cycle are driven outward, while points outside are driven inward.  The limit \
cycle represents a stable periodic behavior \[LongDash] small perturbations \
decay and the system returns to the limit cycle, shifted only in phase. Limit \
cycles can be found in a wide range of phenomena, including population \
dynamics, chemical oscillators, mechanical or electrical systems, etc.\
\>", "Text"],

Cell[TextData[{
  "\tWe have assumed that the model is autonomous \[LongDash] that there is \
no explicit time dependence.  More realistically, the model parameters may \
have small but rapid fluctuations or may gradually change with time due to \
external or environmental changes.  If the parameters change gradually \
without affecting the stability of the fixed point, we might expect the shape \
of the limit cycle to also change gradually (adiabatically) without affecting \
any qualitative features of the dynamics.  However, if the parameters of the \
system are near the transition between ",
  Cell[BoxData[
      \(TraditionalForm\`Re[\[Lambda]] > 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Re[\[Lambda]] < 0\)]],
  ", fluctuations or parameter drift could have profound consequences: a \
stable system could suddenly begin oscillating or a periodic system could \
suddenly spiral toward a fixed point."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1392, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
ShowSelection->True,
ShowCellLabel->False,
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}, {
        Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->0.5,
    CellMargins->{{25, 0}, {6, 6}},
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 1, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 86, 2, 81, "Title"],

Cell[CellGroupData[{
Cell[1887, 59, 31, 0, 83, "Section"],
Cell[1921, 61, 536, 14, 67, "Text"],
Cell[2460, 77, 246, 5, 108, "DisplayFormula"],
Cell[2709, 84, 1035, 26, 119, "Text"],
Cell[3747, 112, 224, 6, 41, "Text"],
Cell[3974, 120, 102, 2, 41, "DisplayFormula"],
Cell[4079, 124, 1151, 31, 119, "Text"],
Cell[5233, 157, 563, 14, 67, "Text"],
Cell[5799, 173, 289, 7, 44, "DisplayFormula",
  Evaluatable->False],
Cell[6091, 182, 21, 0, 41, "Text"],
Cell[6115, 184, 186, 5, 73, "DisplayFormula",
  Evaluatable->False],
Cell[6304, 191, 260, 8, 41, "Text"],
Cell[6567, 201, 258, 6, 44, "DisplayFormula",
  Evaluatable->False],
Cell[6828, 209, 191, 8, 41, "Text"],
Cell[7022, 219, 306, 6, 43, "DisplayFormula",
  Evaluatable->False],
Cell[7331, 227, 54, 0, 41, "Text"],
Cell[7388, 229, 193, 5, 41, "DisplayFormula",
  Evaluatable->False],
Cell[7584, 236, 1449, 33, 171, "Text"],
Cell[9036, 271, 775, 14, 119, "Text"],

Cell[CellGroupData[{
Cell[9836, 289, 33, 0, 68, "Subsection"],
Cell[9872, 291, 203, 6, 41, "Text"],
Cell[10078, 299, 217, 6, 41, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10344, 311, 33, 0, 51, "Section"],
Cell[10380, 313, 122, 2, 99, "Input"],
Cell[10505, 317, 145, 4, 95, "Input"],
Cell[10653, 323, 263, 4, 151, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10953, 332, 48, 0, 51, "Section"],
Cell[11004, 334, 55, 0, 41, "Text"],
Cell[11062, 336, 246, 5, 108, "DisplayFormula"],
Cell[11311, 343, 346, 12, 41, "Text"],
Cell[11660, 357, 137, 3, 41, "DisplayFormula"],
Cell[11800, 362, 25, 0, 41, "Text"],
Cell[11828, 364, 250, 5, 108, "DisplayFormula"],
Cell[12081, 371, 32, 0, 41, "Text"],
Cell[12116, 373, 151, 3, 43, "DisplayFormula"],
Cell[12270, 378, 26, 0, 41, "Text"],
Cell[12299, 380, 102, 2, 43, "DisplayFormula"],
Cell[12404, 384, 52, 0, 41, "Text"],
Cell[12459, 386, 273, 5, 108, "DisplayFormula"],
Cell[12735, 393, 260, 8, 41, "Text"],
Cell[12998, 403, 488, 15, 67, "Text"],
Cell[13489, 420, 133, 2, 99, "Input"],
Cell[13625, 424, 152, 5, 41, "Text"],

Cell[CellGroupData[{
Cell[13802, 433, 68, 1, 73, "Input"],
Cell[13873, 436, 90, 1, 59, "Output"]
}, Closed]],
Cell[13978, 440, 160, 5, 42, "Text"],

Cell[CellGroupData[{
Cell[14163, 449, 57, 1, 73, "Input"],
Cell[14223, 452, 105, 2, 59, "Output"]
}, Closed]],
Cell[14343, 457, 85, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[14453, 463, 49, 1, 73, "Input"],
Cell[14505, 466, 117, 2, 64, "Output"]
}, Closed]],
Cell[14637, 471, 634, 13, 93, "Text"],
Cell[15274, 486, 1112, 30, 122, "Text"],
Cell[16389, 518, 466, 8, 125, "Input"],
Cell[16858, 528, 1078, 20, 281, "Input"],

Cell[CellGroupData[{
Cell[17961, 552, 111, 2, 73, "Input"],
Cell[18075, 556, 256832, 6394, 658, 81370, 4223, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[274944, 6955, 469, 8, 125, "Input"],
Cell[275416, 6965, 93073, 2220, 361, 27769, 1410, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[368504, 9188, 848, 14, 145, "Text"],
Cell[369355, 9204, 381, 7, 64, "DisplayFormula"],
Cell[369739, 9213, 55, 0, 41, "Text"],
Cell[369797, 9215, 157, 3, 41, "DisplayFormula"],
Cell[369957, 9220, 536, 18, 67, "Text"],
Cell[370496, 9240, 187, 3, 41, "DisplayFormula"],
Cell[370686, 9245, 778, 22, 93, "Text"],
Cell[371467, 9269, 696, 10, 119, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[372200, 9284, 53, 0, 51, "Section"],
Cell[372256, 9286, 425, 7, 93, "Text"],
Cell[372684, 9295, 210, 4, 64, "DisplayFormula"],
Cell[372897, 9301, 612, 16, 67, "Text"],
Cell[373512, 9319, 174, 3, 64, "DisplayFormula"],
Cell[373689, 9324, 124, 3, 41, "Text"],
Cell[373816, 9329, 859, 17, 146, "DisplayFormula"],
Cell[374678, 9348, 76, 0, 41, "Text"],
Cell[374757, 9350, 257, 5, 65, "DisplayFormula"],
Cell[375017, 9357, 68, 0, 41, "Text"],
Cell[375088, 9359, 324, 7, 65, "DisplayFormula"],
Cell[375415, 9368, 72, 0, 41, "Text"],
Cell[375490, 9370, 288, 5, 108, "DisplayFormula"],
Cell[375781, 9377, 21, 0, 41, "Text"],
Cell[375805, 9379, 146, 3, 64, "DisplayFormula"],
Cell[375954, 9384, 137, 3, 41, "Text"],
Cell[376094, 9389, 103, 3, 41, "Text"],
Cell[376200, 9394, 171, 3, 120, "Input"],

Cell[CellGroupData[{
Cell[376396, 9401, 68, 1, 73, "Input"],
Cell[376467, 9404, 459, 10, 119, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[376963, 9419, 51, 1, 73, "Input"],
Cell[377017, 9422, 215, 4, 83, "Output"]
}, Closed]],
Cell[377247, 9429, 244, 6, 41, "Text"],

Cell[CellGroupData[{
Cell[377516, 9439, 102, 2, 73, "Input"],
Cell[377621, 9443, 45, 1, 59, "Output"]
}, Closed]],
Cell[377681, 9447, 234, 4, 67, "Text"],
Cell[377918, 9453, 233, 4, 43, "DisplayFormula"],
Cell[378154, 9459, 41, 0, 41, "Text"],
Cell[378198, 9461, 172, 4, 60, "DisplayFormula"],
Cell[378373, 9467, 479, 13, 67, "Text"],

Cell[CellGroupData[{
Cell[378877, 9484, 156, 4, 73, "Input"],
Cell[379036, 9490, 281, 4, 88, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[379354, 9499, 158, 4, 73, "Input"],
Cell[379515, 9505, 232, 3, 88, "Output"]
}, Closed]],
Cell[379762, 9511, 210, 8, 41, "Text"],

Cell[CellGroupData[{
Cell[379997, 9523, 101, 2, 73, "Input"],
Cell[380101, 9527, 454, 7, 92, "Message"],
Cell[380558, 9536, 39, 1, 59, "Output"]
}, Closed]],
Cell[380612, 9540, 791, 24, 98, "Text"],

Cell[CellGroupData[{
Cell[381428, 9568, 125, 2, 73, "Input"],
Cell[381556, 9572, 233, 3, 88, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[381826, 9580, 276, 5, 99, "Input"],
Cell[382105, 9587, 181073, 4078, 468, 54516, 2511, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[563193, 13668, 161, 3, 41, "Text"],
Cell[563357, 13673, 535, 9, 156, "Input"],
Cell[563895, 13684, 1120, 20, 345, "Input"],
Cell[565018, 13706, 139, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[565182, 13713, 223, 4, 99, "Input"],
Cell[565408, 13719, 283559, 11116, 444, 169567, 9704, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[848982, 24838, 267, 5, 67, "Text"],

Cell[CellGroupData[{
Cell[849274, 24847, 225, 4, 99, "Input"],
Cell[849502, 24853, 371059, 15617, 398, 234817, 13930, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1220576, 40473, 164, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[1220765, 40480, 126, 2, 73, "Input"],
Cell[1220894, 40484, 500761, 26758, 341, 419204, 25747, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1721670, 67245, 805, 14, 119, "Text"],

Cell[CellGroupData[{
Cell[1722500, 67263, 494, 9, 125, "Input"],
Cell[1722997, 67274, 115684, 2713, 315, 32127, 1677, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1838696, 69990, 787, 11, 145, "Text"],
Cell[1839486, 70003, 942, 17, 145, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

