(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1651296,      39287]*)
(*NotebookOutlinePosition[   1685359,      40514]*)
(*  CellTagsIndexPosition[   1685315,      40510]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Cobwebbing", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "from ",
  StyleBox[ButtonBox["Essential Mathematica for Students of Science",
    Active->False,
    ButtonData:>{
      URL[ 
      "http://www.physics.umd.edu/courses/CourseWare/EssentialMathematica/"], 
      None},
    Active->False,
    ButtonStyle->"Hyperlink"],
    Active->False],
  "\n\[Copyright] James J. Kelly, 1998\nLast revised: January, 2006"
}], "Author",
  Active->True,
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
A discrete one-dimensional recursive function is described by a mapping of \
the form\
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + 1\)\  = \ f[\[Mu], x\_i]\)]]
}], "Text"],

Cell[TextData[{
  "where \[Mu] is a parameter that governs the dynamical properties of the \
system.  A typical example is the logistic equation, ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + 1\)\  = \ \[Mu]\ \(\(x\_i\)(
            1 - x\_i)\)\)]],
  ", often used to describe population dynamics for species with \
nonoverlapping generations.  See ",
  StyleBox[ButtonBox["logistic map.nb",
    ButtonData:>{"Applications/logistic map.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "for a more complete description of that model."
}], "Text"],

Cell[TextData[{
  "Points which are mapped upon themselves, such that ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + 1\) = x\_i\)]],
  ", are called  ",
  StyleBox["fixed points",
    FontSlant->"Italic"],
  " of the map and play a central role in the analysis of the behavior of \
iterative maps.  As the map is iterated, nearby points may remain at fixed \
distance, be driven toward, or be driven away from a fixed point.  Hence, \
fixed points may be classified as either neutral, stable, or unstable. "
}], "Text"],

Cell[TextData[{
  "In our earlier numerical study of the logistic equation we discovered that \
the system can exhibit several qualitatively different types of behavior \
depending upon the value of the growth parameter, \[Mu].  For small \[Mu] we \
found that there was a single stable fixed point at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", while for somewhat larger \[Mu] the origin became unstable and a new \
stable fixed point emerged for finite ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".  This fixed point remained stable until \[Mu] crossed a bifurcation \
value at which two new solutions emerged and the system settled upon a stable \
oscillation between two values of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", a 2-cycle.  As \[Mu] increased further, these solutions bifurcated again \
as a stable 4-cycle emerged.  As \[Mu] continued to increase the interval \
between successive period doublings decreased until a chaotic regime was \
reached.  For slightly larger \[Mu] a brief island of order interrupts the \
chaotic regime. "
}], "Text"],

Cell[TextData[{
  "In this notebook we analyze these behaviors more rigorously, using \
graphical and analytical techniques to explain these behaviors and to \
calculate the values of the fixed points and the bifurcation parameters.  One \
of the basic tools is the ",
  StyleBox["cobweb plot",
    FontSlant->"Italic"],
  ", which illustrates the iteration sequence for a recursive function.  \
Using the cobweb plot, we will discover the conditions which govern the \
stability of a fixed point and will introduce the methodology of ",
  StyleBox["linear stability analysis",
    FontSlant->"Italic"],
  ".  Although we concentrate here upon the logistic equation, these \
techniques are much more general."
}], "Text"],

Cell["\<\
Much of the present discussion is based upon Chapter 2 of the book\
\>", "Text"],

Cell[TextData[{
  "Mathematical Biology",
  StyleBox[", by J.D. Murray (Springer-Verlag, 1989)",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0,
  FontSlant->"Italic"],

Cell[TextData[{
  "but by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " we can develop versatile tools and empower the student to perform his/her \
own investigations."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(ClearAll["\<Global`*\>"]\), "\n", 
    \(\(Off[General::spell, \ General::spell1, \ Plot::plnr];\)\), "\n", 
    \(\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 12};\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Cobweb plot", "Section"],

Cell["\<\
A manual calculation for a discrete one-dimensional recursive function \
proceeds by the following iteration process.\
\>", "Text"],

Cell[TextData[{
  "\t1) select ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1 = x\_1\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t2) ",
  Cell[BoxData[
      \(TraditionalForm\`y\_\(i + 1\) \[LeftTeeArrow] f[x\_i]\)]]
}], "Text"],

Cell[TextData[{
  "\t3) ",
  Cell[BoxData[
      \(TraditionalForm\`i \[LeftTeeArrow] i + 1\)]]
}], "Text"],

Cell[TextData[{
  "\t4) ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i \[LeftTeeArrow] y\_i\)]]
}], "Text"],

Cell["\t5) return to 2)", "Text"],

Cell[TextData[{
  "A ",
  StyleBox["cobweb plot",
    FontSlant->"Italic"],
  " tracks the sequence of functional evaluations using line segments to \
represent each assignment of either ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " during this iteration.  Hence, step 2) is represented by a vertical the \
line segment between the diagonal ",
  Cell[BoxData[
      \(TraditionalForm\`y \[LeftTeeArrow] x\)]],
  " and the curve ",
  Cell[BoxData[
      \(TraditionalForm\`y = f[x]\)]],
  " while step 4) is represented by a horizontal line segment from that curve \
back to the diagonal ",
  Cell[BoxData[
      \(TraditionalForm\`x \[LeftTeeArrow] y\)]],
  "."
}], "Text"],

Cell[TextData[{
  "A function which produces a cobweb plot is defined below.  ",
  ButtonBox["NestList",
    ButtonStyle->"RefGuideLink"],
  " is used to produce a sequence of iterates.  In order to focus on the \
long-term behavior, one can drop the first ",
  StyleBox["ndrop", "InlineInput",
    FontWeight->"Bold"],
  " iterates to allow transients to decay.  When the entire sequence is \
displayed, the starting point is indicated by a prominent dot.  Line segments \
between the line ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + 1\) = x\_i\)]],
  " and the continuous curve ",
  Cell[BoxData[
      \(TraditionalForm\`y = f[x]\)]],
  " are constructed using ",
  ButtonBox["Map",
    ButtonStyle->"RefGuideLink"],
  " and ",
  ButtonBox["Line",
    ButtonStyle->"RefGuideLink"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "and drawn with ",
  ButtonBox["Graphics",
    ButtonStyle->"RefGuideLink"],
  ".  Finally, ",
  ButtonBox["Show",
    ButtonStyle->"RefGuideLink"],
  " is used to combine the line segments with plots of the diagonal line and \
the continuous function."
}], "Text"],

Cell[BoxData[{
    \(\(\(cobweb::usage\  = \ "\<cobweb[f,x0,nmax,ndrop] produces a cobweb \
plot for the recursive function f[x] with initial value x0, suppressing the \
first ndrop iterates.  Options may also be passed to Plot.\>";\)\(\n\)
    \)\t\t\), "\n", 
    \(cobweb[f_, x0_, nmax_, \ ndrop_:  0, \ opts___Rule] := 
      Module[{plot1, plot2, plot3}, \[IndentingNewLine]plot1 = 
          Plot[{x, f[x]}, {x, 0, 1}, \ opts, Frame \[Rule] True, \ 
            FrameLabel \[Rule] {\*"\"\<\!\(x\_i\)\>\"", \ \*"\"\<\!\(x\_\(i + \
1\)\)\>\""}, 
            PlotLabel \[Rule] 
              StringJoin["\<Cobweb Plot for: \>", \ ToString[f[x]]\ ], 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]plot2 = 
          Graphics[\ 
            Map[\ \ Line[{{#, #}, {#, f[#]}, {f[#], f[#]}}]\  &, \ 
              Drop[NestList[f, x0, nmax], ndrop]], 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]plot3 = 
          ListPlot[{{x0, x0}}, PlotStyle \[Rule] PointSize[0.03], 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]If[
          ndrop \[Equal] 0, 
          Return[Show[{plot1, plot2, plot3}, 
              DisplayFunction \[Rule] $DisplayFunction]], 
          Return[Show[{plot1, plot2}, 
              DisplayFunction \[Rule] $DisplayFunction]]]]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: logistic map", "Section"],

Cell[CellGroupData[{

Cell["Definition of the mapping function", "Subsection"],

Cell[TextData[{
  "The logistic equation is represented by the pure function ",
  StyleBox["\[Mu] # (1-#)&", "InlineInput",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(logisticCobweb[\[Mu]_, x0_, nmax_, ndrop_:  0, opts___Rule]\  := 
      cobweb[\[Mu]  # \((1 - #)\) &, x0, nmax, ndrop, opts]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Extinction for \[Mu]<1"], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(logisticCobweb[0.8, 0.5, 20, 0];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 1.19647 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -9.5 -15.6875 ]
[.21429 -0.0125 9.5 0 ]
[.40476 -0.0125 -9.5 -15.6875 ]
[.40476 -0.0125 9.5 0 ]
[.59524 -0.0125 -9.5 -15.6875 ]
[.59524 -0.0125 9.5 0 ]
[.78571 -0.0125 -9.5 -15.6875 ]
[.78571 -0.0125 9.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .01472 -10 -7.84375 ]
[-0.0125 .01472 0 7.84375 ]
[-0.0125 .13436 -19 -7.84375 ]
[-0.0125 .13436 0 7.84375 ]
[-0.0125 .25401 -19 -7.84375 ]
[-0.0125 .25401 0 7.84375 ]
[-0.0125 .37366 -19 -7.84375 ]
[-0.0125 .37366 0 7.84375 ]
[-0.0125 .4933 -19 -7.84375 ]
[-0.0125 .4933 0 7.84375 ]
[-0.0125 .61295 -19 -7.84375 ]
[-0.0125 .61295 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -11.4063 ]
[-0.01875 .30902 -19 11.4063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74.9688 0 ]
[.5 .63053 74.9688 15.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13436 m
.00625 .13436 L
s
gsave
-0.0125 .13436 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .25401 m
.00625 .25401 L
s
gsave
-0.0125 .25401 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .37366 m
.00625 .37366 L
s
gsave
-0.0125 .37366 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .4933 m
.00625 .4933 L
s
gsave
-0.0125 .4933 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .61295 m
.00625 .61295 L
s
gsave
-0.0125 .61295 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03864 m
.00375 .03864 L
s
0 .06257 m
.00375 .06257 L
s
0 .0865 m
.00375 .0865 L
s
0 .11043 m
.00375 .11043 L
s
0 .15829 m
.00375 .15829 L
s
0 .18222 m
.00375 .18222 L
s
0 .20615 m
.00375 .20615 L
s
0 .23008 m
.00375 .23008 L
s
0 .27794 m
.00375 .27794 L
s
0 .30187 m
.00375 .30187 L
s
0 .3258 m
.00375 .3258 L
s
0 .34973 m
.00375 .34973 L
s
0 .39759 m
.00375 .39759 L
s
0 .42152 m
.00375 .42152 L
s
0 .44544 m
.00375 .44544 L
s
0 .46937 m
.00375 .46937 L
s
0 .51723 m
.00375 .51723 L
s
0 .54116 m
.00375 .54116 L
s
0 .56509 m
.00375 .56509 L
s
0 .58902 m
.00375 .58902 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13436 m
1 .13436 L
s
.99375 .25401 m
1 .25401 L
s
.99375 .37366 m
1 .37366 L
s
.99375 .4933 m
1 .4933 L
s
.99375 .61295 m
1 .61295 L
s
.125 Mabswid
.99625 .03864 m
1 .03864 L
s
.99625 .06257 m
1 .06257 L
s
.99625 .0865 m
1 .0865 L
s
.99625 .11043 m
1 .11043 L
s
.99625 .15829 m
1 .15829 L
s
.99625 .18222 m
1 .18222 L
s
.99625 .20615 m
1 .20615 L
s
.99625 .23008 m
1 .23008 L
s
.99625 .27794 m
1 .27794 L
s
.99625 .30187 m
1 .30187 L
s
.99625 .3258 m
1 .3258 L
s
.99625 .34973 m
1 .34973 L
s
.99625 .39759 m
1 .39759 L
s
.99625 .42152 m
1 .42152 L
s
.99625 .44544 m
1 .44544 L
s
.99625 .46937 m
1 .46937 L
s
.99625 .51723 m
1 .51723 L
s
.99625 .54116 m
1 .54116 L
s
.99625 .56509 m
1 .56509 L
s
.99625 .58902 m
1 .58902 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cobweb) show
105.875 15.813 moveto
(Plot) show
128.188 15.813 moveto
(for) show
142.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
148.375 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.375 15.813 moveto
(H) show
170.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
179.188 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
189.875 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
196.000 15.813 moveto
(L) show
202.813 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
208.938 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .06325 L
.10458 .11619 L
.14415 .1659 L
.18221 .21371 L
.22272 .2646 L
.26171 .31359 L
.30316 .36566 L
.34309 .41582 L
.3815 .46408 L
.42237 .51542 L
.46172 .56486 L
.49955 .61239 L
s
.49955 .61239 m
.50405 .61803 L
s
.02381 .01472 m
.06244 .05197 L
.10458 .08901 L
.14415 .12038 L
.18221 .14743 L
.22272 .17287 L
.26171 .19409 L
.30316 .21312 L
.34309 .22803 L
.3815 .23919 L
.40095 .24366 L
.42237 .24765 L
.44268 .25054 L
.45178 .25156 L
.46172 .25246 L
.4671 .25287 L
.4721 .25319 L
.47727 .25346 L
.48196 .25367 L
.48658 .25382 L
.4887 .25387 L
.49093 .25392 L
.49332 .25396 L
.49438 .25398 L
.49552 .25399 L
.49675 .254 L
.49789 .254 L
.49859 .25401 L
.49925 .25401 L
.50049 .25401 L
.50163 .25401 L
.50286 .254 L
.50401 .25399 L
.50508 .25398 L
.50754 .25395 L
.51014 .2539 L
.51268 .25384 L
.51504 .25377 L
.5204 .25357 L
.5293 .2531 L
.53882 .25242 L
.54906 .25147 L
.56016 .25019 L
.58032 .2472 L
.60019 .24342 L
.62123 .2385 L
.65912 .22729 L
.69946 .21202 L
.73829 .19409 L
.77956 .17153 L
Mistroke
.81932 .1464 L
.85757 .11909 L
.89827 .08662 L
.93745 .05207 L
.97619 .01472 L
Mfstroke
.5 .61295 m
.5 .25401 L
.21429 .25401 L
s
.21429 .25401 m
.21429 .16786 L
.14571 .16786 L
s
.14571 .16786 m
.14571 .12155 L
.10885 .12155 L
s
.10885 .12155 m
.10885 .09255 L
.08577 .09255 L
s
.08577 .09255 m
.08577 .07293 L
.07015 .07293 L
s
.07015 .07293 m
.07015 .05902 L
.05908 .05902 L
s
.05908 .05902 m
.05908 .04885 L
.05098 .04885 L
s
.05098 .04885 m
.05098 .04124 L
.04493 .04124 L
s
.04493 .04124 m
.04493 .03547 L
.04033 .03547 L
s
.04033 .03547 m
.04033 .03103 L
.0368 .03103 L
s
.0368 .03103 m
.0368 .02759 L
.03406 .02759 L
s
.03406 .02759 m
.03406 .0249 L
.03192 .0249 L
s
.03192 .0249 m
.03192 .0228 L
.03024 .0228 L
s
.03024 .0228 m
.03024 .02114 L
.02892 .02114 L
s
.02892 .02114 m
.02892 .01982 L
.02788 .01982 L
s
.02788 .01982 m
.02788 .01878 L
.02705 .01878 L
s
.02705 .01878 m
.02705 .01796 L
.02639 .01796 L
s
.02639 .01796 m
.02639 .0173 L
.02587 .0173 L
s
.02587 .0173 m
.02587 .01678 L
.02545 .01678 L
s
.02545 .01678 m
.02545 .01637 L
.02512 .01637 L
s
.02512 .01637 m
.02512 .01603 L
.02486 .01603 L
s
.03 w
.5 .61295 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00m@3oool01@3ooml0W4P00000
0000B9`0gooo0;H0oooo003f0?ooo`030?oOW01804P0W=oo0;L0oooo003]0?ooo`050;md00000000
07Bo0?ooo`3OW4P00P0000001@00B9`0gooo0?oOW01804P0W=oo0;L0oooo003]0?ooo`0<0?oog`2L
B7@0_ooo0?ooo`3ooml0W4P00018W03Oool0oooo0?oOW01804P0W=oo]`3oool00>h0oooo00/0oono
07A8W03Oool0_g@00000M02oool0oooo0?oo_`1d0000001809cOo`2g0?ooo`00k`3oool0103ogi`0
M4Q80000001d_ol30?ooo`030?oOW01804P0W=oo0;L0oooo003_0?ooo`030?oo_`1d0000B9cO0;h0
oooo003^0?ooo`050?oog`2LB00004RL09adB02Lgol0_@3oool00>h0oooo00H0_g@00000B02Lgol0
oooO09a8M02oool20?ooo`030?oo_`1d0000M;oo0;L0oooo003/0?ooo`090?oog`2LB00000000000
0000M;l0okmd0000000007@0_ooo0;/0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001Q0?ooo`050?oOW01800000000
0000M02oool0;P3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00D0okmd0000001d_ol0oooo
0;md00060000000304RLg`3oool0oooo02@0oooo00D0omnL04P000000000001d0;ooo`030?ooo`03
0?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo9@3oool01@3ogi`0B0000000000007@0
_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3ogi`0B000000000000000M;oo02L0oooo00D0
omnL04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00<0oooo00D0gia8000000000000
000004RLg`0^0?ooo`060;md00000000000000000000B9`0gooo:03oool00600oooo00L0oono07@0
001d_ol0oooo0?noM00007@0_ooo02`0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080
oooo00<0okmd0000001d_ol00P3oool00`3OW4P0000000000003000000030018W03Oool0oooo02<0
oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol01@3oool0
103ooml0W4P00018W03OoolT0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`03
0?noM0000000M;oo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000M;oo02D0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool01`3OW4P00000
07Boo`3oool0oooO09a80018W=l0;P3oool00`3ogi`0B00007Boo`0Z0?ooo`00H03oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo02/0oooo00<0_g@00018W03Oool00P3oool00`2oM000
07Bo0?ooo`070?ooo`030=nLB018W=l0oooo0080oooo00<0giad09cOo`3oool08`3oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo00T0oooo00@0oooO09a80000B9`0gooo903oool00`2o
M00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o
_g@004RL0=ooo`0T0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3o
oml0W4P0001d_`030?ooo`030?noM000B9`0gooo02d0oooo00<0omnL04P0001d_ol0:P3oool005l0
oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0Z0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool0203oool00`3OW4P0M;oo0?ooo`0V0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool01@3oool00`2oM0000000000000050000000307Boo`3oool0oooo0200
oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol08`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0
oooo00<0_g@0001d_`3oool00P3oool00`2oM00004RL0=ooo`0]0?ooo`030?oOW0180000M;oo02X0
oooo001O0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0:P3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0_gA809cOo`3oool09@3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL
0=ooob<0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol08`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00H0oooo00L0omnL04P0M02oool0oooo0;md00000000M;oo02h0oooo00<0omnL04P0001d_ol0
:P3oool005l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol02@3oool00`3ooml0W4Qd0;ooo`0U0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03O
ool08`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d
_ol00`3oool00`2oM000001809cOo`0S0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool01@3ookl0M4Q804P000000000B9cO02l0oooo00<0omnL04P0001d_ol0:P3oool005l0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol02P3oool00`3o_g@007Bo0?ooo`0T0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool08`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0oono07@000000000B9cO0?oo
o`3o_g@00000001d_b@0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`04
0?oOW01800000000001d_c00oooo00<0omnL04P0001d_ol0:P3oool005l0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol02P3oool00`3ookl0M01809cOo`0T0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool01P3ogi`0B7Bo0?oog`2LB00004RL0=ooob<0oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`060?ooo`030;md0000B9`0_ia80080000000<004RL0=ooo`3oool08`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0omnL04P0000007@0_ooo0?no
M000M;l_0?ooo`030?oOW0180000M;oo02X0oooo001O0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool0:P3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0
oono07@00018W=l0903oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00P0oooo00D0
gia807Bog`2LB00004RL0=ooo`0S0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1P3oool00`3ogi`0B00007Boo`0X0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1P3oool00`2oM000001d0;ooo`020?ooo`030;md0018W=l0oooo02d0oooo00<0omnL04P0001d_ol0
:P3oool00600oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`0[0?ooo`030=nLB000
B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW018
0000B9cO02D0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`050?oog`2L
B4P0B4P00018W03Oool0903oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo
00<0gia80000B02Lgol0:03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo
00<0_g@00018W03Oool00P3oool00`3OW4P007Bo0?ooo`0]0?ooo`030?oOW0180000M;oo02X0oooo
001P0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0/0?ooo`070?oo_`1d0000M;oo0?oo
o`3o_g@0001d0;ooo`060?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02ooolU0?ooo`07
0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0:0?ooo`040?oOW018000004RL0=ooob@0oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo00T0oooo00<0okmd00000000M;l09`3oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool01`3oool01`3o_g@0000007Boo`3oool0oono07@0001d_ol0
;03oool01@3ooml0W4P0000000000000M;oo02X0oooo001Q0?ooo`050?oo_`1d000000000000M02o
ool0;P3oool01@3ookl0M0000000000007@0_ooo00P0oooo00H0oooO09a80000000000000000M02o
oolW0?ooo`050?oo_`1d000000000000M02oool0303oool00`3OW4P004RL0=ooo`0U0?ooo`050?oo
_`1d000000000000M02oool02`3oool01@3ooml0W4P00000000007@0_ooo02D0oooo00D0oono07@0
00000000001d0;ooo`090?ooo`050?noM0000000000000000018W=l0;`3oool00`3o_g@0000007Bo
o`0Z0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00CP3oool01@3ogi`0B000
0000000007@0_ooo00T0ooooo`00000b000002<0oooo001=0?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool004d0
oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08@3oool004`0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d
0;ooo`070?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00C03o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0o`3o
ool^0?ooo`030000003oool0oooo0240oooo001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol01`3oool3000000@0oooo0P00003o0?ooob00oooo00<000000?ooo`3oool00`3oool3
000002<0oooo001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0240oooo001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool00`000000oooo0?ooo`050?ooo`<00000o`3ooolL0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool08@3oool004`0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d
0;ooo`070?ooo`030000003oool0oooo00H0oooo0P00003o0?oooa/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0Q0?ooo`00C@3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000
M;l0oooo00L0oooo00<000000?ooo`3oool01`3oool200000?l0oooo6@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0240oooo001=0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d
0;ooo`080?ooo`030000003oool0oooo00P0oooo0P00003o0?oooaL0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0Q0?ooo`00CP3oool01@3ookl0M0000000000007@0_ooo00T0oooo
00<000000?ooo`3oool02@3oool300000?l0oooo503oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0240oooo001L0?ooo`8000002`3oool300000?l0oooo4P3oool00`000000oooo0?oo
o`0:0?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool02P3oool400000?l0oooo403oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo
00/0oooo0P0000000`3oool000000?ooo`3o0?ooo`d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0<0?ooo`@00000o`3oool<0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0
3@3oool010000000oooo00000000003o0?ooo`X0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0>0?ooo`80000000<0oooo0000003oool0
o`3oool70?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08@3oool005`0oooo00<0
00000?ooo`3oool03P3oool500000?l0oooo1P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`800000403oool00`000000oooo0?ooo`0200000?l0oooo103oool0
0`000000oooo0?ooo`0A0?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool0403oool01@00
0000oooo0000003oool000000?l0oooo0P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0240oooo001L0?ooo`030000003oool0oooo0140oooo0P0000020?ooo`030000003oool0oooo
0?d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000
oooo0?ooo`0B0?ooo`040000003oool0oooo0?ooo`800000n`3oool2000001P0oooo00<000000?oo
o`3oool08@3oool005`0oooo00<000000?ooo`3oool04P3oool700000?T0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0C0?ooo`070000
003oool0oooo0?ooo`000000oooo0000003g0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool08@3oool005`0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0?<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0Q0?oo
o`00G03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool0l@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000
5`3oool2000000@0oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`0J0?ooo`<00000
8`3oool005`0oooo00<000000?ooo`3oool05P3oool2000000D0oooo00<000000?ooo`3oool0k@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0
oooo01L0oooo2000003/0?ooo`800000803oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0oooo0`00003Y0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000>L0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`3R0?ooo`800000903oool00`000000oooo0?ooo`0Q0?oo
o`00G03oool00`000000oooo0?ooo`0K0?ooo`040000003oool0oooo000000@0oooo0P00003Q0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool08@3oool005`0oooo0P00000L0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0S0?oo
o`<000008`3oool005`0oooo00<000000?ooo`3oool0703oool00`000000oooo000000070?ooo`03
0000003oool0oooo0=X0oooo0P00000X0?ooo`030000003oool0oooo0240oooo00110?ooo`050?oO
W018000000000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`060;md0000000000000000
0000B9`0gooo1`3oool00`000000oooo0?ooo`0M0?ooo`800000203oool200000=T0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M00007Boo`3oool0
okmd0000M02oool00P3oool00`3o_g@0000007Boo`040?ooo`030?oOW0180000M;oo00T0oooo00<0
00000?ooo`3oool07P3oool<00000=L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0Q0?ooo`00@03oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00P0oooo00<0omnL
04P0001d_ol02@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo0`00003C
0?ooo`800000;03oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`030?oo
o`030=nLB00007@0_ooo00P0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000d@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000
B02Lgol0203oool00`3ogi`0B00007Boo`090?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`3oool000000<l0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00P0oooo00<0omnL04P0001d_ol02@3oool300000240oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`800000b`3oool2000002h0oooo0`00000S0?ooo`00?`3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00P0oooo00<0omnL04P0001d_ol02@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`370?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool08@3oool003l0oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`080?ooo`030?oOW0180000M;oo00T0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0240oooo
000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool00`3ogi`0B00007Bo
o`090?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`800000``3oool2000003@0oooo00<000000?ooo`3oool08@3oool00400oooo00<0gia8
0018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`030?oOW0180000M;oo00T0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0_`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo00100?oo
o`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`070?ooo`050?oog`2LB00000000000001d_ol0
2@3oool00`000000oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`0000002`3oool200000;d0
oooo0P00000g0?ooo`030000003oool0oooo0240oooo00110?ooo`050?oo_`1d000000000000M02o
ool02P3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3o
ool000003@3oool200000;X0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0Q0?oo
o`00G03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0000000l0oooo00<000000?ooo`3o
ool0]@3oool2000003X0oooo00<000000?ooo`3oool08@3oool005`0oooo0P00000X0?ooo`030000
003oool000000100oooo0P00002d0?ooo`030000003oool0oooo03P0oooo0`00000S0?ooo`00G03o
ool00`000000oooo0?ooo`0X0?ooo`8000004P3oool00`000000oooo0?ooo`2_0?ooo`800000?@3o
ool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0Y0?oooaH00000[P3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool04@3oool300000:X0oooo0P0000100?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0403oool010000000
oooo0?ooo`00002W0?ooo`800000@P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0oooo0P00002S0?oo
o`800000A03oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool2000009l0oooo0P0000160?ooo`03
0000003oool0oooo0240oooo001L0?ooo`800000;P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00D0oooo0P00002K0?ooo`800000AP3oool3000002<0oooo001L0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`800000U`3o
ool2000004X0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo0P00002C0?ooo`800000C03oool0
0`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool2000008l0oooo0P00001>0?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0=0?ooo`800000R`3oool200000500oooo00<000000?ooo`3oool08@3oool005`0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo
0P0000270?ooo`800000DP3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool2000008<0oooo0P00
001D0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000<`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01<0oooo0P00001o0?ooo`800000E03oool3000002<0oooo001L0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0E0?oo
o`800000N`3oool2000005P0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo0`00001e0?ooo`<0
0000FP3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool200000740oooo0P00001M0?ooo`030000
003oool0oooo0240oooo001L0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0L0?ooo`800000K@3oool2000005l0oooo00<000000?ooo`3oool08@3o
ool005`0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01h0oooo0`00001W0?ooo`<00000H@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool20000
06<0oooo0P00001T0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000>@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo0`00001M0?ooo`<00000I03oool3000002<0
oooo001L0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0V0?ooo`@00000E@3oool4000006T0oooo00<000000?ooo`3oool08@3oool005`0oooo00<0
00000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool0000002`0oooo1000001=0?ooo`@00000
K@3oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo
00D0okmd0000001d_ol0oooo0;md00060000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3o
ool0>P3oool01@000000oooo0?ooo`3oool000000300oooo1@0000130?ooo`D00000L@3oool00`00
0000oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool0
0`3o_g@0000007Boo`020?ooo`030=nLB0000000000000<0000000<004RL0=ooo`3oool01@3oool0
0`000000oooo0?ooo`0k0?ooo`040000003oool0oooo000003D0oooo1@00000i0?ooo`D00000MP3o
ool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0
oooo00L0oooo00<0gia804RLg`3oool00P3oool00`3OW7@0W=oo0?ooo`050?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`000000>P3oool3000003<0oooo0`00001k0?ooo`030000003oool0
oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool00`3O
W4P0M;oo0?ooo`090?ooo`030000003oool0oooo03d0oooo0P00000m0?ooo`@000009P3oool90000
07h0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`090?ooo`030;mdB02Lgol0oooo00P0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`0o0?ooo`l00000303oool;000008L0oooo00<000000?ooo`3oool08@3oool003l0oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`090?ooo`030?oog`2LB7@0_ooo00P0oooo
0`00000n0?oooed00000T03oool3000002<0oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol02P3oool00`3o_g@007Bo0?ooo`070?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo000o
0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3ookl0M01809cOo`07
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;mdM02oool0oooo00@0oooo00<0_gAd0;oo
o`3oool02@3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0oono07@0
0018W=l01`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`2oM000B9cO0?ooo`030?ooo`03
0=nLB00007@0_ooo00/0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`03
0?noW02Lgol0oooo0080oooo00<0omnL04P00018W=l01`3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0500oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00
;03oool02@2oM00000000000M02oool0oooO09a80018W=l0gibL0;ooo`0;0?ooo`070?oo_`1d0000
M;oo0?ooo`3o_g@0001d0;ooo`060?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02oool7
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo0240oooo000/0?ooo`060;nLW03Ogi`0B0000000000004P0W=oo3`3o
ool01@3ookl0M0000000000007@0_ooo00P0oooo00H0oooO09a80000000000000000M02oool80?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2E0?oo
o`030000003oool0oooo0240oooo000/0?ooo`030;mdM02ogi`0B0000080000000@0001809cOo`3O
W9`0_ooo9`3oool2000004D0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`2C0?oo
o`<000008`3oool002`0oooo00<0_g@00018W03Oool00P3oool0102oM00000000000M02ooolW0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2E0?oo
o`030000003oool0oooo0240oooo000/0?ooo`030;mdB02Lgol0oooo00<0oooo00<0okmd0000M02o
ool09`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`2oW9`0gooo0?ooo`040?ooo`030=nL
W02oool0oooo02H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool08@3o
ool00340oooo00<0_ibL0=ooo`3oool00P3oool00`3OW9`0_ooo0?ooo`0S0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo0240oooo000]0?ooo`050?oo_`1d04P0W=oo0?oo_`1d0000100000000`0007@0_ooo0?ooo`0S
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo0240oooo000f0?ooo`030=nLW02oool0oooo02<0oooo0P00001:0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool0T`3oool3000002<0oooo001L0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo000c0?ooo`030;mdM02o
ool0oooo02H0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool08@3oool003<0oooo00<0_gAd0;ooo`3oool09P3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0U@3oool0
0`000000oooo0?ooo`0Q0?ooo`00<`3oool00`2oM7@0_ooo0?ooo`0V0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo
0240oooo000`0?ooo`030;md00000000000000<0000000<0001d0;ooo`3oool08`3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0Q0?ooo`00<`3oool00`2oM7@0_ooo0?ooo`0V0?ooo`800000C`3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo09<0oooo0`00000S0?ooo`00<`3oool00`2oM7@0_ooo0?oo
o`0V0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo0240oooo000c0?ooo`030;mdM02oool0oooo02H0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo09D0oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool08@3oool002h0oooo00<0oooO09adW03O
ool01@3oool00`3OW9`0_ooo0?ooo`0S0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo000^0?ooo`030?no
M0000000000000D0000000<0001d0;ooo`3oool08`3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00=P3o
ool00`3OW9`0_ooo0?ooo`0S0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo0240oooo001L0?ooo`800000EP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
09<0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3ogi`0B000
0000000007@0_ooo00<0oooo00H0okmd0000001d_ol0oooo0?oo_`1d00030000000307Boo`3oool0
oooo00L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo09D0oooo00<000000?ooo`3oool08@3oool00400oooo00L0oono07@0001d_ol0oooo0?noM000
07@0_ooo0080oooo00L0okmd0000001d_ol0oooo0?oOW0180000B9cO0080oooo00<0_g@004RLg`3o
ool01`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`2oM00004RL0=ooo`020?ooo`030;md
0000M;l0oooo00X0oooo00<0oono07@0B02Lgol01`3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00?`3o
ool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0oono07@0001d_ol01`3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0U@3o
ool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00X0oooo00<0okmd0000001d_ol01`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0oooo00@0omnL04P0000004P0W=oo1`3oool3
000005/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2C0?ooo`<000008`3oool0
03l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`050?noM00000000000
0000B02Lgol0203oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?oo
o`030?noM00004P0W=oo00T0oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`1L0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?oo
o`00?`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0_g@004RLg`3o
ool01`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`3OW4P004RL0=ooo`020?ooo`030;md
0000M;l0oooo00D0oooo00<0oooO09bL_`3oool00P3oool00`3OW4P0001d0;ooo`070?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2E0?ooo`030000
003oool0oooo0240oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`070?ooo`06
0?noM018W=l0oooo0?oo_`1d000007Bo203oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3o
okl0M0000000000007@0_ooo00T0oooo00D0gia8000000000000001d0;ooo`080?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`800000H@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo09<0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?oo
o`0Q0?ooo`00G03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?oo
o`00G03oool2000006L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2C0?ooo`<0
00008`3oool005`0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0J03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool08@3o
ool005`0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo09D0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool08@3oool005`0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo09D0
oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool08@3oool005`0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool08@3oool005`0oooo0P00001^0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0T`3oool3000002<0oooo001L0?ooo`030000003oool0oooo06h0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo001L0?ooo`03
0000003oool0oooo06h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo
0240oooo001L0?ooo`800000L`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo09<0
oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3ogi`0B0000000
000007@0_ooo00<0oooo00<0okmd0000001d_ol01@3oool0103ooml0W4P00018W03Oool70?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo0240oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?oo
o`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q
0?ooo`00@03oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00T0oooo00@0oooO09a8
0000B9`0gooo1`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`030?oo
o`030=nLB00007@0_ooo00D0oooo00<0_g@00000000000001@0000000`1d_ol0oooo0?ooo`040?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2E0?oo
o`030000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01@3oool0203ogi`0M9cO0?ooo`3oool0oooO09a80000B9`0gooo1`3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?oo
o`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0gia8
07Boo`3oool0oooO09a80000B9`0gooo00L0oooo0`00001h0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0T`3oool3000002<0oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol01P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool01`3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo
00H0omnL04Qd_`3ooml0W4P00018W03Oool70?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo000o0?ooo`03
0?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool01@3OW4P0M;oO09a80000B9`0gooo
00L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
09D0oooo00<000000?ooo`3oool08@3oool00400oooo00<0gia80018W03Oool00P3oool00`2oM000
07Bo0?ooo`080?ooo`050?oog`2LB4P0B4P00018W03Oool01`3oool00`000000oooo0?ooo`1k0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?oo
o`00@03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool02P3oool0103ogi`0B0000018W03O
ool70?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo0240oooo00110?ooo`050?oo_`1d000000000000M02oool0303o
ool00`3OW4P004RL0=ooo`070?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo0240oooo001L0?ooo`800000O`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
09<0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q
0?ooo`00G03oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`230?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool2000008@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2C0?ooo`<00000
8`3oool005`0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool08@3oool0
05`0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
09D0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool08@3oool005`0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo09D0oooo
00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool08@3oool005`0oooo0P00002:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0T`3oool3000002<0oooo001L0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2E0?oo
o`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2E0?ooo`030000
003oool0oooo0240oooo001L0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo0240oooo001L0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000T03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo09<0oooo0`00000S0?ooo`00G03oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`2A0?ooo`050000003oool0oooo0?ooo`000000
U`3oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo
00H0okmd0000001d_ol0oooo0?oog`2LB0030000000307Boo`3oool0oooo00L0oooo00<000000?oo
o`3oool0TP3oool010000000oooo0?ooo`00002G0?ooo`030000003oool0oooo0240oooo00100?oo
o`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`070?noM0000000M;oo0?ooo`3ooml0
W4Qd0;ooo`020?ooo`030;md001d_ol0oooo00L0oooo00<000000?ooo`3oool0TP3oool00`000000
oooo00000002000009H0oooo00<000000?ooo`3oool08@3oool00400oooo00<0_g@00018W03Oool0
0P3oool00`2oM00007Bo0?ooo`0:0?ooo`030?oog`2LB7@0_ooo00L0oooo00<000000?ooo`3oool0
TP3oool7000009@0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0oono07@00018W=l00`3o
ool00`3OW4P0001d0;ooo`0;0?ooo`030;md001d_ol0oooo00H0oooo00<000000?ooo`3oool0TP3o
ool7000009@0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`0:0?ooo`030?oog`2LB000B9cO00L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool05P3oool9
000001P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o
_g@0001809cOo`0:0?ooo`030=nLB0000000M;oo00L0oooo0`0000040?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00P0oooo2@0000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo0`00000S0?ooo`00?`3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0gmoO0?ooo`3ookl0M0000000000007@0
_ooo00L0ooooo`00000b000002<0oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000
B02Lgol01P3oool01P3OW4P00000000000000000001809cOool0ooooG@3oool003l0oooo00<0oono
07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`040?oo_`1d0000000004RLgol0ooooG`3o
ool00400oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030;md001d_ol0
oooo0?l0ooooG`3oool00400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00P0oooo00H0
omnL04P00000000000000000B02Lgooo0?oooe`0oooo00110?ooo`050?oo_`1d000000000000M02o
ool02P3oool01@2oM0000000000000000000B9cO0?l0ooooG03oool00?l0oooo/@3oool00?l0oooo
9@3oool00`3ooml0W4Q809cOo`0W0?ooo`030?oOW018B9`0gooo05l0oooo003o0?ooobD0oooo00<0
_gA809cOo`3oool0:03oool00`3ogi`0B7Bo0?ooo`1N0?ooo`00o`3ooolT0?ooo`030=nLB018W=l0
oooo02X0oooo00<0gia804RLg`3oool0G@3oool00?l0oooo8`3oool00`3ookl0M01d0;ooo`0[0?oo
o`030?oo_`1d04P0W=oo05d0oooo00290?ooo`030?oOW018000000000080000000<0001d0;ooo`3o
ool00`3oool01@3OW4P00000000000000000M;oo00<0oooo00H0oooO09a80000000000000000B02L
gol50?ooo`030?oOW01dW=l0oooo0080oooo00<0giad09cOo`3oool0103oool01@2oM00000000000
000007@0_ooo0080oooo00H0oooO09a80000000000000000B02Lgol70?ooo`030;md000000000000
0080000000<007Bo0?ooo`3oool00`3oool01`3OW4P000000000000007@0_ooo0?ooo`3OW4P00`00
0000201d_ol0oooo0?ooo`3oool0omnL04P000000000B9cO103oool00`3ogi`0B000000000020000
000407Boo`3oool0oooo0=nLB0<0000000@0M;oo0?ooo`3oool0_g@00P0000001`0004P0W=oo0?oo
o`3ooml0W4P00000M02oool01`3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000
001d_ol00`3oool01@3OW4P00000000000000000B9cO00L0oooo00<0gia80018W03Oool0103oool0
1P2oM000000000000000000004RL0=oooaH0oooo00D0_g@000000000M;l0oooo0=nLB00200000007
0018W03Oool0oooo0?ooo`3ooml0W4P004RLg`050?ooo`050;md0000000007Bo0?ooo`3OW4P00P00
00000`00B9`0gooo0?ooo`1>0?ooo`00R03oool0103OW4P000000018W03Oool20?ooo`030?oo_`1d
04P0W=oo0080oooo00L0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00L0_g@00018W03O
ool0oooo0?oOW0180000M;oo00@0oooo00L0_g@00000M02oool0oooo0?oo_`1d000007Bo00@0oooo
00l0_g@000000000M;l0oooo0?oOW01807@0_ooo0?ooo`2oM00004RL0=ooo`3oool0omnL04P0001d
_ol01`3oool0103ooml0W4P00018W03Oool70?ooo`0;0=nLB00007@0_ooo0?ooo`3OW4P0000004RL
g`3oool0oooO09a80018W=l00P3oool01@3OW4P0001d0;ooo`3O_kl0gooo00@0oooo00<0oooO09a8
0000M;l00`3oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool00`3OW4P0001d0;oo
o`020?ooo`040?oog`2LB000001d0;ooo`H0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo
0080oooo00<0okmd0000001d_ol00P3oool01`3OW4P0000007Boo`3oool0oooO09a80018W=l01P3o
ool00`2oM00007Bo0?ooo`050?ooo`030?oOW0180000M;oo01P0oooo00P0oooO09a8M02oool0oooo
0?oog`2LB00004RL0=ooo`@0oooo00<0gia80018W03Oool0103oool0203ooml0W4Qd0;ooo`3oool0
oooO09a80000B9`0goooD03oool008L0oooo00<0okmd00000000M;l01@3oool01P3ooml0W4Qd0;oo
o`3ogi`0B000001d_`<0oooo00L0okmd0000M02oool0oooo0;md0000B9`0gooo0080oooo00<0okmd
0000M02oool00P3oool02@3ogi`0B00004QdM01dW=l0oooo0?noM00004P0B4Q809cOo`020?ooo`03
0?oOW0180000B9cO00<0oooo00H0omnL07BLg`3oool0_g@00018W03Oool20?ooo`030?noM00007@0
_ooo00H0oooo00<0oooO09a80000M;l0203oool01P3OW4P0001d0;ooo`3ogi`0B000001d_`<0oooo
00L0okmd0000M02oool0oooo0=nLB000B9`0gooo00H0oooo00<0oooO09a80000M;l00P3oool00`3o
gi`0B000001d_`030?ooo`070?noM00007@0_ooo0?ooo`3OW4P0001d0;ooo`0<0?ooo`030;md0000
B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3ooml0W4P0001d_`030?ooo`030?noM000
B9`0gooo00@0oooo00<0oono07@00018W=l01P3oool00`3ogi`0B00007Boo`0I0?ooo`060?oo_`1d
B9`0gooo0;md000007@0_ooo1@3oool00`3OW4P0001d0;ooo`050?ooo`060?oo_`1dB9`0gooo0;md
000007@0_oooD@3oool008H0oooo00@0oooO09a8000007@0_ooo203oool00`3o_g@0000007Boo`03
0?ooo`070?noM0000000M;oo0?ooo`2oM00004RL0=ooo`020?ooo`030?oOW0180000M;oo0080oooo
00T0gia80000M02oool0_gAd0;oog`2LB00007Bo0?oOW01dW=l00P3oool00`3o_g@0001809cOo`06
0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P0001d_ol01P3oool00`3ooml0W4P0001d_`08
0?ooo`060=nLB00007@0_ooo0?noM0000000M;oo0`3oool01`3o_g@0000007Boo`3oool0gia80018
W03Oool01P3oool00`3ooml0W4P0001d_`020?ooo`030?noM0000000M;oo00<0oooo00L0okmd0000
001d_ol0oooo0=nLB00007@0_ooo00/0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;oo
o`060?ooo`030;md0000M;l0oooo0080oooo00<0_g@00018W03Oool0103oool00`3ookl0M00007Bo
o`060?ooo`030?oOW0180000M;oo01X0oooo00@0omnL07A8B0000000M;oo1P3oool00`3o_g@0001d
0;ooo`060?ooo`040?oOW01dB4P0000007Booe80oooo00260?ooo`040?oOW018000004RL0=ooo`P0
oooo00<0okmd0000001d_ol00`3oool01`3o_g@0000007Boo`3oool0_g@00018W03Oool00P3oool0
4`3ogi`0B00007Boo`3oool0oono07@00018W=l0oooo0?oOW01dM7@0B01809cOo`3oool0_gAd0;oo
o`3oool0okmd0000M02oool01P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000M;oo00H0
oooo00<0oooO09a80000M;l0203oool01P3OW4P0001d0;ooo`3o_g@0000007Boo`<0oooo00L0okmd
0000001d_ol0oooo0=nLB000B9`0gooo00H0oooo00<0oooO09a80000M;l00P3oool00`3o_g@00000
07Boo`030?ooo`070?noM0000000M;oo0?ooo`3OW4P0001d0;ooo`0;0?ooo`030?oOW0180000M;oo
00<0oooo00<0okmd0000B02Lgol01P3oool01`3ogi`0B01d0;ooo`3oool0_g@00000001d_ol01@3o
ool00`3ookl0M00007Boo`060?ooo`030?oOW0180000M;oo00P0oooo00<0oooO09a8000000001`00
00000`18W=l0oooo0?ooo`050?ooo`030?oo_`1d0000B9cO00L0oooo00<0okmd0000B02Lgol01P3o
ool00`3ookl0M00004RLg`1C0?ooo`00QP3oool00`3o_g@00000001d_`090?ooo`030?oo_`1d0000
M;oo00<0oooo00L0_g@00000B02Lgol0oooo0;md0000B9`0gooo0080oooo00/0okmd0000B02Lgol0
oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P0001d_`020?ooo`050?noM018W=l0oooo0?oOW0180000
1@0000001@18W=l0oooo0;md0000B9`0gooo0080oooo00<0okmd0000B02Lgol01P3oool00`3ooml0
W4P0000000040000000:07Boo`3oool0oooo0?ooo`3OW4P0001d0;ooo`3ookl0M00007Boo`<0oooo
00L0_g@00000B02Lgol0oooo0=nLB000B9`0gooo00H0oooo00<0oooO09a80000M;l00P3oool00`3o
okl0M00007Boo`030?ooo`070;md000004P0W=oo0?ooo`3OW4P0001809cOo`0;0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool01@3ookl0M4Q804P000000000B9cO00H0oooo
00<0oono07@0001d_ol01P3oool00`3ogi`0B00007Boo`0I0?ooo`050?oog`2LB00004RL09adB02L
gol01P3oool00`3o_g@0001d0;ooo`050?ooo`050?oog`2LB00004RL09adB02Lgol0DP3oool008H0
oooo00<0okmd00000000M;l02P3oool01`3OW4P004RL0=ooo`3oool0okmd00000000M;l00P3oool0
2`2oM00000000018W03Oool0oono07@00000B9`0gooo0?oo_`1d000007Bo0080oooo00<0omnL04P0
001d_ol00P3oool01P3ooml0W4Qd0;ooo`3oool0_g@004RLg`80oooo00`0gia80000B02Lgol0oooo
0;md0000000004RL0=ooo`3ookl0M0000018W03Oool60?ooo`030?oog`2LB00007Bo0080oooo00@0
oooO09a800000000B9cO0P3oool02`3OW4P0001d0;ooo`3oool0gia80018W03Oool0oooo0?noM000
000007Bo0080oooo00<0gia80018W03Oool01P3oool00`3ooml0W4P0001d_`030?ooo`0B0=nLB000
B9`0gooo0?ooo`3o_g@00000001d_`3ooml0W4P00000000004P0B7BL0=noM00007@0_ooO09a80000
07@0_ooo1@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00@0omnL04P0
0000000007Bo1`3oool00`3ookl0M00004RLg`060?ooo`030?oOW0180000M;oo01T0oooo00H0_g@0
0000B02Lgol0oooO09a8M02oool50?ooo`030=nLB00007@0_ooo00D0oooo00H0_g@00000B02Lgol0
oooO09a8M02ooomA0?ooo`00QP3oool0103ogi`0B0000018W03Oool:0?ooo`050?noM00000000000
00000018W=l00`3oool02@2oM00004RL0=oOW018000000000018W03Oool0oooO09a8000200000003
04RLg`3o_g@000000080000000P0B9cO0?ooo`2oM00000000018W03Oool0oooo0=nLB080000000/0
001809cOo`3oool0oooo0;md0000B9`0gmnL04P00000000004RL0=ooo`070?ooo`030?oog`2LB000
07Bo00<0oooo00P0oono07@0000007@0_ooo0?ooo`3OW4P0001d0;ooo`80oooo00D0okmd00000000
0000000004RLg`020?ooo`060;md00000000000000000000B9`0gooo0`3oool00`3o_g@000000000
0002000000040018W03Oool0oooo0?noM0<0000000d0B9cO0?ooo`3oool0oooo0;md000007@0_mnL
04P0000007@0_ooO09a8000007@0_ooo00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`060?ooo`060?oOW0180000001d0;ooo`3o_g@007Bo1P3oool00`3ooml0W4P004RLg`060?oo
o`030?oOW0180000M;oo01L0oooo00T0oooO09a8000000000000001d_`3o_g@000000000M02oool0
103oool00`3OW4P004RL0=ooo`030?ooo`090?oog`2LB000000000000000M;l0okmd0000000007@0
_ooo0500oooo00260?ooo`040?oog`2LB000001809cOo`D0oooo00<0oooO09adW03Oool02P3oool0
0`2oM00004RL0=ooo`0K0?ooo`030;md0000B9`0gooo00/0oooo00<0oooO09a80000M;l00`3oool0
203ooml0W4P00000B02Lgol0oooo0=nLB00007@0_ooo2P3oool00`2oM00004RL0=ooo`060?ooo`03
0?oog`2LB00007Bo01X0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`03
0;md000007@0_ooo0080oooo00<0_g@004RLg`3oool01@3oool00`3OW4P004RL0=ooo`050?ooo`03
0?oOW0180000M;oo02<0oooo00<0oooO09a80018W=l0G@3oool008L0oooo00<0omnL04P00000M;l0
1@3oool00`3o_g@004RL0=ooo`0:0?ooo`030;md0000B9`0gooo01/0oooo00<0_g@00018W03Oool0
2`3oool00`3ooml0W4P0001d_`030?ooo`080?oOW0180000001d0;ooo`3oool0gia80000M02oool:
0?ooo`030?oo_`1dB9`0gooo00L0oooo00<0_g@0001d_`3oool06P3oool00`3OW4P004RL0=ooo`02
0?ooo`030;md0000M;l0oooo00H0oooo00<0_g@00018W03Oool00P3oool00`3OW4P007Bo0?ooo`05
0?ooo`030?oo_`1d04P0W=oo00D0oooo00<0omnL04P0001d_ol08`3oool00`3ookl0M01809cOo`1M
0?ooo`00R03oool00`3o_g@00000001d_`030?ooo`030=nLB000000007Bo00/0oooo00<0_g@00018
W03Oool06`3oool00`2oM00004RL0=ooo`0;0?ooo`030?oog`2LB00007Bo0080oooo00@0oono07@0
00000000B9cO0P3oool00`3OW4P0001d0;ooo`0:0?ooo`030?oog`2LM9`0gooo00L0oooo00<0gia8
001d_`3oool06P3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool01`3oool01`3o_g@00000
07Boo`3oool0oono07@0001d_ol01`3oool00`3OW4P0B9cO0?ooo`020?ooo`050?oog`2LB0000000
0000001d_ol08`3oool00`3OW4P0B9cO0?ooo`1M0?ooo`00R@3oool00`3ooml0W4P0000000020000
000304RLg`3ookl0M7Bo00T0oooo00D0oono07@00000000004RL0=ooo`0I0?ooo`050?oo_`1d0000
00000018W03Oool02P3oool00`2oM000000000000004000000080000B02Lgol0oooo0?oog`2LB000
00000000M02ooolD0?ooo`070?oo_`1d07@0_ooo0?oog`2LB00004RL0=ooo`0G0?ooo`050?oo_`1d
000000000000M02oool02@3oool01@3o_g@00000000000000000B9cO00T0oooo00<0_g@004RLg`3o
ool00`3oool00`3o_g@0000007Boo`0R0?ooo`030?noM000M;l0oooo05h0oooo002K0?ooo`040?oo
g`2LB00004RL0=oooaX0oooo00@0oooO09a80000B9`0gooo5P3oool00`2oM000001d0;ooo`0E0?oo
o`050?oo_`1d000000000000B02Lgol0=@3oool00`3OW7@0W=oo0?ooo`0V0?ooo`030?oo_`1dM;l0
oooo05l0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.344423, -0.152272, \
0.00518628, 0.00412824}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(logisticCobweb[0.8, 0.8, 20, 0];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 1.1925 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -9.5 -15.6875 ]
[.21429 -0.0125 9.5 0 ]
[.40476 -0.0125 -9.5 -15.6875 ]
[.40476 -0.0125 9.5 0 ]
[.59524 -0.0125 -9.5 -15.6875 ]
[.59524 -0.0125 9.5 0 ]
[.78571 -0.0125 -9.5 -15.6875 ]
[.78571 -0.0125 9.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .01472 -10 -7.84375 ]
[-0.0125 .01472 0 7.84375 ]
[-0.0125 .13396 -19 -7.84375 ]
[-0.0125 .13396 0 7.84375 ]
[-0.0125 .25321 -19 -7.84375 ]
[-0.0125 .25321 0 7.84375 ]
[-0.0125 .37246 -19 -7.84375 ]
[-0.0125 .37246 0 7.84375 ]
[-0.0125 .49171 -19 -7.84375 ]
[-0.0125 .49171 0 7.84375 ]
[-0.0125 .61096 -19 -7.84375 ]
[-0.0125 .61096 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -11.4063 ]
[-0.01875 .30902 -19 11.4063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74.9688 0 ]
[.5 .63053 74.9688 15.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13396 m
.00625 .13396 L
s
gsave
-0.0125 .13396 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .25321 m
.00625 .25321 L
s
gsave
-0.0125 .25321 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .37246 m
.00625 .37246 L
s
gsave
-0.0125 .37246 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .49171 m
.00625 .49171 L
s
gsave
-0.0125 .49171 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .61096 m
.00625 .61096 L
s
gsave
-0.0125 .61096 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03857 m
.00375 .03857 L
s
0 .06242 m
.00375 .06242 L
s
0 .08626 m
.00375 .08626 L
s
0 .11011 m
.00375 .11011 L
s
0 .15781 m
.00375 .15781 L
s
0 .18166 m
.00375 .18166 L
s
0 .20551 m
.00375 .20551 L
s
0 .22936 m
.00375 .22936 L
s
0 .27706 m
.00375 .27706 L
s
0 .30091 m
.00375 .30091 L
s
0 .32476 m
.00375 .32476 L
s
0 .34861 m
.00375 .34861 L
s
0 .39631 m
.00375 .39631 L
s
0 .42016 m
.00375 .42016 L
s
0 .44401 m
.00375 .44401 L
s
0 .46786 m
.00375 .46786 L
s
0 .51556 m
.00375 .51556 L
s
0 .53941 m
.00375 .53941 L
s
0 .56326 m
.00375 .56326 L
s
0 .58711 m
.00375 .58711 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13396 m
1 .13396 L
s
.99375 .25321 m
1 .25321 L
s
.99375 .37246 m
1 .37246 L
s
.99375 .49171 m
1 .49171 L
s
.99375 .61096 m
1 .61096 L
s
.125 Mabswid
.99625 .03857 m
1 .03857 L
s
.99625 .06242 m
1 .06242 L
s
.99625 .08626 m
1 .08626 L
s
.99625 .11011 m
1 .11011 L
s
.99625 .15781 m
1 .15781 L
s
.99625 .18166 m
1 .18166 L
s
.99625 .20551 m
1 .20551 L
s
.99625 .22936 m
1 .22936 L
s
.99625 .27706 m
1 .27706 L
s
.99625 .30091 m
1 .30091 L
s
.99625 .32476 m
1 .32476 L
s
.99625 .34861 m
1 .34861 L
s
.99625 .39631 m
1 .39631 L
s
.99625 .42016 m
1 .42016 L
s
.99625 .44401 m
1 .44401 L
s
.99625 .46786 m
1 .46786 L
s
.99625 .51556 m
1 .51556 L
s
.99625 .53941 m
1 .53941 L
s
.99625 .56326 m
1 .56326 L
s
.99625 .58711 m
1 .58711 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cobweb) show
105.875 15.813 moveto
(Plot) show
128.188 15.813 moveto
(for) show
142.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
148.375 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.375 15.813 moveto
(H) show
170.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
179.188 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
189.875 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
196.000 15.813 moveto
(L) show
202.813 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
208.938 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .06309 L
.10458 .11585 L
.14415 .1654 L
.18221 .21305 L
.22272 .26377 L
.26171 .3126 L
.30316 .36449 L
.34309 .41449 L
.3815 .46259 L
.42237 .51376 L
.46172 .56303 L
.49955 .6104 L
s
.49955 .6104 m
.50565 .61803 L
s
.02381 .01472 m
.06244 .05185 L
.10458 .08876 L
.14415 .12003 L
.18221 .14699 L
.22272 .17235 L
.26171 .19349 L
.30316 .21246 L
.34309 .22732 L
.3815 .23845 L
.40095 .24289 L
.42237 .24688 L
.44268 .24976 L
.45178 .25077 L
.46172 .25167 L
.4671 .25208 L
.4721 .2524 L
.47727 .25267 L
.48196 .25287 L
.48658 .25303 L
.4887 .25308 L
.49093 .25313 L
.49332 .25317 L
.49438 .25318 L
.49552 .25319 L
.49675 .2532 L
.49789 .25321 L
.49859 .25321 L
.49925 .25321 L
.50049 .25321 L
.50163 .25321 L
.50286 .25321 L
.50401 .2532 L
.50508 .25319 L
.50754 .25315 L
.51014 .25311 L
.51268 .25305 L
.51504 .25298 L
.5204 .25278 L
.5293 .25231 L
.53882 .25163 L
.54906 .25068 L
.56016 .24941 L
.58032 .24643 L
.60019 .24266 L
.62123 .23776 L
.65912 .22658 L
.69946 .21137 L
.73829 .19349 L
.77956 .17101 L
Mistroke
.81932 .14597 L
.85757 .11874 L
.89827 .08639 L
.93745 .05194 L
.97619 .01472 L
Mfstroke
.78571 .61803 m
.78571 .16735 L
.14571 .16735 L
s
.14571 .16735 m
.14571 .1212 L
.10885 .1212 L
s
.10885 .1212 m
.10885 .09229 L
.08577 .09229 L
s
.08577 .09229 m
.08577 .07274 L
.07015 .07274 L
s
.07015 .07274 m
.07015 .05888 L
.05908 .05888 L
s
.05908 .05888 m
.05908 .04874 L
.05098 .04874 L
s
.05098 .04874 m
.05098 .04116 L
.04493 .04116 L
s
.04493 .04116 m
.04493 .0354 L
.04033 .0354 L
s
.04033 .0354 m
.04033 .03097 L
.0368 .03097 L
s
.0368 .03097 m
.0368 .02755 L
.03406 .02755 L
s
.03406 .02755 m
.03406 .02487 L
.03192 .02487 L
s
.03192 .02487 m
.03192 .02277 L
.03024 .02277 L
s
.03024 .02277 m
.03024 .02111 L
.02892 .02111 L
s
.02892 .02111 m
.02892 .01981 L
.02788 .01981 L
s
.02788 .01981 m
.02788 .01877 L
.02705 .01877 L
s
.02705 .01877 m
.02705 .01795 L
.02639 .01795 L
s
.02639 .01795 m
.02639 .0173 L
.02587 .0173 L
s
.02587 .0173 m
.02587 .01677 L
.02545 .01677 L
s
.02545 .01677 m
.02545 .01636 L
.02512 .01636 L
s
.02512 .01636 m
.02512 .01603 L
.02486 .01603 L
s
.02486 .01603 m
.02486 .01577 L
.02465 .01577 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00m@3oool01@3ooml0W4P00000
0000B9`0gooo0;H0oooo003f0?ooo`030?oOW01804P0W=oo0;L0oooo003]0?ooo`050;md00000000
07Bo0?ooo`3OW4P00P0000001@00B9`0gooo0?oOW01804P0W=oo0;L0oooo003]0?ooo`0<0?oog`2L
B7@0_ooo0?ooo`3ooml0W4P00018W03Oool0oooo0?oOW01804P0W=oo]`3oool00>h0oooo00/0oono
07A8W03Oool0_g@00000M02oool0oooo0?oo_`1d0000001809cOo`2g0?ooo`00k`3oool0103ogi`0
M4Q80000001d_ol30?ooo`030?oOW01804P0W=oo0;L0oooo003_0?ooo`030?oo_`1d0000B9cO0;h0
oooo003^0?ooo`050?oog`2LB00004RL09adB02Lgol0_@3oool00>h0oooo00H0_g@00000B02Lgol0
oooO09a8M02oool20?ooo`030?oo_`1d0000M;oo0;L0oooo003/0?ooo`090?oog`2LB00000000000
0000M;l0okmd0000000007@0_ooo0;/0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001Q0?ooo`050?oOW01800000000
0000M02oool0;P3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00D0okmd0000001d_ol0oooo
0;md00060000000304RLg`3oool0oooo02@0oooo00D0omnL04P000000000001d0;ooo`030?ooo`03
0?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo9@3oool01@3ogi`0B0000000000007@0
_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3ogi`0B000000000000000M;oo02L0oooo00D0
omnL04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00<0oooo00D0gia8000000000000
000004RLg`0^0?ooo`060;md00000000000000000000B9`0gooo:03oool00600oooo00L0oono07@0
001d_ol0oooo0?noM00007@0_ooo02`0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080
oooo00<0okmd0000001d_ol00P3oool00`3OW4P0000000000003000000030018W03Oool0oooo02<0
oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol01@3oool0
103ooml0W4P00018W03OoolT0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`03
0?noM0000000M;oo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000M;oo02D0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool01`3OW4P00000
07Boo`3oool0oooO09a80018W=l0;P3oool00`3ogi`0B00007Boo`0Z0?ooo`00H03oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo02/0oooo00<0_g@00018W03Oool00P3oool00`2oM000
07Bo0?ooo`070?ooo`030=nLB018W=l0oooo0080oooo00<0giad09cOo`3oool08`3oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo00T0oooo00@0oooO09a80000B9`0gooo903oool00`2o
M00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o
_g@004RL0=ooo`0T0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3o
oml0W4P0001d_`030?ooo`030?noM000B9`0gooo02d0oooo00<0omnL04P0001d_ol0:P3oool005l0
oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0Z0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool0203oool00`3OW4P0M;oo0?ooo`0V0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool01@3oool00`2oM0000000000000050000000307Boo`3oool0oooo0200
oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol08`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0
oooo00<0_g@0001d_`3oool00P3oool00`2oM00004RL0=ooo`0]0?ooo`030?oOW0180000M;oo02X0
oooo001O0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0:P3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0_gA809cOo`3oool09@3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL
0=ooob<0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol08`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00H0oooo00L0omnL04P0M02oool0oooo0;md00000000M;oo02h0oooo00<0omnL04P0001d_ol0
:P3oool005l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol02@3oool00`3ooml0W4Qd0;ooo`0U0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03O
ool08`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d
_ol00`3oool00`2oM000001809cOo`0S0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool01@3ookl0M4Q804P000000000B9cO02l0oooo00<0omnL04P0001d_ol0:P3oool005l0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol02P3oool00`3o_g@007Bo0?ooo`0T0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool08`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0oono07@000000000B9cO0?oo
o`3o_g@00000001d_b@0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`04
0?oOW01800000000001d_c00oooo00<0omnL04P0001d_ol0:P3oool005l0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol02P3oool00`3ookl0M01809cOo`0T0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool01P3ogi`0B7Bo0?oog`2LB00004RL0=ooob<0oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`060?ooo`030;md0000B9`0_ia80080000000<004RL0=ooo`3oool08`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0omnL04P0000007@0_ooo0?no
M000M;l_0?ooo`030?oOW0180000M;oo02X0oooo001O0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool0:P3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0
oono07@00018W=l0903oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00P0oooo00D0
gia807Bog`2LB00004RL0=ooo`0S0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1P3oool00`3ogi`0B00007Boo`0X0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1P3oool00`2oM000001d0;ooo`020?ooo`030;md0018W=l0oooo02d0oooo00<0omnL04P0001d_ol0
:P3oool00600oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`0[0?ooo`030=nLB000
B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW018
0000B9cO02D0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`050?oog`2L
B4P0B4P00018W03Oool0903oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo
00<0gia80000B02Lgol0:03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo
00<0_g@00018W03Oool00P3oool00`3OW4P007Bo0?ooo`0]0?ooo`030?oOW0180000M;oo02X0oooo
001P0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0/0?ooo`070?oo_`1d0000M;oo0?oo
o`3o_g@0001d0;ooo`060?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02ooolU0?ooo`07
0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0:0?ooo`040?oOW018000004RL0=ooob@0oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo00T0oooo00<0okmd00000000M;l09`3oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool01`3oool01`3o_g@0000007Boo`3oool0oono07@0001d_ol0
;03oool01@3ooml0W4P0000000000000M;oo02X0oooo001Q0?ooo`050?oo_`1d000000000000M02o
ool0;P3oool01@3ookl0M0000000000007@0_ooo00P0oooo00H0oooO09a80000000000000000M02o
oolW0?ooo`050?oo_`1d000000000000M02oool0303oool00`3OW4P004RL0=ooo`0U0?ooo`050?oo
_`1d000000000000M02oool02`3oool01@3ooml0W4P00000000007@0_ooo02D0oooo00D0oono07@0
00000000001d0;ooo`090?ooo`050?noM0000000000000000018W=l0;`3oool00`3o_g@0000007Bo
o`0Z0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00CP3oool01@3ogi`0B000
0000000007@0_ooo00T0ooooo`00000b000002<0oooo001=0?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool004d0
oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08@3oool004`0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d
0;ooo`070?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00C03o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0o`3o
ool^0?ooo`030000003oool0oooo0240oooo001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol01`3oool3000000@0oooo0P00003o0?ooob00oooo00<000000?ooo`3oool00`3oool3
000002<0oooo001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool00`00
0000oooo0?ooo`050?ooo`800000o`3ooolN0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool08@3oool004`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`03
0000003oool0oooo00H0oooo0P00003o0?oooa`0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0Q0?ooo`00C03oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00L0oooo
00<000000?ooo`3oool01P3oool200000?l0oooo6`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0240oooo001=0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`800000o`3ooolI0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool08@3oool004d0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00P0oooo
00<000000?ooo`3oool0203oool200000?l0oooo5`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0240oooo001>0?ooo`050?oo_`1d000000000000M02oool02@3oool00`000000oooo
0?ooo`090?ooo`<00000o`3ooolD0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
8@3oool005`0oooo0P00000;0?ooo`<00000o`3ooolB0?ooo`030000003oool0oooo00X0oooo0`00
000S0?ooo`00G03oool00`000000oooo0?ooo`0:0?ooo`@00000o`3oool@0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool02`3oool20000
00030?ooo`000000oooo0?l0oooo3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo00`0oooo1000003o0?ooo``0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0=0?ooo`040000
003oool0000000000?l0oooo2P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240
oooo001L0?ooo`030000003oool0oooo00h0oooo0P0000000`3oool000000?ooo`3o0?ooo`L0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?oo
o`0>0?ooo`D00000o`3oool60?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool08@3o
ool005`0oooo0P00000@0?ooo`030000003oool0oooo00<00000o`3oool30?ooo`030000003oool0
oooo0140oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`0@0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo0140oooo0P0000030?ooo`030000003oool0oooo0?`0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0n@3oool2000001P0oooo
00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool04P3oool700000?T0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0C
0?ooo`060000003oool0oooo0?ooo`000000oooo0P00003f0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0503oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool0l03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo001L
0?ooo`8000005`3oool2000000D0oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`0J
0?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool05P3oool2000000H0oooo00<000000?oo
o`3oool0k03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo001L0?ooo`03
0000003oool0oooo01L0oooo2@00003[0?ooo`800000803oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`000000
0000j03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000>H0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo
0?ooo`0J0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`3Q0?ooo`80
0000903oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0K0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0240oooo001L0?ooo`800000703oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0=d0oooo00<000000?ooo`3oool08`3oool3000002<0oooo001L0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`0000001`3oool200000=/0oooo0P00000X0?ooo`030000
003oool0oooo0240oooo00110?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@00000
07Boo`030?ooo`060;md00000000000000000000B9`0gooo1`3oool00`000000oooo0?ooo`0M0?oo
o`8000002@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool08@3oool00400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd
0000001d_ol0103oool00`3ogi`0B00007Boo`090?ooo`030000003oool0oooo01h0oooo3000003G
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool08@3oool00400oooo00<0_g@00018
W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`030?oOW0180000M;oo00T0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`070?ooo`<00000d`3oool2000002`0oooo00<000000?oo
o`3oool08@3oool003l0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`080?ooo`03
0?oOW0180000M;oo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo00000=40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Q0?oo
o`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00P0oooo00<0omnL04P0001d
_ol02@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo0000003?0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool08@3oool003l0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`080?ooo`030?oOW0180000M;oo00T0
oooo0`00000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool200000</0
oooo0P00000^0?ooo`<000008`3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`080?ooo`030?oOW0180000M;oo00T0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0a`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol0203oool00`3ogi`0B00007Boo`090?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<D0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`03
0?ooo`030=nLB00007@0_ooo00P0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool200000<<0oooo0P00000d
0?ooo`030000003oool0oooo0240oooo00100?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d
_`3oool0203oool00`3ogi`0B00007Boo`090?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;l0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M00007Boo`3oool0okmd
0000M02oool01`3oool01@3ooml0W4P0000000000000M;oo00T0oooo00<000000?ooo`3oool09@3o
ool01@000000oooo0?ooo`3oool0000000/0oooo0P00002m0?ooo`800000=`3oool00`000000oooo
0?ooo`0Q0?ooo`00@@3oool01@3ookl0M0000000000007@0_ooo00X0oooo00<0okmd0000001d_ol0
2@3oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000d0oooo0P00002i0?ooo`80
0000>@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool2000002P0oooo00<000000?ooo`000000
3`3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03L0oooo0`00000S0?ooo`00G03o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool000000100oooo0P00002c0?ooo`800000?03o
ool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0X0?ooo`8000004P3oool0
0`000000oooo0?ooo`2^0?ooo`800000?P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`00
0000oooo0?ooo`0Y0?oool@00000@03oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0180oooo0P00002Y0?ooo`800000@@3oool00`000000
oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0Y03oool2000000030?ooo`000000oooo0400oooo00<000000?ooo`3oool0
8@3oool005`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0D0?ooo`800000XP3o
ool2000000<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01D0oooo0P00002N0?ooo`8000001@3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000;P3oool00`00
0000oooo0?ooo`0F0?ooo`800000VP3oool2000000L0oooo00<000000?ooo`3oool0?@3oool30000
02<0oooo001L0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool2000009H0
oooo0P0000090?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool005`0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0I0?ooo`800000TP3oool2000000/0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo01X0oooo0P00002?0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo01/0oooo0P00002;0?ooo`8000003P3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0703oool2000008L0oooo0P00000@0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool08@3oool005`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0M0?ooo`80
0000P`3oool200000180oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool2000003<0oooo00<000000?ooo`3oool07`3oool2000007l0oooo0P00000D0?ooo`030000
003oool0oooo03d0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0200oooo0P00001k0?ooo`8000005P3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool3
000007D0oooo0`00000H0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool0
05`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0S0?ooo`800000L03oool30000
01/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo02@0oooo0P00001[0?ooo`<000007P3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool09P3oool3000006D0oooo0`00000Q0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0X0?ooo`800000H03oool3000002@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0Q0?ooo`00G03oool2000003T0oooo00<000000?ooo`3oool0:@3oool3000005X0oooo0`00000W
0?ooo`030000003oool0oooo03d0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo02/0oooo1000001D0?ooo`800000:P3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo0240oooo00110?ooo`050?oOW018000000000000M02oool00`3oool01@3o
_g@0000007Boo`3oool0_g@000H0000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo02h0oooo1000001=0?ooo`<00000;03oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0240oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;oo
o`020?ooo`030?noM0000000M;oo0080oooo00<0gia80000000000000`0000000`00B9`0gooo0?oo
o`050?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0<P3oool5000004<0oooo1@00
000_0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool00400oooo00<0_g@0
0018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030=nLB018W=l0oooo0080oooo00<0giad
09cOo`3oool01@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03H0oooo1P00000g
0?ooo`H00000=03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo000o0?oo
o`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool00`3OW4P0M;oo0?ooo`090?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0>`3oool6000002/0oooo1P00000j0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`090?ooo`030;mdB02Lgol0oooo00P0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`100?ooo`D000008@3oool500000400oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?no
M00004P0W=oo00T0oooo00<0oooO09a8M02oool0203oool3000003h0oooo00<000000?ooo`3oool0
A03ooolQ000004D0oooo00<000000?ooo`3oool0?@3oool3000002<0oooo000o0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3o_g@007Bo0?ooo`070?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool0
0`3ookl0M01809cOo`070?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO
00<0oooo00<0gia80000M02oool02P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0240oooo000/0?ooo`030;mdM02oool0oooo00@0oooo00<0_gAd0;ooo`3oool02P3oool00`3OW4P0
04RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oknL09cOo`3oool00P3oool00`3ogi`0
B00004RLg`070?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;md0018W=l0oooo00<0oooo
00<0gia80000M02oool02`3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool01P3oool0203o
oml0W4Q809cOo`3oool0oono07@0000007@0_ooo1`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00;03o
ool02@2oM00000000000M02oool0oooO09a80018W=l0gibL0;ooo`0<0?ooo`050?oo_`1d00000000
0000M02oool0203oool01P3ooml0W4P0000000000000001d0;ooo`P0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
8@3oool002`0oooo00H0_ibL0=oOW018000000000000B02LgolZ0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240
oooo000/0?ooo`030;mdM02ogi`0B0000080000000@0001809cOo`3OW9`0_ooo9`3oool2000004D0
oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0m0?ooo`<000008`3oool002`0oooo
00<0_g@00018W03Oool00P3oool0102oM00000000000M02ooolW0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240
oooo000/0?ooo`030;mdB02Lgol0oooo00<0oooo00<0okmd0000M02oool09`3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0Q0?ooo`00;03oool00`2oW9`0gooo0?ooo`040?ooo`030=nLW02oool0oooo02H0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2Q
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool00340oooo00<0_ibL0=oo
o`3oool00P3oool00`3OW9`0_ooo0?ooo`0S0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0X03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo000]0?ooo`05
0?oo_`1d04P0W=oo0?oo_`1d0000100000000`0007@0_ooo0?ooo`0S0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0240oooo000f0?ooo`030=nLW02oool0oooo02<0oooo0P00001;0?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool0?@3oool3000002<0oooo001L0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo
001L0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0240oooo000c0?ooo`030;mdM02oool0oooo02H0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool08@3oool003<0oooo00<0_gAd0;ooo`3oool09P3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?oo
o`00<`3oool00`2oM7@0_ooo0?ooo`0V0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0VP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo000`0?ooo`030;md
00000000000000<0000000<0001d0;ooo`3oool08`3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00<`3o
ool00`2oM7@0_ooo0?ooo`0V0?ooo`800000D03oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo03d0oooo0`00000S0?ooo`00<`3oool00`2oM7@0_ooo0?ooo`0V0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo0240oooo000c0?ooo`030;mdM02oool0oooo02H0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool005`0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool08@3oool002h0oooo00<0oooO09adW03Oool01@3oool00`3OW9`0_ooo
0?ooo`0S0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0UP3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo0240oooo000^0?ooo`030?noM0000000000000D0000000<0
001d0;ooo`3oool08`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00=P3oool00`3OW9`0_ooo0?ooo`0S
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000EP3oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo03d0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo
00H0okmd0000001d_ol0oooo0?oo_`1d00030000000307Boo`3oool0oooo00L0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool08@3oool00400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00L0okmd
0000001d_ol0oooo0?oOW0180000B9cO0080oooo00<0_g@004RLg`3oool01`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0Q0?ooo`00@03oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00X0oooo00<0
oono07@0B02Lgol01`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`03
0?ooo`030=nLB00007@0_ooo00X0oooo00<0oono07@0001d_ol01`3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q
0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo00<0okmd0000
001d_ol01`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo00T0oooo00@0omnL04P0000004P0W=oo1`3oool3000005/0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0m0?ooo`<000008`3oool003l0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`070?ooo`050?noM000000000000000B02Lgol0203oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0
oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ookl0M000
04RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0_g@004RLg`3oool01`3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0Q0?ooo`00@03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0
oooO09bL_`3oool00P3oool00`3OW4P0001d0;ooo`070?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo0010
0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`070?ooo`060?noM018W=l0oooo0?oo_`1d
000007Bo203oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo08T0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3ookl0M0000000000007@0_ooo
00T0oooo00D0gia8000000000000001d0;ooo`080?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?oo
o`800000HP3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo03d0oooo0`00000S0?oo
o`00G03oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03o
ool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo08@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0880
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool2000006P0oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0m0?ooo`<000008`3oool005`0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`20
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?oo
o`3oool0J@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool08@3oool005`0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0
J`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
8@3oool005`0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1m0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool08@3oool005`0oooo0P00001]0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool0?@3oool3000002<0oooo001L0?ooo`030000003oool0oooo
06d0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo06l0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo
001L0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0700oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?oo
o`030000003oool0oooo0740oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000
L`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03d0oooo0`00000S0?ooo`00G03o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0
okmd0000001d_ol01@3oool0103ooml0W4P00018W03Oool70?ooo`030000003oool0oooo07@0oooo
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo
00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM0000000M;oo00D0
oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo00T0oooo00@0oooO09a80000B9`0gooo1`3oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00D0
oooo00<0_g@00000000000001@0000000`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240
oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool0203ogi`0M9cO
0?ooo`3oool0oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0gia807Boo`3oool0oooO09a80000
B9`0gooo00L0oooo0`00001h0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0?@3o
ool3000002<0oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool0
1`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool01`3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00?`3o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00H0omnL04Qd_`3ooml0W4P0
0018W03Oool70?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0K`3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo
00<0gia80000M02oool0203oool01@3OW4P0M;oO09a80000B9`0gooo00L0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool08@3oool00400oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`050?oo
g`2LB4P0B4P00018W03Oool01`3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo06d0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M000
07Boo`3oool0okmd0000M02oool02P3oool0103ogi`0B0000018W03Oool70?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo0240oooo00110?ooo`050?oo_`1d000000000000M02oool0303oool00`3OW4P004RL0=ooo`07
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000OP3oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo03d0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool0
0`000000oooo0?ooo`200?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000
oooo0?ooo`220?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0Q0?ooo`00G03oool2000008@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`0m0?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool005`0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1R0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool08@3oool005`0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`1Q0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3o
ool005`0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool08@3oool005`0oooo0P00002;0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0?@3oool3000002<0oooo001L0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240
oooo001L0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0G03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0240oooo001L0?ooo`800000T03oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo03d0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool0
1@3ogi`0B0000000000007@0_ooo00<0oooo00H0okmd0000001d_ol0oooo0?oog`2LB00300000003
07Boo`3oool0oooo00L0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool00400oooo00L0oono07@0001d_ol0
oooo0?noM00007@0_ooo0080oooo00L0okmd0000001d_ol0oooo0?oog`2LB7@0_ooo0080oooo00<0
_g@007Boo`3oool01`3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`2oM00004RL0=ooo`02
0?ooo`030;md0000M;l0oooo00X0oooo00<0oooO09a8M02oool01`3oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q
0?ooo`00?`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00/0oooo00<0_g@007Bo
o`3oool01P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo00X0oooo00<0oooO09a80018W=l01`3oool00`000000oooo0?ooo`2D0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00
?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo00<0gia80000001d_ol0
1`3oool3000000@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool00`3oool3000002<0oooo000o0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3Ogml0oooo0?oo_`1d000000000000M02o
ool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oO
W0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01P3OW4P00000000000000000001809cO
o`P0ooooo`00000b000002<0oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02o
ool01P3oool0103ookl0M00000000018W=oo0?oooel0oooo00100?ooo`030=nLB000B9`0gooo0080
oooo00<0_g@0001d_`3oool01`3oool00`2oM000M;oo0?ooo`3o0?oooel0oooo00100?ooo`070?oo
_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`080?ooo`060?oOW018000000000000000004P0W=ooo`3o
oomL0?ooo`00@@3oool01@3ookl0M0000000000007@0_ooo00X0oooo00D0_g@00000000000000000
04RLg`3o0?oooe`0oooo003o0?oook40oooo003o0?oook40oooo003o0?ooobD0oooo00<0oooO09a8
B02Lgol09`3oool00`3ogi`0B4RL0=ooo`1O0?ooo`00o`3ooolU0?ooo`030;mdB02Lgol0oooo02P0
oooo00<0omnL04Qd_`3oool0GP3oool00?l0oooo903oool00`3OW4P0B9cO0?ooo`0Z0?ooo`030=nL
B018W=l0oooo05d0oooo003o0?ooob<0oooo00<0oono07@0M02oool0:`3oool00`3ookl0M01809cO
o`1M0?ooo`00R@3oool00`3ogi`0B00000000002000000030000M02oool0oooo00<0oooo00D0gia8
000000000000000007Boo`030?ooo`060?oog`2LB00000000000000004P0W=oo1@3oool00`3ogi`0
M9cO0?ooo`020?ooo`030=nLM02Lgol0oooo00@0oooo00D0_g@0000000000000001d0;ooo`020?oo
o`060?oog`2LB00000000000000004P0W=oo1`3oool00`2oM00000000000000200000003001d_`3o
ool0oooo00<0oooo00L0gia8000000000000001d0;ooo`3oool0gia800<0000000P0M;oo0?ooo`3o
ool0oooo0?oOW0180000000004RLg`@0oooo00<0omnL04P0000000000P000000101d_ol0oooo0?oo
o`3OW4P30000000407Boo`3oool0oooo0;md0080000000L0001809cOo`3oool0oooO09a8000007@0
_ooo00L0oooo00D0omnL04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00<0oooo00D0
gia8000000000000000004RLg`070?ooo`030=nLB000B9`0gooo00@0oooo00H0_g@0000000000000
00000018W03OoolF0?ooo`050;md0000000007Bo0?ooo`3OW4P00P0000001`00B9`0gooo0?ooo`3o
ool0oooO09a80018W=l01@3oool01@2oM0000000001d_`3oool0gia80080000000<004RL0=ooo`3o
ool0CP3oool008P0oooo00@0gia800000000B9`0gooo0P3oool00`3ookl0M01809cOo`020?ooo`07
0=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B000
07Boo`040?ooo`070;md000007@0_ooo0?ooo`3ookl0M000001d_`040?ooo`0?0;md0000000007Bo
0?ooo`3ogi`0B01d0;ooo`3oool0_g@00018W03Oool0oooo0?oOW0180000M;oo00L0oooo00@0oooO
09a80000B9`0gooo1`3oool02`3OW4P0001d0;ooo`3oool0gia800000018W=l0oooo0?oog`2LB000
B9cO0080oooo00D0gia80000M02oool0gkno0=ooo`040?ooo`030?oog`2LB00007Bo00<0oooo00L0
gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00<0gia80000M02oool00P3oool0103ooml0
W4P00000M02oool60?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM000
0000M;oo0080oooo00L0gia80000001d_ol0oooo0?oog`2LB000B9cO00H0oooo00<0_g@0001d_`3o
ool01@3oool00`3ogi`0B00007Boo`0H0?ooo`080?oog`2LB7@0_ooo0?ooo`3ooml0W4P00018W03O
ool40?ooo`030=nLB000B9`0gooo00@0oooo00P0oooO09a8M02oool0oooo0?oog`2LB00004RL0=oo
oe00oooo00270?ooo`030?noM000000007Bo00D0oooo00H0oooO09a8M02oool0omnL04P00000M;l3
0?ooo`070?noM00007@0_ooo0?ooo`2oM00004RL0=ooo`020?ooo`030?noM00007@0_ooo0080oooo
00T0omnL04P00018M7@0M9cO0?ooo`3o_g@0001804Q8B02Lgol00P3oool00`3ogi`0B00004RLg`03
0?ooo`060?oOW01dW=l0oooo0;md0000B9`0gooo0P3oool00`3o_g@0001d0;ooo`060?ooo`030?oo
g`2LB00007Bo00P0oooo00H0gia80000M02oool0omnL04P00000M;l30?ooo`070?noM00007@0_ooo
0?ooo`3OW4P004RL0=ooo`060?ooo`030?oog`2LB00007Bo0080oooo00<0omnL04P00000M;l00`3o
ool01`3o_g@0001d0;ooo`3oool0gia80000M02oool0303oool00`2oM00004RL0=ooo`020?ooo`03
0;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL0=ooo`040?ooo`03
0?oo_`1d0000B9cO00H0oooo00<0omnL04P0001d_ol06@3oool01P3ookl0M4RL0=ooo`2oM000001d
0;ooo`D0oooo00<0gia80000M02oool01@3oool01P3ookl0M4RL0=ooo`2oM000001d0;oooe40oooo
00260?ooo`040?oog`2LB000001d0;ooo`P0oooo00<0okmd0000001d_ol00`3oool01`3o_g@00000
07Boo`3oool0_g@00018W03Oool00P3oool00`3ogi`0B00007Boo`020?ooo`090=nLB00007@0_ooo
0;mdM02ooml0W4P0001d_`3ogi`0M9cO0080oooo00<0okmd0000B02Lgol01P3oool00`2oM00004RL
0=ooo`020?ooo`030?oOW0180000M;oo00H0oooo00<0oooO09a80000M;l0203oool01P3OW4P0001d
0;ooo`3o_g@0000007Boo`<0oooo00L0okmd0000001d_ol0oooo0=nLB000B9`0gooo00H0oooo00<0
oooO09a80000M;l00P3oool00`3o_g@0000007Boo`030?ooo`070?noM0000000M;oo0?ooo`3OW4P0
001d0;ooo`0;0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM000
07Bo0?ooo`020?ooo`030;md0000B9`0gooo00@0oooo00<0oono07@0001d_ol01P3oool00`3ogi`0
B00007Boo`0J0?ooo`040?oOW01dB4P0000007Boo`H0oooo00<0okmd0000M02oool01P3oool0103o
gi`0M4Q80000001d_omB0?ooo`00QP3oool0103ogi`0B0000018W03Oool80?ooo`030?noM0000000
M;oo00<0oooo00L0okmd0000001d_ol0oooo0;md0000B9`0gooo0080oooo01<0omnL04P0001d_ol0
oooo0?oo_`1d0000B9cO0?ooo`3ogi`0M7Ad04P0B02Lgol0oooo0;mdM02oool0oooo0?noM00007@0
_ooo00H0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00007Boo`060?ooo`030?oog`2LB000
07Bo00P0oooo00H0gia80000M02oool0okmd0000001d_ol30?ooo`070?noM0000000M;oo0?ooo`3O
W4P004RL0=ooo`060?ooo`030?oog`2LB00007Bo0080oooo00<0okmd0000001d_ol00`3oool01`3o
_g@0000007Boo`3oool0gia80000M02oool02`3oool00`3ogi`0B00007Boo`030?ooo`030?noM000
04P0W=oo00H0oooo00L0omnL04P0M02oool0oooo0;md00000000M;oo00D0oooo00<0oono07@0001d
_ol01P3oool00`3ogi`0B00007Boo`080?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3o
ool01@3oool00`3ookl0M00004RLg`070?ooo`030?noM00004P0W=oo00H0oooo00<0oono07@00018
W=l0D`3oool008H0oooo00<0okmd00000000M;l02@3oool00`3ookl0M00007Boo`030?ooo`070;md
000004P0W=oo0?ooo`2oM00004RL0=ooo`020?ooo`0;0?noM00004P0W=oo0?ooo`3OW4P0001809cO
o`3oool0oooO09a80000M;l00P3oool01@3o_g@0B9cO0?ooo`3ogi`0B00000D0000000D0B9cO0?oo
o`2oM00004RL0=ooo`020?ooo`030?noM00004P0W=oo00H0oooo00<0oooO09a80000000010000000
2P1d_ol0oooo0?ooo`3oool0gia80000M02oool0oono07@0001d_ol30?ooo`070;md000004P0W=oo
0?ooo`3OW4P004RL0=ooo`060?ooo`030?oog`2LB00007Bo0080oooo00<0oono07@0001d_ol00`3o
ool01`2oM000001809cOo`3oool0gia80000B02Lgol02`3oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo00L0oooo00D0oono07A8B0180000000004RLg`060?ooo`030?oo_`1d0000M;oo
00H0oooo00<0omnL04P0001d_ol06@3oool01@3ooml0W4P00018W02LM4P0W=oo00H0oooo00<0okmd
0000M02oool01@3oool01@3ooml0W4P00018W02LM4P0W=oo0580oooo00260?ooo`030?noM0000000
07Bo00X0oooo00L0gia80018W03Oool0oooo0?noM000000007Bo0080oooo00/0_g@000000000B9`0
gooo0?oo_`1d000004RL0=ooo`3ookl0M000001d_`020?ooo`030?oOW0180000M;oo0080oooo00H0
oooO09a8M02oool0oooo0;md0018W=l20?ooo`0<0=nLB00004P0W=oo0?ooo`2oM00000000018W03O
ool0oono07@00000B9`0gooo1P3oool00`3ooml0W4P0001d_`020?ooo`040?oog`2LB000000004RL
g`80oooo00/0gia80000M02oool0oooo0=nLB000B9`0gooo0?ooo`3o_g@00000001d_`020?ooo`03
0=nLB000B9`0gooo00H0oooo00<0oooO09a80000M;l00`3oool04P3OW4P004RL0=ooo`3oool0okmd
00000000M;l0oooO09a800000000001804QdW03O_g@0001d0;oog`2LB000001d0;ooo`D0oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`040?oOW01800000000001d_`L0oooo
00<0oono07@00018W=l01P3oool00`3ogi`0B00007Boo`0I0?ooo`060;md000004P0W=oo0?oog`2L
B7@0_ooo1@3oool00`3OW4P0001d0;ooo`050?ooo`060;md000004P0W=oo0?oog`2LB7@0_oooD@3o
ool008H0oooo00@0omnL04P00000B9`0gooo2P3oool01@3o_g@00000000000000000B9cO00<0oooo
00T0_g@00018W03Ogi`0B00000000000B9`0gooo0?oog`2LB0000P0000000`18W=l0okmd00000002
0000000804RLg`3oool0_g@000000000B9`0gooo0?ooo`3OW4P20000000;0000B02Lgol0oooo0?oo
o`2oM00004RL0=oOW018000000000018W03Oool01`3oool00`3ooml0W4P0001d_`030?ooo`080?oo
_`1d0000001d0;ooo`3oool0gia80000M02oool20?ooo`050?noM0000000000000000018W=l00P3o
ool01P2oM000000000000000000004RL0=ooo`<0oooo00<0okmd0000000000000P0000001000B9`0
gooo0?ooo`3o_g@30000000=04RLg`3oool0oooo0?ooo`2oM000001d0;oOW0180000001d0;oog`2L
B000001d0;ooo`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01P3o
gi`0B0000000M02oool0okmd001d_`H0oooo00<0oooO09a80018W=l01P3oool00`3ogi`0B00007Bo
o`0G0?ooo`090?oog`2LB000000000000000M;l0okmd0000000007@0_ooo00@0oooo00<0gia80018
W03Oool00`3oool02@3ooml0W4P000000000000007Bo0?noM0000000001d0;ooo`1@0?ooo`00QP3o
ool0103ooml0W4P00000B02Lgol50?ooo`030?oog`2LM9`0gooo00X0oooo00<0_g@00018W03Oool0
6`3oool00`2oM00004RL0=ooo`0;0?ooo`030?oog`2LB00007Bo00<0oooo00P0oooO09a8000004P0
W=oo0?ooo`3OW4P0001d0;ooo`X0oooo00<0_g@00018W03Oool01P3oool00`3ooml0W4P0001d_`0J
0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM000001d0;ooo`02
0?ooo`030;md0018W=l0oooo00D0oooo00<0gia80018W03Oool01@3oool00`3ogi`0B00007Boo`0S
0?ooo`030?oog`2LB000B9cO05d0oooo00270?ooo`030?oOW018000007Bo00D0oooo00<0okmd0018
W03Oool02P3oool00`2oM00004RL0=ooo`0K0?ooo`030;md0000B9`0gooo00/0oooo00<0oooO09a8
0000M;l00`3oool0203ogi`0B0000000M02oool0oooo0=nLB00007@0_ooo2P3oool00`3ookl0M4RL
0=ooo`070?ooo`030;md0000M;l0oooo01X0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo
0?ooo`060?ooo`030;md0000B9`0gooo0080oooo00<0gia8001d_`3oool01@3oool00`3ookl0M018
09cOo`050?ooo`030?oOW0180000M;oo02<0oooo00<0oono07@0B02Lgol0G@3oool008P0oooo00<0
okmd00000000M;l00`3oool00`3OW4P00000001d_`0;0?ooo`030;md0000B9`0gooo01/0oooo00<0
_g@00018W03Oool02`3oool00`3ooml0W4P0001d_`020?ooo`040?oo_`1d0000000004RLg`80oooo
00<0gia80000M02oool02P3oool00`3ooml0W7BL0=ooo`070?ooo`030=nLB000M;l0oooo01X0oooo
00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00L0oooo00L0okmd0000001d_ol0oooo0?oo_`1d
0000M;oo00L0oooo00<0gia804RLg`3oool00P3oool01@3ooml0W4P0000000000000M;oo02<0oooo
00<0gia804RLg`3oool0G@3oool008T0oooo00<0oooO09a8000000000P0000000`18W=l0oono07Ad
_`090?ooo`050?oo_`1d000000000018W03Oool06@3oool01@3ookl0M00000000000B9`0gooo00X0
oooo00<0_g@000000000000010000000200004P0W=oo0?ooo`3ooml0W4P00000000007@0_ooo503o
ool01`3ookl0M01d0;ooo`3ooml0W4P00018W03Oool05`3oool01@3ookl0M0000000000007@0_ooo
00T0oooo00D0okmd000000000000000004RLg`090?ooo`030;md0018W=l0oooo00<0oooo00<0okmd
0000001d_ol08P3oool00`3o_g@007Bo0?ooo`1N0?ooo`00V`3oool0103ooml0W4P00018W03OoolJ
0?ooo`040?oog`2LB00004RL0=oooaH0oooo00<0_g@00000M02oool05@3oool01@3ookl0M0000000
000004P0W=oo03D0oooo00<0giad09cOo`3oool09P3oool00`3ookl0M7Bo0?ooo`1O0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.344423, -0.152779, \
0.00518628, 0.00414198}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Approach to stable population for 1<\[Mu]<3"], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(logisticCobweb[1.5, 0.1, 20, 0];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.961281 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -9.5 -15.6875 ]
[.21429 -0.0125 9.5 0 ]
[.40476 -0.0125 -9.5 -15.6875 ]
[.40476 -0.0125 9.5 0 ]
[.59524 -0.0125 -9.5 -15.6875 ]
[.59524 -0.0125 9.5 0 ]
[.78571 -0.0125 -9.5 -15.6875 ]
[.78571 -0.0125 9.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .01472 -10 -7.84375 ]
[-0.0125 .01472 0 7.84375 ]
[-0.0125 .11084 -19 -7.84375 ]
[-0.0125 .11084 0 7.84375 ]
[-0.0125 .20697 -19 -7.84375 ]
[-0.0125 .20697 0 7.84375 ]
[-0.0125 .3031 -19 -7.84375 ]
[-0.0125 .3031 0 7.84375 ]
[-0.0125 .39923 -19 -7.84375 ]
[-0.0125 .39923 0 7.84375 ]
[-0.0125 .49536 -19 -7.84375 ]
[-0.0125 .49536 0 7.84375 ]
[-0.0125 .59148 -19 -7.84375 ]
[-0.0125 .59148 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -11.4063 ]
[-0.01875 .30902 -19 11.4063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74.9688 0 ]
[.5 .63053 74.9688 15.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .11084 m
.00625 .11084 L
s
gsave
-0.0125 .11084 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .20697 m
.00625 .20697 L
s
gsave
-0.0125 .20697 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .3031 m
.00625 .3031 L
s
gsave
-0.0125 .3031 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .39923 m
.00625 .39923 L
s
gsave
-0.0125 .39923 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .49536 m
.00625 .49536 L
s
gsave
-0.0125 .49536 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .59148 m
.00625 .59148 L
s
gsave
-0.0125 .59148 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03394 m
.00375 .03394 L
s
0 .05317 m
.00375 .05317 L
s
0 .07239 m
.00375 .07239 L
s
0 .09162 m
.00375 .09162 L
s
0 .13007 m
.00375 .13007 L
s
0 .14929 m
.00375 .14929 L
s
0 .16852 m
.00375 .16852 L
s
0 .18775 m
.00375 .18775 L
s
0 .2262 m
.00375 .2262 L
s
0 .24542 m
.00375 .24542 L
s
0 .26465 m
.00375 .26465 L
s
0 .28387 m
.00375 .28387 L
s
0 .32232 m
.00375 .32232 L
s
0 .34155 m
.00375 .34155 L
s
0 .36078 m
.00375 .36078 L
s
0 .38 m
.00375 .38 L
s
0 .41845 m
.00375 .41845 L
s
0 .43768 m
.00375 .43768 L
s
0 .4569 m
.00375 .4569 L
s
0 .47613 m
.00375 .47613 L
s
0 .51458 m
.00375 .51458 L
s
0 .53381 m
.00375 .53381 L
s
0 .55303 m
.00375 .55303 L
s
0 .57226 m
.00375 .57226 L
s
0 .61071 m
.00375 .61071 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11084 m
1 .11084 L
s
.99375 .20697 m
1 .20697 L
s
.99375 .3031 m
1 .3031 L
s
.99375 .39923 m
1 .39923 L
s
.99375 .49536 m
1 .49536 L
s
.99375 .59148 m
1 .59148 L
s
.125 Mabswid
.99625 .03394 m
1 .03394 L
s
.99625 .05317 m
1 .05317 L
s
.99625 .07239 m
1 .07239 L
s
.99625 .09162 m
1 .09162 L
s
.99625 .13007 m
1 .13007 L
s
.99625 .14929 m
1 .14929 L
s
.99625 .16852 m
1 .16852 L
s
.99625 .18775 m
1 .18775 L
s
.99625 .2262 m
1 .2262 L
s
.99625 .24542 m
1 .24542 L
s
.99625 .26465 m
1 .26465 L
s
.99625 .28387 m
1 .28387 L
s
.99625 .32232 m
1 .32232 L
s
.99625 .34155 m
1 .34155 L
s
.99625 .36078 m
1 .36078 L
s
.99625 .38 m
1 .38 L
s
.99625 .41845 m
1 .41845 L
s
.99625 .43768 m
1 .43768 L
s
.99625 .4569 m
1 .4569 L
s
.99625 .47613 m
1 .47613 L
s
.99625 .51458 m
1 .51458 L
s
.99625 .53381 m
1 .53381 L
s
.99625 .55303 m
1 .55303 L
s
.99625 .57226 m
1 .57226 L
s
.99625 .61071 m
1 .61071 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cobweb) show
105.875 15.813 moveto
(Plot) show
128.188 15.813 moveto
(for) show
142.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
148.375 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.375 15.813 moveto
(H) show
170.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
179.188 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
189.875 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
196.000 15.813 moveto
(L) show
202.813 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
208.938 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .05371 L
.10458 .09624 L
.14415 .13618 L
.18221 .17459 L
.22272 .21548 L
.26171 .25484 L
.30316 .29667 L
.34309 .33697 L
.3815 .37575 L
.42237 .417 L
.46172 .45671 L
.49955 .4949 L
.53984 .53557 L
.57861 .5747 L
.61984 .61631 L
s
.61984 .61631 m
.62154 .61803 L
s
.02381 .01472 m
.06244 .07084 L
.10458 .12663 L
.14415 .17389 L
.18221 .21465 L
.22272 .25297 L
.26171 .28493 L
.30316 .3136 L
.34309 .33605 L
.3815 .35287 L
.40095 .3596 L
.42237 .36561 L
.44268 .36997 L
.45178 .3715 L
.46172 .37287 L
.4671 .37347 L
.4721 .37396 L
.47727 .37437 L
.48196 .37468 L
.48658 .37491 L
.4887 .37499 L
.49093 .37506 L
.49332 .37512 L
.49438 .37515 L
.49552 .37516 L
.49675 .37518 L
.49789 .37519 L
.49859 .37519 L
.49925 .37519 L
.50049 .37519 L
.50163 .37519 L
.50286 .37518 L
.50401 .37517 L
.50508 .37515 L
.50754 .3751 L
.51014 .37503 L
.51268 .37494 L
.51504 .37484 L
.5204 .37453 L
.5293 .37383 L
.53882 .3728 L
.54906 .37137 L
.56016 .36944 L
.58032 .36494 L
.60019 .35924 L
.62123 .35183 L
.65912 .33494 L
.69946 .31195 L
.73829 .28493 L
.77956 .25095 L
Mistroke
.81932 .2131 L
.85757 .17194 L
.89827 .12304 L
.93745 .07099 L
.97619 .01472 L
Mfstroke
.11905 .11084 m
.11905 .14449 L
.15238 .14449 L
s
.15238 .14449 m
.15238 .1831 L
.19063 .1831 L
s
.19063 .1831 m
.19063 .22304 L
.23021 .22304 L
s
.23021 .22304 m
.23021 .25949 L
.26631 .25949 L
s
.26631 .25949 m
.26631 .28838 L
.29494 .28838 L
s
.29494 .28838 m
.29494 .30835 L
.31473 .30835 L
s
.31473 .30835 m
.31473 .32063 L
.32689 .32063 L
s
.32689 .32063 m
.32689 .32756 L
.33375 .32756 L
s
.33375 .32756 m
.33375 .33126 L
.33742 .33126 L
s
.33742 .33126 m
.33742 .33318 L
.33932 .33318 L
s
.33932 .33318 m
.33932 .33415 L
.34029 .33415 L
s
.34029 .33415 m
.34029 .33465 L
.34078 .33465 L
s
.34078 .33465 m
.34078 .33489 L
.34102 .33489 L
s
.34102 .33489 m
.34102 .33502 L
.34115 .33502 L
s
.34115 .33502 m
.34115 .33508 L
.34121 .33508 L
s
.34121 .33508 m
.34121 .33511 L
.34124 .33511 L
s
.34124 .33511 m
.34124 .33513 L
.34125 .33513 L
s
.34125 .33513 m
.34125 .33513 L
.34126 .33513 L
s
.34126 .33513 m
.34126 .33514 L
.34127 .33514 L
s
.34127 .33514 m
.34127 .33514 L
.34127 .33514 L
s
.34127 .33514 m
.34127 .33514 L
.34127 .33514 L
s
.03 w
.11905 .11084 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00m@3oool01@3ooml0W4P00000
0000B9`0gooo0;H0oooo003f0?ooo`030?oOW01804P0W=oo0;L0oooo003]0?ooo`050;md00000000
07Bo0?ooo`3OW4P00P0000001@00B9`0gooo0?oOW01804P0W=oo0;L0oooo003]0?ooo`0<0?oog`2L
B7@0_ooo0?ooo`3ooml0W4P00018W03Oool0oooo0?oOW01804P0W=oo]`3oool00>h0oooo00/0oono
07A8W03Oool0_g@00000M02oool0oooo0?oo_`1d0000001809cOo`2g0?ooo`00k`3oool0103ogi`0
M4Q80000001d_ol30?ooo`030?oOW01804P0W=oo0;L0oooo003_0?ooo`030?oo_`1d0000B9cO0;h0
oooo003^0?ooo`050?oog`2LB00004RL09adB02Lgol0_@3oool00>h0oooo00H0_g@00000B02Lgol0
oooO09a8M02oool20?ooo`030?oo_`1d0000M;oo0;L0oooo003/0?ooo`090?oog`2LB00000000000
0000M;l0okmd0000000007@0_ooo0;/0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001Q0?ooo`050?oOW01800000000
0000M02oool0;P3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00D0okmd0000001d_ol0oooo
0;md00060000000304RLg`3oool0oooo02@0oooo00D0omnL04P000000000001d0;ooo`030?ooo`03
0?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo9@3oool01@3ogi`0B0000000000007@0
_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3ogi`0B000000000000000M;oo02L0oooo00D0
omnL04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00<0oooo00D0gia8000000000000
000004RLg`0^0?ooo`060;md00000000000000000000B9`0gooo:03oool00600oooo00L0oono07@0
001d_ol0oooo0?noM00007@0_ooo02`0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080
oooo00<0okmd0000001d_ol00P3oool00`3OW4P0000000000003000000030018W03Oool0oooo02<0
oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol01@3oool0
103ooml0W4P00018W03OoolT0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`03
0?noM0000000M;oo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000M;oo02D0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool01`3OW4P00000
07Boo`3oool0oooO09a80018W=l0;P3oool00`3ogi`0B00007Boo`0Z0?ooo`00H03oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo02/0oooo00<0_g@00018W03Oool00P3oool00`2oM000
07Bo0?ooo`070?ooo`030=nLB018W=l0oooo0080oooo00<0giad09cOo`3oool08`3oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo00T0oooo00@0oooO09a80000B9`0gooo903oool00`2o
M00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o
_g@004RL0=ooo`0T0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3o
oml0W4P0001d_`030?ooo`030?noM000B9`0gooo02d0oooo00<0omnL04P0001d_ol0:P3oool005l0
oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0Z0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool0203oool00`3OW4P0M;oo0?ooo`0V0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool01@3oool00`2oM0000000000000050000000307Boo`3oool0oooo0200
oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol08`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0
oooo00<0_g@0001d_`3oool00P3oool00`2oM00004RL0=ooo`0]0?ooo`030?oOW0180000M;oo02X0
oooo001O0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0:P3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0_gA809cOo`3oool09@3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL
0=ooob<0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol08`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00H0oooo00L0omnL04P0M02oool0oooo0;md00000000M;oo02h0oooo00<0omnL04P0001d_ol0
:P3oool005l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol02@3oool00`3ooml0W4Qd0;ooo`0U0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03O
ool08`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d
_ol00`3oool00`2oM000001809cOo`0S0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool01@3ookl0M4Q804P000000000B9cO02l0oooo00<0omnL04P0001d_ol0:P3oool005l0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol02P3oool00`3o_g@007Bo0?ooo`0T0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool08`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0oono07@000000000B9cO0?oo
o`3o_g@00000001d_b@0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`04
0?oOW01800000000001d_c00oooo00<0omnL04P0001d_ol0:P3oool005l0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol02P3oool00`3ookl0M01809cOo`0T0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool01P3ogi`0B7Bo0?oog`2LB00004RL0=ooob<0oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`060?ooo`030;md0000B9`0_ia80080000000<004RL0=ooo`3oool08`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0omnL04P0000007@0_ooo0?no
M000M;l_0?ooo`030?oOW0180000M;oo02X0oooo001O0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool0:P3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0
oono07@00018W=l0903oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00P0oooo00D0
gia807Bog`2LB00004RL0=ooo`0S0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1P3oool00`3ogi`0B00007Boo`0X0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1P3oool00`2oM000001d0;ooo`020?ooo`030;md0018W=l0oooo02d0oooo00<0omnL04P0001d_ol0
:P3oool00600oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`0[0?ooo`030=nLB000
B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW018
0000B9cO02D0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`050?oog`2L
B4P0B4P00018W03Oool0903oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo
00<0gia80000B02Lgol0:03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo
00<0_g@00018W03Oool00P3oool00`3OW4P007Bo0?ooo`0]0?ooo`030?oOW0180000M;oo02X0oooo
001P0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0/0?ooo`070?oo_`1d0000M;oo0?oo
o`3o_g@0001d0;ooo`060?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02ooolU0?ooo`07
0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0:0?ooo`040?oOW018000004RL0=ooob@0oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo00T0oooo00<0okmd00000000M;l09`3oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool01`3oool01`3o_g@0000007Boo`3oool0oono07@0001d_ol0
;03oool01@3ooml0W4P0000000000000M;oo02X0oooo001Q0?ooo`050?oo_`1d000000000000M02o
ool0;P3oool01@3ookl0M0000000000007@0_ooo00P0oooo00H0oooO09a80000000000000000M02o
oolW0?ooo`050?oo_`1d000000000000M02oool0303oool00`3OW4P004RL0=ooo`0U0?ooo`050?oo
_`1d000000000000M02oool02`3oool01@3ooml0W4P00000000007@0_ooo02D0oooo00D0oono07@0
00000000001d0;ooo`090?ooo`050?noM0000000000000000018W=l0;`3oool00`3o_g@0000007Bo
o`0Z0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00CP3oool01@3ogi`0B000
0000000007@0_ooo00T0ooooo`00000b000002<0oooo001=0?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool004d0
oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08@3oool004`0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d
0;ooo`070?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00C03o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0o`3o
ool^0?ooo`030000003oool0oooo0240oooo001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol01`3oool3000000@0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030000003oool0
oooo00<0oooo0`00000S0?ooo`00C03oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooad0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`00C03oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo00L0oooo00<000000?ooo`3oool01@3oool200000?l0oooo7P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0240oooo001<0?ooo`030?oo_`1d0000B9cO00<0oooo
00<0gia80000M02oool01`3oool00`000000oooo0?ooo`060?ooo`800000o`3ooolL0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool004d0oooo00<0gia80018W03Oool00P3o
ool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P00003o0?oooaX0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`00C@3oool01`3ookl0M00007Boo`3o
ool0okmd0000M02oool0203oool00`000000oooo0?ooo`080?ooo`800000o`3ooolI0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool08@3oool004h0oooo00D0oono07@000000000001d
0;ooo`090?ooo`8000002@3oool00`000000oooo0000003o0?oooaL0oooo00<000000?ooo`3oool0
1`3oool3000002<0oooo001L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000o`3o
oolE0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08@3oool005`0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0000003o0?oooa@0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo
00000?l0oooo4P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0240oooo001L0?oo
o`030000003oool0oooo00/0oooo00@000000?ooo`3oool00000o`3ooolA0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0303oool01000
0000oooo0?ooo`00003o0?ooo`l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Q
0?ooo`00G03oool2000000d0oooo00D000000?ooo`3oool0oooo0000003o0?ooo`d0oooo00<00000
0?ooo`3oool02`3oool3000002<0oooo001L0?ooo`030000003oool0oooo00d0oooo00D000000?oo
o`3oool0oooo0000003o0?ooo``0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q
0?ooo`00G03oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`000000o`3oool:
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?oo
o`3oool03`3oool01@000000oooo0?ooo`3oool000000?l0oooo203oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool200000140oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool03P3oool3000002<0oooo001L0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`40oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`3m0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0?/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Q0?oo
o`00G03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0n@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000
5P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?L0oooo00<000000?ooo`3oool0
4`3oool3000002<0oooo00110?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@00000
07Boo`030?ooo`060;md00000000000000000000B9`0gooo1`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0240oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`02
0?ooo`030?noM0000000M;oo00@0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`00003a0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool08@3oool00400oooo00<0_g@00018W03Oool00P3oool00`2o
M00007Bo0?ooo`080?ooo`030?oOW0180000M;oo00T0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`040?ooo`L00000kP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool00`3ogi`0
B00007Boo`090?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool700000>d0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00P0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo0080oooo2@00003/0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cO
o`080?ooo`030?oOW0180000M;oo00T0oooo0`00000I0?ooo`040000003oool0oooo0?ooo`T00000
j`3oool00`000000oooo0?ooo`0G0?ooo`<000008`3oool003l0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`080?ooo`030?oOW0180000M;oo00T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0900000>X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00P0oooo00<0omnL
04P0001d_ol02@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L00000jP3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO
00<0oooo00<0gia80000M02oool0203oool00`3ogi`0B00007Boo`090?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01`00003Z0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool08@3oool00400oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`03
0?oOW0180000M;oo00T0oooo00<000000?ooo`3oool0703oool010000000oooo0?ooo`3oool30000
0080oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0240oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`070?ooo`050?oog`2LB000
00000000001d_ol02@3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
8@3oool00440oooo00D0oono07@000000000001d0;ooo`0:0?ooo`030?noM0000000M;oo00T0oooo
0P00000O0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0hP3oool00`000000
oooo0?ooo`0L0?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool07`3oool00`000000oooo
000000060?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0P0?ooo`8000001`3oool00`000000oooo0?oo
o`3O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08@3oool005`0oooo00<00000
0?ooo`3oool0803oool2000000P0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0240oooo2`00003M0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`060?ooo`800000f`3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0240oooo001L0?ooo`800000903oool00`000000oooo0?ooo`050?ooo`030000
003oool000000=T0oooo00<000000?ooo`3oool08@3oool3000002<0oooo001L0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00003G0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000=H0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo0000003D0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo02L0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0Q0?ooo`00G03oool2000002T0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo02H0oooo0`00000S0?ooo`00G03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0b`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo
02X0oooo0P0000080?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0240
oooo001L0?ooo`030000003oool0oooo02/0oooo3@0000360?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool08@3oool005`0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0``3oool00`000000oooo0?ooo`0[0?ooo`<000008`3oool00440oooo00D0omnL
04P000000000001d0;ooo`030?ooo`050?noM0000000M;oo0?ooo`2oM0001P0000000`18W=l0oooo
0?ooo`050?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01`3oool200000<<0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M00007Bo
o`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?ooo`030=nLB0000000000000<0
000000<004RL0=ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`000000`@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0240
oooo00100?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`3OW4P0B9cO
0?ooo`020?ooo`030=nLM02Lgol0oooo00D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00800000_`3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203o
ool00`3OW4P0M;oo0?ooo`090?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00T0oooo00<0_gA809cOo`3oool0203oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o
_g@0001809cOo`090?ooo`030?oog`2LB7@0_ooo00P0oooo0`00000a0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo
0300oooo0`00000S0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00X0
oooo00<0okmd001d_`3oool01`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`0:0?ooo`030?oo_`1d04P0W=oo00L0oooo00<000000?ooo`3oool0<`3oool01@000000oooo
0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
2P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0oooo03@0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool08@3oool00400oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?no
W02Lgol0oooo0080oooo00<0omnL04P00018W=l01`3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0000000X0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo0240oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`060?ooo`08
0?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02oool70?ooo`030000003oool0oooo03H0oooo3P00
002_0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool08@3oool00440oooo00D0oono
07@000000000001d0;ooo`080?ooo`060?oog`2LB00000000000000007@0_ooo203oool2000003P0
oooo0P00000:0?ooo`800000[@3oool00`000000oooo0?ooo`0f0?ooo`<000008`3oool005`0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`070?ooo`030000003oool000000:/0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000Z@3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`00002X0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`000000YP3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo0240oooo001L0?ooo`030000003oool0oooo03d0oooo0P0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`800000@03oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool0X03oool00`000000oooo0?ooo`0l0?ooo`<000008`3oool005`0oooo00<00000
0?ooo`3oool0@03oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`11
0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0480oooo0P0000080?oo
o`030000003oool0oooo09X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0Q0?oo
o`00G03oool00`000000oooo0?ooo`130?ooo``00000V03oool2000004@0oooo00<000000?ooo`3o
ool08@3oool005`0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0Q0?ooo`00;03o
ool00`2oM7@0_ooo0?ooo`040?ooo`030;mdM02oool0oooo02H0oooo0P0000160?ooo`030000003o
ool0oooo00H0oooo0P00002E0?ooo`030000003oool0oooo04<0oooo0`00000S0?ooo`00;03oool0
0`2oM000B9cO0?ooo`030?ooo`030=nLB00007@0_ooo02L0oooo00<000000?ooo`3oool0AP3oool2
000000H0oooo00<000000?ooo`000000TP3oool2000004P0oooo00<000000?ooo`3oool08@3oool0
02`0oooo00T0_g@00000000007@0_ooo0?oog`2LB000B9cO0=nLW02oool09`3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000T03oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0240oooo000/0?ooo`060;nLW03Ogi`0B00000000000
04P0W=oo:P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo0000002>0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool08@3oool0
02`0oooo00<0_gAd0;oOW01800000P000000100004P0W=oo0=nLW02ooolW0?ooo`030000003oool0
oooo04X0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo08T0oooo0P00
001<0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;md0000B9`0gooo0080oooo00@0_g@0
0000000007@0_ooo9`3oool00`000000oooo0?ooo`1;0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0240oooo
000/0?ooo`030;mdB02Lgol0oooo00<0oooo00<0okmd0000M02oool09`3oool2000004d0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo04/0oooo0`00
000S0?ooo`00;03oool00`2oW9`0gooo0?ooo`040?ooo`030=nLW02oool0oooo00/0oooo00D0omnL
04P000000000001d0;ooo`030?ooo`060?noM0000000M;oo0?ooo`3ookl0M0000`0000000`1d_ol0
oooo0?ooo`070?ooo`030000003oool0oooo04d0oooo2P0000240?ooo`800000D03oool00`000000
oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool01`3o
_g@0000007Boo`3oool0omnL04P00018W=l00P3oool00`2oM000B9cO0?ooo`070?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0103oool200000880oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`0Q0?ooo`00<@3oool00`2oW9`0gooo0?ooo`020?ooo`030=nLW02oool0
oooo00L0oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`0:0?ooo`030?oo_`1d04P0
W=oo00L0oooo00<000000?ooo`3oool0D03oool2000000@0oooo00<000000?ooo`000000O`3oool2
000005<0oooo00<000000?ooo`3oool08@3oool002d0oooo00D0oono07@0B02Lgol0oono07@00004
000000030000M02oool0oooo00H0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0:
0?ooo`030?oo_`1d0000M;oo00L0oooo00<000000?ooo`3oool0DP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo0240oooo000f0?ooo`030=nLW02oool0oooo00H0oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`0:0?ooo`030?noM0000000M;oo00L0oooo00<000000?ooo`3oool0D`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo07P0oooo0P00001F0?ooo`030000003o
ool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02@3oool0
103ogi`0B0000000B02Lgol70?ooo`<00000E03oool3000000@0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`1D0?ooo`<000008`3oool003l0oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`070?ooo`050?noM000000000000000B02Lgol0203oool00`000000oooo0?oo
o`1F0?ooo`L00000M@3oool2000005T0oooo00<000000?ooo`3oool08@3oool003<0oooo00<0_gAd
0;ooo`3oool02@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0_g@0
001d_`3oool0203oool00`000000oooo0?ooo`1G0?ooo`8000000`3oool2000007<0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`0Q0?ooo`00<`3oool00`2oM7@0_ooo0?ooo`090?oo
o`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool02P3oool00`2oM000B9cO0?ooo`070?oo
o`030000003oool0oooo05T0oooo00H000000?ooo`3oool000000?ooo`00001`0?ooo`800000G03o
ool00`000000oooo0?ooo`0Q0?ooo`00<`3oool00`2oM7@0_ooo0?ooo`0:0?ooo`030=nLB000B9`0
gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3ooml0W9bo0?ooo`020?ooo`030=nLB00007@0
_ooo00L0oooo00<000000?ooo`3oool0FP3oool300000080oooo00<000000?ooo`3oool0J`3oool2
000005h0oooo00<000000?ooo`3oool08@3oool00300oooo00<0_g@00000000000000`0000000`00
07@0_ooo0?ooo`070?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`070?ooo`060?noM018
W=l0oooo0?oo_`1d000007Bo203oool2000005d0oooo1@00001[0?ooo`030000003oool0oooo05`0
oooo0`00000S0?ooo`00<`3oool00`2oM7@0_ooo0?ooo`0;0?ooo`050?oo_`1d000000000000M02o
ool02@3oool01@3OW4P000000000000007@0_ooo00P0oooo00<000000?ooo`3oool0GP3oool01000
0000oooo00000000001X0?ooo`800000H@3oool00`000000oooo0?ooo`0Q0?ooo`00<`3oool00`2o
M7@0_ooo0?ooo`0V0?ooo`030000003oool0oooo05l0oooo1000001U0?ooo`800000H`3oool00`00
0000oooo0?ooo`0Q0?ooo`00<`3oool00`2oM7@0_ooo0?ooo`0V0?ooo`030000003oool0oooo0640
oooo0`00001R0?ooo`800000I@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo
0?ooo`1S0?ooo`<00000GP3oool2000006L0oooo00<000000?ooo`3oool08@3oool002h0oooo00<0
oooO09adW03Oool01@3oool00`3OW9`0_ooo0?ooo`0S0?ooo`030000003oool0oooo06D0oooo0P00
001K0?ooo`800000J@3oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool00`3o_g@0000000000005
000000030000M02oool0oooo02<0oooo0P00001W0?ooo`<00000E`3oool2000006T0oooo0`00000S
0?ooo`00=P3oool00`3OW9`0_ooo0?ooo`0S0?ooo`030000003oool0oooo06L0oooo00@000000?oo
o`0000000000D`3oool2000006d0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?oo
o`3oool0J03oool00`000000oooo0?ooo`03000004h0oooo0P00001_0?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool00P3oool2000004T0
oooo0`00001a0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool00`3oool3000004@0oooo0P00001d0?ooo`030000003oool0oooo0240oooo
001L0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool01@3oool3000003l0oooo0P00
001f0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000K@3oool00`000000oooo0?ooo`07
0?ooo`<00000>03oool4000007H0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo00T0oooo0`00000`0?ooo`D00000O03oool00`000000oooo0?ooo`0Q0?oo
o`00G03oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00/0oooo1000000Y0?ooo`<0
0000P@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo00h0oooo2000000K0?ooo`H00000Q03oool00`000000oooo0?ooo`0Q0?ooo`00G03o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01D0oooo6`00002:0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`0Q0?ooo`00G03oool2000007<0oooo00<000000?ooo`3oool0]P3oool30000
02<0oooo00110?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`050?oo
o`040?oog`2LB00004RL0=ooo`L0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`2g
0?ooo`030000003oool0oooo0240oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;oo
o`020?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool08@3oool00400oooo00<0
_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`090?ooo`040?oog`2LB00004RL0=ooo`L0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo0240oooo
000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`2oM00000000000
00050000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`2d0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol01@3oool0203ogi`0M9cO0?ooo`3oool0oooO09a80000B9`0gooo1`3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool08@3oool003l0oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`070=nLB01d_ol0oooo0?oog`2L
B00004RL0=ooo`070?ooo`<00000N03oool00`000000oooo0?ooo`2`0?ooo`<000008`3oool003l0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`070?oog`2LB7@0_ooo0?oo
g`2LB00004RL0=ooo`070?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00L0oooo00H0omnL04Qd_`3ooml0W4P00018W03Oool70?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`03
0?ooo`030=nLB00007@0_ooo00P0oooo00D0gia807Bog`2LB00004RL0=ooo`070?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool0
0`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00P0oooo00D0oooO09a8B018B00004RL0=oo
o`070?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?oo
o`0Q0?ooo`00@03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool02P3oool0103ogi`0B000
0018W03Oool70?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0[@3oool00`000000
oooo0?ooo`0Q0?ooo`00@@3oool01@3ookl0M0000000000007@0_ooo00`0oooo00<0gia80018W03O
ool01`3oool2000007l0oooo00<000000?ooo`3oool0ZP3oool3000002<0oooo001L0?ooo`030000
003oool0oooo07l0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0Q0?ooo`00G03o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool08@3o
ool005`0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0
oooo0240oooo001L0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool2000008@0oooo00<000000?ooo`3oool0Y@3oool3000002<0
oooo001L0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0:D0oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool0X`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0:80oooo00<000000?ooo`3oool08@3oool005`0oooo0P00002:0?ooo`030000
003oool0oooo09l0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo0:00oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool08@3oool005`0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0240oooo
001L0?ooo`800000T03oool00`000000oooo0?ooo`2I0?ooo`<000008`3oool00440oooo00D0omnL
04P000000000001d0;ooo`030?ooo`060?noM0000000M;oo0?ooo`3ooml0W4P00`0000000`1d_ol0
oooo0?ooo`070?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0VP3oool00`000000
oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool01`3o
_g@0000007Boo`3oool0oooO09a8M02oool00P3oool00`2oM000M;oo0?ooo`070?ooo`030000003o
ool0oooo0940oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool0
0`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00X0oooo00<0oooO09a8M02oool01`3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool08@3oool0
03l0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0;0?ooo`030;md001d_ol0oooo
00H0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo
0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3ooml0
W4P004RLg`070?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0UP3oool00`000000
oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo
00<0gia80000001d_ol01`3oool3000009D0oooo00<000000?ooo`3oool0T`3oool3000002<0oooo
000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3Ogml0oooo0?oo
_`1d000000000000M02oool01`3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`060?ooo`060=nLB000000000000000000004P0W=oo203oool00`000000oooo0?ooo`2G0?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0oono07@00018
W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`040?oo_`1d0000000004RLg`X0oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo00100?ooo`03
0=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`2oM000M;oo0?ooo`0:0?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0Q0?ooo`00
@03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool0203oool01P3ogi`0B000000000000000
001809cOo`L0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo0240oooo00110?ooo`050?oo_`1d000000000000M02oool02P3oool01@2oM00000000000
00000000B9cO00L0oooo0P00002L0?ooo`030000003oool0oooo08d0oooo0`00000S0?ooo`00G03o
ool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool08@3o
ool005`0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0240oooo001L0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0X03oool00`000000oooo
0?ooo`2:0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000XP3oool00`000000oooo0?oo
o`270?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0:<0oooo00<000000?oo
o`3oool0Q`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0
Y@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0240oooo001L0?ooo`800000Y`3o
ool00`000000oooo0?ooo`220?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool0Y`3oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000
oooo0?ooo`2Y0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool005`0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0240oooo
001L0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?oo
o`0Q0?ooo`00G03oool200000:d0oooo00<000000?ooo`3oool0O03oool3000002<0oooo00110?oo
o`050?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`050?oOW0180000
00000000001d_ol0203oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo07d0oooo00<0
00000?ooo`3oool08@3oool00400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo
00<0okmd0000001d_ol00P3oool01`3ogi`0B00004RLg`3oool0oono07@0001d_ol01`3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool08@3oool00400
oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo00<0
oooo00<0okmd0018W03Oool01P3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool08@3oool003l0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d
0;ooo`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol01P3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`05
0?ooo`030?oOW0180000M;oo00<0oooo00<0_g@00000B02Lgol01P3oool300000;80oooo00<00000
0?ooo`3oool0MP3oool3000002<0oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000
B02Lgol01@3oool0203ookl0M00000000018W=l0oooo0?noM000000007Bo1`3oool00`000000oooo
0?ooo`2c0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`030;md0000B9`0_ia80080000000<0
04RL0=ooo`3oool01P3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool08@3oool003l0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`06
0?ooo`030?oOW0180000M;oo00/0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo0240oooo00100?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d
_`3oool01`3oool00`3OW4P0001809cOo`0:0?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool0M@3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M00007Boo`3oool0okmd
0000M02oool02@3oool00`3o_g@00000001d_`090?ooo`030000003oool0oooo0;H0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3ookl0M0000000000007@0
_ooo00/0oooo00D0oooO09a800000000001d0;ooo`060?ooo`8000001@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`030?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0240oooo001L0?ooool00000<P00000S0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooolU0?ooo`030?oog`2LB4P0W=oo02L0oooo00<0omnL04Q8W03Oool0G`3oool00?l0oooo9@3o
ool00`2oM4P0W=oo0?ooo`0X0?ooo`030?oOW018M;l0oooo05h0oooo003o0?ooob@0oooo00<0gia8
04RLg`3oool0:P3oool00`3OW4P0B9cO0?ooo`1M0?ooo`00o`3ooolS0?ooo`030?oo_`1d07@0_ooo
02/0oooo00<0oono07@0B02Lgol0G@3oool008T0oooo00<0omnL04P0000000000P0000000`0007@0
_ooo0?ooo`030?ooo`050=nLB000000000000000001d_ol00`3oool01P3ooml0W4P0000000000000
001809cOo`D0oooo00<0omnL07BLg`3oool00P3oool00`3OW7@0W=oo0?ooo`040?ooo`050;md0000
000000000000M02oool00P3oool01P3ooml0W4P0000000000000001809cOo`L0oooo00<0_g@00000
000000000P0000000`00M;l0oooo0?ooo`030?ooo`070=nLB000000000000000M02oool0oooo0=nL
B0030000000807Boo`3oool0oooo0?ooo`3ogi`0B00000000018W=l40?ooo`030?oOW01800000000
0080000000@0M;oo0?ooo`3oool0gia80`000000101d_ol0oooo0?ooo`2oM002000000070000B02L
gol0oooo0?oog`2LB000001d0;ooo`070?ooo`060;md00000000000000000000B9`0gooo0P3oool0
1P3o_g@0000007Boo`3oool0oooO09a800<0000000<0M;oo0?ooo`3oool01P3oool00`3OW4P004RL
0=ooo`040?ooo`060;md00000000000000000000B9`0gooo5P3oool01@2oM0000000001d_`3oool0
gia80080000000L004RL0=ooo`3oool0oooo0?oog`2LB000B9cO00D0oooo00D0_g@000000000M;l0
oooo0=nLB002000000030018W03Oool0oooo04h0oooo00280?ooo`040=nLB000000004RL0=ooo`80
oooo00<0oono07@0B02Lgol00P3oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool0
1`2oM00004RL0=ooo`3oool0omnL04P0001d_ol0103oool01`2oM000001d0;ooo`3oool0oono07@0
0000M;l0103oool03`2oM0000000001d_`3oool0omnL04P0M02oool0oooo0;md0000B9`0gooo0?oo
o`3ogi`0B00007Boo`070?ooo`040?oog`2LB00004RL0=ooo`L0oooo00/0gia80000M02oool0oooo
0=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`050=nLB00007@0_ooo0=no_`3Oool0103o
ool00`3ooml0W4P0001d_`030?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`03
0=nLB00007@0_ooo0080oooo00@0oooO09a8000007@0_ooo203oool00`3ogi`0B00007Boo`040?oo
o`070?noM0000000M;oo0?ooo`3ooml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo00H0oooo00<0
_g@0001d_`3oool01@3oool00`3ogi`0B00007Boo`0H0?ooo`080?oog`2LB7@0_ooo0?ooo`3ooml0
W4P00018W03Oool40?ooo`030=nLB000B9`0gooo00@0oooo00P0oooO09a8M02oool0oooo0?oog`2L
B00004RL0=oooe00oooo00270?ooo`030?noM000000007Bo00D0oooo00H0oooO09a8M02oool0omnL
04P00000M;l30?ooo`070?noM00007@0_ooo0?ooo`2oM00004RL0=ooo`020?ooo`030?noM00007@0
_ooo0080oooo00T0omnL04P00018M7@0M9cO0?ooo`3o_g@0001804Q8B02Lgol00P3oool00`3ogi`0
B00004RLg`030?ooo`060?oOW01dW=l0oooo0;md0000B9`0gooo0P3oool00`3o_g@0001d0;ooo`06
0?ooo`030?oog`2LB00007Bo00P0oooo00H0gia80000M02oool0omnL04P00000M;l30?ooo`070?no
M00007@0_ooo0?ooo`3OW4P004RL0=ooo`060?ooo`030?oog`2LB00007Bo0080oooo00<0omnL04P0
0000M;l00`3oool01`3o_g@0001d0;ooo`3oool0gia80000M02oool03P3oool00`3ogi`0B00007Bo
o`0=0?ooo`030?oog`2LB7@0_ooo00D0oooo00<0oono07@00018W=l01P3oool00`3ogi`0B00007Bo
o`0I0?ooo`060?oo_`1dB9`0gooo0;md000007@0_ooo1@3oool00`3OW4P0001d0;ooo`050?ooo`06
0?oo_`1dB9`0gooo0;md000007@0_oooD@3oool008H0oooo00@0oooO09a8000007@0_ooo203oool0
0`3o_g@0000007Boo`030?ooo`070?noM0000000M;oo0?ooo`2oM00004RL0=ooo`020?ooo`030?oO
W0180000M;oo0080oooo00T0gia80000M02oool0_gAd0;oog`2LB00007Bo0?oOW01dW=l00P3oool0
0`3o_g@0001809cOo`060?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P0001d_ol01P3oool0
0`3ooml0W4P0001d_`080?ooo`060=nLB00007@0_ooo0?noM0000000M;oo0`3oool01`3o_g@00000
07Boo`3oool0gia80018W03Oool01P3oool00`3ooml0W4P0001d_`020?ooo`030?noM0000000M;oo
00<0oooo00L0okmd0000001d_ol0oooo0=nLB00007@0_ooo00h0oooo00<0omnL04P0001d_ol03P3o
ool00`2oM000M;oo0?ooo`040?ooo`030?oo_`1d0000M;oo00H0oooo00<0omnL04P0001d_ol06P3o
ool0103ogi`0M4Q80000001d_ol60?ooo`030?noM00007@0_ooo00H0oooo00@0omnL07A8B0000000
M;ooDP3oool008H0oooo00@0omnL04P00000B9`0gooo203oool00`3o_g@0000007Boo`030?ooo`07
0?noM0000000M;oo0?ooo`2oM00004RL0=ooo`020?ooo`0C0?oOW0180000M;oo0?ooo`3ookl0M000
04RLg`3oool0omnL07AdM01804P0W=oo0?ooo`2oM7@0_ooo0?ooo`3o_g@0001d0;ooo`060?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P0001d_ol01P3oool00`3ooml0W4P0001d_`080?ooo`06
0=nLB00007@0_ooo0?noM0000000M;oo0`3oool01`3o_g@0000007Boo`3oool0gia80018W03Oool0
1P3oool00`3ooml0W4P0001d_`020?ooo`030?noM0000000M;oo00<0oooo00L0okmd0000001d_ol0
oooo0=nLB00007@0_ooo00h0oooo00<0omnL04P0001d_ol03@3oool00`3ooml0W4P004RLg`050?oo
o`030?oo_`1d0000M;oo00H0oooo00<0omnL04P0001d_ol0203oool00`3ooml0W4P0000000070000
000304RLg`3oool0oooo00D0oooo00<0oono07@00018W=l01`3oool00`3o_g@0001809cOo`060?oo
o`030?oo_`1d0000B9cO05<0oooo00260?ooo`030?noM000000007Bo00T0oooo00<0oono07@0001d
_ol00`3oool01`2oM000001809cOo`3oool0_g@00018W03Oool00P3oool02`3o_g@0001809cOo`3o
ool0gia80000B02Lgol0oooo0?oog`2LB00007Bo0080oooo00D0okmd04RLg`3oool0omnL04P00005
0000000504RLg`3oool0_g@00018W03Oool00P3oool00`3o_g@0001809cOo`060?ooo`030?oog`2L
B000000000@0000000X0M;oo0?ooo`3oool0oooo0=nLB00007@0_ooo0?oo_`1d0000M;oo0`3oool0
1`2oM000001809cOo`3oool0gia80018W03Oool01P3oool00`3ooml0W4P0001d_`020?ooo`030?oo
_`1d0000M;oo00<0oooo00L0_g@00000B02Lgol0oooo0=nLB00004P0W=oo00h0oooo00<0omnL04P0
001d_ol03@3oool00`3OW4P0000007Boo`050?ooo`030?oo_`1d0000M;oo00H0oooo00<0omnL04P0
001d_ol06@3oool01@3ooml0W4P00018W02LM4P0W=oo00H0oooo00<0okmd0000M02oool01@3oool0
1@3ooml0W4P00018W02LM4P0W=oo0580oooo00260?ooo`030?noM000000007Bo00X0oooo00L0gia8
0018W03Oool0oooo0?noM000000007Bo0080oooo00/0_g@000000000B9`0gooo0?oo_`1d000004RL
0=ooo`3ookl0M000001d_`020?ooo`030?oOW0180000M;oo0080oooo00H0oooO09a8M02oool0oooo
0;md0018W=l20?ooo`0<0=nLB00004P0W=oo0?ooo`2oM00000000018W03Oool0oono07@00000B9`0
gooo1P3oool00`3ooml0W4P0001d_`020?ooo`040?oog`2LB000000004RLg`80oooo00/0gia80000
M02oool0oooo0=nLB000B9`0gooo0?ooo`3o_g@00000001d_`020?ooo`030=nLB000B9`0gooo00H0
oooo00<0oooO09a80000M;l00`3oool04P3OW4P004RL0=ooo`3oool0okmd00000000M;l0oooO09a8
00000000001804QdW03O_g@0001d0;oog`2LB000001d0;ooo`P0oooo00<0omnL04P0001d_ol02@3o
ool01`3Ogml0oooo0?oo_`1d000000000000M02oool01@3oool00`3ookl0M00004RLg`060?ooo`03
0?oOW0180000M;oo01T0oooo00H0_g@00000B02Lgol0oooO09a8M02oool50?ooo`030=nLB00007@0
_ooo00D0oooo00H0_g@00000B02Lgol0oooO09a8M02ooomA0?ooo`00QP3oool0103ogi`0B0000018
W03Oool:0?ooo`050?noM0000000000000000018W=l00`3oool02@2oM00004RL0=oOW01800000000
0018W03Oool0oooO09a800020000000304RLg`3o_g@000000080000000P0B9cO0?ooo`2oM0000000
0018W03Oool0oooo0=nLB080000000/0001809cOo`3oool0oooo0;md0000B9`0gmnL04P000000000
04RL0=ooo`070?ooo`030?oog`2LB00007Bo00<0oooo00P0oono07@0000007@0_ooo0?ooo`3OW4P0
001d0;ooo`80oooo00D0okmd000000000000000004RLg`020?ooo`060;md00000000000000000000
B9`0gooo0`3oool00`3o_g@0000000000002000000040018W03Oool0oooo0?noM0<0000000d0B9cO
0?ooo`3oool0oooo0;md000007@0_mnL04P0000007@0_ooO09a8000007@0_ooo00P0oooo00<0omnL
04P0001d_ol02@3oool01P3OW4P00000000000000000001809cOo`H0oooo00<0oooO09a80018W=l0
1P3oool00`3ogi`0B00007Boo`0G0?ooo`090?oog`2LB000000000000000M;l0okmd0000000007@0
_ooo00@0oooo00<0gia80018W03Oool00`3oool02@3ooml0W4P000000000000007Bo0?noM0000000
001d0;ooo`1@0?ooo`00QP3oool0103ooml0W4P00000B02Lgol50?ooo`030?oog`2LM9`0gooo00X0
oooo00<0_g@00018W03Oool06`3oool00`2oM00004RL0=ooo`0;0?ooo`030?oog`2LB00007Bo00<0
oooo00P0oooO09a8000004P0W=oo0?ooo`3OW4P0001d0;ooo`X0oooo00<0_g@00018W03Oool01P3o
ool00`3ooml0W4P0001d_`0M0?ooo`030?oOW0180000M;oo00T0oooo00@0oono07@000000000B9cO
2@3oool00`3OW4P004RL0=ooo`050?ooo`030?oOW0180000M;oo02<0oooo00<0oooO09a80018W=l0
G@3oool008L0oooo00<0omnL04P00000M;l01@3oool00`3o_g@004RL0=ooo`0:0?ooo`030;md0000
B9`0gooo01/0oooo00<0_g@00018W03Oool02`3oool00`3ooml0W4P0001d_`030?ooo`080?oOW018
0000001d0;ooo`3oool0gia80000M02oool:0?ooo`030?oo_`1dB9`0gooo00L0oooo00<0_g@0001d
_`3oool0703oool00`3ogi`0B00007Boo`0:0?ooo`030;md001d_ol0oooo00T0oooo00<0oono07@0
B02Lgol01@3oool00`3ogi`0B00007Boo`0S0?ooo`030?oo_`1d04P0W=oo05d0oooo00280?ooo`03
0?noM000000007Bo00<0oooo00<0gia800000000M;l02`3oool00`2oM00004RL0=ooo`0K0?ooo`03
0;md0000B9`0gooo00/0oooo00<0oooO09a80000M;l00P3oool0103ookl0M00000000018W=l20?oo
o`030=nLB00007@0_ooo00X0oooo00<0oooO09adW03Oool01`3oool00`3OW4P007Bo0?ooo`0J0?oo
o`050?oog`2LB00000000000001d_ol02P3oool01P3ogi`0B000000000000000001809cOo`L0oooo
00<0gia804RLg`3oool00P3oool01@3ooml0W4P0000000000000M;oo02<0oooo00<0gia804RLg`3o
ool0G@3oool008T0oooo00<0oooO09a8000000000P0000000`18W=l0oono07Ad_`090?ooo`050?oo
_`1d000000000018W03Oool06@3oool01@3ookl0M00000000000B9`0gooo00X0oooo00<0_g@00000
0000000010000000200004P0W=oo0?ooo`3ooml0W4P00000000007@0_ooo503oool01`3ookl0M01d
0;ooo`3ooml0W4P00018W03Oool0603oool00`3o_g@0000007Boo`0;0?ooo`050;md000000000000
00000018W=l0203oool00`2oM000B9cO0?ooo`030?ooo`030?noM0000000M;oo0280oooo00<0okmd
001d_`3oool0GP3oool009/0oooo00@0oooO09a80000B9`0gooo6P3oool0103ooml0W4P00018W03O
oolF0?ooo`030;md000007@0_ooo01D0oooo00D0oono07@000000000001809cOo`0e0?ooo`030=nL
M02Lgol0oooo02H0oooo00<0oono07Ad_`3oool0G`3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.344423, -0.189527, \
0.00518628, 0.00513826}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(logisticCobweb[2.5, 0.7, 20, 0, 
        PlotRange \[Rule] {{0, 1}, {0, 1}}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9.5 -15.6875 ]
[.2 -0.0125 9.5 0 ]
[.4 -0.0125 -9.5 -15.6875 ]
[.4 -0.0125 9.5 0 ]
[.6 -0.0125 -9.5 -15.6875 ]
[.6 -0.0125 9.5 0 ]
[.8 -0.0125 -9.5 -15.6875 ]
[.8 -0.0125 9.5 0 ]
[1 -0.0125 -5 -15.6875 ]
[1 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .12361 -19 -7.84375 ]
[-0.0125 .12361 0 7.84375 ]
[-0.0125 .24721 -19 -7.84375 ]
[-0.0125 .24721 0 7.84375 ]
[-0.0125 .37082 -19 -7.84375 ]
[-0.0125 .37082 0 7.84375 ]
[-0.0125 .49443 -19 -7.84375 ]
[-0.0125 .49443 0 7.84375 ]
[-0.0125 .61803 -10 -7.84375 ]
[-0.0125 .61803 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -11.4063 ]
[-0.01875 .30902 -19 11.4063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74.9688 0 ]
[.5 .63053 74.9688 15.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cobweb) show
105.875 15.813 moveto
(Plot) show
128.188 15.813 moveto
(for) show
142.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
148.375 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.375 15.813 moveto
(H) show
170.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
179.188 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
189.875 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
196.000 15.813 moveto
(L) show
202.813 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
208.938 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.04057 .02507 L
.08481 .05241 L
.12636 .07809 L
.16632 .10279 L
.20885 .12908 L
.2498 .15438 L
.29331 .18128 L
.33524 .20719 L
.37557 .23212 L
.41848 .25864 L
.4598 .28417 L
.49953 .30873 L
.54183 .33487 L
.58254 .36003 L
.62583 .38678 L
.66752 .41255 L
.70762 .43734 L
.7503 .46371 L
.79139 .4891 L
.83505 .51609 L
.87712 .54209 L
.9176 .56711 L
.96065 .59371 L
1 .61803 L
s
0 0 m
.04057 .06014 L
.08481 .11992 L
.12636 .17057 L
.16632 .21424 L
.20885 .2553 L
.2498 .28955 L
.29331 .32027 L
.33524 .34433 L
.37557 .36235 L
.39599 .36956 L
.41848 .376 L
.43982 .38067 L
.44937 .38231 L
.4598 .38377 L
.46545 .38443 L
.4707 .38494 L
.47614 .38539 L
.48106 .38572 L
.48591 .38596 L
.48813 .38605 L
.49048 .38613 L
.49299 .3862 L
.4941 .38622 L
.4953 .38624 L
.49658 .38625 L
.49778 .38626 L
.49852 .38627 L
.49921 .38627 L
.50051 .38627 L
.50171 .38627 L
.503 .38626 L
.50421 .38624 L
.50533 .38623 L
.50792 .38617 L
.51065 .3861 L
.51331 .386 L
.51579 .38589 L
.52142 .38556 L
.53077 .38481 L
.54076 .3837 L
.55151 .38217 L
.56317 .38011 L
.58433 .37528 L
.6052 .36917 L
.6273 .36123 L
.66708 .34314 L
.70943 .3185 L
.7502 .28955 L
.79354 .25314 L
Mistroke
.83529 .21257 L
.87545 .16848 L
.91818 .11608 L
.95932 .0603 L
1 0 L
Mfstroke
.7 .43262 m
.7 .32447 L
.525 .32447 L
s
.525 .32447 m
.525 .38531 L
.62344 .38531 L
s
.62344 .38531 m
.62344 .36273 L
.58691 .36273 L
s
.58691 .36273 m
.58691 .3746 L
.60612 .3746 L
s
.60612 .3746 m
.60612 .36887 L
.59685 .36887 L
s
.59685 .36887 m
.59685 .37178 L
.60155 .37178 L
s
.60155 .37178 m
.60155 .37034 L
.59922 .37034 L
s
.59922 .37034 m
.59922 .37106 L
.60039 .37106 L
s
.60039 .37106 m
.60039 .3707 L
.5998 .3707 L
s
.5998 .3707 m
.5998 .37088 L
.6001 .37088 L
s
.6001 .37088 m
.6001 .37079 L
.59995 .37079 L
s
.59995 .37079 m
.59995 .37084 L
.60002 .37084 L
s
.60002 .37084 m
.60002 .37081 L
.59999 .37081 L
s
.59999 .37081 m
.59999 .37082 L
.60001 .37082 L
s
.60001 .37082 m
.60001 .37082 L
.6 .37082 L
s
.6 .37082 m
.6 .37082 L
.6 .37082 L
s
.6 .37082 m
.6 .37082 L
.6 .37082 L
s
.6 .37082 m
.6 .37082 L
.6 .37082 L
s
.6 .37082 m
.6 .37082 L
.6 .37082 L
s
.6 .37082 m
.6 .37082 L
.6 .37082 L
s
.6 .37082 m
.6 .37082 L
.6 .37082 L
s
.03 w
.7 .43262 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00lP3oool01@3ooml0W4P00000
0000B9`0gooo0;T0oooo003c0?ooo`030?oOW01804P0W=oo0;X0oooo003Y0?ooo`050;md00000000
07Bo0?ooo`3OW4P00P0000001P00B9`0gooo0?ooo`3ogi`0B01809cOokX0oooo003Y0?ooo`080?oo
g`2LB7@0_ooo0?ooo`3ooml0W4P00018W03Oool20?ooo`030?oOW01804P0W=oo0;X0oooo003Z0?oo
o`060?oo_`1dB9`0gooo0;md000007@0_ooo0P3oool0103ookl0M0000000B02Lgonj0?ooo`00j`3o
ool0103ogi`0M4Q80000001d_ol40?ooo`030?oOW01804P0W=oo0;X0oooo003[0?ooo`030?oo_`1d
0000B9cO0<80oooo003Z0?ooo`050?oog`2LB00004RL09adB02Lgol0`@3oool00>X0oooo00H0_g@0
0000B02Lgol0oooO09a8M02oool30?ooo`030?oo_`1d0000M;oo0;X0oooo003X0?ooo`090?oog`2L
B000000000000000M;l0okmd0000000007@0_ooo0;l0oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo002<0?ooo`050?oO
W018000000000000M02oool00`3oool01@3o_g@0000007Boo`3oool0_g@000H0000000<0B9cO0?oo
o`3oool09P3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol01@3oool0
103ooml0W4P00018W03OoolY0?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@00000
07Boo`030?ooo`050?oOW018000000000000001d_ol0:P3oool01@3ogi`0B0000000000007@0_ooo
00<0oooo00<0okmd0000001d_ol00`3oool01@3OW4P00000000000000000B9cO0300oooo00H0_g@0
00000000000000000018W03OoolU0?ooo`00R`3oool01`3ookl0M00007Boo`3oool0okmd0000M02o
ool00P3oool00`3o_g@0000007Boo`020?ooo`030=nLB0000000000000<0000000<004RL0=ooo`3o
ool09@3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`05
0?ooo`040?oog`2LB00004RL0=ooobP0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080
oooo00<0okmd0000001d_ol00P3oool01`3ogi`0B00004RLg`3oool0oono07@0001d_ol0:03oool0
1`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?ooo`070=nL
B0000000M;oo0?ooo`3ooml0W4P004RLg`0`0?ooo`030?oOW0180000M;oo02L0oooo002;0?ooo`03
0;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0=nLM02Lgol0oooo02D0oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`090?ooo`04
0?oog`2LB00004RL0=ooobP0oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`050?oo
o`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03Oool09`3oool00`2oM00004RL0=ooo`020?oo
o`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL0=ooo`0_0?oo
o`030?oOW0180000M;oo02L0oooo002:0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02o
ool0203oool00`3OW4P0M;oo0?ooo`0X0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02o
ool01@3oool00`2oM0000000000000050000000307Boo`3oool0oooo02@0oooo00<0oono07@00018
W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol09P3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0_g@0001d_`3o
ool00P3oool00`2oM00004RL0=ooo`0_0?ooo`030?oOW0180000M;oo02L0oooo002:0?ooo`030?oO
W0180000M;oo00<0oooo00<0okmd0000B02Lgol02@3oool00`2oM4P0W=oo0?ooo`0W0?ooo`030?oO
W0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool0203ogi`0M9cO0?ooo`3oool0oooO09a8
0000B9`0gooo9`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL
04P0001d_ol00`3oool00`3o_g@0001809cOo`0V0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol01P3oool01`3ogi`0B01d0;ooo`3oool0_g@00000001d_ol0<03oool00`3ogi`0B000
07Boo`0W0?ooo`00RP3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0
oooO09a8M02oool09`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0
gia807Boo`3oool0oooO09a80000B9`0gooo02L0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0_g@00000B02Lgol09P3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00D0oono07A8B0180000000004RLg`0a0?oo
o`030?oOW0180000M;oo02L0oooo002:0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol02P3oool00`3o_g@007Bo0?ooo`0V0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool09`3oool00`3ogi`0B00007Boo`03
0?ooo`030?noM00004P0W=oo00D0oooo00P0oono07@000000000B9cO0?ooo`3o_g@00000001d_bL0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`040?oOW01800000000001d
_c80oooo00<0omnL04P0001d_ol09`3oool008X0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`0:0?ooo`030?oo_`1d04P0W=oo02H0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`070?ooo`060?oOW018M;l0oooO09a80000B9`0gooo9`3oool00`3ogi`0B00007Boo`03
0?ooo`030?noM00004P0W=oo00H0oooo00<0_g@00018W02oW4P00P0000000`00B9`0gooo0?ooo`0V
0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01P3ogi`0B0000000M02o
ool0okmd001d_c40oooo00<0omnL04P0001d_ol09`3oool008X0oooo00<0oono07@00018W=l00`3o
ool00`3OW4P0001d0;ooo`0:0?ooo`030?oo_`1d0000B9cO02H0oooo00<0oono07@00018W=l00`3o
ool00`3OW4P0001d0;ooo`080?ooo`050=nLB01d_ml0W4P00018W03Oool09`3oool00`3ookl0M000
04RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0omnL04P0001d_ol0:`3oool00`3ookl0M000
04RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0_g@00000M02oool00P3oool00`2oM000B9cO
0?ooo`0_0?ooo`030?oOW0180000M;oo02L0oooo002;0?ooo`030=nLB000B9`0gooo0080oooo00<0
_g@0001d_`3oool01@3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW0180000B9cO02L0oooo00<0
gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`050?oog`2LB4P0B4P00018W03Oool0
:03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000B02Lgol0
:`3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo00<0_g@00018W03Oool0
0P3oool00`3OW4P007Bo0?ooo`0_0?ooo`030?oOW0180000M;oo02L0oooo002;0?ooo`070?oo_`1d
0000M;oo0?ooo`3o_g@0001d0;ooo`060?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02o
oolW0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0:0?ooo`040?oOW018000004RL0=oo
obP0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00T0oooo00<0okmd00000000M;l0:P3o
ool01`3ookl0M00007Boo`3oool0okmd0000M02oool01`3oool01`3o_g@0000007Boo`3oool0oono
07@0001d_ol0;P3oool01@3ooml0W4P0000000000000M;oo02L0oooo002<0?ooo`050?oo_`1d0000
00000000M02oool0203oool01P3ooml0W4P0000000000000001d0;ooobT0oooo00D0oono07@00000
0000001d0;ooo`0<0?ooo`030=nLB000B9`0gooo02T0oooo00D0oono07@000000000001d0;ooo`0;
0?ooo`050?oog`2LB00000000000M02oool0:03oool01@3ookl0M0000000000007@0_ooo00T0oooo
00D0okmd000000000000000004RLg`0a0?ooo`030?noM0000000M;oo02L0oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo001H0?ooool00000<P00000W0?ooo`00F03oool3000000`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool2000002L0oooo001H0?ooo`80000000<0oooo000000000000
2P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0;0?ooo`8000009`3oool005P0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`0000009`3oool005P0oooo00@00000
0?ooo`3oool000000P3oool200000?l0oooo9P3oool010000000oooo0?ooo`00000W0?ooo`00F03o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo8`3oool010000000oooo
0?ooo`00000W0?ooo`00F03oool01@000000oooo0?ooo`3oool0000000@0oooo0P00003o0?ooob80
oooo00D000000?ooo`3oool0oooo0000000W0?ooo`00F03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo0P00003o0?ooob00oooo00D000000?ooo`3oool0oooo0000000W0?oo
o`00F03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooolL0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool005P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`800000o`3ooolK0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool005P0oooo0P0000050?ooo`030000003o
ool0oooo00H0oooo0P00003o0?oooaT0oooo00<000000?ooo`3oool00P3oool2000002L0oooo001H
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o
0?oooaD0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0P00003o0?oooa@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`800000o`3oool@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
9@3oool005P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`800000o`3o
ool>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool09@3oool005P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo2P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0303oool200000?l0oooo2@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03P3oool200000?l0oooo1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02D0
oooo001H0?ooo`8000002`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo
0`3oool00`000000oooo0?ooo`080?ooo`8000009`3oool005P0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0?0?ooo`800000o`3oool20?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U
0?ooo`00F03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo0P00003m0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0B0?ooo`800000nP3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
9@3oool005P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`800000m@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3b0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0E0?ooo`800000l@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
02D0oooo001H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`3]0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09@3oool005P0oooo
0P00000B0?ooo`030000003oool0oooo01L0oooo0P00003/0?ooo`030000003oool0oooo0100oooo
0P00000W0?ooo`00F03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0j@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo001H
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0603oool200000>P0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo02D0oooo000m0?ooo`050?oOW018000000000000M02oool00`3oool01@3o
_g@0000007Boo`3oool0_g@000H0000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01X0oooo0P00003S0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool09@3oool003`0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0
okmd0000001d_ol00P3oool00`3OW4P0000000000003000000030018W03Oool0oooo00D0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0K0?ooo`800000h@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo02D0oooo000l0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0
001d_`3oool01`3oool00`3OW4P0B9cO0?ooo`020?ooo`030=nLM02Lgol0oooo00D0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0=d0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0U0?ooo`00>`3oool00`3ookl0M00004RLg`030?oo
o`030=nLB00007@0_ooo00P0oooo00<0gia807Boo`3oool02@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01d0oooo0P00003L0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool09@3oool003/0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`090?ooo`03
0;mdB02Lgol0oooo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0=P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0U0?ooo`00
>`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0oooO09a8M02oool0
203oool3000001P0oooo00<000000?ooo`3oool07P3oool200000=L0oooo00<000000?ooo`3oool0
5P3oool3000002L0oooo000k0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3o
ool00`3o_g@007Bo0?ooo`070?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool07`3o
ool200000=D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0U0?ooo`00>`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo00<0oono07@0B02Lgol01`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0d@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02D0oooo000k0?ooo`030?oo_`1d0000B9cO
00<0oooo00<0gia80000M02oool02P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool08@3oool200000=00oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0U0?ooo`00?03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0
oooo00<0oknL09cOo`3oool00P3oool00`3ogi`0B00004RLg`070?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool08P3oool200000<d0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0U0?ooo`00?03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool01P3oool0203o
oml0W4Q809cOo`3oool0oono07@0000007@0_ooo1`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo02D0oooo000m0?ooo`050?oo_`1d000000000000M02oool0203oool01P3ooml0W4P0
000000000000001d0;ooo`P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0S0?oo
o`800000b03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02D0oooo001H0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0903oool200000<H0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo02D0oooo0P0000330?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
9@3oool005P0oooo0P00000Q0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0_`3o
ool00`000000oooo0?ooo`0N0?ooo`8000009`3oool005P0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0V0?ooo`800000_P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo02D0oooo001H0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`2j0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool09@3oool005P0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0X0?ooo`800000^P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0U0?ooo`00F03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02T0oooo0P00002c
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0:l0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo02X0oooo0P00002^0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool09@3oool005P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo0:X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0U0?ooo`00F03o
ool2000002T0oooo00<000000?ooo`3oool0;03oool200000:T0oooo00<000000?ooo`3oool09`3o
ool2000002L0oooo001H0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;@3oool2
00000:H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02h0oooo0P00002T0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0_0?ooo`800000X@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02D0
oooo001H0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0<03oool2000009h0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo0340oooo0P00002K0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0U
0?ooo`00F03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03<0oooo0P00002F0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0U0?ooo`00F03oool200000340oooo00<000000?ooo`3oool0
=03oool200000940oooo00<000000?ooo`3oool0;`3oool2000002L0oooo001H0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0e0?ooo`800000S03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo02D0oooo001H0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`280?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool09@3oool005P0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0f0?ooo`800000Q`3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo02D0oooo000m0?ooo`050?oOW018000000000000M02o
ool00`3oool00`3o_g@0000007Boo`050?ooo`040?oog`2LB00004RL0=ooo`L0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0880oooo0P00000g0?oo
o`030000003oool0oooo02D0oooo000l0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`02
0?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo0?oo
o`0f0?ooo`800000>03oool200000840oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0U0?ooo`00?03oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00T0oooo00@0oooO
09a80000B9`0gooo1`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03L0oooo0P00
001n0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool09@3oool003/0oooo00<0oono
07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030;md00000000000000D0000000<0M;oo
0?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02D0oooo000k0?oo
o`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool0203ogi`0M9cO0?ooo`3oool0
oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03P0oooo
0P00001i0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool09@3oool003/0oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`070=nLB01d_ol0oooo0?oog`2LB000
04RL0=ooo`070?ooo`<00000>`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0>@3oool3000002L0oooo000k0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol01P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool01`3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo03T0oooo0P00001d0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool09@3oool003/0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`070?ooo`060?oOW018M;l0oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo03X0oooo0P00001a0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool09@3oool003/0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`080?oo
o`050=nLB01d_ml0W4P00018W03Oool01`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo02D0oooo000l0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool0203oool01@3o
oml0W4Q804Q80000B9`0gooo00L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0k
0?ooo`800000J`3oool200000440oooo00<000000?ooo`3oool09@3oool002P0oooo00<0_gAd0;oo
o`3oool0103oool00`2oM7@0_ooo0?ooo`0:0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;oo
o`0:0?ooo`040?oOW018000004RL0=ooo`L0oooo00<000000?ooo`3oool0@03oool2000003d0oooo
0P00001X0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool09@3oool002P0oooo00<0
_g@004RLg`3oool00`3oool00`3OW4P0001d0;ooo`0<0?ooo`050?oo_`1d000000000000M02oool0
303oool00`3OW4P004RL0=ooo`070?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
9@3oool002P0oooo00T0_g@00000000007@0_ooo0?oog`2LB000B9cO0=nLW02oool09`3oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo03`0oooo0P00001S0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool09@3oool002P0oooo00H0_ibL0=oOW018000000000000B02LgolZ
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool09@3oool002P0oooo00<0_gAd0;oO
W01800000P000000100004P0W=oo0=nLW02ooolW0?ooo`800000AP3oool00`000000oooo0?ooo`0m
0?ooo`800000G@3oool2000004H0oooo0P00000W0?ooo`00:03oool00`2oM00004RL0=ooo`020?oo
o`040;md00000000001d0;ooobL0oooo00<000000?ooo`3oool0AP3oool2000003l0oooo0P00001J
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool09@3oool002P0oooo00<0_gA809cO
o`3oool00`3oool00`3o_g@0001d0;ooo`0W0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool09@3oool002P0oooo00<0_ibL0=ooo`3oool0103oool00`3OW9`0_ooo0?ooo`0V0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0?P3oool2000005D0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo03l0oooo0P00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002d0oooo00<0_ibL0=ooo`3oool00P3oool00`3OW9`0_ooo0?ooo`0S0?ooo`030000003o
ool0oooo04/0oooo0P0000110?ooo`030000003oool0oooo04d0oooo0P00001=0?ooo`030000003o
ool0oooo02D0oooo000Y0?ooo`050?oo_`1d04P0W=oo0?oo_`1d0000100000000`0007@0_ooo0?oo
o`0S0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0?`3oool2000004`0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`0U0?ooo`00<P3oool00`3OW9`0_ooo0?ooo`0S
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0@03oool2000004T0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`1?0?oo
o`800000@P3oool2000004D0oooo0P00001A0?ooo`030000003oool0oooo02D0oooo001H0?ooo`80
0000DP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0D03oool2000002L0oooo000_0?ooo`030;mdM02oool0oooo02H0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`110?ooo`800000@03oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo02D0oooo000_0?ooo`030;mdM02oool0oooo02H0oooo00<000000?ooo`3oool0D`3o
ool2000004<0oooo0P00000l0?ooo`800000E@3oool00`000000oooo0?ooo`0U0?ooo`00;`3oool0
0`2oM7@0_ooo0?ooo`0V0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool09@3oool0
02`0oooo00<0_g@00000000000000`0000000`0007@0_ooo0?ooo`0S0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool0@P3oool2000003H0oooo0P00001H0?ooo`030000003oool0oooo
02D0oooo000_0?ooo`030;mdM02oool0oooo02H0oooo00<000000?ooo`3oool0E`3oool2000004@0
oooo=P00001J0?ooo`030000003oool0oooo02D0oooo000_0?ooo`030;mdM02oool0oooo02H0oooo
00<000000?ooo`3oool0F@3oool200000480oooo0`00000`0?ooo`030000003oool0000005X0oooo
00<000000?ooo`3oool09@3oool002l0oooo00<0_gAd0;ooo`3oool09P3oool00`000000oooo0?oo
o`1K0?ooo`800000@03oool00`000000oooo0?ooo`02000002`0oooo0P0000020?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0G@3oool2
000003h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0U0?ooo`00:P3oool00`3o
oml0W7BL0=ooo`050?ooo`030=nLW02oool0oooo02<0oooo00<000000?ooo`3oool0G`3oool20000
03`0oooo00<000000?ooo`3oool00`3oool2000002H0oooo0P0000050?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool09@3oool002X0oooo00<0okmd0000000000001@0000000`0007@0
_ooo0?ooo`0S0?ooo`800000HP3oool2000003X0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0Q0?ooo`8000001`3oool00`000000oooo0?ooo`1G0?ooo`8000009`3oool00380oooo
00<0gibL0;ooo`3oool08`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool01P3oool2000001l0oooo0P0000090?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0I03oool2000003L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`8000002`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo06H0oooo0P00000e
0?ooo`030000003oool0oooo00T0oooo0P00000H0?ooo`8000003@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo02D0oooo000m0?ooo`050?oOW018000000000000M02oool00`3oool0
0`3o_g@0000007Boo`030?ooo`050?oOW018000000000000001d_ol0203oool00`000000oooo0?oo
o`1X0?ooo`800000<`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo0`00
000?0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool09@3oool003`0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool01`3ogi`0B000
04RLg`3oool0oono07@0001d_ol01`3oool00`000000oooo0?ooo`1Z0?ooo`800000<@3oool00`00
0000oooo0?ooo`0<0?ooo`800000403oool200000180oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0U0?ooo`00?03oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0
oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL0=ooo`060?ooo`030000003oool0oooo06`0
oooo0P00000_0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool3000001@0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0U0?ooo`00>`3oool00`3ookl0M000
04RLg`030?ooo`030=nLB00007@0_ooo00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`060?ooo`030000003oool0oooo06h0oooo0`00000/0?ooo`030000003oool0oooo00l0oooo
3@00000F0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool09@3oool003/0oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol01P3oool00`000000oooo0?ooo`1a0?ooo`@00000:03oool00`000000oooo0?oo
o`0@0?ooo`<00000103oool200000080oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo02D0oooo000k0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol01@3oool00`3ogi`0B00007Boo`030?ooo`030;md000004P0W=oo00H0oooo0`00001e
0?ooo`<000009@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@00000103oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05H0oooo0`00000W0?ooo`00>`3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0oono07@000000000B9cO0?ooo`3o
_g@00000001d_`L0oooo00<000000?ooo`3oool0N03oool300000280oooo00<000000?ooo`3oool0
3P3oool8000000D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo02D0oooo000k0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3o
ool00`2oM00004RL0;nLB002000000030018W03Oool0oooo00H0oooo00<000000?ooo`3oool0N`3o
ool5000001d0oooo00<000000?ooo`3oool02P3oool4000000P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool09@3o
ool003/0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030?oOW0180000
M;oo00/0oooo00<000000?ooo`3oool0P03oool5000001P0oooo00<000000?ooo`3oool01`3oool3
000000d0oooo0P0000020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0U0?ooo`00?03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo
00L0oooo00<0gia80000B02Lgol02P3oool00`000000oooo0?ooo`250?ooo`P00000403ooolO0000
01H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0U0?ooo`00?03oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool02@3oool00`3o_g@00000001d_`090?ooo`030000003oool0
oooo08d0oooo4@00000M0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0U0?ooo`00?@3oool01@3ookl0M0000000000007@0_ooo00/0oooo00D0oooO
09a800000000001d0;ooo`060?ooo`030000003oool0oooo0;`0oooo0P00000D0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0_P3oool2
00000180oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`00
0000oooo0?ooo`300?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0U0?ooo`00F03oool200000<80oooo0P00000?0?ooo`030000003oool0oooo05L0
oooo0P00000W0?ooo`00F03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?oo
o`340?ooo`800000303oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02D0oooo001H
0?ooo`030000003oool0oooo0<H0oooo0P00000:0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3o
ool0b@3oool2000000L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0U0?ooo`00
F03oool00`000000oooo0?ooo`3;0?ooo`800000103oool3000005T0oooo00<000000?ooo`3oool0
9@3oool005P0oooo00<000000?ooo`3oool0c@3oool00`000000oooo00000006000005L0oooo00<0
00000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0cP3oool8000005L0oooo00<00000
0?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0cP3oool9000005H0oooo00<000000?oo
o`3oool09@3oool005P0oooo0P00003?0?ooo`T00000E@3oool2000002L0oooo001H0?ooo`030000
003oool0oooo0<h0oooo2@00001F0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003o
ool0oooo0<l0oooo2000001F0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0
oooo0<l0oooo1`0000000`3oool000000000001D0?ooo`030000003oool0oooo02D0oooo001H0?oo
o`030000003oool0oooo0=40oooo0`0000050?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool09@3oool005P0oooo00<000000?ooo`3oool0fP3oool200000540oooo00<000000?ooo`3o
ool09@3oool005P0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo0=d0oooo0P00001>0?ooo`030000003o
ool0oooo02D0oooo001H0?ooo`030000003oool0oooo0=l0oooo0P00001<0?ooo`030000003oool0
oooo02D0oooo001H0?ooo`800000hP3oool00`000000oooo0?ooo`180?ooo`8000009`3oool005P0
oooo00<000000?ooo`3oool0hP3oool2000004T0oooo00<000000?ooo`3oool09@3oool005P0oooo
00<000000?ooo`3oool0i03oool2000004L0oooo00<000000?ooo`3oool09@3oool005P0oooo00<0
00000?ooo`3oool0iP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02D0oooo001H
0?ooo`030000003oool0oooo0>L0oooo0P0000140?ooo`030000003oool0oooo02D0oooo000m0?oo
o`050?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`050=nLB0000000
000000000018W=l0203oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool09@3oool003`0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo
00<0okmd0000001d_ol00P3oool01`3OW4P0000007Boo`3oool0oooO09a80018W=l01`3oool00`00
0000oooo0?ooo`3Z0?ooo`800000@@3oool00`000000oooo0?ooo`0U0?ooo`00?03oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@0
04RL0=ooo`060?ooo`030000003oool0oooo0>`0oooo0P00000o0?ooo`030000003oool0oooo02D0
oooo000k0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM00007Bo
0?ooo`020?ooo`030;md0000B9`0gooo00H0oooo00<000000?ooo`3oool0kP3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo02D0oooo000k0?ooo`030?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol01P3oool01`3ogi`0B01d0;ooo`3oool0_g@00000001d_ol01`3oool00`000000
oooo0?ooo`3_0?ooo`800000?03oool00`000000oooo0?ooo`0U0?ooo`00>`3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00L0oooo00D0oono07A8B0180000000004RLg`080?ooo`<0
0000l@3oool2000003P0oooo0`00000W0?ooo`00>`3oool00`3ogi`0B00007Boo`030?ooo`030?no
M00004P0W=oo00L0oooo00@0omnL04P00000000007Bo2@3oool00`000000oooo0?ooo`3c0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool09@3oool003/0oooo00<0omnL04P0001d_ol0
0`3oool00`3o_g@0001809cOo`060?ooo`060?oOW0180000001d0;ooo`3o_g@007Bo203oool00`00
0000oooo0?ooo`3d0?ooo`800000=`3oool00`000000oooo0?ooo`0U0?ooo`00>`3oool00`3ookl0
M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0_g@00000M02oool00P3oool00`2oM000
B9cO0?ooo`060?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0U0?ooo`00?03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo
00<0_g@00018W03Oool00P3oool00`3OW4P007Bo0?ooo`060?ooo`030000003oool0oooo0?L0oooo
0P00000d0?ooo`030000003oool0oooo02D0oooo000l0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0
001d0;ooo`070?ooo`070?noM0000000M;oo0?ooo`3ookl0M00007Boo`070?ooo`030000003oool0
oooo0?T0oooo0P00000b0?ooo`030000003oool0oooo02D0oooo000m0?ooo`050?oo_`1d00000000
0000M02oool02@3oool01@3o_g@00000000000000000B9cO00P0oooo00<000000?ooo`3oool0n`3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0
oooo0?`0oooo0P00000_0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo
0?h0oooo0P00000]0?ooo`030000003oool0oooo02D0oooo001H0?ooo`800000o`3oool20?ooo`03
0000003oool0oooo02T0oooo0P00000W0?ooo`00F03oool00`000000oooo0?ooo`3o0?ooo`80oooo
0P00000Z0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo0?l0oooo103o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0
oooo0?l0oooo1@3oool2000002L0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?oo
o`3oool0o`3oool70?ooo`8000009@3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000
oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0U0?ooo`00
F03oool00`000000oooo0?ooo`3o0?ooo`X0oooo0P00000R0?ooo`030000003oool0oooo02D0oooo
001H0?ooo`030000003oool0oooo0?l0oooo303oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02D0oooo001H0?ooo`030000003oool0oooo0?l0oooo3@3oool2000001l0oooo00<00000
0?ooo`3oool09@3oool005P0oooo0P00003o0?oooa00oooo00<000000?ooo`3oool06`3oool20000
02L0oooo001H0?ooo`030000003oool0oooo0?l0oooo403oool2000001`0oooo00<000000?ooo`3o
ool09@3oool005P0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`8000006@3o
ool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`3o0?oooaD0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`3o0?oo
oaH0oooo0P00000F0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo0?l0
oooo603oool2000001@0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0
o`3ooolJ0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool005P0oooo00<0
00000?ooo`3oool0o`3ooolK0?ooo`8000004@3oool00`000000oooo0?ooo`0U0?ooo`00F03oool0
0`000000oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0U
0?ooo`00F03oool200000?l0oooo7`3oool2000000d0oooo0P00000W0?ooo`00F03oool00`000000
oooo0?ooo`3o0?ooob00oooo0P00000<0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000
003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo
001H0?ooo`030000003oool0oooo0?l0oooo8`3oool2000000T0oooo00<000000?ooo`3oool09@3o
ool004/0oooo00H0_g@000000000000000000018W03Oool70?ooo`030000003oool0oooo0?l0oooo
9@3oool2000000L0oooo00<000000?ooo`3oool09@3oool004`0oooo00<0omnL04P0001d_ol02@3o
ool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0U0?ooo`00C03oool00`3ogi`0B00007Boo`090?ooo`030000003oool0oooo0?l0oooo:03oool2
000000@0oooo00<000000?ooo`3oool09@3oool004`0oooo00<0omnL04P0001d_ol02@3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo03H0oooo0P0000020?ooo`030000003oool0oooo
02D0oooo001<0?ooo`030?oOW0180000M;oo00T0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0:0?ooo`<000009`3oool004`0oooo00<0omnL04P0001d_ol02@3ooooo000003800000
9`3oool004`0oooo00<0omnL04P0001d_ol0o`3ooomR0?ooo`00C03oool00`3ogi`0B00007Boo`3o
0?ooof80oooo001<0?ooo`030?oOW0180000M;oo0?l0ooooHP3oool004`0oooo00<0omnL04P0001d
_ol0o`3ooomR0?ooo`00BP3oool01@3ooml0W4P0000000000000M;oo0?l0ooooHP3oool004`0oooo
00<0okmd0000001d_ol0o`3ooomR0?ooo`00o`3ooolR0?ooo`030?oog`2LB4P0W=oo02H0oooo00<0
omnL04Q8W03Oool0H`3oool00?l0oooo8P3oool00`2oM4P0W=oo0?ooo`0W0?ooo`030?oOW018M;l0
oooo0680oooo003o0?ooob40oooo00<0gia804RLg`3oool0:@3oool00`3OW4P0B9cO0?ooo`1Q0?oo
o`00o`3ooolP0?ooo`030?oo_`1d07@0_ooo02X0oooo00<0oono07@0B02Lgol0H@3oool008H0oooo
00<0omnL04P0000000000P0000000`0007@0_ooo0?ooo`030?ooo`050=nLB000000000000000001d
_ol00`3oool01P3ooml0W4P0000000000000001809cOo`D0oooo00<0omnL07BLg`3oool00P3oool0
0`3OW7@0W=oo0?ooo`040?ooo`050;md0000000000000000M02oool00P3oool01P3ooml0W4P00000
00000000001809cOo`H0oooo00<0_g@00000000000000P0000000`00M;l0oooo0?ooo`030?ooo`07
0=nLB000000000000000M02oool0oooo0=nLB0030000000807Boo`3oool0oooo0?ooo`3ogi`0B000
00000018W=l40?ooo`030?oOW018000000000080000000@0M;oo0?ooo`3oool0gia80`000000101d
_ol0oooo0?ooo`2oM002000000070000B02Lgol0oooo0?oog`2LB000001d0;ooo`060?ooo`030;md
00000000000000@0000000T0B9cO0?ooo`3oool0okmd0000001d_ol0oooo0?oog`2LB0000`000000
0`1d_ol0oooo0?ooo`060?ooo`030=nLB000B9`0gooo00<0oooo00H0_g@000000000000000000018
W03OoolF0?ooo`050;md0000000007Bo0?ooo`3OW4P00P0000001`00B9`0gooo0?ooo`3oool0oooO
09a80018W=l01@3oool01@2oM0000000001d_`3oool0gia80080000000<004RL0=ooo`3oool0DP3o
ool008D0oooo00@0gia800000000B9`0gooo0P3oool00`3ookl0M01809cOo`020?ooo`070=nLB000
0000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B00007Boo`04
0?ooo`070;md000007@0_ooo0?ooo`3ookl0M000001d_`040?ooo`0?0;md0000000007Bo0?ooo`3o
gi`0B01d0;ooo`3oool0_g@00018W03Oool0oooo0?oOW0180000M;oo00H0oooo00@0oooO09a80000
B9`0gooo1`3oool02`3OW4P0001d0;ooo`3oool0gia800000018W=l0oooo0?oog`2LB000B9cO0080
oooo00D0gia80000M02oool0gkno0=ooo`040?ooo`030?oog`2LB00007Bo00<0oooo00L0gia80000
0018W=l0oooo0?oog`2LB000B9cO0080oooo00<0gia80000M02oool00P3oool0103ooml0W4P00000
M02oool70?ooo`030=nLB0000000000000<0000000X004RL0=ooo`3oool0okmd0000001d_ol0oooo
0?oog`2LB7@0_ooo0P3oool00`2oM000M;oo0?ooo`060?ooo`030;md0000M;l0oooo00@0oooo00<0
omnL04P0001d_ol0603oool0203ooml0W4Qd0;ooo`3oool0oooO09a80000B9`0gooo103oool00`3O
W4P004RL0=ooo`040?ooo`080?oog`2LB7@0_ooo0?ooo`3ooml0W4P00018W03OoomD0?ooo`00Q03o
ool00`3o_g@00000001d_`050?ooo`060?oog`2LB7@0_ooo0?oOW018000007Bo0`3oool01`3o_g@0
001d0;ooo`3oool0_g@00018W03Oool00P3oool00`3o_g@0001d0;ooo`020?ooo`090?oOW0180000
B7Ad07BLg`3oool0okmd0000B018B4P0W=oo0080oooo00<0omnL04P00018W=l00`3oool01P3ogi`0
M9cO0?ooo`2oM00004RL0=ooo`80oooo00<0okmd0000M02oool01@3oool00`3ooml0W4P0001d_`08
0?ooo`060=nLB00007@0_ooo0?oOW018000007Bo0`3oool01`3o_g@0001d0;ooo`3oool0gia80018
W03Oool01P3oool00`3ooml0W4P0001d_`020?ooo`030?oOW018000007Bo00<0oooo00L0okmd0000
M02oool0oooo0=nLB00007@0_ooo00h0oooo00<0gia804RLg`3oool00P3oool00`3OW7@0W=oo0?oo
o`090?ooo`030?oog`2LB7@0_ooo00D0oooo00<0oono07@00018W=l01@3oool00`3ogi`0B00007Bo
o`0I0?ooo`060?oo_`1dB9`0gooo0;md000007@0_ooo1@3oool00`3OW4P0001d0;ooo`050?ooo`06
0?oo_`1dB9`0gooo0;md000007@0_oooE@3oool008<0oooo00@0oooO09a8000007@0_ooo203oool0
0`3o_g@0000007Boo`030?ooo`070?noM0000000M;oo0?ooo`2oM00004RL0=ooo`020?ooo`030?oO
W0180000M;oo0080oooo00T0gia80000M02oool0_gAd0;oog`2LB00007Bo0?oOW01dW=l00P3oool0
0`3o_g@0001809cOo`060?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P0001d_ol01@3oool0
0`3ooml0W4P0001d_`080?ooo`060=nLB00007@0_ooo0?noM0000000M;oo0`3oool01`3o_g@00000
07Boo`3oool0gia80018W03Oool01P3oool00`3ooml0W4P0001d_`020?ooo`030?noM0000000M;oo
00<0oooo00L0okmd0000001d_ol0oooo0=nLB00007@0_ooo00l0oooo00<0gia807Boo`3oool03P3o
ool00`2oM000M;oo0?ooo`040?ooo`030?oo_`1d0000M;oo00D0oooo00<0omnL04P0001d_ol06P3o
ool0103ogi`0M4Q80000001d_ol60?ooo`030?noM00007@0_ooo00H0oooo00@0omnL07A8B0000000
M;ooEP3oool008<0oooo00@0omnL04P00000B9`0gooo203oool00`3o_g@0000007Boo`030?ooo`07
0?noM0000000M;oo0?ooo`2oM00004RL0=ooo`020?ooo`0C0?oOW0180000M;oo0?ooo`3ookl0M000
04RLg`3oool0omnL07AdM01804P0W=oo0?ooo`2oM7@0_ooo0?ooo`3o_g@0001d0;ooo`060?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P0001d_ol01@3oool00`3ooml0W4P0001d_`080?ooo`06
0=nLB00007@0_ooo0?noM0000000M;oo0`3oool01`3o_g@0000007Boo`3oool0gia80018W03Oool0
1P3oool00`3ooml0W4P0001d_`020?ooo`030?noM0000000M;oo00<0oooo00L0okmd0000001d_ol0
oooo0=nLB00007@0_ooo0100oooo00<0_gA809cOo`3oool0303oool00`3ooml0W4P004RLg`050?oo
o`030?oo_`1d0000M;oo00D0oooo00<0omnL04P0001d_ol0203oool00`3ooml0W4P0000000070000
000304RLg`3oool0oooo00D0oooo00<0oono07@00018W=l01`3oool00`3o_g@0001809cOo`060?oo
o`030?oo_`1d0000B9cO05L0oooo00230?ooo`030?noM000000007Bo00T0oooo00<0oono07@0001d
_ol00`3oool01`2oM000001809cOo`3oool0_g@00018W03Oool00P3oool02`3o_g@0001809cOo`3o
ool0gia80000B02Lgol0oooo0?oog`2LB00007Bo0080oooo00D0okmd04RLg`3oool0omnL04P00005
0000000504RLg`3oool0_g@00018W03Oool00P3oool00`3o_g@0001809cOo`050?ooo`030?oog`2L
B000000000@0000000X0M;oo0?ooo`3oool0oooo0=nLB00007@0_ooo0?oo_`1d0000M;oo0`3oool0
1`2oM000001809cOo`3oool0gia80018W03Oool01P3oool00`3ooml0W4P0001d_`020?ooo`030?oo
_`1d0000M;oo00<0oooo00L0_g@00000B02Lgol0oooo0=nLB00004P0W=oo0100oooo00<0oooO09a8
M02oool0303oool00`3OW4P0000007Boo`050?ooo`030?oo_`1d0000M;oo00D0oooo00<0omnL04P0
001d_ol06@3oool01@3ooml0W4P00018W02LM4P0W=oo00H0oooo00<0okmd0000M02oool01@3oool0
1@3ooml0W4P00018W02LM4P0W=oo05H0oooo00230?ooo`030?noM000000007Bo00X0oooo00L0gia8
0018W03Oool0oooo0?noM000000007Bo0080oooo00/0_g@000000000B9`0gooo0?oo_`1d000004RL
0=ooo`3ookl0M000001d_`020?ooo`030?oOW0180000M;oo0080oooo00H0oooO09a8M02oool0oooo
0;md0018W=l20?ooo`0<0=nLB00004P0W=oo0?ooo`2oM00000000018W03Oool0oono07@00000B9`0
gooo1@3oool00`3ooml0W4P0001d_`020?ooo`040?oog`2LB000000004RLg`80oooo00/0gia80000
M02oool0oooo0=nLB000B9`0gooo0?ooo`3o_g@00000001d_`020?ooo`030=nLB000B9`0gooo00H0
oooo00<0oooO09a80000M;l00`3oool04P3OW4P004RL0=ooo`3oool0okmd00000000M;l0oooO09a8
00000000001804QdW03O_g@0001d0;oog`2LB000001d0;ooo`/0oooo00<0okmd001d_`3oool01`3o
ool01`3Ogml0oooo0?oo_`1d000000000000M02oool01@3oool00`3ookl0M00004RLg`050?ooo`03
0?oOW0180000M;oo01T0oooo00H0_g@00000B02Lgol0oooO09a8M02oool50?ooo`030=nLB00007@0
_ooo00D0oooo00H0_g@00000B02Lgol0oooO09a8M02ooomE0?ooo`00P`3oool0103ogi`0B0000018
W03Oool:0?ooo`050?noM0000000000000000018W=l00`3oool02@2oM00004RL0=oOW01800000000
0018W03Oool0oooO09a800020000000304RLg`3o_g@000000080000000P0B9cO0?ooo`2oM0000000
0018W03Oool0oooo0=nLB080000000/0001809cOo`3oool0oooo0;md0000B9`0gmnL04P000000000
04RL0=ooo`060?ooo`030?oog`2LB00007Bo00<0oooo00P0oono07@0000007@0_ooo0?ooo`3OW4P0
001d0;ooo`80oooo00D0okmd000000000000000004RLg`020?ooo`060;md00000000000000000000
B9`0gooo0`3oool00`3o_g@0000000000002000000040018W03Oool0oooo0?noM0<0000000d0B9cO
0?ooo`3oool0oooo0;md000007@0_mnL04P0000007@0_ooO09a8000007@0_ooo00/0oooo00<0oono
07@0B02Lgol01`3oool01P3OW4P00000000000000000001809cOo`H0oooo00<0oooO09a80018W=l0
1@3oool00`3ogi`0B00007Boo`0G0?ooo`090?oog`2LB000000000000000M;l0okmd0000000007@0
_ooo00@0oooo00<0gia80018W03Oool00`3oool02@3ooml0W4P000000000000007Bo0?noM0000000
001d0;ooo`1D0?ooo`00P`3oool0103ooml0W4P00000B02Lgol50?ooo`030?oog`2LM9`0gooo00X0
oooo00<0_g@00018W03Oool06`3oool00`2oM00004RL0=ooo`0:0?ooo`030?oog`2LB00007Bo00<0
oooo00P0oooO09a8000004P0W=oo0?ooo`3OW4P0001d0;ooo`X0oooo00<0_g@00018W03Oool01P3o
ool00`3ooml0W4P0001d_`0P0?ooo`030?oo_`1d0000B9cO00L0oooo00@0oono07@000000000B9cO
2@3oool00`3OW4P004RL0=ooo`040?ooo`030?oOW0180000M;oo02<0oooo00<0oooO09a80018W=l0
H@3oool008@0oooo00<0omnL04P00000M;l01@3oool00`3o_g@004RL0=ooo`0:0?ooo`030;md0000
B9`0gooo01/0oooo00<0_g@00018W03Oool02P3oool00`3ooml0W4P0001d_`030?ooo`080?oOW018
0000001d0;ooo`3oool0gia80000M02oool:0?ooo`030?oo_`1dB9`0gooo00L0oooo00<0_g@0001d
_`3oool06P3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW0180000B9cO00P0oooo00<0_g@007Bo
o`3oool02@3oool00`3ookl0M01809cOo`040?ooo`030?oOW0180000M;oo02<0oooo00<0oono07@0
B02Lgol0H@3oool008D0oooo00<0okmd00000000M;l00`3oool00`3OW4P00000001d_`0;0?ooo`03
0;md0000B9`0gooo01/0oooo00<0_g@00018W03Oool02P3oool00`3ooml0W4P0001d_`020?ooo`04
0?oo_`1d0000000004RLg`80oooo00<0gia80000M02oool02P3oool00`3ooml0W7BL0=ooo`070?oo
o`030=nLB000M;l0oooo01X0oooo00P0oooO09a8B02Lgol0oooo0?oo_`1d0000001d0;ooo`P0oooo
00H0omnL04P00000000000000000B02Lgol70?ooo`060=nLB018W=l0oooo0?ooo`3ooml0W4P00P00
00000`1d_ol0oooo0?ooo`0Q0?ooo`030=nLB018W=l0oooo0640oooo00260?ooo`030?oog`2LB000
00000080000000<0B9cO0?oo_`1dM;l02@3oool01@3ookl0M00000000000B9`0gooo01T0oooo00D0
oono07@00000000004RL0=ooo`090?ooo`030;md00000000000000@0000000P0001809cOo`3oool0
oooO09a800000000001d0;oooa@0oooo00L0oono07@0M02oool0oooO09a80000B9`0gooo01L0oooo
00H0oooO09a80000000000000000M02oool:0?ooo`050;md00000000000000000018W=l0203oool0
0`2oM000B9cO0?ooo`020?ooo`030?noM0000000M;oo0280oooo00<0okmd001d_`3oool0HP3oool0
09P0oooo00@0oooO09a80000B9`0gooo6P3oool0103ooml0W4P00018W03OoolE0?ooo`030;md0000
07@0_ooo01D0oooo00D0oono07@000000000001809cOo`0f0?ooo`030=nLM02Lgol0oooo02D0oooo
00<0oono07Ad_`3oool0H`3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.292307, -0.270979, \
0.00493931, 0.00799197}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Emergence of stable cycles for 3<\[Mu]\[LessTilde]3.8"], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(logisticCobweb[3.2, 0.2, 20, 0];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -9.5 -15.6875 ]
[.21429 -0.0125 9.5 0 ]
[.40476 -0.0125 -9.5 -15.6875 ]
[.40476 -0.0125 9.5 0 ]
[.59524 -0.0125 -9.5 -15.6875 ]
[.59524 -0.0125 9.5 0 ]
[.78571 -0.0125 -9.5 -15.6875 ]
[.78571 -0.0125 9.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .01472 -10 -7.84375 ]
[-0.0125 .01472 0 7.84375 ]
[-0.0125 .13244 -19 -7.84375 ]
[-0.0125 .13244 0 7.84375 ]
[-0.0125 .25016 -19 -7.84375 ]
[-0.0125 .25016 0 7.84375 ]
[-0.0125 .36788 -19 -7.84375 ]
[-0.0125 .36788 0 7.84375 ]
[-0.0125 .4856 -19 -7.84375 ]
[-0.0125 .4856 0 7.84375 ]
[-0.0125 .60332 -10 -7.84375 ]
[-0.0125 .60332 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -11.4063 ]
[-0.01875 .30902 -19 11.4063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74.9688 0 ]
[.5 .63053 74.9688 15.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cobweb) show
105.875 15.813 moveto
(Plot) show
128.188 15.813 moveto
(for) show
142.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
148.375 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.375 15.813 moveto
(H) show
170.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
179.188 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
189.875 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
196.000 15.813 moveto
(L) show
202.813 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
208.938 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
.02381 .01472 m
.06244 .08802 L
.10458 .16091 L
.14415 .22264 L
.18221 .27588 L
.22272 .32594 L
.26171 .36768 L
.30316 .40513 L
.34309 .43447 L
.3815 .45644 L
.40095 .46522 L
.42237 .47308 L
.44268 .47878 L
.45178 .48077 L
.46172 .48255 L
.4671 .48335 L
.4721 .48398 L
.47727 .48453 L
.48196 .48492 L
.48658 .48522 L
.4887 .48533 L
.49093 .48543 L
.49332 .48551 L
.49438 .48553 L
.49552 .48556 L
.49675 .48558 L
.49789 .48559 L
.49859 .48559 L
.49925 .4856 L
.50049 .4856 L
.50163 .48559 L
.50286 .48558 L
.50401 .48556 L
.50508 .48554 L
.50754 .48548 L
.51014 .48538 L
.51268 .48526 L
.51504 .48513 L
.5204 .48473 L
.5293 .48381 L
.53882 .48247 L
.54906 .4806 L
.56016 .47808 L
.58032 .4722 L
.60019 .46475 L
.62123 .45508 L
.65912 .43302 L
.69946 .40298 L
.73829 .36769 L
.77956 .3233 L
Mistroke
.81932 .27385 L
.85757 .2201 L
.89827 .15622 L
.93745 .08822 L
.97619 .01472 L
Mfstroke
.21429 .13244 m
.21429 .31608 L
.51143 .31608 L
s
.51143 .31608 m
.51143 .48533 L
.78528 .48533 L
s
.78528 .48533 m
.78528 .3166 L
.51227 .3166 L
s
.51227 .3166 m
.51227 .48529 L
.78521 .48529 L
s
.78521 .48529 m
.78521 .31668 L
.5124 .31668 L
s
.5124 .31668 m
.5124 .48528 L
.7852 .48528 L
s
.7852 .48528 m
.7852 .31669 L
.51242 .31669 L
s
.51242 .31669 m
.51242 .48528 L
.7852 .48528 L
s
.7852 .48528 m
.7852 .31669 L
.51242 .31669 L
s
.51242 .31669 m
.51242 .48528 L
.7852 .48528 L
s
.7852 .48528 m
.7852 .31669 L
.51242 .31669 L
s
.51242 .31669 m
.51242 .48528 L
.7852 .48528 L
s
.7852 .48528 m
.7852 .3167 L
.51242 .3167 L
s
.51242 .3167 m
.51242 .48528 L
.7852 .48528 L
s
.7852 .48528 m
.7852 .3167 L
.51242 .3167 L
s
.51242 .3167 m
.51242 .48528 L
.7852 .48528 L
s
.7852 .48528 m
.7852 .3167 L
.51242 .3167 L
s
.51242 .3167 m
.51242 .48528 L
.7852 .48528 L
s
.7852 .48528 m
.7852 .3167 L
.51242 .3167 L
s
.51242 .3167 m
.51242 .48528 L
.7852 .48528 L
s
.7852 .48528 m
.7852 .3167 L
.51242 .3167 L
s
.03 w
.21429 .13244 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00m@3oool01@3ooml0W4P00000
0000B9`0gooo0;H0oooo003f0?ooo`030?oOW01804P0W=oo0;L0oooo003]0?ooo`050;md00000000
07Bo0?ooo`3OW4P00P0000001@00B9`0gooo0?oOW01804P0W=oo0;L0oooo003]0?ooo`0<0?oog`2L
B7@0_ooo0?ooo`3ooml0W4P00018W03Oool0oooo0?oOW01804P0W=oo]`3oool00>h0oooo00/0oono
07A8W03Oool0_g@00000M02oool0oooo0?oo_`1d0000001809cOo`2g0?ooo`00k`3oool0103ogi`0
M4Q80000001d_ol30?ooo`030?oOW01804P0W=oo0;L0oooo003_0?ooo`030?oo_`1d0000B9cO0;h0
oooo003^0?ooo`050?oog`2LB00004RL09adB02Lgol0_@3oool00>h0oooo00H0_g@00000B02Lgol0
oooO09a8M02oool20?ooo`030?oo_`1d0000M;oo0;L0oooo003/0?ooo`090?oog`2LB00000000000
0000M;l0okmd0000000007@0_ooo0;/0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001Q0?ooo`050?oOW01800000000
0000M02oool0;P3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00D0okmd0000001d_ol0oooo
0;md00060000000304RLg`3oool0oooo02@0oooo00D0omnL04P000000000001d0;ooo`030?ooo`03
0?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo9@3oool01@3ogi`0B0000000000007@0
_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3ogi`0B000000000000000M;oo02L0oooo00D0
omnL04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00<0oooo00D0gia8000000000000
000004RLg`0^0?ooo`060;md00000000000000000000B9`0gooo:03oool00600oooo00L0oono07@0
001d_ol0oooo0?noM00007@0_ooo02`0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080
oooo00<0okmd0000001d_ol00P3oool00`3OW4P0000000000003000000030018W03Oool0oooo02<0
oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol01@3oool0
103ooml0W4P00018W03OoolT0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`03
0?noM0000000M;oo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000M;oo02D0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool01`3OW4P00000
07Boo`3oool0oooO09a80018W=l0;P3oool00`3ogi`0B00007Boo`0Z0?ooo`00H03oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo02/0oooo00<0_g@00018W03Oool00P3oool00`2oM000
07Bo0?ooo`070?ooo`030=nLB018W=l0oooo0080oooo00<0giad09cOo`3oool08`3oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo00T0oooo00@0oooO09a80000B9`0gooo903oool00`2o
M00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o
_g@004RL0=ooo`0T0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3o
oml0W4P0001d_`030?ooo`030?noM000B9`0gooo02d0oooo00<0omnL04P0001d_ol0:P3oool005l0
oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0Z0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool0203oool00`3OW4P0M;oo0?ooo`0V0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool01@3oool00`2oM0000000000000050000000307Boo`3oool0oooo0200
oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol08`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0
oooo00<0_g@0001d_`3oool00P3oool00`2oM00004RL0=ooo`0]0?ooo`030?oOW0180000M;oo02X0
oooo001O0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0:P3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0_gA809cOo`3oool09@3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL
0=ooob<0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol08`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00H0oooo00L0omnL04P0M02oool0oooo0;md00000000M;oo02h0oooo00<0omnL04P0001d_ol0
:P3oool005l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol02@3oool00`3ooml0W4Qd0;ooo`0U0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03O
ool08`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d
_ol00`3oool00`2oM000001809cOo`0S0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool01@3ookl0M4Q804P000000000B9cO02l0oooo00<0omnL04P0001d_ol0:P3oool005l0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol02P3oool00`3o_g@007Bo0?ooo`0T0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool08`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0oono07@000000000B9cO0?oo
o`3o_g@00000001d_b@0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`04
0?oOW01800000000001d_c00oooo00<0omnL04P0001d_ol0:P3oool005l0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol02P3oool00`3ookl0M01809cOo`0T0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool01P3ogi`0B7Bo0?oog`2LB00004RL0=ooob<0oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`060?ooo`030;md0000B9`0_ia80080000000<004RL0=ooo`3oool08`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0omnL04P0000007@0_ooo0?no
M000M;l_0?ooo`030?oOW0180000M;oo02X0oooo001O0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool0:P3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0
oono07@00018W=l0903oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00P0oooo00D0
gia807Bog`2LB00004RL0=ooo`0S0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1P3oool00`3ogi`0B00007Boo`0X0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1P3oool00`2oM000001d0;ooo`020?ooo`030;md0018W=l0oooo02d0oooo00<0omnL04P0001d_ol0
:P3oool00600oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`0[0?ooo`030=nLB000
B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW018
0000B9cO02D0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`050?oog`2L
B4P0B4P00018W03Oool0903oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo
00<0gia80000B02Lgol0:03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo
00<0_g@00018W03Oool00P3oool00`3OW4P007Bo0?ooo`0]0?ooo`030?oOW0180000M;oo02X0oooo
001P0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0/0?ooo`070?oo_`1d0000M;oo0?oo
o`3o_g@0001d0;ooo`060?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02ooolU0?ooo`07
0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0:0?ooo`040?oOW018000004RL0=ooob@0oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo00T0oooo00<0okmd00000000M;l09`3oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool01`3oool01`3o_g@0000007Boo`3oool0oono07@0001d_ol0
;03oool01@3ooml0W4P0000000000000M;oo02X0oooo001Q0?ooo`050?oo_`1d000000000000M02o
ool0;P3oool01@3ookl0M0000000000007@0_ooo00P0oooo00H0oooO09a80000000000000000M02o
oolW0?ooo`050?oo_`1d000000000000M02oool0303oool00`3OW4P004RL0=ooo`0U0?ooo`050?oo
_`1d000000000000M02oool02`3oool01@3ooml0W4P00000000007@0_ooo02D0oooo00D0oono07@0
00000000001d0;ooo`090?ooo`050?noM0000000000000000018W=l0;`3oool00`3o_g@0000007Bo
o`0Z0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00CP3oool01@3ogi`0B000
0000000007@0_ooo00T0ooooo`00000b000002<0oooo001=0?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool004d0
oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08@3oool004`0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d
0;ooo`070?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00C03o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0o`3o
ool^0?ooo`030000003oool0oooo0240oooo001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol01`3oool3000000@0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030000003oool0
oooo00<0oooo0`00000S0?ooo`00C03oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00L0oooo00<000000?ooo`3oool01@3oool200000?l0oooo7P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0240oooo001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool00`000000oooo0?ooo`050?ooo`040000003oool0000000000?l0oooo703oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0240oooo001<0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool01`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0000
0?l0oooo6P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0240oooo001=0?ooo`03
0=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo0?ooo`800000o`3ooolH0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool08@3oool004d0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`800000o`3ooolE0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool08@3oool004h0oooo00D0oono07@000000000001d0;ooo`09
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool200000?l0oooo4`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00H0oooo0P00003o0?ooo`l0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0Q0?ooo`00G03oool2000000X0oooo00<000000?ooo`3oool01`3oool200000?l0oooo
303oool00`000000oooo0?ooo`080?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool200000?l0oooo203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0240oooo001L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Q0?oo
o`00G03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo0P00003o0?ooo`@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00`0oooo0P00003o0?ooo`80oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool2
00000?d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0n@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0240oooo001L0?ooo`8000003`3oool00`000000
oooo0?ooo`0@0?ooo`800000n@3oool00`000000oooo0?ooo`0<0?ooo`<000008`3oool005`0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?D0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0180oooo0P00003e0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q
0?ooo`00G03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo0P00003a0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01H0oooo0P00003]0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
8@3oool005`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0>T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01P0oooo0P00003Y0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool08@3oool005`0oooo0P00000D0?ooo`030000003oool0oooo
01T0oooo0P00003V0?ooo`030000003oool0oooo0140oooo0`00000S0?ooo`00G03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0h`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool06`3oool200000>80oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0gP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0240oooo0011
0?ooo`050?oOW018000000000000M02oool00`3oool01@3o_g@0000007Boo`3oool0_g@000H00000
00<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo
0P00003N0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool08@3oool00400oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool00`3OW4P0
000000000003000000030018W03Oool0oooo00D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0N0?ooo`800000103oool300000=@0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0Q0?ooo`00@03oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo
00<0gia804RLg`3oool00P3oool00`3OW7@0W=oo0?ooo`050?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0803oool900000=80oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00P0oooo00<0
gia807Boo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0240oooo1`00
003A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL
04P0001d_ol00`3oool00`3o_g@0001809cOo`090?ooo`030;mdB02Lgol0oooo00P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0O0?ooo`T00000d03oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000
B02Lgol02@3oool00`3ooml0W4Qd0;ooo`080?ooo`<00000603oool00`000000oooo0?ooo`0O0?oo
o`T00000c`3oool00`000000oooo0?ooo`0F0?ooo`<000008`3oool003l0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?noM000M;l0oooo00L0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0N0?ooo`T00000cP3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0
2P3oool00`3ookl0M01809cOo`070?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
7`3oool900000<d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0Q0?ooo`00?`3o
ool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0oono07@00018W=l01`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01h0oooo1`0000020?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool0
0`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oknL09cOo`3oool00P3oool0
0`3ogi`0B00004RLg`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07`3oool3
000000D0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0240oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`060?ooo`080?oog`2L
B4P0W=oo0?ooo`3ookl0M0000000M02oool70?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`050?ooo`800000a`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0240oooo00110?ooo`050?oo_`1d000000000000M02oool0203oool01P3o
oml0W4P0000000000000001d0;ooo`P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0<80oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool200000<40oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool2000001l0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool06`3oool3000002<0oooo001L0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0<0?ooo`800000_@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0240oooo001L0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0>0?ooo`800000^P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0@0?ooo`800000^03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0240oooo001L0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0B0?ooo`800000]@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0D0?ooo`800000/P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240
oooo001L0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0F0?ooo`800000/03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo
001L0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0Q0?ooo`00G03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool06@3oool200000:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Q
0?ooo`00G03oool2000002@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0:L0oooo00<000000?ooo`3oool08P3oool3000002<0oooo001L0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0L0?ooo`80
0000Y`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0:<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Q0?ooo`00G03o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07`3o
ool200000:80oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool08@3oool0
05`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0280oooo0P00002N0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool08@3oool005`0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0240
oooo001L0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0U0?ooo`800000VP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0240oooo
001L0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0W0?ooo`800000U`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0240oooo001L
0?ooo`800000:P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`0X0?ooo`<000008`3oool005`0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02X0oooo0P00002C0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02`0oooo0P00002@0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool08@3oool00440oooo00D0omnL04P000000000
001d0;ooo`030?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo1`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;P3oool20000
08d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`050?ooo`040?oog`2LB000
04RL0=ooo`L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo0240oooo00100?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool02@3oool0
103ooml0W4P00018W03Oool70?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0a0?ooo`800000R@3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool0
0`2oM0000000000000050000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo
00<0oooo00<0okmd0000B02Lgol01@3oool0203ogi`0M9cO0?ooo`3oool0oooO09a80000B9`0gooo
1`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
=03oool2000008D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Q0?ooo`00?`3o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0gia807Boo`3oool0oooO
09a80000B9`0gooo00L0oooo0`00000^0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo02d0oooo0`00000S0?ooo`00
?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0oooO09a8M02oool0
oooO09a80000B9`0gooo00L0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo03L0oooo0P0000210?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`06
0?oOW018M;l0oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool08@3oool003l0oooo00<0oono07@00018W=l00`3oool00`3O
W4P0001d0;ooo`080?ooo`050=nLB01d_ml0W4P00018W03Oool01`3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0>P3oool2000007`0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`3OW4P004RL0=ooo`020?oo
o`030;md0000M;l0oooo00P0oooo00D0oooO09a8B018B00004RL0=ooo`070?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`2o
M7@0_ooo0?ooo`040?ooo`030;mdM02oool0oooo00X0oooo00L0oono07@0001d_ol0oooo0?noM000
07@0_ooo00X0oooo00@0omnL04P00000B9`0gooo1`3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0?@3oool2000007P0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`2oM000B9cO0?ooo`030?ooo`030=nLB000
07@0_ooo00`0oooo00D0oono07@000000000001d0;ooo`0<0?ooo`030=nLB000B9`0gooo00L0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03l0oooo
0P00001e0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool08@3oool002`0oooo00T0
_g@00000000007@0_ooo0?oog`2LB000B9cO0=nLW02oool09`3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool08@3oool002`0oooo00H0_ibL0=oOW018
000000000000B02LgolZ0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`120?ooo`800000L@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0240oooo000/0?ooo`030;mdM02ogi`0B0000080000000@0001809cOo`3OW9`0_ooo9`3oool2
000003H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`140?ooo`800000KP3oool0
0`000000oooo0?ooo`0c0?ooo`<000008`3oool002`0oooo00<0_g@00018W03Oool00P3oool0102o
M00000000000M02ooolW0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`160?ooo`800000J`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo0240oooo000/0?ooo`030;mdB02Lgol0oooo00<0oooo00<0okmd0000M02oool09`3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool08@3oool002`0
oooo00<0_ibL0=ooo`3oool0103oool00`3OW9`0_ooo0?ooo`0V0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`190?ooo`800000I`3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;0?ooo`800000I03oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo0240oooo000a0?ooo`030;nLW03Oool0oooo0080oooo00<0
gibL0;ooo`3oool08`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool08@3oool002d0oooo00D0oono07@0B02Lgol0oono07@00004000000030000M02o
ool0oooo02<0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool000000500oooo
0P00001O0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool08@3oool003H0oooo00<0
gibL0;ooo`3oool08`3oool00`000000oooo0?ooo`0k0?ooo`040000003oool0oooo00000580oooo
0P00001M0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool08@3oool005`0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0000001D0?ooo`800000FP3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000?P3oool2000005H0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0j0?ooo`<000008`3oool003<0oooo00<0_gAd0;oo
o`3oool09P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo05D0oooo0P00001E0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool08@3oool003<0oooo00<0_gAd0;ooo`3o
ool09P3oool00`000000oooo0?ooo`0n0?oooe/00000D`3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo0240oooo000c0?ooo`030;mdM02oool0oooo02H0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`1F0?oooeD00000@03oool00`000000oooo0?ooo`0Q0?ooo`00<03o
ool00`2oM000000000000003000000030000M02oool0oooo02<0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`1E0?ooo`80000000<0oooo0000003oool0CP3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0240oooo000c0?ooo`030;mdM02oool0oooo02H0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`1D0?ooo`8000000P3oool2000004`0oooo0P000011
0?ooo`030000003oool0oooo0240oooo000c0?ooo`030;mdM02oool0oooo02H0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`1C0?ooo`800000103oool00`000000oooo0?ooo`180?oo
o`030000003oool000000440oooo00<000000?ooo`3oool08@3oool003<0oooo00<0_gAd0;ooo`3o
ool09P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0580oooo0P0000050?ooo`80
0000A`3oool010000000oooo0?ooo`0000110?ooo`030000003oool0oooo0240oooo001L0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0D@3oool2000000L0oooo00<000000?ooo`3o
ool0@`3oool01@000000oooo0?ooo`3oool000000440oooo00<000000?ooo`3oool08@3oool002h0
oooo00<0oooO09adW03Oool01@3oool00`3OW9`0_ooo0?ooo`0S0?ooo`800000A@3oool00`000000
oooo0?ooo`1A0?ooo`800000203oool200000480oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0m0?ooo`<000008`3oool002h0oooo00<0okmd0000000000001@0000000`0007@0_ooo
0?ooo`0S0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0D03oool2000000X0oooo
0P00000o0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0Q0?ooo`00=P3oool00`3OW9`0_ooo0?ooo`0S0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0C`3oool2000000`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool005`0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`1>0?ooo`8000003@3oool2000003X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo00110?oo
o`050?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`050?oOW0180000
00000000001d_ol0203oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04d0oooo0P00
000?0?ooo`800000=`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool08@3oool00400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo
00<0okmd0000001d_ol00P3oool01`3ogi`0B00004RLg`3oool0oono07@0001d_ol01`3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo04`0oooo0P00000A0?ooo`800000=03oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool00400
oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo00<0
oooo00<0okmd0018W03Oool01P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04`0
oooo0P00000C0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo
00<0gia80000M02oool01@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`800000503oool2000002l0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo
000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0B00007Bo
o`030?ooo`030?noM00004P0W=oo00H0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`1:0?ooo`8000005P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`03
0?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool00`2oM000001809cOo`06
0?ooo`<00000C03oool00`000000oooo0?ooo`190?ooo`8000005`3oool2000002X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0m0?ooo`<000008`3oool003l0oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`080?oo_`1d0000000004RLg`3oool0okmd0000
0000M;l70?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0B03oool2000001T0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cO
o`060?ooo`030;md0000B9`0_ia80080000000<004RL0=ooo`3oool01P3oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo04L0oooo0P00000J0?ooo`8000009@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0oono
07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030?oOW0180000M;oo00/0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`160?ooo`800000703oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q
0?ooo`00@03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000
B02Lgol02P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo04D0oooo0P00000M0?oo
o`800000803oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool08@3oool00400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00T0oooo00<0okmd
00000000M;l02@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo04@0oooo0P00000O
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0240oooo00110?ooo`050?oo_`1d000000000000M02oool02`3oool0
1@3ooml0W4P00000000007@0_ooo00H0oooo00<000000?ooo`3oool0DP3oool2000004@0oooo0P00
000P0?ooo`8000006P3oool2000001<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0Q0?ooo`00G03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0440oooo0P00000R
0?ooo`8000005`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`100?oo
o`800000903oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool2000005L0oooo00<000000?ooo`3o
ool0?`3oool2000002D0oooo0P00000B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0?@3oool3000002<0oooo001L0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
?P3oool2000002L0oooo0P00000?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo03d0oooo0P00000Y0?ooo`800000303oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`0l0?ooo`800000:`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`00
0000oooo0?ooo`1J0?ooo`800000?03oool2000002`0oooo0P0000060?ooo`8000006`3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool0>@3oool2000002h0oooo0P0000030?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo
0?ooo`1M0?ooo`800000>@3oool200000300oooo00<000000?ooo`0000007P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0=P3oool200000300oooo0`00000N0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0H03oool2000003H0oooo0P00000_
0?ooo`040000003oool0oooo0?ooo`800000703oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`800000H`3oool00`000000oooo0?ooo`0c0?ooo`800000;P3oool0
0`000000oooo0?ooo`040?ooo`8000006P3oool00`000000oooo0?ooo`0m0?ooo`<000008`3oool0
05`0oooo00<000000?ooo`3oool0H`3oool2000003<0oooo0P00000/0?ooo`8000002@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool005`0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0`0?ooo`800000:`3oool00`000000
oooo0?ooo`0:0?ooo`8000005`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240
oooo001L0?ooo`030000003oool0oooo06H0oooo0P00000`0?ooo`800000:@3oool2000000l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo
001L0?ooo`030000003oool0oooo06P0oooo0P00000^0?ooo`800000:03oool00`000000oooo0?oo
o`0@0?ooo`800000503oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0:`3oool2000002H0oooo0P00000E
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q
0?ooo`00G03oool00`000000oooo0?ooo`1[0?ooo`800000:`3oool2000002@0oooo0P00000H0?oo
o`8000004@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?ooo`03
0000003oool0oooo06d0oooo0P00000Y0?ooo`8000008`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool00`000000oooo0?ooo`1_0?ooo`8000009`3oool200000240oooo0P00000N0?ooo`800000
3P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000LP3o
ool00`000000oooo0?ooo`0T0?ooo`8000007`3oool200000280oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0m0?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool0LP3oool2
000002@0oooo0P00000M0?ooo`8000009@3oool2000000/0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1d0?ooo`8000008P3oool20000
01/0oooo0P00000Y0?ooo`8000002@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo07H0oooo0`00000O0?ooo`800000603oool3000002d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240
oooo00110?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`05
0=nLB0000000000000000018W=l0203oool00`000000oooo0?ooo`1i0?ooo`<00000703oool20000
01D0oooo0`00000a0?ooo`8000001P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0240oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM0000000
M;oo0080oooo00L0gia80000001d_ol0oooo0?oog`2LB000B9cO00L0oooo00<000000?ooo`3oool0
O03oool3000001T0oooo0P00000B0?ooo`<00000=P3oool2000000@0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`2oM00004RL0=ooo`020?ooo`030;md0000
M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL0=ooo`060?ooo`030000003o
ool0oooo07l0oooo0`00000F0?ooo`8000003`3oool3000003/0oooo0P0000020?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0oono07@00018W=l00`3oool0
0`3OW4P0001d0;ooo`060?ooo`030;md0000M;l0oooo0080oooo00<0_g@00018W03Oool01P3oool0
0`000000oooo0?ooo`220?ooo`H00000403oool2000000T0oooo1P0000100?ooo`030000003oool0
00000440oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o
_g@0001809cOo`060?ooo`070?oOW01807@0_ooo0?ooo`2oM000000007Boo`070?ooo`030000003o
ool0oooo08P0oooo1@00000;0?ooo`8000000`3oool6000004L0oooo0P0000110?ooo`030000003o
ool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool0
1@3ookl0M4Q804P000000000B9cO00P0oooo0`00002=0?ooof400000?@3oool3000002<0oooo000o
0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool0103ogi`0B00000000000
M;l90?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0omnL
04P0000007@0_ooo0?noM000M;l80?ooo`030000003oool0oooo0>l0oooo0P00000l0?ooo`030000
003oool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3o
ool00`2oM000001d0;ooo`020?ooo`030;md0018W=l0oooo00H0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0240oooo00100?ooo`030=nLB000B9`0
gooo0080oooo00<0_g@0001d_`3oool01P3oool00`2oM00004RL0=ooo`020?ooo`030=nLB000M;l0
oooo00H0oooo00<000000?ooo`3oool0lP3oool2000003T0oooo00<000000?ooo`3oool08@3oool0
0400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00L0oooo00L0okmd0000001d_ol0oooo
0?oo_`1d0000M;oo00L0oooo00<000000?ooo`3oool0m03oool2000003L0oooo00<000000?ooo`3o
ool08@3oool00440oooo00D0oono07@000000000001d0;ooo`090?ooo`050?noM000000000000000
0018W=l0203oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool08@3oool005`0oooo00<000000?ooo`3oool0m`3oool2000003@0oooo00<000000?ooo`3o
ool08@3oool005`0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0240oooo001L0?ooo`800000n`3oool2000002l0oooo0`00000S0?ooo`00G03oool0
0`000000oooo0?ooo`3l0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08@3oool0
05`0oooo00<000000?ooo`3oool0o@3oool2000002h0oooo00<000000?ooo`3oool08@3oool005`0
oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0240
oooo001L0?ooo`030000003oool0oooo0?l0oooo0@3oool2000002/0oooo00<000000?ooo`3oool0
8@3oool005`0oooo00<000000?ooo`3oool0o`3oool30?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3oool40?ooo`800000:03oool0
0`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooo`H0oooo0P00000V0?oo
o`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo203oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000o`3oool:0?ooo`800000
8@3oool3000002<0oooo001L0?ooo`030000003oool0oooo0?l0oooo2`3oool200000240oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3oool=0?ooo`8000007`3oool0
0`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?oooa00
oooo0P00000L0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo
4P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003o
ool0oooo0?l0oooo4`3oool2000001T0oooo00<000000?ooo`3oool08@3oool005`0oooo00<00000
0?ooo`3oool0o`3ooolE0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool08@3oool0
05`0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`8000005P3oool00`000000oooo0?ooo`0Q0?oo
o`00G03oool200000?l0oooo6@3oool00`000000oooo0?ooo`0A0?ooo`<000008`3oool005`0oooo
00<000000?ooo`3oool0o`3ooolI0?ooo`8000004`3oool00`000000oooo0?ooo`0Q0?ooo`00G03o
ool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?oooa`0oooo0P00000@0?ooo`030000003oool0
oooo0240oooo001>0?ooo`060;md00000000000000000000B9`0gooo203oool00`000000oooo0?oo
o`3o0?oooah0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool0
0`3ogi`0B00007Boo`0:0?ooo`030000003oool0oooo0?l0oooo7`3oool2000000d0oooo00<00000
0?ooo`3oool08@3oool004l0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?oo
ob40oooo0P00000;0?ooo`030000003oool0oooo0240oooo001?0?ooo`030?oOW0180000M;oo00X0
oooo00<000000?ooo`3oool0o`3ooolS0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool08@3oool004l0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?ooob@0oooo
0P0000080?ooo`030000003oool0oooo0240oooo001?0?ooo`030?oOW0180000M;oo00X0oooo0`00
003o0?ooobH0oooo00<000000?ooo`3oool00`3oool3000002<0oooo001?0?ooo`030?oOW0180000
M;oo00X0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001?0?oo
o`030?oOW0180000M;oo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?oo
o`00C`3oool00`3ogi`0B00007Boo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool08@3oool004l0oooo00<0omnL04P0001d_ol02P3ooooo0000038000008`3oool004d0oooo00D0
oooO09a800000000000007Boo`3o0?oooel0oooo001?0?ooo`030?noM0000000M;oo0?l0ooooG`3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo9@3o
ool00`3ooml0W4Q809cOo`0W0?ooo`030?oOW018B9`0gooo05l0oooo003o0?ooobD0oooo00<0_gA8
09cOo`3oool0:03oool00`3ogi`0B7Bo0?ooo`1N0?ooo`00o`3ooolT0?ooo`030=nLB018W=l0oooo
02X0oooo00<0gia804RLg`3oool0G@3oool00?l0oooo8`3oool00`3ookl0M01d0;ooo`0[0?ooo`03
0?oo_`1d04P0W=oo05d0oooo00290?ooo`030?oOW018000000000080000000<0001d0;ooo`3oool0
0`3oool01@3OW4P00000000000000000M;oo00<0oooo00H0oooO09a80000000000000000B02Lgol5
0?ooo`030?oOW01dW=l0oooo0080oooo00<0giad09cOo`3oool0103oool01@2oM000000000000000
07@0_ooo0080oooo00H0oooO09a80000000000000000B02Lgol70?ooo`030;md0000000000000080
000000<007Bo0?ooo`3oool00`3oool01`3OW4P000000000000007@0_ooo0?ooo`3OW4P00`000000
201d_ol0oooo0?ooo`3oool0omnL04P000000000B9cO103oool00`3ogi`0B0000000000200000004
07Boo`3oool0oooo0=nLB0<0000000@0M;oo0?ooo`3oool0_g@00P0000001`0004P0W=oo0?ooo`3o
oml0W4P00000M02oool01@3oool00`3ookl0M000000000020000000307Boo`3oool0oooo0080oooo
00D0okmd0000001d_ol0oooo0;md00060000000304RLg`3oool0oooo00@0oooo00<0gia80018W03O
ool0103oool01P2oM000000000000000000004RL0=oooaH0oooo00D0_g@000000000M;l0oooo0=nL
B002000000070018W03Oool0oooo0?ooo`3ooml0W4P004RLg`050?ooo`050;md0000000007Bo0?oo
o`3OW4P00P0000000`00B9`0gooo0?ooo`1>0?ooo`00R03oool0103OW4P000000018W03Oool20?oo
o`030?oo_`1d04P0W=oo0080oooo00L0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00L0
_g@00018W03Oool0oooo0?oOW0180000M;oo00@0oooo00L0_g@00000M02oool0oooo0?oo_`1d0000
07Bo00@0oooo00l0_g@000000000M;l0oooo0?oOW01807@0_ooo0?ooo`2oM00004RL0=ooo`3oool0
omnL04P0001d_ol01`3oool0103ooml0W4P00018W03Oool70?ooo`0;0=nLB00007@0_ooo0?ooo`3O
W4P0000004RLg`3oool0oooO09a80018W=l00P3oool01@3OW4P0001d0;ooo`3O_kl0gooo00@0oooo
00<0oooO09a80000M;l00`3oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool00`3O
W4P0001d0;ooo`020?ooo`040?oog`2LB000001d0;ooo`D0oooo00<0omnL04P00018W=l00P3oool0
0`2oM000B9cO0?ooo`020?ooo`030?noM0000000M;oo0080oooo00<0gia80000000000000`000000
0`00B9`0gooo0?ooo`040?ooo`030;md0000M;l0oooo00D0oooo00<0omnL04P0001d_ol0603oool0
203ooml0W4Qd0;ooo`3oool0oooO09a80000B9`0gooo103oool00`3OW4P004RL0=ooo`040?ooo`08
0?oog`2LB7@0_ooo0?ooo`3ooml0W4P00018W03Ooom@0?ooo`00Q`3oool00`3o_g@00000001d_`05
0?ooo`060?oog`2LB7@0_ooo0?oOW018000007Bo0`3oool01`3o_g@0001d0;ooo`3oool0_g@00018
W03Oool00P3oool00`3o_g@0001d0;ooo`020?ooo`090?oOW0180000B7Ad07BLg`3oool0okmd0000
B018B4P0W=oo0080oooo00<0omnL04P00018W=l00`3oool01P3ogi`0M9cO0?ooo`2oM00004RL0=oo
o`80oooo00<0okmd0000M02oool01P3oool00`3ooml0W4P0001d_`080?ooo`060=nLB00007@0_ooo
0?oOW018000007Bo0`3oool01`3o_g@0001d0;ooo`3oool0gia80018W03Oool01P3oool00`3ooml0
W4P0001d_`020?ooo`030?oOW018000007Bo00<0oooo00L0okmd0000M02oool0oooo0=nLB00007@0
_ooo0100oooo00<0oono07@0B02Lgol0203oool00`3OW4P0B9cO0?ooo`020?ooo`030=nLM02Lgol0
oooo00<0oooo00<0oono07@00018W=l01P3oool00`3ogi`0B00007Boo`0I0?ooo`060?oo_`1dB9`0
gooo0;md000007@0_ooo1@3oool00`3OW4P0001d0;ooo`050?ooo`060?oo_`1dB9`0gooo0;md0000
07@0_oooD@3oool008H0oooo00@0oooO09a8000007@0_ooo203oool00`3o_g@0000007Boo`030?oo
o`070?noM0000000M;oo0?ooo`2oM00004RL0=ooo`020?ooo`030?oOW0180000M;oo0080oooo00T0
gia80000M02oool0_gAd0;oog`2LB00007Bo0?oOW01dW=l00P3oool00`3o_g@0001809cOo`060?oo
o`030;md0000B9`0gooo0080oooo00<0omnL04P0001d_ol01P3oool00`3ooml0W4P0001d_`080?oo
o`060=nLB00007@0_ooo0?noM0000000M;oo0`3oool01`3o_g@0000007Boo`3oool0gia80018W03O
ool01P3oool00`3ooml0W4P0001d_`020?ooo`030?noM0000000M;oo00<0oooo00L0okmd0000001d
_ol0oooo0=nLB00007@0_ooo0100oooo00<0oono07@0001d_ol02@3oool00`3OW4P0M;oo0?ooo`07
0?ooo`030?oo_`1d0000M;oo00H0oooo00<0omnL04P0001d_ol06P3oool0103ogi`0M4Q80000001d
_ol60?ooo`030?noM00007@0_ooo00H0oooo00@0omnL07A8B0000000M;ooDP3oool008H0oooo00@0
omnL04P00000B9`0gooo203oool00`3o_g@0000007Boo`030?ooo`070?noM0000000M;oo0?ooo`2o
M00004RL0=ooo`020?ooo`0C0?oOW0180000M;oo0?ooo`3ookl0M00004RLg`3oool0omnL07AdM018
04P0W=oo0?ooo`2oM7@0_ooo0?ooo`3o_g@0001d0;ooo`060?ooo`030;md0000B9`0gooo0080oooo
00<0omnL04P0001d_ol01P3oool00`3ooml0W4P0001d_`080?ooo`060=nLB00007@0_ooo0?noM000
0000M;oo0`3oool01`3o_g@0000007Boo`3oool0gia80018W03Oool01P3oool00`3ooml0W4P0001d
_`020?ooo`030?noM0000000M;oo00<0oooo00L0okmd0000001d_ol0oooo0=nLB00007@0_ooo0100
oooo00<0okmd0000001d_ol02P3oool00`2oM4P0W=oo0?ooo`060?ooo`030?oo_`1d0000M;oo00H0
oooo00<0omnL04P0001d_ol0203oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00D0
oooo00<0oono07@00018W=l01`3oool00`3o_g@0001809cOo`060?ooo`030?oo_`1d0000B9cO05<0
oooo00260?ooo`030?noM000000007Bo00T0oooo00<0oono07@0001d_ol00`3oool01`2oM0000018
09cOo`3oool0_g@00018W03Oool00P3oool02`3o_g@0001809cOo`3oool0gia80000B02Lgol0oooo
0?oog`2LB00007Bo0080oooo00D0okmd04RLg`3oool0omnL04P000050000000504RLg`3oool0_g@0
0018W03Oool00P3oool00`3o_g@0001809cOo`060?ooo`030?oog`2LB000000000@0000000X0M;oo
0?ooo`3oool0oooo0=nLB00007@0_ooo0?oo_`1d0000M;oo0`3oool01`2oM000001809cOo`3oool0
gia80018W03Oool01P3oool00`3ooml0W4P0001d_`020?ooo`030?oo_`1d0000M;oo00<0oooo00L0
_g@00000B02Lgol0oooo0=nLB00004P0W=oo00l0oooo00@0omnL04P0000004P0W=oo2P3oool00`3o
oml0W4Qd0;ooo`060?ooo`030?oo_`1d0000M;oo00H0oooo00<0omnL04P0001d_ol06@3oool01@3o
oml0W4P00018W02LM4P0W=oo00H0oooo00<0okmd0000M02oool01@3oool01@3ooml0W4P00018W02L
M4P0W=oo0580oooo00260?ooo`030?noM000000007Bo00X0oooo00L0gia80018W03Oool0oooo0?no
M000000007Bo0080oooo00/0_g@000000000B9`0gooo0?oo_`1d000004RL0=ooo`3ookl0M000001d
_`020?ooo`030?oOW0180000M;oo0080oooo00H0oooO09a8M02oool0oooo0;md0018W=l20?ooo`0<
0=nLB00004P0W=oo0?ooo`2oM00000000018W03Oool0oono07@00000B9`0gooo1P3oool00`3ooml0
W4P0001d_`020?ooo`040?oog`2LB000000004RLg`80oooo00/0gia80000M02oool0oooo0=nLB000
B9`0gooo0?ooo`3o_g@00000001d_`020?ooo`030=nLB000B9`0gooo00H0oooo00<0oooO09a80000
M;l00`3oool04P3OW4P004RL0=ooo`3oool0okmd00000000M;l0oooO09a800000000001804QdW03O
_g@0001d0;oog`2LB000001d0;ooo`L0oooo00D0okmd000000000000001809cOo`0<0?ooo`030?no
M000M;l0oooo00D0oooo00<0oono07@00018W=l01P3oool00`3ogi`0B00007Boo`0I0?ooo`060;md
000004P0W=oo0?oog`2LB7@0_ooo1@3oool00`3OW4P0001d0;ooo`050?ooo`060;md000004P0W=oo
0?oog`2LB7@0_oooD@3oool008H0oooo00@0omnL04P00000B9`0gooo2P3oool01@3o_g@000000000
00000000B9cO00<0oooo00T0_g@00018W03Ogi`0B00000000000B9`0gooo0?oog`2LB0000P000000
0`18W=l0okmd000000020000000804RLg`3oool0_g@000000000B9`0gooo0?ooo`3OW4P20000000;
0000B02Lgol0oooo0?ooo`2oM00004RL0=oOW018000000000018W03Oool01`3oool00`3ooml0W4P0
001d_`030?ooo`080?oo_`1d0000001d0;ooo`3oool0gia80000M02oool20?ooo`050?noM0000000
000000000018W=l00P3oool01P2oM000000000000000000004RL0=ooo`<0oooo00<0okmd00000000
00000P0000001000B9`0gooo0?ooo`3o_g@30000000=04RLg`3oool0oooo0?ooo`2oM000001d0;oO
W0180000001d0;oog`2LB000001d0;ooo`090?ooo`030;md0000M;l0oooo00`0oooo00<0oono07@0
B02Lgol01@3oool00`3ooml0W4P004RLg`060?ooo`030?oOW0180000M;oo01L0oooo00T0oooO09a8
000000000000001d_`3o_g@000000000M02oool0103oool00`3OW4P004RL0=ooo`030?ooo`090?oo
g`2LB000000000000000M;l0okmd0000000007@0_ooo0500oooo00260?ooo`040?oog`2LB0000018
09cOo`D0oooo00<0oooO09adW03Oool02P3oool00`2oM00004RL0=ooo`0K0?ooo`030;md0000B9`0
gooo00/0oooo00<0oooO09a80000M;l00`3oool0203ooml0W4P00000B02Lgol0oooo0=nLB00007@0
_ooo2P3oool00`2oM00004RL0=ooo`060?ooo`030?oog`2LB00007Bo01l0oooo00<0_g@004RLg`3o
ool02`3oool00`3ookl0M00004RLg`060?ooo`030=nLB000B9`0gooo00D0oooo00<0omnL04P0001d
_ol08`3oool00`3ooml0W4P004RLg`1M0?ooo`00Q`3oool00`3ogi`0B000001d_`050?ooo`030?no
M000B9`0gooo00X0oooo00<0_g@00018W03Oool06`3oool00`2oM00004RL0=ooo`0;0?ooo`030?oo
g`2LB00007Bo00<0oooo00P0omnL04P0000007@0_ooo0?ooo`3OW4P0001d0;ooo`X0oooo00<0oono
07A8W03Oool01`3oool00`2oM00007Bo0?ooo`0I0?ooo`030?oog`2LW;l0oooo0080oooo00<0gia8
0000M02oool01P3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0oono
07@0B02Lgol01@3oool00`3ogi`0B00007Boo`0S0?ooo`030?oo_`1d04P0W=oo05d0oooo00280?oo
o`030?noM000000007Bo00<0oooo00<0gia800000000M;l02`3oool00`2oM00004RL0=ooo`0K0?oo
o`030;md0000B9`0gooo00/0oooo00<0oooO09a80000M;l00P3oool0103ookl0M00000000018W=l2
0?ooo`030=nLB00007@0_ooo00X0oooo00<0oooO09adW03Oool01`3oool00`3OW4P007Bo0?ooo`0J
0?ooo`060?noM018W=l0oooo0?oo_`1d000007Bo1`3oool0203ooml0W4Q809cOo`3oool0oono07@0
000007@0_ooo1`3oool00`3OW4P0B9cO0?ooo`020?ooo`050?oog`2LB00000000000001d_ol08`3o
ool00`3OW4P0B9cO0?ooo`1M0?ooo`00R@3oool00`3ooml0W4P0000000020000000304RLg`3ookl0
M7Bo00T0oooo00D0oono07@00000000004RL0=ooo`0I0?ooo`050?oo_`1d000000000018W03Oool0
2P3oool00`2oM000000000000004000000080000B02Lgol0oooo0?oog`2LB00000000000M02ooolD
0?ooo`070?oo_`1d07@0_ooo0?oog`2LB00004RL0=ooo`0G0?ooo`050=nLB000000000000000M02o
ool0203oool01P3ooml0W4P0000000000000001d0;ooo`T0oooo00<0_g@004RLg`3oool00`3oool0
0`3o_g@0000007Boo`0R0?ooo`030?noM000M;l0oooo05h0oooo002K0?ooo`040?oog`2LB00004RL
0=oooaX0oooo00@0oooO09a80000B9`0gooo5P3oool00`2oM000001d0;ooo`0E0?ooo`050?oo_`1d
000000000000B02Lgol0=@3oool00`3OW7@0W=oo0?ooo`0V0?ooo`030?oo_`1dM;l0oooo05l0oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.344423, -0.309528, \
0.00518628, 0.00839157}}]
}, Closed]],

Cell[TextData[{
  "Clearly, with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] \[TildeTilde] 3.2\)]],
  " this system exhibits a stable 2-cycle after the initial transients have \
decayed."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(logisticCobweb[3.5, 0.2, 100, 50];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -9.5 -15.6875 ]
[.21429 -0.0125 9.5 0 ]
[.40476 -0.0125 -9.5 -15.6875 ]
[.40476 -0.0125 9.5 0 ]
[.59524 -0.0125 -9.5 -15.6875 ]
[.59524 -0.0125 9.5 0 ]
[.78571 -0.0125 -9.5 -15.6875 ]
[.78571 -0.0125 9.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .01472 -10 -7.84375 ]
[-0.0125 .01472 0 7.84375 ]
[-0.0125 .13244 -19 -7.84375 ]
[-0.0125 .13244 0 7.84375 ]
[-0.0125 .25016 -19 -7.84375 ]
[-0.0125 .25016 0 7.84375 ]
[-0.0125 .36788 -19 -7.84375 ]
[-0.0125 .36788 0 7.84375 ]
[-0.0125 .4856 -19 -7.84375 ]
[-0.0125 .4856 0 7.84375 ]
[-0.0125 .60332 -10 -7.84375 ]
[-0.0125 .60332 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -11.4063 ]
[-0.01875 .30902 -19 11.4063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74.9688 0 ]
[.5 .63053 74.9688 15.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cobweb) show
105.875 15.813 moveto
(Plot) show
128.188 15.813 moveto
(for) show
142.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
148.375 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.375 15.813 moveto
(H) show
170.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
179.188 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
189.875 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
196.000 15.813 moveto
(L) show
202.813 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
208.938 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
.02381 .01472 m
.06244 .0949 L
.10458 .17461 L
.14415 .24214 L
.18221 .30036 L
.22272 .35511 L
.26171 .40078 L
.30316 .44174 L
.34309 .47382 L
.3815 .49785 L
.40095 .50746 L
.42237 .51605 L
.44268 .52228 L
.45178 .52446 L
.46172 .52641 L
.4671 .52728 L
.4721 .52798 L
.47727 .52857 L
.48196 .529 L
.48658 .52933 L
.4887 .52945 L
.49093 .52956 L
.49332 .52964 L
.49438 .52967 L
.49552 .5297 L
.49675 .52972 L
.49789 .52973 L
.49859 .52974 L
.49925 .52974 L
.50049 .52974 L
.50163 .52974 L
.50286 .52972 L
.50401 .52971 L
.50508 .52968 L
.50754 .52961 L
.51014 .52951 L
.51268 .52938 L
.51504 .52923 L
.5204 .5288 L
.5293 .52779 L
.53882 .52632 L
.54906 .52428 L
.56016 .52152 L
.58032 .51509 L
.60019 .50694 L
.62123 .49636 L
.65912 .47224 L
.69946 .43938 L
.73829 .40078 L
.77956 .35223 L
Mistroke
.81932 .29815 L
.85757 .23935 L
.89827 .16948 L
.93745 .09511 L
.97619 .01472 L
Mfstroke
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
.50084 .30954 m
.50084 .52974 L
.85714 .52974 L
s
.85714 .52974 m
.85714 .24004 L
.3884 .24004 L
s
.3884 .24004 m
.3884 .50146 L
.81137 .50146 L
s
.81137 .50146 m
.81137 .30954 L
.50084 .30954 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{322.375, 199.25},
  ImageMargins->{{0, 0}, {0, 0.75}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007S0001:R000`400?l00000o`00003oo`3ooooT
0?ooo`00o`3ooooT0?ooo`00o`3ooooT0?ooo`00o`3ooooT0?ooo`00o`3oool@0?ooo`050?oog`2L
B00000000018W03Oool0c`3oool00?l0oooo4@3oool00`3ogi`0B01809cOo`3@0?ooo`00o`3oool8
0?ooo`050;md0000000007Bo0?ooo`3OW4P00P0000001@00B9`0gooo0?oOW01804P0W=oo0=00oooo
003o0?ooo`P0oooo00`0oooO09a8M02oool0oooo0?oog`2LB00004RL0=ooo`3oool0omnL04P0B02L
goo@0?ooo`00o`3oool90?ooo`0;0?oo_`1dB9`0gooo0;md000007@0_ooo0?ooo`3ookl0M0000000
B02Lgol0d03oool00?l0oooo2P3oool0103ogi`0M4Q80000001d_ol30?ooo`030?oOW01804P0W=oo
0=00oooo003o0?ooo`X0oooo00<0oono07@00018W=l0e`3oool00?l0oooo2@3oool01@3ooml0W4P0
0018W02LM4P0W=oo0=H0oooo003o0?ooo`T0oooo00H0_g@00000B02Lgol0oooO09a8M02oool20?oo
o`030?oo_`1d0000M;oo0=00oooo003o0?ooo`L0oooo00T0oooO09a8000000000000001d_`3o_g@0
00000000M02oool0e03oool00?l0ooooi03oool00?l0ooooi03oool00?l0ooooi03oool00?l0oooo
i03oool00?l0ooooi03oool00?l0ooooi03oool00?l0ooooi03oool00?l0ooooi03oool00?l0oooo
i03oool00?l0ooooi03oool00?l0ooooi03oool00?l0ooooi03oool00?l0ooooi03oool00?l0oooo
i03oool00?l0ooooi03oool00?l0ooooi03oool006<0oooo00D0omnL04P000000000001d0;ooo`0h
0?ooo`050?oOW018000000000000M02oool00`3oool01@3o_g@0000007Boo`3oool0_g@000H00000
00<0B9cO0?ooo`3oool0;@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d
_ol01@3oool0103ooml0W4P00018W03Oool_0?ooo`050?oOW018000000000000M02oool00`3oool0
0`3o_g@0000007Boo`030?ooo`050?oOW018000000000000001d_ol0<@3oool01@3ogi`0B0000000
000007@0_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3OW4P00000000000000000B9cO03L0
oooo00H0_g@000000000000000000018W03OoolY0?ooo`00HP3oool01`3ookl0M00007Boo`3oool0
okmd0000M02oool0=P3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0
000007Boo`020?ooo`030=nLB0000000000000<0000000<004RL0=ooo`3oool0;03oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`050?ooo`040?oog`2LB000
04RL0=ooobh0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d
_ol00P3oool01`3ogi`0B00004RLg`3oool0oono07@0001d_ol0;`3oool01`3ookl0M00007Boo`3o
ool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?ooo`070=nLB0000000M;oo0?ooo`3o
oml0W4P004RLg`0g0?ooo`030?oOW0180000M;oo02/0oooo001R0?ooo`030;md0000B9`0gooo0080
oooo00<0_g@0001d_`3oool0=@3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0
oooo00<0gia804RLg`3oool00P3oool00`3OW7@0W=oo0?ooo`0/0?ooo`030;md0000B9`0gooo0080
oooo00<0_g@0001d_`3oool02@3oool0103ooml0W4P00018W03Oool^0?ooo`030;md0000B9`0gooo
0080oooo00<0_g@0001d_`3oool01@3oool00`3ooml0W4P0001d_`030?ooo`030?noM000B9`0gooo
02h0oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo
00<0oooo00<0okmd0018W03Oool0=P3oool00`3ogi`0B00007Boo`0[0?ooo`00H@3oool00`3ookl0
M00004RLg`030?ooo`030=nLB00007@0_ooo03@0oooo00<0oono07@00018W=l00`3oool00`3OW4P0
001d0;ooo`080?ooo`030=nLB01d_ol0oooo02l0oooo00<0oono07@00018W=l00`3oool00`3OW4P0
001d0;ooo`050?ooo`030;md00000000000000D0000000<0M;oo0?ooo`3oool0:P3oool00`3ookl0
M00004RLg`030?ooo`030=nLB00007@0_ooo00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`0]0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM000
07Bo0?ooo`020?ooo`030;md0000B9`0gooo03H0oooo00<0omnL04P0001d_ol0:`3oool00640oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0d0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol02@3oool00`2oM4P0W=oo0?ooo`0^0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol01@3oool0203ogi`0M9cO0?ooo`3oool0oooO09a80000B9`0gooo;@3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`0]0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool0
1`3ogi`0B01d0;ooo`3oool0_g@00000001d_ol0=`3oool00`3ogi`0B00007Boo`0[0?ooo`00H@3o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo03@0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`090?ooo`030?oog`2LB7@0_ooo02h0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`060?ooo`070=nLB01d_ol0oooo0?oog`2LB00004RL0=ooo`0]0?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0B00007Boo`030?ooo`03
0;md000004P0W=oo02d0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`05
0?oo_`1dB4P0B00000000018W=l0>03oool00`3ogi`0B00007Boo`0[0?ooo`00H@3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo03@0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`0:0?ooo`030?noM000M;l0oooo02d0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`060?ooo`070?oog`2LB7@0_ooo0?oog`2LB00004RL0=ooo`0]0?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol01@3oool0203ookl0M00000000018W=l0oooo0?noM0000000
07Bo;P3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00@0omnL04P00000
000007Bo>@3oool00`3ogi`0B00007Boo`0[0?ooo`00H@3oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo03@0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`03
0?oo_`1d04P0W=oo02d0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`06
0?oOW018M;l0oooO09a80000B9`0gooo;@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00H0oooo00<0_g@00018W02oW4P00P0000000`00B9`0gooo0?ooo`0]0?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01P3ogi`0B0000000M02oool0okmd001d_cP0oooo
00<0omnL04P0001d_ol0:`3oool00640oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;oo
o`0d0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool02P3oool00`3ookl0M00004RL
g`0]0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool01@3OW4P0M;oO09a8
0000B9`0gooo02d0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030?oO
W0180000M;oo0380oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030;md
000007@0_ooo0080oooo00<0_g@004RLg`3oool0=P3oool00`3ogi`0B00007Boo`0[0?ooo`00HP3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo03D0oooo00<0gia80018W03Oool00P3o
ool00`2oM00007Bo0?ooo`050?ooo`030?noW02Lgol0oooo0080oooo00<0omnL04P00018W=l0;P3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00P0oooo00D0oooO09a8B018B00004RL
0=ooo`0^0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`3OW4P00018
09cOo`0b0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01P3oool00`2oM00004RL
0=ooo`020?ooo`030=nLB000M;l0oooo03H0oooo00<0omnL04P0001d_ol0:`3oool00680oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo03H0oooo00L0oono07@0001d_ol0oooo0?noM00007@0
_ooo00H0oooo00P0oooO09a8B02Lgol0oooo0?oo_`1d0000001d0;ooobh0oooo00L0oono07@0001d
_ol0oooo0?noM00007@0_ooo00X0oooo00@0omnL04P00000B9`0gooo;P3oool01`3ookl0M00007Bo
o`3oool0okmd0000M02oool02@3oool00`3o_g@00000001d_`0a0?ooo`070?oo_`1d0000M;oo0?oo
o`3o_g@0001d0;ooo`070?ooo`070?noM0000000M;oo0?ooo`3ookl0M00007Boo`0e0?ooo`050?oo
g`2LB00000000000001d_ol0:`3oool006<0oooo00D0oono07@000000000001d0;ooo`0h0?ooo`05
0?oo_`1d000000000000M02oool0203oool01P3ooml0W4P0000000000000001d0;oooc00oooo00D0
oono07@000000000001d0;ooo`0<0?ooo`030=nLB000B9`0gooo02l0oooo00D0oono07@000000000
001d0;ooo`0;0?ooo`050?oog`2LB00000000000M02oool0;`3oool01@3ookl0M0000000000007@0
_ooo00T0oooo00D0okmd000000000000000004RLg`0h0?ooo`030?noM0000000M;oo02/0oooo003o
0?ooon@0oooo003o0?ooon@0oooo003o0?ooon@0oooo003o0?ooon@0oooo003o0?ooon@0oooo003o
0?ooon@0oooo003o0?ooon@0oooo003o0?ooon@0oooo003o0?ooon@0oooo001?0?ooo`050?oOW018
000000000000M02oool02@3ooooo000006@000008`3oool004h0oooo00L0oono07@0001d_ol0oooo
0?noM00007@0_ooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`00
CP3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0Q0?ooo`00C@3oool00`3ookl0M00004RLg`030?ooo`030=nLB000
07@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`030000003oool0oooo0240oooo001=
0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool00`000000oooo0?ooo`3o
0?ooof00oooo00<000000?ooo`3oool08@3oool004d0oooo00<0omnL04P0001d_ol00`3oool00`3o
_g@0001809cOo`070?ooo`@000001@3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?oo
o`3oool0103oool3000002<0oooo001=0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool00`000000oooo0?ooo`060?ooo`<00000o`3ooom>0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool08@3oool004d0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000o`3ooom<0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool004d0oooo00<0oono07@00018W=l00`3o
ool00`3OW4P0001d0;ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P00
003o0?ooodX0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`00CP3oool0
0`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<000000?ooo`3oool0203oool0
1@000000oooo0?ooo`3oool000000?l0ooooB03oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0240oooo001>0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooodD0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool01@3ookl0M0000000
000007@0_ooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`800000
o`3ooom40?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08@3oool005d0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo@@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0103oool200000?l0oooo@03oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3o0?ooocd0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0
oooo0P00003o0?ooocd0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?ooo`00
G@3oool3000000/0oooo00<000000?ooo`3oool0203oool200000?l0oooo>P3oool00`000000oooo
0?ooo`090?ooo`<000008`3oool005d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0?l0oooo=`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0240oooo001M0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool2
00000?l0oooo=P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0240oooo001M0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool200000?l0oooo=03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooc00oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo0P00003o0?oooc00oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo0P00
003o0?ooobd0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooolZ
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`800000o`3ooolY0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo9P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0240oooo001M0?ooo`<000003`3oool00`000000oooo0?ooo`0D0?ooo`800000
o`3ooolV0?ooo`030000003oool0oooo00d0oooo0`00000S0?ooo`00G@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0F0?ooo`800000o`3ooolR0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?oo
o`800000o`3ooolO0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08@3oool005d0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0
oooo703oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool06@3oool200000?l0oooo6`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?oooaP0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01/0oooo0P00003o0?oooaL0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Q
0?ooo`00G@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo0P00003o0?oo
oaD0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01h0oooo0P00003o0?oooa80oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool08@3oool005d0oooo0`00000E0?ooo`030000003oool0oooo0200oooo0P00
003o0?ooo`h0oooo00<000000?ooo`3oool04`3oool3000002<0oooo001M0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool08P3oool200000?l0oooo303oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool08`3oool200000?l0oooo2@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0240oooo001M0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0Q0?ooo`00
G@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02D0oooo0P00003o0?ooo`D0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3ogi`0B0000000
000007@0_ooo00<0oooo00D0okmd0000001d_ol0oooo0;md00060000000304RLg`3oool0oooo00H0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0
oooo0P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0240oooo00100?ooo`070?oo
_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM0000000M;oo0080oooo00<0gia80000
000000000`0000000`00B9`0gooo0?ooo`060?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool09`3oool200000?l0oooo0@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0240oooo00100?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`3OW4P0
B9cO0?ooo`020?ooo`030=nLM02Lgol0oooo00H0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00P0oooo
00<0gia807Boo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02T0oooo
0P00003l0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`090?ooo`030;mdB02Lgol0oooo00T0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0[0?ooo`800000nP3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol02@3oool00`3ooml0W4Qd0;ooo`090?ooo`@000006@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool0603oool3000002<0oooo000o0?oo
o`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3o_g@007Bo0?ooo`080?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;@3oool200000?D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo00X0oooo00<0oono07@0B02Lgol0203oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
2P3oool00`3ookl0M00004RLg`080?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
;P3oool200000?40oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0Q0?ooo`00@03o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oknL09cOo`3oool00P3o
ool00`3ogi`0B00004RLg`080?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<03o
ool200000>l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0Q0?ooo`00@03oool0
1`3ookl0M00007Boo`3oool0okmd0000M02oool01P3oool0203ooml0W4Q809cOo`3oool0oono07@0
000007@0_ooo203oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0340oooo0P00003/
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool08@3oool00440oooo00D0oono07@0
00000000001d0;ooo`080?ooo`060?oog`2LB00000000000000007@0_ooo2@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0j@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0<`3oool200000>P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0Q0?ooo`00G@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03D0oooo0P00003V
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0f0?ooo`800000h`3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0240oooo001M0?ooo`<000007`3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo0>00oooo00<000000?ooo`3oool07@3oool3000002<0oooo001M0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0>03oool200000=l0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0240oooo001M0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0>P3oool2
00000=/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0e`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0?03oool200000=L0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03d0oooo
0P00003D0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08@3oool005d0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0=40oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo03l0oooo0P00003@0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0<`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Q0?oo
o`00G@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0440oooo0P00003<0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool08@3oool005d0oooo0`00000U0?ooo`030000
003oool0oooo04<0oooo0P0000390?ooo`030000003oool0oooo02@0oooo0`00000S0?ooo`00G@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0aP3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0A03oool200000<D0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
04H0oooo0P0000320?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool08@3oool005d0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0;l0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo04P0oooo0P00002n0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`190?ooo`800000_03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0240oooo001M
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`2h
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`1;0?ooo`800000]`3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0C03oool200000;D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0Q0?ooo`00
G@3oool3000002/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo02X0oooo0`00000S0?ooo`00G@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo04h0oooo0P00002a0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool08@3o
ool005d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo0:d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo0500oooo0P00002/0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`1A0?ooo`800000ZP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0240
oooo001M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`2V0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool08@3oool00440oooo00D0
omnL04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0
gooo203oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05<0oooo0P00002V0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool08@3oool00400oooo00L0oono07@0001d_ol0
oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol01@3oool0103ooml0W4P00018W03Oool8
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0E@3ooonV00000380oooo00<00000
0?ooo`3oool08@3oool00400oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`090?oo
o`040?oog`2LB00004RL0=ooo`P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1D
0?ooo`030000003oool000000:40oooo0P00000b0?ooo`030000003oool0oooo0240oooo000o0?oo
o`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`2oM0000000000000050000
000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo00800000W`3oool200000380oooo00<000000?ooo`3oool08@3oool003l0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`080?oOW01dW=l0oooo0?oo
o`3ooml0W4P00018W03Oool80?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`020?ooo`800000W03oool00`000000oooo0000000b0?ooo`030000003o
ool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool0
1`3OW4P0M;oo0?ooo`3ooml0W4P00018W03Oool0203oool400000340oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo09P0oooo00@000000?ooo`3oool0
0000<03oool3000002<0oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0
1P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool0203oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool01@3oool2000009P0oooo00@000000?oo
o`3oool00000<P3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?oo
o`030?noM00004P0W=oo00L0oooo00H0omnL04Qd_`3ooml0W4P00018W03Oool80?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`070?ooo`800000U@3o
ool01@000000oooo0?ooo`3oool000000380oooo00<000000?ooo`3oool08@3oool003l0oooo00<0
oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`080?ooo`050=nLB01d_ml0W4P00018W03Oool0
203oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000
M;l0oooo00P0oooo00D0oooO09a8B018B00004RL0=ooo`080?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0:0?ooo`800000T@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool08@3oool00400oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo00X0oooo00@0omnL04P00000B9`0gooo203oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0Q0?ooo`00@@3oool01@3ookl0M0000000000007@0_ooo00`0oooo00<0gia80018
W03Oool0203oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool03@3oool2000008`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0240oooo000/0?ooo`030;mdM02oool0oooo00@0oooo00<0_gAd0;ooo`3o
ool09`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`2oM000B9cO0?ooo`030?ooo`030=nL
B00007@0_ooo02P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool08@3oool002`0oooo00T0_g@00000000007@0_ooo
0?oog`2LB000B9cO0=nLW02oool0:03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool04@3oool2000008L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo000/0?ooo`060;nLW03Ogi`0B0000000
000004P0W=oo:`3oool3000003T0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0^
0?ooo`<000008`3oool002`0oooo00<0_gAd0;oOW01800000P000000100004P0W=oo0=nLW02ooolX
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0D
0?ooo`800000PP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool08@3oool002`0oooo00<0_g@00018W03Oool00P3oool0102oM00000000000M02ooolX
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;mdB02Lgol0oooo00<0oooo00<0okmd0000
M02oool0:03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool05`3oool2000007h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0240oooo000/0?ooo`030;nLW03Oool0oooo00@0oooo00<0gibL0;ooo`3o
ool09`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool06@3oool2000007/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0K0?ooo`800000N@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool08@3oool00340oooo00<0_ibL0=ooo`3oool00P3o
ool00`3OW9`0_ooo0?ooo`0T0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo000]0?ooo`050?oo_`1d04P0
W=oo0?oo_`1d0000100000000`0007@0_ooo0?ooo`0T0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0N0?ooo`800000M03oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool08@3oool003H0oooo00<0gibL
0;ooo`3oool0903oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0803oool200000780oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0R0?ooo`800000K`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool08@3oool005d0oooo0`0000100?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0;P3oool3000002<0oooo000c0?ooo`030;md
M02oool0oooo02L0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo02@0ooooK`00000?0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
8@3oool003<0oooo00<0_gAd0;ooo`3oool09`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00001Y0?ooo`800000
3`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo000c0?ooo`030;mdM02o
ool0oooo02L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo02@0oooo00@000000?ooo`3oool0oooo0P00001V0?ooo`030000003oool0000000l0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?ooo`00<03oool00`2oM00000000000
0003000000030000M02oool0oooo02@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1R0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0Q0?ooo`00<`3oool00`2oM7@0_ooo0?ooo`0W0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo0P00
001R0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0Q0?ooo`00<`3oool00`2oM7@0_ooo0?ooo`0W0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo0P00
001O0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0240oooo000c0?ooo`030;mdM02oool0oooo02L0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo00T0oooo0P00001K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo000^0?ooo`030?oog`2LM9`0gooo
00D0oooo00<0gibL0;ooo`3oool0903oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool08@3oool002h0oooo00<0okmd0000000000001@0000000`0007@0
_ooo0?ooo`0T0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo0P00001F0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240
oooo000f0?ooo`030=nLW02oool0oooo02@0oooo0`0000180?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0>0?ooo`800000D`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0;P3oool3000002<0oooo
001M0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo0100oooo0P00001A0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo001M
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q
0?ooo`00G@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0C0?ooo`800000C03oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?oo
o`00G@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0E0?ooo`800000BP3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?ooo`00
@@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3ogi`0
B000000000000000M;oo00T0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool05`3oool2000004L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool08@3oool00400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd
0000001d_ol00P3oool01`3ogi`0B00004RLg`3oool0oono07@0001d_ol0203oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool08@3oool00400oooo00<0
_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0
okmd0018W03Oool01`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0J0?ooo`800000@P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00D0oooo00<0omnL
04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?oo
o`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?oo
o`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d
_ol00`3oool00`2oM000001809cOo`070?ooo`@00000CP3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool07P3oool2000003`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02h0oooo0`00000S0?ooo`00
?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0oono07@000000000
B9cO0?ooo`3o_g@00000001d_`P0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000
B02Lgol01P3oool00`2oM00004RL0;nLB002000000030018W03Oool0oooo00L0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool08@3oool2000003L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool08@3oool003l0oooo00<0oono07@00018
W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030?oOW0180000M;oo00`0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo00100?ooo`030=nL
B000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`3OW4P0001809cOo`0;0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?ooo`00@03o
ool01`3ookl0M00007Boo`3oool0okmd0000M02oool02@3oool00`3o_g@00000001d_`0:0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo02D0oooo0P00000`0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo00110?ooo`050?oo
_`1d000000000000M02oool02`3oool01@3ooml0W4P00000000007@0_ooo00L0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo001M0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo02P0oooo0P00000[0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo02X0oooo0P00000Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo02`0oooo0P00000V0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool30000
05T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02l0oooo0P00000Q0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0^0?ooo`<000008`3oool005d0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<@3oool2000001h0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<`3oool2000001/0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03H0oooo0P00000F
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0i0?ooo`80
00004@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0?03o
ool2000000`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0?P3oool2
000000T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool08@3oool005d0oooo0`00001S0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02h0oooo0`00000S0?ooo`00G@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`110?ooo`800000103oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`130?ooo`040000003oool0oooo000002@0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240
oooo001M0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo04@0oooo0P00000U0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?oo
o`1W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`140?ooo`040000003oool00000000002<0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool00P3oool200000240oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0440oooo0P000007
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo06X0oooo0P00000K0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`080?oo
o`8000007P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool08@3oool005d0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0;0?ooo`80
0000703oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool08@3oool005d0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0>0?ooo`800000
6P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
8@3oool005d0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0l0?ooo`8000004`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0;P3oool3000002<0oooo001M0?ooo`030000003oool0
oooo06l0oooo0P00000F0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0D0?ooo`8000005`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool06@3oool2000001@0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03L0oooo
0P00000N0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo07@0oooo0P00
000A0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0O0?ooo`8000004@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool08@3oool00440oooo00D0omnL04P000000000001d0;ooo`030?ooo`030?noM000
0000M;oo00<0oooo00D0gia8000000000000000004RLg`090?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool08P3oool2000000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo0240oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0
001d0;ooo`020?ooo`030?noM0000000M;oo0080oooo00L0gia80000001d_ol0oooo0?oog`2LB000
B9cO00P0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0<`3oool2000002L0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool08@3oool0
0400oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo
00<0oooo00<0okmd0018W03Oool01`3oool00`000000oooo0?ooo`1h0?ooo`8000003@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0:03oool20000
00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM000
07Bo0?ooo`020?ooo`030;md0000B9`0gooo00L0oooo00<000000?ooo`3oool0NP3oool2000000/0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0`0?ooo`800000;@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo
00L0omnL04P0M02oool0oooo0;md00000000M;oo00P0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0^0?ooo`8000002@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`070?ooo`050?oo_`1dB4P0B00000000018W=l02@3oool4000007`0oooo0P0000080?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0a0?oo
o`8000001`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02h0oooo0`00000S0?oo
o`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00@0omnL04P00000
000007Bo2P3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0/0?ooo`800000=P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?oo
o`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0omnL04P00000
07@0_ooo0?noM000M;l90?ooo`030000003oool0oooo0800oooo0P0000050?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0g0?ooo`800000103oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool08@3oool0
03l0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030;md000007@0_ooo
0080oooo00<0_g@004RLg`3oool01`3oool00`000000oooo0?ooo`220?ooo`8000000`3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02T0oooo0P00000l0?ooo`8000000P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool08@3oool00400
oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`060?ooo`030;md0000B9`0gooo0080
oooo00<0gia8001d_`3oool01`3oool00`000000oooo0?ooo`240?ooo`80000000<0oooo0000003o
ool09@3oool00`000000oooo0?ooo`0W0?ooo`800000@03oool00`000000oooo0000000?0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool08@3oool00400oooo00L0oono07@0001d_ol0
oooo0?noM00007@0_ooo00L0oooo00L0okmd0000001d_ol0oooo0?oo_`1d0000M;oo00P0oooo00<0
00000?ooo`3oool0QP3ooonG000000l0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0Q0?ooo`00@@3oool01@3ookl0M0000000000007@0_ooo00T0oooo00D0okmd0000000000000000
04RLg`090?ooo`030000003oool0oooo08P0oooo0P00000T0?ooo`030000003oool0oooo0280oooo
0`0000170?ooo`8000003@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0240oooo
001M0?ooo`030000003oool0oooo08X0oooo0P00000R0?ooo`030000003oool0oooo01l0oooo0`00
001<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0Q0?ooo`00G@3oool00`000000oooo0?ooo`2<0?ooo`800000803oool00`000000oooo0?ooo`0M
0?ooo`800000D03oool2000000X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q
0?ooo`00G@3oool00`000000oooo0?ooo`2>0?ooo`8000007P3oool00`000000oooo0?ooo`0K0?oo
o`800000E03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool08@3oool005d0oooo0`00002@0?ooo`800000703oool00`000000oooo0?ooo`0H0?ooo`<0
0000E`3oool2000000L0oooo00<000000?ooo`3oool0;P3oool3000002<0oooo001M0?ooo`030000
003oool0oooo0980oooo0`00000I0?ooo`030000003oool0oooo01@0oooo1000001L0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?ooo`00G@3o
ool00`000000oooo0?ooo`2E0?ooo`@000005@3oool00`000000oooo0?ooo`0A0?ooo`<00000H@3o
ool2000000@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool0
0`000000oooo0?ooo`2I0?ooo`H000003`3oool00`000000oooo0?ooo`0=0?ooo`@00000IP3oool2
00000080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`00
0000oooo0?ooo`2O0?ooo`@000002`3oool00`000000oooo0?ooo`0:0?ooo`<00000K03oool00`00
0000oooo0000000b0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo0:<0
ooooRP00000b0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo0?l0oooo
;P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003o
ool0oooo0?l0oooo;`3oool2000002l0oooo00<000000?ooo`3oool08@3oool005d0oooo00<00000
0?ooo`3oool0o`3ooola0?ooo`800000;@3oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`00
0000oooo0?ooo`3o0?oooc<0oooo0P00000[0?ooo`030000003oool0oooo0240oooo001M0?ooo`03
0000003oool0oooo0?l0oooo=@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0240
oooo001M0?ooo`<00000o`3ooolf0?ooo`8000009P3oool3000002<0oooo001M0?ooo`030000003o
ool0oooo0?l0oooo>03oool2000002H0oooo00<000000?ooo`3oool08@3oool005d0oooo00<00000
0?ooo`3oool0o`3ooolj0?ooo`800000903oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`00
0000oooo0?ooo`3o0?oooc`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?oo
o`00G@3oool00`000000oooo0?ooo`3o0?ooocd0oooo0P00000Q0?ooo`030000003oool0oooo0240
oooo001M0?ooo`030000003oool0oooo0?l0oooo?`3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0240oooo001M0?ooo`030000003oool0oooo0?l0oooo@03oool2000001h0oooo00<0
00000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool0o`3ooom20?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3oool0o`3ooom30?oo
o`8000006`3oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool00`000000oooo0?ooo`3o0?ooodD0
oooo0P00000I0?ooo`030000003oool0oooo0240oooo001M0?ooo`<00000o`3ooom70?ooo`030000
003oool0oooo01@0oooo0`00000S0?ooo`00G@3oool00`000000oooo0?ooo`3o0?ooodP0oooo0P00
000F0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo0?l0ooooBP3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0240oooo001M0?ooo`030000003oool0oooo
0?l0ooooB`3oool2000001<0oooo00<000000?ooo`3oool08@3oool005d0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`8000004@3oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool01P2oM0000000
00000000000004RL0=ooo`P0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool08@3oool00500oooo00<0omnL04P0001d_ol02P3oool00`000000
oooo0?ooo`3o0?oooe00oooo0P00000>0?ooo`030000003oool0oooo0240oooo001@0?ooo`030?oO
W0180000M;oo00X0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool08@3oool00500oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?oo
o`3o0?oooe<0oooo0P00000;0?ooo`030000003oool0oooo0240oooo001@0?ooo`030?oOW0180000
M;oo00X0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`8000002@3oool00`000000oooo0?ooo`0Q
0?ooo`00D03oool00`3ogi`0B00007Boo`0:0?ooo`@00000o`3ooomF0?ooo`030000003oool0oooo
00@0oooo0`00000S0?ooo`00D03oool00`3ogi`0B00007Boo`0:0?ooo`030000003oool0oooo0?l0
ooooH03oool00`000000oooo0?ooo`0Q0?ooo`00D03oool00`3ogi`0B00007Boo`0:0?ooo`030000
003oool0oooo0?l0ooooH03oool00`000000oooo0?ooo`0Q0?ooo`00D03oool00`3ogi`0B00007Bo
o`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00500oooo00<0omnL
04P0001d_ol02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0240oooo001>0?oo
o`050?oog`2LB00000000000001d_ol02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0240oooo001@0?ooo`030?noM0000000M;oo00X0ooooo`00001T000002<0oooo003o0?ooon@0
oooo003o0?ooon@0oooo003o0?ooon@0oooo003o0?ooon@0oooo003o0?ooon@0oooo003o0?ooon@0
oooo003o0?oood00oooo00<0oooO09a8B02Lgol09P3oool00`3ogi`0B4RL0=ooo`1h0?ooo`00o`3o
oom00?ooo`030;mdB02Lgol0oooo02L0oooo00<0omnL04Qd_`3oool0M`3oool00?l0oooo?`3oool0
0`3OW4P0B9cO0?ooo`0Y0?ooo`030=nLB018W=l0oooo07H0oooo003o0?oooch0oooo00<0oono07@0
M02oool0:P3oool00`3ookl0M01809cOo`1f0?ooo`00Y03oool00`3ogi`0B0000000000200000003
0000M02oool0oooo00<0oooo00D0gia8000000000000000007Boo`030?ooo`060?oog`2LB0000000
0000000004P0W=oo1@3oool00`3ogi`0M9cO0?ooo`020?ooo`030=nLM02Lgol0oooo00@0oooo00D0
_g@0000000000000001d0;ooo`020?ooo`060?oog`2LB00000000000000004P0W=oo1P3oool00`2o
M00000000000000200000003001d_`3oool0oooo00<0oooo00L0gia8000000000000001d0;ooo`3o
ool0gia800<0000000P0M;oo0?ooo`3oool0oooo0?oOW0180000000004RLg`@0oooo00<0omnL04P0
000000000P000000101d_ol0oooo0?ooo`3OW4P30000000407Boo`3oool0oooo0;md0080000000L0
001809cOo`3oool0oooO09a8000007@0_ooo00H0oooo00<0oono07@0000000000P0000000`1d_ol0
oooo0?ooo`020?ooo`060?noM0000000M;oo0?ooo`3ooml0W4P00`0000000`1d_ol0oooo0?ooo`06
0?ooo`030=nLB000B9`0gooo00<0oooo00H0_g@000000000000000000018W03OoolF0?ooo`050;md
0000000007Bo0?ooo`3OW4P00P0000001`00B9`0gooo0?ooo`3oool0oooO09a80018W=l01@3oool0
1@2oM0000000001d_`3oool0gia80080000000<004RL0=ooo`3oool0I`3oool00:<0oooo00@0gia8
00000000B9`0gooo0P3oool00`3ookl0M01809cOo`020?ooo`070=nLB0000000B9cO0?ooo`3ooml0
W4P004RLg`020?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B00007Boo`040?ooo`070;md000007@0
_ooo0?ooo`3ookl0M000001d_`040?ooo`0?0;md0000000007Bo0?ooo`3ogi`0B01d0;ooo`3oool0
_g@00018W03Oool0oooo0?oOW0180000M;oo00H0oooo00@0oooO09a80000B9`0gooo1`3oool02`3O
W4P0001d0;ooo`3oool0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00D0gia80000M02o
ool0gkno0=ooo`040?ooo`030?oog`2LB00007Bo00<0oooo00L0gia800000018W=l0oooo0?oog`2L
B000B9cO0080oooo00<0gia80000M02oool00P3oool0103ooml0W4P00000M02oool60?ooo`030?oO
W0180000B9cO0080oooo00<0_g@004RLg`3oool00P3oool01`3o_g@0000007Boo`3oool0oooO09a8
M02oool00P3oool00`2oM000M;oo0?ooo`060?ooo`030;md0000M;l0oooo00@0oooo00<0omnL04P0
001d_ol0603oool0203ooml0W4Qd0;ooo`3oool0oooO09a80000B9`0gooo103oool00`3OW4P004RL
0=ooo`040?ooo`080?oog`2LB7@0_ooo0?ooo`3ooml0W4P00018W03OoomY0?ooo`00XP3oool00`3o
_g@00000001d_`050?ooo`060?oog`2LB7@0_ooo0?oOW018000007Bo0`3oool01`3o_g@0001d0;oo
o`3oool0_g@00018W03Oool00P3oool00`3o_g@0001d0;ooo`020?ooo`090?oOW0180000B7Ad07BL
g`3oool0okmd0000B018B4P0W=oo0080oooo00<0omnL04P00018W=l00`3oool01P3ogi`0M9cO0?oo
o`2oM00004RL0=ooo`80oooo00<0okmd0000M02oool01@3oool00`3ooml0W4P0001d_`080?ooo`06
0=nLB00007@0_ooo0?oOW018000007Bo0`3oool01`3o_g@0001d0;ooo`3oool0gia80018W03Oool0
1P3oool00`3ooml0W4P0001d_`020?ooo`030?oOW018000007Bo00<0oooo00L0okmd0000M02oool0
oooo0=nLB00007@0_ooo0140oooo00<0oono07@0B02Lgol02`3oool00`3ooml0W4Qd0;ooo`050?oo
o`030?oo_`1d0000B9cO00D0oooo00<0omnL04P0001d_ol06@3oool01P3ookl0M4RL0=ooo`2oM000
001d0;ooo`D0oooo00<0gia80000M02oool01@3oool01P3ookl0M4RL0=ooo`2oM000001d0;ooofX0
oooo002Q0?ooo`040?oog`2LB000001d0;ooo`P0oooo00<0okmd0000001d_ol00`3oool01`3o_g@0
000007Boo`3oool0_g@00018W03Oool00P3oool00`3ogi`0B00007Boo`020?ooo`090=nLB00007@0
_ooo0;mdM02ooml0W4P0001d_`3ogi`0M9cO0080oooo00<0okmd0000B02Lgol01P3oool00`2oM000
04RL0=ooo`020?ooo`030?oOW0180000M;oo00D0oooo00<0oooO09a80000M;l0203oool01P3OW4P0
001d0;ooo`3o_g@0000007Boo`<0oooo00L0okmd0000001d_ol0oooo0=nLB000B9`0gooo00H0oooo
00<0oooO09a80000M;l00P3oool00`3o_g@0000007Boo`030?ooo`070?noM0000000M;oo0?ooo`3O
W4P0001d0;ooo`0A0?ooo`030?oo_`1d0000M;oo00`0oooo00<0_g@007Boo`3oool0103oool00`3o
okl0M00007Boo`050?ooo`030?oOW0180000M;oo01X0oooo00@0omnL07A8B0000000M;oo1P3oool0
0`3o_g@0001d0;ooo`060?ooo`040?oOW01dB4P0000007Boof/0oooo002Q0?ooo`040?oOW0180000
04RL0=ooo`P0oooo00<0okmd0000001d_ol00`3oool01`3o_g@0000007Boo`3oool0_g@00018W03O
ool00P3oool04`3ogi`0B00007Boo`3oool0oono07@00018W=l0oooo0?oOW01dM7@0B01809cOo`3o
ool0_gAd0;ooo`3oool0okmd0000M02oool01P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW018
0000M;oo00D0oooo00<0oooO09a80000M;l0203oool01P3OW4P0001d0;ooo`3o_g@0000007Boo`<0
oooo00L0okmd0000001d_ol0oooo0=nLB000B9`0gooo00H0oooo00<0oooO09a80000M;l00P3oool0
0`3o_g@0000007Boo`030?ooo`070?noM0000000M;oo0?ooo`3OW4P0001d0;ooo`0A0?ooo`030?no
M0000000M;oo00/0oooo00<0oooO09a80018W=l01@3oool00`3ookl0M00007Boo`050?ooo`030?oO
W0180000M;oo00P0oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?ooo`050?ooo`030?oo
_`1d0000B9cO00L0oooo00<0okmd0000B02Lgol01P3oool00`3ookl0M00004RLg`1/0?ooo`00X@3o
ool00`3o_g@00000001d_`090?ooo`030?oo_`1d0000M;oo00<0oooo00L0_g@00000B02Lgol0oooo
0;md0000B9`0gooo0080oooo00/0okmd0000B02Lgol0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P0
001d_`020?ooo`050?noM018W=l0oooo0?oOW01800001@0000001@18W=l0oooo0;md0000B9`0gooo
0080oooo00<0okmd0000B02Lgol01@3oool00`3ooml0W4P0000000040000000:07Boo`3oool0oooo
0?ooo`3OW4P0001d0;ooo`3ookl0M00007Boo`<0oooo00L0_g@00000B02Lgol0oooo0=nLB000B9`0
gooo00H0oooo00<0oooO09a80000M;l00P3oool00`3ookl0M00007Boo`030?ooo`070;md000004P0
W=oo0?ooo`3OW4P0001809cOo`0@0?ooo`040?oOW0180000001809cOo`/0oooo00<0gia80000001d
_ol01@3oool00`3ookl0M00007Boo`050?ooo`030?oOW0180000M;oo01T0oooo00D0oooO09a80000
B9`0W7A809cOo`060?ooo`030?noM00007@0_ooo00D0oooo00D0oooO09a80000B9`0W7A809cOo`1[
0?ooo`00X@3oool00`3o_g@00000001d_`0:0?ooo`070=nLB000B9`0gooo0?ooo`3o_g@00000001d
_`020?ooo`0;0;md0000000004RL0=ooo`3ookl0M0000018W03Oool0oono07@00000M;l00P3oool0
0`3ogi`0B00007Boo`020?ooo`060?oog`2LB7@0_ooo0?ooo`2oM000B9cO0P3oool0303OW4P00018
09cOo`3oool0_g@000000000B9`0gooo0?oo_`1d000004RL0=ooo`D0oooo00<0oooO09a80000M;l0
0P3oool0103ooml0W4P000000018W=l20?ooo`0;0=nLB00007@0_ooo0?ooo`3OW4P004RL0=ooo`3o
ool0okmd00000000M;l00P3oool00`3OW4P004RL0=ooo`060?ooo`030?oog`2LB00007Bo00<0oooo
0180gia80018W03Oool0oooo0?noM000000007Bo0?oog`2LB00000000000B018M9`0gkmd0000M02o
oml0W4P00000M02oool80?ooo`050?noM000000000000000B02Lgol0203oool01`3Ogml0oooo0?oo
_`1d000000000000M02oool01@3oool00`3ookl0M00004RLg`050?ooo`030?oOW0180000M;oo01T0
oooo00H0_g@00000B02Lgol0oooO09a8M02oool50?ooo`030=nLB00007@0_ooo00D0oooo00H0_g@0
0000B02Lgol0oooO09a8M02ooomZ0?ooo`00X@3oool0103ogi`0B0000018W03Oool:0?ooo`050?no
M0000000000000000018W=l00`3oool02@2oM00004RL0=oOW018000000000018W03Oool0oooO09a8
00020000000304RLg`3o_g@000000080000000P0B9cO0?ooo`2oM00000000018W03Oool0oooo0=nL
B080000000/0001809cOo`3oool0oooo0;md0000B9`0gmnL04P00000000004RL0=ooo`060?ooo`03
0?oog`2LB00007Bo00<0oooo00P0oono07@0000007@0_ooo0?ooo`3OW4P0001d0;ooo`80oooo00D0
okmd000000000000000004RLg`020?ooo`060;md00000000000000000000B9`0gooo0`3oool00`3o
_g@0000000000002000000040018W03Oool0oooo0?noM0<0000000d0B9cO0?ooo`3oool0oooo0;md
000007@0_mnL04P0000007@0_ooO09a8000007@0_ooo00X0oooo00<0_g@0001d_`3oool0203oool0
1P3OW4P00000000000000000001809cOo`H0oooo00<0oooO09a80018W=l01@3oool00`3ogi`0B000
07Boo`0G0?ooo`090?oog`2LB000000000000000M;l0okmd0000000007@0_ooo00@0oooo00<0gia8
0018W03Oool00`3oool02@3ooml0W4P000000000000007Bo0?noM0000000001d0;ooo`1Y0?ooo`00
X@3oool0103ooml0W4P00000B02Lgol50?ooo`030?oog`2LM9`0gooo00X0oooo00<0_g@00018W03O
ool06`3oool00`2oM00004RL0=ooo`0:0?ooo`030?oog`2LB00007Bo00<0oooo00P0oooO09a80000
04P0W=oo0?ooo`3OW4P0001d0;ooo`X0oooo00<0_g@00018W03Oool01P3oool00`3ooml0W4P0001d
_`0P0?ooo`030;md0018W=l0oooo00L0oooo00@0oono07@000000000B9cO2@3oool00`3OW4P004RL
0=ooo`040?ooo`030?oOW0180000M;oo02<0oooo00<0oooO09a80018W=l0MP3oool00:80oooo00<0
omnL04P00000M;l01@3oool00`3o_g@004RL0=ooo`0:0?ooo`030;md0000B9`0gooo01/0oooo00<0
_g@00018W03Oool02P3oool00`3ooml0W4P0001d_`030?ooo`080?oOW0180000001d0;ooo`3oool0
gia80000M02oool:0?ooo`030?oo_`1dB9`0gooo00L0oooo00<0_g@0001d_`3oool06P3oool00`3o
oml0W9bo0?ooo`020?ooo`030=nLB00007@0_ooo00P0oooo00<0_g@007Boo`3oool02@3oool00`3o
okl0M01809cOo`040?ooo`030?oOW0180000M;oo02<0oooo00<0oono07@0B02Lgol0MP3oool00:<0
oooo00<0okmd00000000M;l00`3oool00`3OW4P00000001d_`0;0?ooo`030;md0000B9`0gooo01/0
oooo00<0_g@00018W03Oool02P3oool00`3ooml0W4P0001d_`020?ooo`040?oo_`1d0000000004RL
g`80oooo00<0gia80000M02oool02P3oool00`3ooml0W7BL0=ooo`070?ooo`030=nLB000M;l0oooo
01/0oooo00H0okmd04RLg`3oool0oono07@00000M;l90?ooo`060?oOW018000000000000000004P0
W=oo1`3oool01P3OW4P0B9cO0?ooo`3oool0oooO09a80080000000<0M;oo0?ooo`3oool08@3oool0
0`3OW4P0B9cO0?ooo`1f0?ooo`00Y03oool00`3ooml0W4P0000000020000000304RLg`3ookl0M7Bo
00T0oooo00D0oono07@00000000004RL0=ooo`0I0?ooo`050?oo_`1d000000000018W03Oool02@3o
ool00`2oM000000000000004000000080000B02Lgol0oooo0?oog`2LB00000000000M02ooolD0?oo
o`070?oo_`1d07@0_ooo0?oog`2LB00004RL0=ooo`0H0?ooo`050=nLB000000000000000M02oool0
2P3oool01@2oM0000000000000000000B9cO00P0oooo00<0_g@004RLg`3oool00P3oool00`3o_g@0
000007Boo`0R0?ooo`030?noM000M;l0oooo07L0oooo002f0?ooo`040?oog`2LB00004RL0=oooaX0
oooo00@0oooO09a80000B9`0gooo5@3oool00`2oM000001d0;ooo`0E0?ooo`050?oo_`1d00000000
0000B02Lgol0=P3oool00`3OW7@0W=oo0?ooo`0U0?ooo`030?oo_`1dM;l0oooo07P0oooo003o0?oo
on@0oooo003o0?ooon@0oooo003o0?ooon@0oooo003o0?ooon@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 482.563}, {297.875, 0}} -> {-0.303629, -0.272458, \
0.00445607, 0.00721008}}]
}, Closed]],

Cell[TextData[{
  "Thus, after the transients have died away, we find a stable 4-cycle for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] \[TildeTilde] 3.5\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Chaos", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(logisticCobweb[3.8, 0.2, 200, 100];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -9.5 -15.6875 ]
[.21429 -0.0125 9.5 0 ]
[.40476 -0.0125 -9.5 -15.6875 ]
[.40476 -0.0125 9.5 0 ]
[.59524 -0.0125 -9.5 -15.6875 ]
[.59524 -0.0125 9.5 0 ]
[.78571 -0.0125 -9.5 -15.6875 ]
[.78571 -0.0125 9.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .01472 -10 -7.84375 ]
[-0.0125 .01472 0 7.84375 ]
[-0.0125 .13244 -19 -7.84375 ]
[-0.0125 .13244 0 7.84375 ]
[-0.0125 .25016 -19 -7.84375 ]
[-0.0125 .25016 0 7.84375 ]
[-0.0125 .36788 -19 -7.84375 ]
[-0.0125 .36788 0 7.84375 ]
[-0.0125 .4856 -19 -7.84375 ]
[-0.0125 .4856 0 7.84375 ]
[-0.0125 .60332 -10 -7.84375 ]
[-0.0125 .60332 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -11.4063 ]
[-0.01875 .30902 -19 11.4063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74.9688 0 ]
[.5 .63053 74.9688 15.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cobweb) show
105.875 15.813 moveto
(Plot) show
128.188 15.813 moveto
(for) show
142.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
148.375 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.375 15.813 moveto
(H) show
170.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
179.188 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
189.875 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
196.000 15.813 moveto
(L) show
202.813 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
208.938 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
.02381 .01472 m
.06244 .10177 L
.10458 .18832 L
.14415 .26163 L
.18221 .32485 L
.22272 .38429 L
.26171 .43387 L
.30316 .47834 L
.34309 .51317 L
.3815 .53926 L
.40095 .54969 L
.42237 .55903 L
.44268 .56579 L
.45178 .56816 L
.46172 .57027 L
.4671 .57122 L
.4721 .57197 L
.47727 .57261 L
.48196 .57309 L
.48658 .57344 L
.4887 .57357 L
.49093 .57369 L
.49332 .57378 L
.49438 .57381 L
.49552 .57384 L
.49675 .57386 L
.49789 .57388 L
.49859 .57388 L
.49925 .57389 L
.50049 .57389 L
.50163 .57388 L
.50286 .57387 L
.50401 .57385 L
.50508 .57383 L
.50754 .57375 L
.51014 .57364 L
.51268 .57349 L
.51504 .57333 L
.5204 .57286 L
.5293 .57177 L
.53882 .57017 L
.54906 .56795 L
.56016 .56496 L
.58032 .55798 L
.60019 .54913 L
.62123 .53764 L
.65912 .51145 L
.69946 .47578 L
.73829 .43387 L
.77956 .38116 L
Mistroke
.81932 .32244 L
.85757 .2586 L
.89827 .18275 L
.93745 .102 L
.97619 .01472 L
Mfstroke
.2181 .13479 m
.2181 .37792 L
.61149 .37792 L
s
.61149 .37792 m
.61149 .54324 L
.87897 .54324 L
s
.87897 .54324 m
.87897 .21972 L
.35552 .21972 L
s
.35552 .21972 m
.35552 .52241 L
.84528 .52241 L
s
.84528 .52241 m
.84528 .2799 L
.45288 .2799 L
s
.45288 .2799 m
.45288 .56841 L
.91971 .56841 L
s
.91971 .56841 m
.91971 .13949 L
.22569 .13949 L
s
.22569 .13949 m
.22569 .38834 L
.62835 .38834 L
s
.62835 .38834 m
.62835 .53327 L
.86284 .53327 L
s
.86284 .53327 m
.86284 .24923 L
.40326 .24923 L
s
.40326 .24923 m
.40326 .55081 L
.89123 .55081 L
s
.89123 .55081 m
.89123 .19644 L
.31785 .19644 L
s
.31785 .19644 m
.31785 .49207 L
.79619 .49207 L
s
.79619 .49207 m
.79619 .35756 L
.57854 .35756 L
s
.57854 .35756 m
.57854 .55868 L
.90396 .55868 L
s
.90396 .55868 m
.90396 .17149 L
.27748 .17149 L
s
.27748 .17149 m
.27748 .45179 L
.73101 .45179 L
s
.73101 .45179 m
.73101 .44229 L
.71565 .44229 L
s
.71565 .44229 m
.71565 .45921 L
.74302 .45921 L
s
.74302 .45921 m
.74302 .42825 L
.69292 .42825 L
s
.69292 .42825 m
.69292 .48211 L
.78007 .48211 L
s
.78007 .48211 m
.78007 .38047 L
.61561 .38047 L
s
.61561 .38047 m
.61561 .54093 L
.87524 .54093 L
s
.87524 .54093 m
.87524 .22666 L
.36675 .22666 L
s
.36675 .22666 m
.36675 .5301 L
.85772 .5301 L
s
.85772 .5301 m
.85772 .25833 L
.41798 .25833 L
s
.41798 .25833 m
.41798 .5573 L
.90173 .5573 L
s
.90173 .5573 m
.90173 .17591 L
.28463 .17591 L
s
.28463 .17591 m
.28463 .45951 L
.7435 .45951 L
s
.7435 .45951 m
.7435 .42768 L
.692 .42768 L
s
.692 .42768 m
.692 .48298 L
.78148 .48298 L
s
.78148 .48298 m
.78148 .3785 L
.61243 .3785 L
s
.61243 .3785 m
.61243 .54272 L
.87814 .54272 L
s
.87814 .54272 m
.87814 .22129 L
.35805 .22129 L
s
.35805 .22129 m
.35805 .5242 L
.84818 .5242 L
s
.84818 .5242 m
.84818 .27495 L
.44488 .27495 L
s
.44488 .27495 m
.44488 .5664 L
.91645 .5664 L
s
.91645 .5664 m
.91645 .14622 L
.23659 .14622 L
s
.23659 .14622 m
.23659 .40278 L
.65172 .40278 L
s
.65172 .40278 m
.65172 .51713 L
.83673 .51713 L
s
.83673 .51713 m
.83673 .29429 L
.47616 .29429 L
s
.47616 .29429 m
.47616 .57249 L
.9263 .57249 L
s
.9263 .57249 m
.9263 .12574 L
.20345 .12574 L
s
.20345 .12574 m
.20345 .35702 L
.57768 .35702 L
s
.57768 .35702 m
.57768 .55901 L
.9045 .55901 L
s
.9045 .55901 m
.9045 .17041 L
.27574 .17041 L
s
.27574 .17041 m
.27574 .44986 L
.7279 .44986 L
s
.7279 .44986 m
.7279 .44582 L
.72135 .44582 L
s
.72135 .44582 m
.72135 .45307 L
.73309 .45307 L
s
.73309 .45307 m
.73309 .43991 L
.7118 .43991 L
s
.7118 .43991 m
.7118 .46327 L
.74959 .46327 L
s
.74959 .46327 m
.74959 .42027 L
.68002 .42027 L
s
.68002 .42027 m
.68002 .49398 L
.79927 .49398 L
s
.79927 .49398 m
.79927 .35303 L
.57122 .35303 L
s
.57122 .35303 m
.57122 .56138 L
.90834 .56138 L
s
.90834 .56138 m
.90834 .16272 L
.26329 .16272 L
s
.26329 .16272 m
.26329 .43571 L
.705 .43571 L
s
.705 .43571 m
.705 .47026 L
.76089 .47026 L
s
.76089 .47026 m
.76089 .40605 L
.657 .40605 L
s
.657 .40605 m
.657 .51311 L
.83022 .51311 L
s
.83022 .51311 m
.83022 .30498 L
.49347 .30498 L
s
.49347 .30498 m
.49347 .57378 L
.9284 .57378 L
s
.9284 .57378 m
.9284 .12132 L
.1963 .12132 L
s
.1963 .12132 m
.1963 .34644 L
.56055 .34644 L
s
.56055 .34644 m
.56055 .56485 L
.91394 .56485 L
s
.91394 .56485 m
.91394 .15135 L
.24489 .15135 L
s
.24489 .15135 m
.24489 .4134 L
.66889 .4134 L
s
.66889 .4134 m
.66889 .50355 L
.81476 .50355 L
s
.81476 .50355 m
.81476 .32958 L
.53327 .32958 L
s
.53327 .32958 m
.53327 .57116 L
.92416 .57116 L
s
.92416 .57116 m
.92416 .13024 L
.21074 .13024 L
s
.21074 .13024 m
.21074 .36755 L
.59472 .36755 L
s
.59472 .36755 m
.59472 .55177 L
.89278 .55177 L
s
.89278 .55177 m
.89278 .19346 L
.31302 .19346 L
s
.31302 .19346 m
.31302 .48767 L
.78907 .48767 L
s
.78907 .48767 m
.78907 .36782 L
.59515 .36782 L
s
.59515 .36782 m
.59515 .55156 L
.89245 .55156 L
s
.89245 .55156 m
.89245 .1941 L
.31406 .1941 L
s
.31406 .1941 m
.31406 .48863 L
.79062 .48863 L
s
.79062 .48863 m
.79062 .36562 L
.59158 .36562 L
s
.59158 .36562 m
.59158 .55321 L
.89511 .55321 L
s
.89511 .55321 m
.89511 .18893 L
.30569 .18893 L
s
.30569 .18893 m
.30569 .48078 L
.77793 .48078 L
s
.77793 .48078 m
.77793 .38341 L
.62037 .38341 L
s
.62037 .38341 m
.62037 .53816 L
.87076 .53816 L
s
.87076 .53816 m
.87076 .23492 L
.3801 .23492 L
s
.3801 .23492 m
.3801 .53844 L
.87121 .53844 L
s
.87121 .53844 m
.87121 .23408 L
.37876 .23408 L
s
.37876 .23408 m
.37876 .53764 L
.86992 .53764 L
s
.86992 .53764 m
.86992 .23645 L
.38258 .23645 L
s
.38258 .23645 m
.38258 .53989 L
.87356 .53989 L
s
.87356 .53989 m
.87356 .22977 L
.37177 .22977 L
s
.37177 .22977 m
.37177 .53334 L
.86296 .53334 L
s
.86296 .53334 m
.86296 .24902 L
.40292 .24902 L
s
.40292 .24902 m
.40292 .55065 L
.89097 .55065 L
s
.89097 .55065 m
.89097 .19695 L
.31867 .19695 L
s
.31867 .19695 m
.31867 .49281 L
.79738 .49281 L
s
.79738 .49281 m
.79738 .35582 L
.57572 .35582 L
s
.57572 .35582 m
.57572 .55975 L
.90569 .55975 L
s
.90569 .55975 m
.90569 .16803 L
.27187 .16803 L
s
.27187 .16803 m
.27187 .44556 L
.72092 .44556 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{346.438, 214.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000870001@B000`400?l00000o`00003oo`3ooooo
0?ooo`T0oooo003o0?ooool0oooo2@3oool00?l0ooooo`3oool90?ooo`00o`3ooooo0?ooo`T0oooo
003o0?ooob<0oooo00D0oooO09a80000000004RL0=ooo`3P0?ooo`00o`3ooolT0?ooo`030?oOW018
04P0W=oo0>40oooo003o0?ooob@0oooo00<0omnL04P0B02Lgol0h@3oool00?l0oooo6`3oool01@2o
M0000000001d_`3oool0gia80080000000D004RL0=ooo`3ogi`0B01809cOo`3Q0?ooo`00o`3ooolK
0?ooo`0<0?oog`2LB7@0_ooo0?ooo`3ooml0W4P00018W03Oool0oono07@0000004P0W=ooh@3oool0
0?l0oooo703oool01P3ookl0M4RL0=ooo`2oM000001d0;ooo`80oooo00<0omnL04P0B02Lgol0h@3o
ool00?l0oooo7@3oool0103ogi`0M4Q80000001d_ooW0?ooo`00o`3ooolM0?ooo`030?oo_`1d0000
B9cO0>P0oooo003o0?oooa`0oooo00D0oooO09a80000B9`0W7A809cOo`030?ooo`030?oo_`1d0000
M;oo0>40oooo003o0?oooa`0oooo00H0_g@00000B02Lgol0oooO09a8M02ooooV0?ooo`00o`3ooolJ
0?ooo`090?oog`2LB000000000000000M;l0okmd0000000007@0_ooo0>D0oooo003o0?ooool0oooo
2@3oool00?l0ooooo`3oool90?ooo`00o`3ooooo0?ooo`T0oooo003o0?ooool0oooo2@3oool00?l0
ooooo`3oool90?ooo`00o`3ooooo0?ooo`T0oooo003o0?ooool0oooo2@3oool00?l0ooooo`3oool9
0?ooo`00o`3ooooo0?ooo`T0oooo003o0?ooool0oooo2@3oool00?l0ooooo`3oool90?ooo`00o`3o
oooo0?ooo`T0oooo003o0?ooool0oooo2@3oool00?l0ooooo`3oool90?ooo`00o`3ooooo0?ooo`T0
oooo003o0?ooool0oooo2@3oool006D0oooo00D0omnL04P000000000001d0;ooo`0n0?ooo`050?oO
W018000000000000M02oool00`3oool01@3o_g@0000007Boo`3oool0_g@000H0000000<0B9cO0?oo
o`3oool0=03oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol01@3oool0
103ooml0W4P00018W03Ooolf0?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@00000
07Boo`030?ooo`050?oOW018000000000000001d_ol0=`3oool01@3ogi`0B0000000000007@0_ooo
00<0oooo00<0okmd0000001d_ol00`3oool01@3OW4P00000000000000000B9cO03h0oooo00H0_g@0
00000000000000000018W03OoolZ0?ooo`00I03oool01`3ookl0M00007Boo`3oool0okmd0000M02o
ool0?03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`02
0?ooo`030=nLB0000000000000<0000000<004RL0=ooo`3oool0<`3oool01`3ookl0M00007Boo`3o
ool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`050?ooo`040?oog`2LB00004RL0=ooocD0
oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool0
1`3ogi`0B00004RLg`3oool0oono07@0001d_ol0=@3oool01`3ookl0M00007Boo`3oool0okmd0000
M02oool00P3oool00`3o_g@0000007Boo`020?ooo`070=nLB0000000M;oo0?ooo`3ooml0W4P004RL
g`0n0?ooo`030?oOW0180000M;oo02`0oooo001T0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0
001d_`3oool0>`3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia8
04RLg`3oool00P3oool00`3OW7@0W=oo0?ooo`0c0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0
001d_`3oool02@3oool0103ooml0W4P00018W03Ooole0?ooo`030;md0000B9`0gooo0080oooo00<0
_g@0001d_`3oool01@3oool00`3ooml0W4P0001d_`030?ooo`030?noM000B9`0gooo03@0oooo00<0
_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0
okmd0018W03Oool0?@3oool00`3ogi`0B00007Boo`0/0?ooo`00H`3oool00`3ookl0M00004RLg`03
0?ooo`030=nLB00007@0_ooo03X0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`08
0?ooo`030=nLB01d_ol0oooo03H0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`05
0?ooo`030;md00000000000000D0000000<0M;oo0?ooo`3oool0<@3oool00`3ookl0M00004RLg`03
0?ooo`030=nLB00007@0_ooo00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0c
0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM00007Bo0?ooo`02
0?ooo`030;md0000B9`0gooo03d0oooo00<0omnL04P0001d_ol0;03oool006<0oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@0001809cOo`0j0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000
B02Lgol02@3oool00`2oM4P0W=oo0?ooo`0e0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000
B02Lgol01@3oool0203ogi`0M9cO0?ooo`3oool0oooO09a80000B9`0gooo=03oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`0c0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3ogi`0B01d
0;ooo`3oool0_g@00000001d_ol0?P3oool00`3ogi`0B00007Boo`0/0?ooo`00H`3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo03X0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`090?ooo`030?oog`2LB7@0_ooo03D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`060?ooo`070=nLB01d_ol0oooo0?oog`2LB00004RL0=ooo`0d0?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0B00007Boo`030?ooo`030;md000004P0
W=oo03<0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`050?oo_`1dB4P0
B00000000018W=l0?`3oool00`3ogi`0B00007Boo`0/0?ooo`00H`3oool00`3ogi`0B00007Boo`03
0?ooo`030?noM00004P0W=oo03X0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:
0?ooo`030?noM000M;l0oooo03@0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`06
0?ooo`070?oog`2LB7@0_ooo0?oog`2LB00004RL0=ooo`0d0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol01@3oool0203ookl0M00000000018W=l0oooo0?noM000000007Bo=03oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00@0omnL04P00000000007Bo@03o
ool00`3ogi`0B00007Boo`0/0?ooo`00H`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo03X0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?oo_`1d04P0
W=oo03@0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`060?oOW018M;l0
oooO09a80000B9`0gooo=03oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo
00<0_g@00018W02oW4P00P0000000`00B9`0gooo0?ooo`0c0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol01P3oool01P3ogi`0B0000000M02oool0okmd001d_cl0oooo00<0omnL04P0
001d_ol0;03oool006<0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0j0?ooo`03
0?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool02P3oool00`3ookl0M00004RLg`0d0?ooo`03
0?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool01@3OW4P0M;oO09a80000B9`0gooo
03@0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030?oOW0180000M;oo
03P0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030;md000007@0_ooo
0080oooo00<0_g@004RLg`3oool0?@3oool00`3ogi`0B00007Boo`0/0?ooo`00I03oool00`3OW4P0
04RL0=ooo`020?ooo`030;md0000M;l0oooo03/0oooo00<0gia80018W03Oool00P3oool00`2oM000
07Bo0?ooo`050?ooo`030?noW02Lgol0oooo0080oooo00<0omnL04P00018W=l0=@3oool00`3OW4P0
04RL0=ooo`020?ooo`030;md0000M;l0oooo00P0oooo00D0oooO09a8B018B00004RL0=ooo`0e0?oo
o`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`3OW4P0001809cOo`0h0?oo
o`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01P3oool00`2oM00004RL0=ooo`020?oo
o`030=nLB000M;l0oooo03d0oooo00<0omnL04P0001d_ol0;03oool006@0oooo00L0oono07@0001d
_ol0oooo0?noM00007@0_ooo03`0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00H0oooo
00P0oooO09a8B02Lgol0oooo0?oo_`1d0000001d0;ooocD0oooo00L0oono07@0001d_ol0oooo0?no
M00007@0_ooo00X0oooo00@0omnL04P00000B9`0gooo=@3oool01`3ookl0M00007Boo`3oool0okmd
0000M02oool02@3oool00`3o_g@00000001d_`0g0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d
0;ooo`070?ooo`070?noM0000000M;oo0?ooo`3ookl0M00007Boo`0l0?ooo`050?oog`2LB0000000
0000001d_ol0;03oool006D0oooo00D0oono07@000000000001d0;ooo`0n0?ooo`050?oo_`1d0000
00000000M02oool0203oool01P3ooml0W4P0000000000000001d0;ooocL0oooo00D0oono07@00000
0000001d0;ooo`0<0?ooo`030=nLB000B9`0gooo03H0oooo00D0oono07@000000000001d0;ooo`0;
0?ooo`050?oog`2LB00000000000M02oool0=@3oool01@3ookl0M0000000000007@0_ooo00T0oooo
00D0okmd000000000000000004RLg`0o0?ooo`030?noM0000000M;oo02`0oooo003o0?ooool0oooo
2@3oool00?l0ooooo`3oool90?ooo`00o`3ooooo0?ooo`T0oooo003o0?ooool0oooo2@3oool00?l0
ooooo`3oool90?ooo`00o`3ooooo0?ooo`T0oooo003o0?ooool0oooo2@3oool00?l0ooooo`3oool9
0?ooo`00o`3ooooo0?ooo`T0oooo001N0?ooool00000QP00000T0?ooo`00D03oool01@3ogi`0B000
0000000007@0_ooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`00
C`3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool0203oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0280oooo001?0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo001>0?ooo`030?oo
_`1d0000B9cO00<0oooo00<0gia80000M02oool01`3oool00`000000oooo0?ooo`3o0?oooh80oooo
00<000000?ooo`3oool08P3oool004h0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cO
o`070?ooo`030000003oool0oooo0?l0ooooPP3oool00`000000oooo0?ooo`0R0?ooo`00CP3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo100000060?ooo`030000003oool0
oooo0?l0ooooK`3oool00`000000oooo0?ooo`040?ooo`<00000903oool004h0oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`030000003oool0oooo00L0oooo0`00003o0?oo
ofl0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`00CP3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0203oool010000000
oooo00000000003o0?ooof`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0R0?oo
o`00CP3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00L0oooo00<000000?ooo`3o
ool0203oool01@000000oooo0?ooo`3oool000000?l0ooooJ`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0280oooo001?0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3o
ool01`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`800000o`3ooomX0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool08P3oool004l0oooo00L0oono07@0001d
_ol0oooo0?noM00007@0_ooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`800000o`3ooomV0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool08P3oool0
0500oooo00D0oono07@000000000001d0;ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooof80oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00D0oooo0P00003o0?ooof80oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?oo
o`00GP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo0P00003o0?oooel0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`090?ooo`800000o`3ooomL0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool08P3oool005h0oooo0`00000<0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0o`3ooomH0?ooo`030000003oool0oooo00X0oooo0P00000T0?ooo`00GP3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo0P00003o0?oooeP0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo0P00003o0?oooeD0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0o`3ooomB0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
8P3oool005h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`800000o`3o
oomA0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08P3oool005h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooCP3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool04@3oool200000?l0ooooC@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04P3oool200000?l0ooooB`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0280
oooo001N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`3o0?ooodP0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0R0?ooo`00GP3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo0P00003o0?ooodL0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooom40?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0F0?ooo`800000o`3ooom30?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool08P3oool005h0oooo0`00000A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0o`3ooom00?ooo`030000003oool0oooo00l0oooo0P00000T0?ooo`00GP3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01P0oooo0P00003o0?ooocl0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0o`3oooll0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0K
0?ooo`800000o`3oooll0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08P3oool0
05h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0?l0oooo>03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0280oooo001N0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool200000?l0oooo>03oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?oooc@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01l0oooo0P00003o0?oooc@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0R0?ooo`00GP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0200oooo0P00003o
0?oooc40oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3oool^0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0R0?ooo`800000o`3oool]0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool08P3oool005h0oooo0`00000F0?ooo`030000003oool0oooo02@0oooo
0P00003o0?ooob/0oooo00<000000?ooo`3oool0503oool2000002@0oooo001N0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo02H0oooo0P00003o0?ooobL0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
02P0oooo0P00003o0?ooobD0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R0?oo
o`00GP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0o`3ooolQ0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool08P3oool005h0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0Z0?ooo`800000o`3ooolQ0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0280oooo00120?ooo`050?oOW018000000000000M02oool00`3o
ool01@3o_g@0000007Boo`3oool0_g@000H0000000<0B9cO0?ooo`3oool01P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo02`0ooooo`00000P000001X0oooo00<000000?ooo`3oool0
8P3oool00440oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d
_ol00P3oool00`3OW4P0000000000003000000030018W03Oool0oooo00H0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0/0?ooo`<00000o`3ooolJ0?ooo`8000006P3oool00`000000
oooo0?ooo`0R0?ooo`00@@3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo
00<0gia804RLg`3oool00P3oool00`3OW7@0W=oo0?ooo`060?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o000001`000006P3oool00`000000oooo
0?ooo`0R0?ooo`00@03oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00P0oooo00<0
gia807Boo`3oool02P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool00`00003o0?oooaH0oooo0`00000J0?ooo`030000003oool0oooo0280oooo0010
0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02@3oool00`2oM4P0W=oo0?ooo`09
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`00
00020?ooool000006@00000J0?ooo`030000003oool0oooo0280oooo00100?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol02@3oool00`3ooml0W4Qd0;ooo`090?ooo`@000006`3oool0
0`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo00000080oooo0`00003o0?oooa80oooo1000
000H0?ooo`<00000903oool00400oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:
0?ooo`030?noM000M;l0oooo00P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0Z
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P00003o0?oooa00oooo1000
000J0?ooo`030000003oool0oooo0280oooo00100?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol02P3oool00`3ookl0M01809cOo`080?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0:@3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0000003oool0
o`00000@000000040?ooo`0000000000000001X0oooo00<000000?ooo`3oool08P3oool00400oooo
00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0:0?ooo`030?oo_`1d0000B9cO00P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool200000?l0oooo303oool00`000000oooo000000020000
01X0oooo00<000000?ooo`3oool08P3oool00440oooo00<0gia80018W03Oool00P3oool00`2oM000
07Bo0?ooo`050?ooo`030?noW02Lgol0oooo0080oooo00<0omnL04P00018W=l0203oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0000000000?l0oooo2@3oool2000000040?ooo`00
00000000000001X0oooo00<000000?ooo`3oool08P3oool00440oooo00L0oono07@0001d_ol0oooo
0?noM00007@0_ooo00H0oooo00P0oooO09a8B02Lgol0oooo0?oo_`1d0000001d0;ooo`P0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3ooooo000000/0000000@0oooo0000
0000000000006P3oool00`000000oooo0?ooo`0R0?ooo`00@P3oool01@3ookl0M0000000000007@0
_ooo00P0oooo00H0oooO09a80000000000000000M02oool90?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool09`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool0oooo0`00003o0?ooo`D0oooo0`000000103oool0000000000000
000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool09`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00D000000?ooo`3oool0oooo000000020?ooool0000020000000103oool0000000000000000J0?oo
o`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool09P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool000000?l0oooo0@3oool4000000040?ooo`00
00000000000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00003n0?oo
o`@0000000@0oooo00000000000000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo02D0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`800000n`3oool00`000000oooo00000002000000040?ooo`0000000000000001X0
oooo00<000000?ooo`3oool08P3oool005h0oooo0`00000Q0?ooo`030000003oool0oooo02D0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`040?oooo`0000000D0oooo00000000000000000?oo
o`03000001T0oooo0P00000T0?ooo`00GP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo02@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`<00000m`3oool200000005
0?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0n@0000001@3oool00000000000000000oooo00<00000
6P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo02<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
0?ooooP0000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3o
ool005h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3ooooh000000050?ooo`0000000000
0000003oool00`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool0oooo0`0000000`3oool000000?ooo`3^0?ooo`@0000000D0oooo00000000
000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`3oool300000080ooool`0000001@3oool00000000000000000oooo00<0
00006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo0240oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo0?ooo`<000000P3oool00`000000oooo0000003[0?ooo`D0000000D0oooo0000000000000000
0?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool00P00003Y0?ooo`D0000000D0oooo
00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool00P3oool20000
0>H0oooo00<000000?ooo`0000000`0000001@3oool00000000000000000oooo00<000006P3oool0
0`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
0200oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<0
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0><0oooo00<000000?ooo`00
00000`0000001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?oo
o`00GP3oool3000002L0oooo00<000000?ooo`3oool07`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo
iP0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000I0?ooo`80
0000903oool005h0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0O0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0000003S000000030?ooo`00000000000080000000D0
oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3S000000030?ooo`00000000000080000000D0oooo00000000000000000?oo
o`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0N0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`000000
oooo0>40000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<000006P3o
ool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo01d0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?oo
o`<000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0000003oool00`00003J
0?ooo`@0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<000006P3o
ool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo01d0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?oo
o`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`3G0?ooo`@0000000<0oooo0000000000000P0000001@3oool000000000
00000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo01`0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0
oooo0000003oool000000`3oool200000=H0oooo00<000000?ooo`0000000P0000000`3oool00000
00000002000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280
oooo001N0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0703oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003o
ool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003oool0oooo0=<0
oooo00<000000?ooo`0000000P0000000`3oool0000000000002000000050?ooo`00000000000000
003oool00`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool06`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool0
00000?ooo`0000060?ooo`800000dP3oool00`000000oooo0?ooo`03000000030?ooo`0000000000
0080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool0
05h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0K0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3o
ool01@3oool01P000000oooo0?ooo`000000oooo000000P0oooo00<000000?ooo`3oool0c`3oool0
0`000000oooo0?ooo`03000000030?ooo`00000000000080000000D0oooo00000000000000000?oo
o`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0J0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000
oooo000000T0oooo0P00003>0?ooo`040000003oool0oooo0?ooo`<0000000<0oooo000000000000
0P0000001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00
GP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?oo
o`050?ooo`060000003oool0oooo0000003oool000002`3oool200000<`0oooo00@000000?ooo`3o
ool0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J
0?ooo`030000003oool0oooo0280oooo001N0?ooo`<00000;@3oool00`000000oooo0?ooo`0I0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080
oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000d0ooooc0000004
0?ooo`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<000006@3o
ool2000002@0oooo001N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`0000020?oo
o`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`<00000a`3o
ool2000000@0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool0
0`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0603oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?oo
o`00000=0?ooo`80000000<0oooo000000000000a`0000040?ooo`<0000000<0oooo000000000000
0P0000001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00
GP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?oo
o`050?ooo`060000003oool0oooo0000003oool000003@3oool2000000<0oooo00<000000?ooo`00
0000a00000040?ooo`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo
00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003o
ool000003@3oool2000000<0oooo0`0000310?ooo`<00000103oool3000000030?ooo`0000000000
0080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool0
05h0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3o
ool01@3oool01P000000oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`030000003oool0
00000<@00000103oool3000000030?ooo`00000000000080000000D0oooo00000000000000000?oo
o`03000001X0oooo00<000000?ooo`3oool08P3oool00480oooo00D0omnL04P000000000001d0;oo
o`030?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo203oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003o
ool0oooo0000003oool000003@3oool2000000<0oooo00@000000?ooo`000000oooo``0000040?oo
o`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<000006P3oool0
0`000000oooo0?ooo`0R0?ooo`00@@3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3o
ool00`3o_g@0000007Boo`050?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?oo
o`000000oooo000000d0oooo0P0000030?ooo`040000003oool000000?ooo`@00000^P3oool50000
00@0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J
0?ooo`030000003oool0oooo0280oooo00110?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d
_`3oool02@3oool0103ooml0W4P00018W03Oool80?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool05@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00
000=0?ooo`8000000`3oool010000000oooo0000003oool3000000030?ooo`000000oooo0;P0oooo
1@0000040?ooo`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<0
00006P3oool00`000000oooo0?ooo`0R0?ooo`00@03oool00`3ookl0M00004RLg`030?ooo`030=nL
B00007@0_ooo00D0oooo00<0_g@00000000000001@0000000`1d_ol0oooo0?ooo`050?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00@0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H0
00000?ooo`3oool000000?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003oool30000
0080oooo0P00002f0?ooo`030000003oool0000000<00000103oool3000000030?ooo`0000000000
0080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool0
0400oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`080?oOW01dW=l0oooo
0?ooo`3ooml0W4P00018W03Oool80?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
503oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`00
00020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`80
00000`3oool010000000oooo0000003oool3000000@0oooo0P00002d0?ooo`030000003oool00000
00<00000103oool3000000030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03
000001X0oooo00<000000?ooo`3oool08P3oool00400oooo00<0omnL04P0001d_ol00`3oool00`3o
_g@0001809cOo`060?ooo`070=nLB01d_ol0oooo0?oog`2LB00004RL0=ooo`080?ooo`@00000<@3o
ool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`00
0000oooo000000d0oooo0P0000030?ooo`040000003oool000000?ooo`<000001P3ooond00000080
oooo100000040?ooo`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo
00<00000603oool3000002@0oooo00100?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool0203oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo
0000003oool000003@3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`800000
/03oool00`000000oooo0?ooo`04000000@0oooo0`0000000`3oool0000000000002000000050?oo
o`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo00100?ooo`030?oO
W0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool01P3ogi`0B7Bo0?oog`2LB00004RL0=oo
o`P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3o
ool01@3oool01P000000oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003oool0
00000?ooo`<000001`3oool00`000000oooo0000002^0?ooo`8000000P3oool4000000@0oooo0`00
00000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J0?ooo`030000
003oool0oooo0280oooo00100?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203o
ool01@3OW4P0M;oO09a80000B9`0gooo00P0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3o
ool300000080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000d0
oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool00`000000oooo0?ooo`020000
00030?ooo`00000000000:/000000P3oool4000000@0oooo0`0000000`3oool00000000000020000
00050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo00110?oo
o`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool0203oool01@3ooml0W4Q804Q80000B9`0
gooo00P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080oooo00<000000?oo
o`3oool01@3oool01P000000oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003o
ool000000?ooo`<000001`3oool00`000000oooo0?ooo`020?ooo`800000Z@3oool00`000000oooo
000000020?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo000000000000
00000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool00440oooo00L0oono07@0001d_ol0
oooo0?noM00007@0_ooo00X0oooo00@0omnL04P00000B9`0gooo203oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo
0000003oool000003@3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000
003oool0oooo00<0oooo0P00002W0?ooo`80000000@0oooo0000003oool0oooo100000040?ooo`<0
000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<000006P3oool00`00
0000oooo0?ooo`0R0?ooo`00@P3oool01@3ookl0M0000000000007@0_ooo00`0oooo00<0gia80018
W03Oool0203oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0100oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000
oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000003@3oool2000000<0oooo00@00000
0?ooo`000000oooo0`0000070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0000000000
Y@3oool2000000040?ooo`000000oooo0?ooo`@00000103oool3000000030?ooo`00000000000080
000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool0
1@3oool01P000000oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003oool00000
0?ooo`<000001`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`800000XP3o
ool01@000000oooo0000003oool000000080oooo100000040?ooo`<0000000<0oooo000000000000
0P0000001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00
GP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?oo
o`050?ooo`060000003oool0oooo0000003oool000003@3oool2000000<0oooo00@000000?ooo`00
0000oooo0`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool20000
09l0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`@00000103oool3000000030?ooo`00
000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool0
8P3oool005h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0?0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080oooo00<00000
0?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000
003oool000000?ooo`<000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0W03oool01P000000oooo0?ooo`000000oooo00000080oooo10000004
0?ooo`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<000006P3o
ool00`000000oooo0?ooo`0R0?ooo`00;@3oool00`2oM7@0_ooo0?ooo`040?ooo`030;mdM02oool0
oooo02L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0>0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080oooo00<000000?oo
o`3oool01@3oool01P000000oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003o
ool000000?ooo`<000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
W`0000020?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo000000000000
0P0000001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00
;@3oool00`2oM000B9cO0?ooo`030?ooo`030=nLB00007@0_ooo02P0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?oo
o`000000oooo000000d0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0`00002I0?ooo`8000000P3oool00`00
0000oooo000000020?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo0000
0000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool002d0oooo00T0_g@00000
000007@0_ooo0?oog`2LB000B9cO0=nLW02oool0:03oool3000003T0oooo00<000000?ooo`3oool0
3@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`00
00020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`80
00000`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo09T0000000L0oooo0000003oool0oooo0000003o
ool000000080oooo100000040?ooo`<0000000<0oooo0000000000000P0000001@3oool000000000
00000000oooo00<000006@3oool2000002@0oooo000]0?ooo`060;nLW03Ogi`0B0000000000004P0
W=oo:`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo
0?ooo`050?ooo`060000003oool0oooo0000003oool000003@3oool2000000<0oooo00@000000?oo
o`000000oooo0`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
1@000000oooo0?ooo`000000oooo00800000T`3oool2000000070?ooo`000000oooo0?ooo`000000
oooo000000020?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo00000000
000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool002d0oooo00<0_gAd0;oOW018
00000P000000100004P0W=oo0=nLW02ooolX0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool02`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=
0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
T03oool2000000070?ooo`000000oooo0?ooo`000000oooo000000020?ooo`@00000103oool30000
00030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<00000
0?ooo`3oool08P3oool002d0oooo00<0_g@00018W03Oool00P3oool0102oM00000000000M02ooolX
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo
00D0oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`8000000`3oool010000000oooo0000
003oool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000
003oool0oooo000000@0oooo0P00002?0?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000020?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo0000
0000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool002d0oooo00<0_gA809cO
o`3oool00`3oool00`3o_g@0001d0;ooo`0X0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool02P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=
0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0
R`3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3oool40000
00@0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J
0?ooo`030000003oool0oooo0280oooo000]0?ooo`030;nLW03Oool0oooo00@0oooo00<0gibL0;oo
o`3oool09`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000
oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000003@3oool2000000<0oooo00@00000
0?ooo`000000oooo0`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`0000070?ooohh000000P3oool00`000000oooo000000020?ooo`030000
003oool000000080oooo100000040?ooo`<0000000<0oooo0000000000000P0000001@3oool00000
000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003o
ool0oooo0000003oool000003@3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`000008
0?ooo`800000R@3oool200000080oooo00<000000?ooo`0000000P3oool00`000000oooo00000002
0?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo00000000000000000?oo
o`03000001X0oooo00<000000?ooo`3oool08P3oool00380oooo00<0_ibL0=ooo`3oool00P3oool0
0`3OW9`0_ooo0?ooo`0T0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0203oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`0000020?oo
o`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`8000000`3o
ool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`0000000000Q`3oool20000
0080oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool30000
00030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<00000
0?ooo`3oool08P3oool002h0oooo00D0oono07@0B02Lgol0oono07@00004000000030000M02oool0
oooo02@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`080?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080oooo00<000000?oo
o`3oool01@3oool01P000000oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003o
ool000000?ooo`<000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`3oool2000008@0oooo00<000000?oo
o`0000000P3oool00`000000oooo000000020?ooo`030000003oool000000080oooo100000040?oo
o`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<000006P3oool0
0`000000oooo0?ooo`0R0?ooo`00=`3oool00`3OW9`0_ooo0?ooo`0T0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3o
ool000000?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`200?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool300000003
0?ooo`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?oo
o`3oool08P3oool005h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080oooo
00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000d0oooo0P0000030?oo
o`040000003oool000000?ooo`<000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`040?oooh@0000000L0
oooo0000003oool0oooo0000003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0
oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J0?oo
o`030000003oool0oooo0280oooo001N0?ooo`<00000@03oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool300000080oooo
00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000d0oooo0P0000030?oo
o`040000003oool000000?ooo`<000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`040?ooo`030000003o
ool0000007h0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool000000080oooo
00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002000000050?oo
o`00000000000000003oool00`00000I0?ooo`800000903oool003@0oooo00<0_gAd0;ooo`3oool0
9`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?oo
o`050?ooo`060000003oool0oooo0000003oool000003@3oool2000000<0oooo00@000000?ooo`00
0000oooo0`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P00001k
0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo000000020?ooo`030000
003oool000000080oooo100000040?ooo`<0000000<0oooo0000000000000P0000001@3oool00000
000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00=03oool00`2oM7@0_ooo
0?ooo`0W0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003o
ool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`8000000`3oool010000000
oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo07P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000
003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool00000
00000002000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280
oooo000d0?ooo`030;mdM02oool0oooo02L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3o
ool300000080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000d0
oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo0P00001g0?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo
0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J0?ooo`03
0000003oool0oooo0280oooo000a0?ooo`030;md00000000000000<0000000<0001d0;ooo`3oool0
903oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?oo
o`050?ooo`060000003oool0oooo0000003oool000003@3oool2000000<0oooo00@000000?ooo`00
0000oooo0`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool2
000007D0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`000000
0P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?ooo`000000000000800000
00D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool003@0oooo
00<0_gAd0;ooo`3oool09`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000000P3o
ool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000003@3oool2000000<0
oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool000000080oooo10000004
0?ooo`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<000006P3o
ool00`000000oooo0?ooo`0R0?ooo`00=03oool00`2oM7@0_ooo0?ooo`0W0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?oo
o`3oool000000?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`800000L03oool00`000000
oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000
oooo000000020?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo00000000
000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool003@0oooo00<0_gAd0;ooo`3o
ool09`3oool00`000000oooo0?ooo`150?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
1P3oool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool01@3oool01P000000
oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?ooo`000000000000800000
00D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo
00<000000?ooo`3oool0A@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000H0oooo00@0
00000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool0
00000?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooog0000001@3oool00`000000oooo0000
00020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`00
00000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J0?ooo`030000
003oool0oooo0280oooo000_0?ooo`030?oog`2LM9`0gooo00D0oooo00<0gibL0;ooo`3oool0903o
ool00`000000oooo0?ooo`160?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000H0oooo00@00000
0?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool00000
0?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`<00000J@3oool00`000000oooo00000005
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo00000002
0?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo00000000000000000?oo
o`03000001X0oooo00<000000?ooo`3oool08P3oool002l0oooo00<0okmd0000000000001@000000
0`0007@0_ooo0?ooo`0T0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool0
00001P3oool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool01@3oool01P00
0000oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003oool000000?ooo`<00000
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3o
ool00000J03oool00`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?oo
o`0000000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?ooo`0000000000
0080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool0
03L0oooo00<0gibL0;ooo`3oool0903oool00`000000oooo0?ooo`170?ooo`030000003oool00000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`040000003o
ool0oooo000000H0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0
oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003o
ool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`040000
003oool0oooo0?ooo`800000I@3oool010000000oooo0?ooo`0000050?ooo`030000003oool00000
0080oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool30000
00030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<00000
0?ooo`3oool08P3oool005h0oooo0`0000180?ooo`8000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000001P3oool010000000oooo
0?ooo`3oool300000080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo
000000d0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool200000680oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`00
00000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?ooo`00000000000080
000000D0oooo00000000000000000?ooo`03000001T0oooo0P00000T0?ooo`00GP3oool00`000000
oooo0?ooo`190?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`3oool300000080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo0000
00d0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1O0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?ooo`030000
003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool00000
00000002000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280
oooo001N0?ooo`030000003oool0oooo04T0oooo0P0000001@3oool000000?ooo`3oool000000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000060?ooo`040000003oool0
oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool0
00003@3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`800000GP3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000020?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo
0000000000000P0000001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?oo
o`0R0?ooo`00GP3oool00`000000oooo0?ooo`190?oooi000000F`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo00000002
0?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo0000000000000P000000
1@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool0
0`000000oooo0?ooo`1;0?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<0
00000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000003@3oool2
000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0000005X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo
00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?oo
o`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3o
ool08P3oool005h0oooo00<000000?ooo`3oool0C03oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000<0oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`3o
ool300000080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000d0
oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1K
000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002
000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo0012
0?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`050?oOW018
000000000000001d_ol02@3oool00`000000oooo0?ooo`1<0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000060?ooo`040000003oool0
oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool0
00003@3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`040000003oool0
oooo0?oooeX000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?ooo`00
000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool0
8P3oool00440oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d
_ol00P3oool01`3ogi`0B00004RLg`3oool0oono07@0001d_ol0203oool00`000000oooo0?ooo`1<
0?ooonT000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?ooo`000000
00000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3o
ool00440oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB000
07Bo00<0oooo00<0okmd0018W03Oool01`3oool00`000000oooo0?ooo`1>0?ooo`8000000P3oool0
10000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool0
oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=
0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0
oooo0000003oool400000500oooo100000050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000P3oool00`000000oooo000000020?ooo`030000003oool000000080oooo100000040?oo
o`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<000006P3oool0
0`000000oooo0?ooo`0R0?ooo`00@03oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo
00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`030000003oool0oooo
04h0oooo0P0000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000001P3o
ool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool01@3oool01P000000oooo
0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203o
ool01P000000oooo0?ooo`3oool000000?ooo`8000000P3oool00`000000oooo0?ooo`1=0?ooo`@0
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`00
00000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?ooo`00000000000080
000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool00400
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01`3oool00`000000oooo0?ooo`1?0?ooo`040000003oool0oooo0000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool00000
0?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H00000
0?ooo`3oool0oooo0000003oool2000000<0ooooC`000000103oool000000000000000050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`03
0000003oool000000080oooo100000040?ooo`<0000000<0oooo0000000000000P0000001@3oool0
0000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00@03oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool00`2oM000
001809cOo`070?ooo`@00000CP3ooooR000000040?ooo`0000000000000000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?oo
o`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002000000050?ooo`0000000000
0000003oool00`00000H0?ooo`<00000903oool00400oooo00<0omnL04P0001d_ol00`3oool00`3o
_g@0001809cOo`050?ooo`080?oo_`1d0000000004RLg`3oool0okmd00000000M;l80?ooo`030000
003oool0oooo0540oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?oo
o`060000003oool0oooo0000003oool000003@3oool2000000<0oooo00@000000?ooo`000000oooo
0`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`080?ooo`060000003oool0oooo0?ooo`000000oooo0P0000040?ooo`80000000<0oooo
0000003oool0A`3oool2000000040?ooo`0000000000000000D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3o
ool4000000@0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool0
0`00000J0?ooo`030000003oool0oooo0280oooo00100?ooo`030?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol01P3oool00`2oM00004RL0;nLB002000000030018W03Oool0oooo00L0oooo00<0
00000?ooo`3oool0D@3oool200000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0
oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003o
ool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00P0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo0P0000020?oo
o`800000A@3oool010000000oooo0000003oool3000000D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool4
000000@0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00
000J0?ooo`030000003oool0oooo0280oooo00100?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia8
0000M02oool01P3oool00`3ogi`0B00007Boo`0<0?ooo`030000003oool0oooo0580oooo00@00000
0?ooo`3oool000000`3oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo0?ooo`<0
00000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000003@3oool2
000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0?ooo`00
0000oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`110?ooo`050000003oool0oooo
0000003oool00`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000020?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo
0000000000000P0000001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?oo
o`0R0?ooo`00@@3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia8
0000B02Lgol02`3oool00`000000oooo0?ooo`1B0?ooom`000000P3oool00`000000oooo00000002
000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002
000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo0011
0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`090?ooo`030?noM000000007Bo00X0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000H0
oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?oo
o`3oool000000?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0
oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo0P0000060?oood<000000P3oool0
0`000000oooo00000002000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000002
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`000000
0`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003o
ool0oooo0280oooo00120?ooo`050?oo_`1d000000000000M02oool02`3oool01@3ooml0W4P00000
000007@0_ooo00L0oooo00<000000?ooo`3oool0E03oool2000000<0oooo00@000000?ooo`3oool0
00001P3oool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool01@3oool01P00
0000oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003oool000000?ooo`<00000
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0203oool01P000000oooo0?ooo`3oool000000?ooo`800000103oool2000000H0oooo0P000000
0`3oool000000000000n00000080oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo100000040?ooo`<0000000<0oooo0000000000000P0000001@3oool0000000000000
0000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`1E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003o
ool000003@3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`060000003o
ool0oooo0?ooo`000000oooo0P0000040?ooo`8000001P3oool2000000040?ooo`00000000000000
03T0oooo100000020?ooo`030000003oool00000008000001@3oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?oo
o`@00000103oool3000000030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03
000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0E@3ooonN0000
03L0oooo100000020?ooo`030000003oool00000008000001@3oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?oo
o`@00000103oool3000000030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03
000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0EP3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`00
00020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`80
00000`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0oooo0000
003oool2000000@0oooo0P0000060?ooo`80000000L0oooo0000003oool0oooo0000003oool00000
03D0oooo00<000000?ooo`0000000P0000020?ooo`030000003oool00000008000001@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000020?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo0000
0000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?oo
o`00000=0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H000000?oo
o`3oool0oooo0000003oool2000000@0oooo0P0000060?ooo`80000000D0oooo0000003oool0oooo
000000020?ooo`800000<P3oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`000000
0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000020?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo000000000000
0P0000001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00
GP3oool3000005P0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=
0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0
oooo0000003oool2000000@0oooo0P0000060?ooo`80000000D0oooo0000003oool0oooo00000004
0?ooo`800000;`3oool010000000oooo0?ooo`3oool300000080oooo00<000000?ooo`0000000P00
00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00020?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo0000000000000P00
00001@3oool00000000000000000oooo00<000006@3oool2000002@0oooo001N0?ooo`030000003o
ool0oooo05P0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo
0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=0?oo
o`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0oooo
0000003oool2000000@0oooo0P0000060?ooo`80000000D0oooo0000003oool0oooo000000060?oo
o`030000003oool0oooo02`0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0
0000008000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?ooo`000000
00000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3o
ool005h0oooo00<000000?ooo`3oool0F@3oool010000000oooo0?ooo`0000060?ooo`040000003o
ool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003o
ool000003@3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`060000003o
ool0oooo0?ooo`000000oooo0P0000040?ooo`8000001P3oool2000000050?ooo`000000oooo0?oo
o`0000001`3oool2000002/0oooo00<000000?ooo`3oool00P3oool300000080oooo00<000000?oo
o`0000000P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000020?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo0000
000000000P0000001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R
0?ooo`00GP3oool00`000000oooo0?ooo`1I0?oooj@00000:03oool00`000000oooo0?ooo`030?oo
o`<000000P3oool00`000000oooo00000002000000D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool40000
00@0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J
0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo05/0oooo0P0000060?oo
o`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0
oooo0000003oool000003@3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?oo
o`060000003oool0oooo0?ooo`000000oooo0P0000040?ooo`8000001P3oool2000000050?ooo`00
0000oooo0?ooo`000000203oool00`000000oooo0000000Y000000D0oooo0`0000020?ooo`030000
003oool00000008000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo
00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?oo
o`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3o
ool08P3oool005h0oooo00<000000?ooo`3oool0F`3oool2000000H0oooo00@000000?ooo`3oool0
oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=
0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0
oooo0000003oool2000000@0oooo0P0000060?ooo`80000000D0oooo0000003oool0oooo00000008
0?ooo`040000003oool000000?ooo`800000903oool2000000D0oooo0`0000020?ooo`030000003o
ool00000008000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?ooo`00
000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool0
8P3oool005h0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003o
ool000003@3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`060000003o
ool0oooo0?ooo`000000oooo0P0000040?ooo`8000001P3oool2000000050?ooo`000000oooo0?oo
o`000000203oool00`000000oooo000000030?ooo`030000003oool0oooo0200oooo00<000000?oo
o`0000001@3oool300000080oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool00000
0080oooo100000040?ooo`<0000000<0oooo0000000000000P0000001@3oool00000000000000000
oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`1L0?oo
ojL000007`3oool010000000oooo0?ooo`0000050?ooo`<000000P3oool00`000000oooo00000002
000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002
000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo001N
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3o
ool300000080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000d0
oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`3o
ool000000?ooo`800000103oool2000000H0oooo0P0000001@3oool000000?ooo`3oool0000000P0
oooo00<000000?ooo`000000103oool00`000000oooo0000000M0?ooo`050000003oool0oooo0?oo
o`0000001@3oool300000080oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool00000
0080oooo100000040?ooo`<0000000<0oooo0000000000000P0000001@3oool00000000000000000
oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0
oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`8000000`3oool010000000oooo
0000003oool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00P0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo0P00
00060?ooo`80000000D0oooo0000003oool0oooo000000080?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool07P0000030?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`030000
003oool00000008000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo
00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?oo
o`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3o
ool08P3oool005h0oooo00<000000?ooo`3oool0G`3oool01@000000oooo0?ooo`3oool0000000<0
oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=
0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0
oooo0000003oool2000000@0oooo0P0000060?ooo`80000000D0oooo0000003oool0oooo00000008
0?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool0oooo0P00000I0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool300000080oooo00<000000?ooo`0000000P00
00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00020?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo0000000000000P00
00001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3o
ool00`000000oooo0?ooo`1P0?ooo`040000003oool0oooo000000<0oooo0`0000020?ooo`030000
003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`8000000`3oool01000
0000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0
oooo0P0000060?ooo`80000000D0oooo0000003oool0oooo000000080?ooo`030000003oool00000
00@0oooo00H000000?ooo`3oool0oooo0000003oool2000001H0oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo0`0000020?ooo`030000003oool00000008000001@3oool00`000000oooo0?oo
o`030?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00020?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo0000000000000000
0?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo0`00001Q0?ooo`030000003o
ool0000000<0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool00000
0?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H00000
0?ooo`3oool0oooo0000003oool2000000@0oooo0P0000060?ooo`80000000D0oooo0000003oool0
oooo000000080?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?oo
oaH0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`<000000P3oool00`00
0000oooo00000002000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?oo
o`030000003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3o
ool0000000000002000000050?ooo`00000000000000003oool00`00000I0?ooo`800000903oool0
05h0oooo00<000000?ooo`3oool0H@3oool00`000000oooo000000030?ooo`<000000P3oool00`00
0000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000003@3oool2000000<0oooo00@0
00000?ooo`000000oooo0`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0?ooo`000000oooo0P000004
0?ooo`8000001P3oool2000000050?ooo`000000oooo0?ooo`000000203oool00`000000oooo0000
00040?ooo`050000003oool0oooo0?ooo`000000103oool200000180oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`<000000P3oool00`000000oooo00000002000000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool000000080oooo
00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002000000050?oo
o`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000
003oool0oooo0680oooo0P0000030?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`060000
003oool0oooo0000003oool000003@3oool2000000<0oooo00@000000?ooo`000000oooo0`000007
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`080?ooo`060000003oool0oooo0?ooo`000000oooo0P0000040?ooo`8000001P3oool200000005
0?ooo`000000oooo0?ooo`000000203oool00`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0000000@0?ooo`80000000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`030?ooo`<000000P3oool00`000000oooo00000002000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool000000080oooo00<00000
0?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002000000050?ooo`000000
00000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0
oooo06<0oooo[@00000<0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`<000000P3oool00`000000oooo00000002000000D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3o
ool4000000@0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool0
0`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool00`0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool00000
0?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H00000
0?ooo`3oool0oooo0000003oool2000000@0oooo0P0000060?ooo`80000000D0oooo0000003oool0
oooo000000080?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0080oooo0P00000:0?ooo`060000003oool0oooo0000003oool00000103o
ool00`000000oooo0?ooo`030?ooo`<000000P3oool00`000000oooo00000002000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002000000050?ooo`00
000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`0000000P0000020?ooo`030000003oool0oooo00D0oooo00H0
00000?ooo`3oool000000?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003oool30000
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00P0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo0P0000060?ooo`800000
00D0oooo0000003oool0oooo000000080?ooo`030000003oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000002@0000030?oo
o`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool300000080oooo00<000000?oo
o`0000000P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000020?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo0000
000000000P0000001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R
0?ooo`00GP3oool00`000000oooo0?ooo`1V0?ooo`@000000P3oool00`000000oooo0?ooo`050?oo
o`060000003oool0oooo0000003oool000003@3oool2000000<0oooo00@000000?ooo`000000oooo
0`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`080?ooo`060000003oool0oooo0?ooo`000000oooo0P0000040?ooo`8000001P3oool2
000000050?ooo`000000oooo0?ooo`000000203oool00`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T00000
0`3oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`030000
003oool00000008000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo
00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?oo
o`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3o
ool08P3oool005h0oooo00<000000?ooo`3oool0I`3ooond000000<0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`<000000P3oool00`000000oooo00000002000000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool000000080oooo
00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002000000050?oo
o`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000
003oool0oooo06P0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool0
00000?ooo`00000=0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H0
00000?ooo`3oool0oooo0000003oool2000000@0oooo0P0000060?ooo`80000000D0oooo0000003o
ool0oooo000000080?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000000`3oool0000000000004
000000<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`<000000P3oool0
0`000000oooo00000002000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000002
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`000000
0`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003o
ool0oooo0280oooo001N0?ooo`030000003oool0oooo06P0oooo/`0000030?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool00`3oool300000080oooo00<000000?ooo`0000000P000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo00000002
0?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo0000000000000P000000
1@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool0
0`000000oooo0?ooo`1Y0?oook<000000P3oool00`000000oooo000000040?ooo`030000003oool0
oooo00<0oooo0`0000020?ooo`030000003oool00000008000001@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo00000002
0?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo00000000000000000?oo
o`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo0`00001[0?ooo`8000001`3oool0
1P000000oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003oool000000?ooo`<0
00001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0203oool01P000000oooo0?ooo`3oool000000?ooo`800000103oool2000000H0oooo0P00
00001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03000000L0
oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo0`0000020?oo
o`030000003oool00000008000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
0080oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool30000
00030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03000001T0oooo0P00000T
0?ooo`00GP3oool00`000000oooo0?ooo`1[0?ooo`8000001`3oool01P000000oooo0?ooo`000000
oooo000000d0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01P000000
oooo0?ooo`3oool000000?ooo`800000103oool2000000H0oooo0P0000001@3oool000000?ooo`3o
ool0000000P0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool00`3oool300000080oooo00<000000?ooo`0000000P0000050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000
003oool000000080oooo100000040?ooo`<0000000<0oooo0000000000000P0000001@3oool00000
000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo
0?ooo`1/0?oookD00000103oool00`000000oooo0?ooo`030?ooo`<000000P3oool00`000000oooo
00000002000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000
003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool00000
00000002000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280
oooo001N0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0103oool01P000000oooo
0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203o
ool01P000000oooo0?ooo`3oool000000?ooo`800000103oool2000000H0oooo0P0000001@3oool0
00000?ooo`3oool0000000P0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@000000<0oooo00<00000
0?ooo`3oool00`3oool300000080oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo100000040?ooo`<0000000<0oooo0000000000000P0000001@3oool0000000000000
0000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`800000
0`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0oooo0000003o
ool2000000@0oooo0P0000060?ooo`80000000D0oooo0000003oool0oooo000000080?ooo`030000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000403oool010000000oooo0?ooo`0000050?ooo`<000000P3oool00`00
0000oooo00000002000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?oo
o`030000003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3o
ool0000000000002000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0
oooo0280oooo001N0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool00P3oool01P00
0000oooo0?ooo`000000oooo000000d0oooo0P0000030?ooo`040000003oool000000?ooo`<00000
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0203oool01P000000oooo0?ooo`3oool000000?ooo`800000103oool2000000H0oooo0P000000
1@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool00P3oool200000180oooo0`0000050?ooo`<00000
0P3oool00`000000oooo00000002000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo
0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J0?ooo`03
0000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo0700oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0000000d0oooo0P0000030?ooo`040000003oool000000?oo
o`<000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0203oool01P000000oooo0?ooo`3oool000000?ooo`800000103oool2000000H0oooo
0P0000001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3ooolG000000D0oooo0`0000020?oo
o`030000003oool00000008000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
0080oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool30000
00030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<00000
0?ooo`3oool08P3oool00480oooo00D0omnL04P000000000001d0;ooo`030?ooo`030?noM0000000
M;oo00<0oooo00D0gia8000000000000000004RLg`090?ooo`030000003oool0oooo0740oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0000000=0?ooo`8000000`3oool010000000oooo
0000003oool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00P0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo0P00
00060?ooo`80000000D0oooo0000003oool0oooo000000080?ooo`030000003oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000005`3oool20000
00<0oooo0`0000020?ooo`030000003oool00000008000001@3oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?oo
o`@00000103oool3000000030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03
000001X0oooo00<000000?ooo`3oool08P3oool00440oooo00L0oono07@0001d_ol0oooo0?noM000
07@0_ooo0080oooo00<0okmd0000001d_ol00P3oool01`3OW4P0000007Boo`3oool0oooO09a80018
W=l0203oool00`000000oooo0?ooo`1b0?ooo`030000003oool000000080oooo00<000000?ooo`00
00003@3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`060000003oool0
oooo0?ooo`000000oooo0P0000040?ooo`8000001P3oool2000000050?ooo`000000oooo0?ooo`00
0000203oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01000
0000oooo0?ooo`00000J0?ooo`030000003oool0oooo00<000000P3oool00`000000oooo00000002
000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002
000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo0011
0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3ooml0W4P0001d_`03
0?ooo`030?noM000B9`0gooo00L0oooo00<000000?ooo`3oool0L`3oool200000080oooo00<00000
0?ooo`0000003@3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`060000
003oool0oooo0?ooo`000000oooo0P0000040?ooo`8000001P3oool2000000050?ooo`000000oooo
0?ooo`000000203oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0000000L0?ooo`D000000P3oool00`000000oooo00000002000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002000000050?ooo`00
000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo00100?ooo`030?oo_`1d
0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM00007Bo0?ooo`020?ooo`030;md0000
B9`0gooo00L0oooo00<000000?ooo`3oool0M03ooonj00000080oooo00<000000?ooo`0000000P00
00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00020?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo0000000000000P00
00001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00@03o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0omnL04P0M02oool0oooo
0;md00000000M;oo00P0oooo00<000000?ooo`3oool0M@3oool01@000000oooo0000003oool00000
00d0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01P000000oooo0?oo
o`3oool000000?ooo`800000103oool2000000H0oooo0P0000001@3oool000000?ooo`3oool00000
00P0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo90000002
0?ooo`030000003oool00000008000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`@00000103oool3
000000030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<0
00000?ooo`3oool08P3oool00400oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`07
0?ooo`050?oo_`1dB4P0B00000000018W=l02@3oool4000007D0oooo0P0000000`3oool000000?oo
o`0<0?ooo`8000000`3oool010000000oooo0000003oool3000000L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3o
ool0oooo0000003oool2000000@0oooo0P0000060?ooo`80000000D0oooo0000003oool0oooo0000
00080?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`800000
903oool010000000oooo0000003oool3000000D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0
oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000H0?oo
o`<00000903oool00400oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`04
0?oOW01800000000001d_`X0oooo00<000000?ooo`3oool0M`3ooonj000000040?ooo`0000000000
000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0000000000002
000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo0010
0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01P3ogi`0B0000000M02o
ool0okmd001d_`T0oooo00<000000?ooo`3oool0N@3ooonl000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`000000
0P3oool4000000@0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003o
ool00`00000J0?ooo`030000003oool0oooo0280oooo00100?ooo`030?oo_`1d0000B9cO00<0oooo
00<0gia80000M02oool01P3oool00`2oM000001d0;ooo`020?ooo`030;md0018W=l0oooo00L0oooo
00<000000?ooo`3oool0N@3ooonl000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo
0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J0?ooo`03
0000003oool0oooo0280oooo00110?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool0
1P3oool00`2oM00004RL0=ooo`020?ooo`030=nLB000M;l0oooo00L0oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`090?ooo`8000000`3oool010000000oooo0000003oool3000000L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00P0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo0P0000060?ooo`80000000D0
oooo0000003oool0oooo000000080?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool0
0000;`3oool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000P3oool4000000@0oooo0`0000000`3oool0
000000000002000000050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo
0280oooo00110?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`070?ooo`070?noM0000000
M;oo0?ooo`3ookl0M00007Boo`080?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
203oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo
0?ooo`000000oooo0P0000040?ooo`8000001P3oool2000000050?ooo`000000oooo0?ooo`000000
203oool00`000000oooo000000040?ooo`030000003oool000000380oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000
oooo000000020?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo00000000
000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool00480oooo00D0oono07@00000
0000001d0;ooo`090?ooo`050?noM0000000000000000018W=l02@3oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
203oool01P000000oooo0?ooo`3oool000000?ooo`800000103oool2000000H0oooo0P0000001@3o
ool000000?ooo`3oool0000000P0oooo00<000000?ooo`000000103oool2000003@0oooo0P000000
0`3oool000000?ooo`040?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool0
0`000000oooo000000020?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo
00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<00000
0?ooo`3oool0OP3oool2000000L0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
203oool01P000000oooo0?ooo`3oool000000?ooo`800000103oool2000000H0oooo0P0000001@3o
ool000000?ooo`3oool0000000P0oooo00<000000?ooo`0000000`3ooolk000000D0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool000000080oooo10000004
0?ooo`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<000006P3o
ool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`200?ooo`030000003oool0
oooo00@0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool01P000000oooo
0?ooo`3oool000000?ooo`800000103oool2000000H0oooo0P0000001@3oool000000?ooo`3oool0
000000P0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo100000040?ooo`<0000000<0oooo0000000000000P0000001@3oool0000000000000
0000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`040000003oool000000?ooo`<000001`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
203oool01P000000oooo0?ooo`3oool000000?ooo`800000103oool2000000H0oooo0P0000001@3o
ool000000?ooo`3oool0000000P0oooo00D000000?ooo`000000oooo0000000m0?ooo`8000000P3o
ool00`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3o
ool4000000@0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool0
0`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`06
0000003oool0oooo0?ooo`000000oooo0P0000040?ooo`8000001P3oool2000000050?ooo`000000
oooo0?ooo`000000203oool00`000000oooo00000014000000070?ooo`000000oooo0?ooo`000000
oooo000000020?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo00000000
00000P0000001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?oo
o`00GP3oool3000008<0oooo0P0000020?ooo`8000000`3oool010000000oooo0000003oool30000
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00P0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo0P0000060?ooo`800000
00D0oooo0000003oool0oooo000000080?ooo`<00000@`3oool300000080oooo00<000000?ooo`00
00000P3oool00`000000oooo000000020?ooo`@00000103oool3000000030?ooo`00000000000080
000000D0oooo00000000000000000?ooo`03000001T0oooo0P00000T0?ooo`00GP3oool00`000000
oooo0?ooo`250?ooo`040000003oool00000000000<0oooo00@000000?ooo`000000oooo0`000007
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`080?ooo`060000003oool0oooo0?ooo`000000oooo0P0000040?ooo`8000001P3oool200000005
0?ooo`000000oooo0?ooo`000000203ooom900000080oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000020?ooo`@00000103oool3000000030?ooo`00000000000080000000D0oooo0000
0000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?oo
o`3oool0QP3oool3000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`060000003o
ool0oooo0?ooo`000000oooo0P0000040?ooo`8000001P3oool2000000050?ooo`000000oooo0?oo
o`0000001P3oool2000004T0oooo0`0000001`3oool000000?ooo`3oool000000?ooo`0000000P3o
ool4000000@0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool0
0`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo08L0oooo`@00
00020?ooo`030000003oool000000080oooo100000040?ooo`<0000000<0oooo0000000000000P00
00001@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3o
ool00`000000oooo0?ooo`280?oool40000000@0oooo0000003oool000000P3oool4000000@0oooo
0`0000000`3oool0000000000002000000050?ooo`00000000000000003oool00`00000J0?ooo`03
0000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo08X0oooo00H000000?ooo`000000
oooo0000003oool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo
0P0000060?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`030000003oool0oooo0580
oooo0P000000103oool000000?ooo`3oool4000000@0oooo0`0000000`3oool00000000000020000
00050?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo001N0?oo
o`030000003oool0oooo08/0oooo`P0000020?ooo`@00000103oool3000000030?ooo`0000000000
0080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool0
05h0oooo00<000000?ooo`3oool0S@3oooo1000000030?ooo`000000000000800000103oool30000
00030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<00000
0?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo000000020000
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00P0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo0P0000060?ooo`800000
00@0oooo0000000000000000G@3oool5000000@0oooo0`0000000`3oool000000000000200000005
0?ooo`00000000000000003oool00`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`03
0000003oool0oooo08l0ooooa00000040?ooo`<0000000<0oooo0000000000000P0000001@3oool0
0000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000
oooo0?ooo`2A0?oool800000103oool3000000030?ooo`00000000000080000000D0oooo00000000
000000000?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3o
ool0TP3oool2000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00P0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo0P00
00050?ooofX000000`3oool3000000030?ooo`00000000000080000000D0oooo0000000000000000
0?ooo`03000001X0oooo00<000000?ooo`3oool08P3oool005h0oooo0`00002D0?ooo`800000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
203oool01P000000oooo0?ooo`3oool000000?ooo`800000103oool2000000<0oooo0P00001Z0?oo
o`030000003oool0oooo00<0000000<0oooo0000000000000P0000001@3oool00000000000000000
oooo00<000006@3oool2000002@0oooo001N0?ooo`030000003oool0oooo09H0oooo0P0000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`08
0?ooo`060000003oool0oooo0?ooo`000000oooo0P0000040?ooo`80000000<0oooo000000000000
K@3oool5000000030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03000001X0
oooo00<000000?ooo`3oool08P3oool005h0oooo00<000000?ooo`3oool0V03oooo2000000030?oo
o`00000000000080000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?ooo`3o
ool08P3oool005h0oooo00<000000?ooo`3oool0V`3oool2000000<0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0?ooo`000000oooo0P000003
0?ooogP0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<000006P3o
ool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`2M0?ooo`@000002@3oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0?ooo`000000oooo0P0000000`3oool0
00000000001h0?ooo`D0000000D0oooo00000000000000000?ooo`03000001X0oooo00<000000?oo
o`3oool08P3oool005h0oooo00<000000?ooo`3oool0X03ooono000000050?ooo`00000000000000
003oool00`00000J0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0oooo0:<0
oooo0P0000050?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0ooooQ0000000
1@3oool00000000000000000oooo00<000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool0
0`000000oooo0?ooo`2U0?ooo`<000000P3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?oooh`0000000@0
oooo00000000000000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?oo
o`2X0?oook/0000000@0oooo00000000000000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3o
ool00`000000oooo0?ooo`2[0?oook`000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool0
0`000000oooo0?ooo`2_0?oookP000006P3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool30000
0;P0oooo/000000H0?ooo`800000903oool005h0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`80
00005`3oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooof/0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0R0?ooo`00GP3oool00`000000oooo0?oo
o`3o0?ooof`0oooo0P00000D0?ooo`030000003oool0oooo0280oooo001N0?ooo`030000003oool0
oooo0?l0ooooKP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0280oooo001N0?oo
o`030000003oool0oooo0?l0ooooK`3oool200000140oooo00<000000?ooo`3oool08P3oool00500
oooo00H0_g@000000000000000000018W03Oool80?ooo`030000003oool0oooo0?l0ooooL@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0280oooo001A0?ooo`030?oOW0180000M;oo
00X0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`8000003P3oool00`000000oooo0?ooo`0R0?oo
o`00D@3oool00`3ogi`0B00007Boo`0:0?ooo`030000003oool0oooo0?l0ooooM03oool2000000`0
oooo00<000000?ooo`3oool08P3oool00540oooo00<0omnL04P0001d_ol02P3oool00`000000oooo
0?ooo`3o0?ooogH0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?ooo`00D@3o
ool00`3ogi`0B00007Boo`0:0?ooo`030000003oool0oooo0?l0ooooM`3oool2000000T0oooo00<0
00000?ooo`3oool08P3oool00540oooo00<0omnL04P0001d_ol02P3oool400000?l0ooooN03oool0
0`000000oooo0?ooo`040?ooo`<00000903oool00540oooo00<0omnL04P0001d_ol02P3oool00`00
0000oooo0?ooo`3o0?oooh80oooo00<000000?ooo`3oool08P3oool00540oooo00<0omnL04P0001d
_ol02P3oool00`000000oooo0?ooo`3o0?oooh80oooo00<000000?ooo`3oool08P3oool00540oooo
00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?oooh80oooo00<000000?ooo`3oool0
8P3oool00540oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0280oooo001?0?ooo`050?oog`2LB00000000000001d_ol02P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0280oooo001A0?ooo`030?noM0000000M;oo00X0ooooo`000026
000002@0oooo003o0?ooool0oooo2@3oool00?l0ooooo`3oool90?ooo`00o`3ooooo0?ooo`T0oooo
003o0?ooool0oooo2@3oool00?l0ooooo`3oool90?ooo`00o`3ooooo0?ooo`T0oooo003o0?ooool0
oooo2@3oool00?l0ooooDP3oool00`3ooml0W4Q809cOo`0V0?ooo`030?oOW018B9`0gooo08X0oooo
003o0?oooe80oooo00<0_gA809cOo`3oool09`3oool00`3ogi`0B7Bo0?ooo`290?ooo`00o`3ooomA
0?ooo`030=nLB018W=l0oooo02T0oooo00<0gia804RLg`3oool0R03oool00?l0ooooD03oool00`3o
okl0M01d0;ooo`0Z0?ooo`030?oo_`1d04P0W=oo08P0oooo002f0?ooo`030?oOW018000000000080
000000<0001d0;ooo`3oool00`3oool01@3OW4P00000000000000000M;oo00<0oooo00H0oooO09a8
0000000000000000B02Lgol50?ooo`030?oOW01dW=l0oooo0080oooo00<0giad09cOo`3oool0103o
ool01@2oM00000000000000007@0_ooo0080oooo00H0oooO09a80000000000000000B02Lgol60?oo
o`030;md0000000000000080000000<007Bo0?ooo`3oool00`3oool01`3OW4P000000000000007@0
_ooo0?ooo`3OW4P00`000000201d_ol0oooo0?ooo`3oool0omnL04P000000000B9cO1@3oool00`3o
gi`0B000000000020000000407Boo`3oool0oooo0=nLB0<0000000@0M;oo0?ooo`3oool0_g@00P00
00001P0004P0W=oo0?oog`2LB000001d0;ooo`H0oooo00<0oono07@0000000000P0000000`1d_ol0
oooo0?ooo`020?ooo`030?noM0000000M;oo00<0oooo00D0gia8000000000000000004RLg`070?oo
o`030=nLB000B9`0gooo00@0oooo00H0_g@000000000000000000018W03OoolE0?ooo`050;md0000
000007Bo0?ooo`3OW4P00P0000001`00B9`0gooo0?ooo`3oool0oooO09a80018W=l01P3oool01@2o
M0000000001d_`3oool0gia80080000000<004RL0=ooo`3oool0N03oool00;D0oooo00@0gia80000
0000B9`0gooo0P3oool00`3ookl0M01809cOo`020?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P0
04RLg`020?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B00007Boo`040?ooo`070;md000007@0_ooo
0?ooo`3ookl0M000001d_`040?ooo`0?0;md0000000007Bo0?ooo`3ogi`0B01d0;ooo`3oool0_g@0
0018W03Oool0oooo0?oOW0180000M;oo00H0oooo00@0oooO09a80000B9`0gooo1`3oool02`3OW4P0
001d0;ooo`3oool0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00D0gia80000M02oool0
gkno0=ooo`050?ooo`030?oog`2LB00007Bo00<0oooo00L0gia800000018W=l0oooo0?oog`2LB000
B9cO0080oooo00P0gia80000M02oool0oooo0?oog`2LB000001d0;ooo`H0oooo00<0omnL04P00018
W=l00P3oool00`2oM000B9cO0?ooo`020?ooo`030?noM0000000M;oo0080oooo00L0gia80000001d
_ol0oooo0?oog`2LB000B9cO00H0oooo00<0_g@0001d_`3oool01@3oool00`3ogi`0B00007Boo`0G
0?ooo`080?oog`2LB7@0_ooo0?ooo`3ooml0W4P00018W03Oool40?ooo`030=nLB000B9`0gooo00D0
oooo00P0oooO09a8M02oool0oooo0?oog`2LB00004RL0=ooogX0oooo002d0?ooo`030?noM0000000
07Bo00D0oooo00H0oooO09a8M02oool0omnL04P00000M;l30?ooo`070?noM00007@0_ooo0?ooo`2o
M00004RL0=ooo`020?ooo`030?noM00007@0_ooo0080oooo00T0omnL04P00018M7@0M9cO0?ooo`3o
_g@0001804Q8B02Lgol00P3oool00`3ogi`0B00004RLg`030?ooo`060?oOW01dW=l0oooo0;md0000
B9`0gooo0P3oool00`3o_g@0001d0;ooo`050?ooo`030?oog`2LB00007Bo00P0oooo00H0gia80000
M02oool0omnL04P00000M;l30?ooo`070?noM00007@0_ooo0?ooo`3OW4P004RL0=ooo`070?ooo`03
0?oog`2LB00007Bo0080oooo00<0omnL04P00000M;l00`3oool01`3o_g@0001d0;ooo`3oool0gia8
0000M02oool0403oool00`3ookl0M01809cOo`060?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd
0018W03Oool0103oool00`3ookl0M00004RLg`060?ooo`030?oOW0180000M;oo01P0oooo00H0oono
07A8W03Oool0_g@00000M02oool50?ooo`030=nLB00007@0_ooo00H0oooo00H0oono07A8W03Oool0
_g@00000M02ooomk0?ooo`00/`3oool0103ooml0W4P00000M02oool80?ooo`030?noM0000000M;oo
00<0oooo00L0okmd0000001d_ol0oooo0;md0000B9`0gooo0080oooo00<0omnL04P0001d_ol00P3o
ool02@3OW4P0001d0;ooo`2oM7@0_ooO09a80000M;l0omnL07BLg`020?ooo`030?noM00004P0W=oo
00H0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00007Boo`050?ooo`030?oog`2LB00007Bo
00P0oooo00H0gia80000M02oool0okmd0000001d_ol30?ooo`070?noM0000000M;oo0?ooo`3OW4P0
04RL0=ooo`070?ooo`030?oog`2LB00007Bo0080oooo00<0okmd0000001d_ol00`3oool01`3o_g@0
000007Boo`3oool0gia80000M02oool0403oool00`3ookl0M00007Boo`070?ooo`030;md0000M;l0
oooo0080oooo00<0_g@00018W03Oool0103oool00`3ookl0M00007Boo`060?ooo`030?oOW0180000
M;oo01T0oooo00@0omnL07A8B0000000M;oo1P3oool00`3o_g@0001d0;ooo`070?ooo`040?oOW01d
B4P0000007Boog`0oooo002c0?ooo`040?oOW018000004RL0=ooo`P0oooo00<0okmd0000001d_ol0
0`3oool01`3o_g@0000007Boo`3oool0_g@00018W03Oool00P3oool04`3ogi`0B00007Boo`3oool0
oono07@00018W=l0oooo0?oOW01dM7@0B01809cOo`3oool0_gAd0;ooo`3oool0okmd0000M02oool0
1P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000M;oo00D0oooo00<0oooO09a80000M;l0
203oool01P3OW4P0001d0;ooo`3o_g@0000007Boo`<0oooo00L0okmd0000001d_ol0oooo0=nLB000
B9`0gooo00L0oooo00<0oooO09a80000M;l00P3oool00`3o_g@0000007Boo`030?ooo`070?noM000
0000M;oo0?ooo`3OW4P0001d0;ooo`0@0?ooo`030?noM0000000M;oo00L0oooo00L0omnL04P0M02o
ool0oooo0;md00000000M;oo00D0oooo00<0oono07@0001d_ol01P3oool00`3ogi`0B00007Boo`07
0?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool01@3oool00`3ookl0M00004RLg`07
0?ooo`030?noM00004P0W=oo00L0oooo00<0oono07@00018W=l0O@3oool00;<0oooo00<0okmd0000
0000M;l02@3oool00`3ookl0M00007Boo`030?ooo`070;md000004P0W=oo0?ooo`2oM00004RL0=oo
o`020?ooo`0;0?noM00004P0W=oo0?ooo`3OW4P0001809cOo`3oool0oooO09a80000M;l00P3oool0
1@3o_g@0B9cO0?ooo`3ogi`0B00000D0000000D0B9cO0?ooo`2oM00004RL0=ooo`020?ooo`030?no
M00004P0W=oo00D0oooo00<0oooO09a800000000100000002P1d_ol0oooo0?ooo`3oool0gia80000
M02oool0oono07@0001d_ol30?ooo`070;md000004P0W=oo0?ooo`3OW4P004RL0=ooo`070?ooo`03
0?oog`2LB00007Bo0080oooo00<0oono07@0001d_ol00`3oool01`2oM000001809cOo`3oool0gia8
0000B02Lgol03`3oool0103ogi`0B0000000B02Lgol80?ooo`050?oo_`1dB4P0B00000000018W=l0
1P3oool00`3ookl0M00007Boo`060?ooo`030?oOW0180000M;oo01P0oooo00D0oooO09a80000B9`0
W7A809cOo`060?ooo`030?noM00007@0_ooo00H0oooo00D0oooO09a80000B9`0W7A809cOo`1l0?oo
o`00/`3oool00`3o_g@00000001d_`0:0?ooo`070=nLB000B9`0gooo0?ooo`3o_g@00000001d_`02
0?ooo`0;0;md0000000004RL0=ooo`3ookl0M0000018W03Oool0oono07@00000M;l00P3oool00`3o
gi`0B00007Boo`020?ooo`060?oog`2LB7@0_ooo0?ooo`2oM000B9cO0P3oool0303OW4P0001809cO
o`3oool0_g@000000000B9`0gooo0?oo_`1d000004RL0=ooo`D0oooo00<0oooO09a80000M;l00P3o
ool0103ooml0W4P000000018W=l20?ooo`0;0=nLB00007@0_ooo0?ooo`3OW4P004RL0=ooo`3oool0
okmd00000000M;l00P3oool00`3OW4P004RL0=ooo`070?ooo`030?oog`2LB00007Bo00<0oooo0140
gia80018W03Oool0oooo0?noM000000007Bo0?oog`2LB00000000000B018M9`0gkmd0000IP1dB000
001d0;ooo`080?ooo`050?noM000000000000000B02Lgol02@3oool0103ogi`0B00000000000M;l7
0?ooo`030?oo_`1d0000B9cO00H0oooo00<0omnL04P0001d_ol0603oool01P2oM000001809cOo`3o
oml0W4Qd0;ooo`D0oooo00<0gia80000M02oool01P3oool01P2oM000001809cOo`3ooml0W4Qd0;oo
og/0oooo002c0?ooo`040?oOW018000004RL0=ooo`X0oooo00D0okmd000000000000000004RLg`03
0?ooo`090;md0000B9`0gmnL04P00000000004RL0=ooo`3ooml0W4P00080000000<0B9cO0?noM000
00000P0000002018W=l0oooo0;md0000000004RL0=ooo`3oool0gia80P0000002`0004P0W=oo0?oo
o`3oool0_g@00018W03Ogi`0B00000000000B9`0gooo00H0oooo00<0oooO09a80000M;l00`3oool0
203ookl0M0000000M02oool0oooo0=nLB00007@0_ooo0P3oool01@3o_g@00000000000000000B9cO
0080oooo00H0_g@000000000000000000018W03Oool40?ooo`030?noM000000000000080000000@0
04RL0=ooo`3oool0okmd0`0000003018W=l0oooo0?ooo`3oool0_g@00000M02ogi`0B0000000IP1d
B000001d0;ooo`X0oooo00<0_g@0001d_`3oool0203oool01P3ogi`0B0000000M02oool0okmd001d
_`H0oooo00<0oooO09a80018W=l01P3oool00`3ogi`0B00007Boo`0F0?ooo`090?oog`2LB0000000
00000000M;l0okmd0000000007@0_ooo00@0oooo00<0gia80018W03Oool0103oool02@3ooml0W4P0
00000000000007Bo0?noM0000000001d0;ooo`1j0?ooo`00/`3oool0103ooml0W4P00000B02Lgol5
0?ooo`030?oog`2LM9`0gooo00X0oooo00<0_g@00018W03Oool06`3oool00`2oM00004RL0=ooo`0:
0?ooo`030?oog`2LB00007Bo00<0oooo00P0oooO09a8000004P0W=oo0?ooo`3OW4P0001d0;ooo`X0
oooo00<0_g@00018W03Oool01`3oool00`3ooml0W4P0001d_`0O0?ooo`030;md0018W=l0oooo00L0
oooo00<0_g@00000M02oool00P3oool00`2oM000B9cO0?ooo`050?ooo`030=nLB000B9`0gooo00D0
oooo00<0omnL04P0001d_ol08P3oool00`3ooml0W4P004RLg`280?ooo`00]03oool00`3ogi`0B000
001d_`050?ooo`030?noM000B9`0gooo00X0oooo00<0_g@00018W03Oool06`3oool00`2oM00004RL
0=ooo`0:0?ooo`030?oog`2LB00007Bo00<0oooo00P0omnL04P0000007@0_ooo0?ooo`3OW4P0001d
0;ooo`X0oooo00<0oono07A8W03Oool0203oool00`2oM00007Bo0?ooo`0I0?ooo`030?oog`2LW;l0
oooo0080oooo00<0gia80000M02oool01`3oool00`2oM00004RL0=ooo`020?ooo`030=nLB000M;l0
oooo00D0oooo00<0oono07@0B02Lgol01@3oool00`3ogi`0B00007Boo`0R0?ooo`030?oo_`1d04P0
W=oo08P0oooo002e0?ooo`030?noM000000007Bo00<0oooo00<0gia800000000M;l02`3oool00`2o
M00004RL0=ooo`0K0?ooo`030;md0000B9`0gooo00X0oooo00<0oooO09a80000M;l00P3oool0103o
okl0M00000000018W=l20?ooo`030=nLB00007@0_ooo00X0oooo00<0oooO09adW03Oool0203oool0
0`3OW4P007Bo0?ooo`0J0?ooo`060?noM018W=l0oooo0?oo_`1d000007Bo203oool01`3o_g@00000
07Boo`3oool0oono07@0001d_ol01`3oool00`3OW4P0B9cO0?ooo`020?ooo`050?oog`2LB0000000
0000001d_ol08P3oool00`3OW4P0B9cO0?ooo`280?ooo`00]P3oool00`3ooml0W4P0000000020000
000304RLg`3ookl0M7Bo00T0oooo00D0oono07@00000000004RL0=ooo`0I0?ooo`050?oo_`1d0000
00000018W03Oool02@3oool00`2oM000000000000004000000080000B02Lgol0oooo0?oog`2LB000
00000000M02ooolE0?ooo`070?oo_`1d07@0_ooo0?oog`2LB00004RL0=ooo`0G0?ooo`050=nLB000
000000000000M02oool02@3oool01@3o_g@00000000000000000B9cO00T0oooo00<0_g@004RLg`3o
ool00`3oool00`3o_g@0000007Boo`0Q0?ooo`030?noM000M;l0oooo08T0oooo00380?ooo`040?oo
g`2LB00004RL0=oooaX0oooo00@0oooO09a80000B9`0gooo5@3oool00`2oM000001d0;ooo`0F0?oo
o`050?oo_`1d000000000000B02Lgol0=@3oool00`3OW7@0W=oo0?ooo`0U0?ooo`030?oo_`1dM;l0
oooo08X0oooo003o0?ooool0oooo2@3oool00?l0ooooo`3oool90?ooo`00o`3ooooo0?ooo`T0oooo
003o0?ooool0oooo2@3oool00001\
\>"],
  ImageRangeCache->{{{0, 518.625}, {320.188, 0}} -> {-0.281445, -0.252236, \
0.00405772, 0.00656553}}]
}, Closed]],

Cell[TextData[{
  "In the chaotic regime the cobweb plot appears to visit practically every \
point within a large but finite range eventually.  Nevertheless, for a \
slightly larger value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  " order miraculously re-emerges!  However, the appearance of a 3-cycle is a \
new feature \[LongDash] for smaller ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  " we had observed ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " cycles arising from bifurcations."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(logisticCobweb[3.84, 0.2, 200, 100];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -9.5 -15.6875 ]
[.21429 -0.0125 9.5 0 ]
[.40476 -0.0125 -9.5 -15.6875 ]
[.40476 -0.0125 9.5 0 ]
[.59524 -0.0125 -9.5 -15.6875 ]
[.59524 -0.0125 9.5 0 ]
[.78571 -0.0125 -9.5 -15.6875 ]
[.78571 -0.0125 9.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .01472 -10 -7.84375 ]
[-0.0125 .01472 0 7.84375 ]
[-0.0125 .13244 -19 -7.84375 ]
[-0.0125 .13244 0 7.84375 ]
[-0.0125 .25016 -19 -7.84375 ]
[-0.0125 .25016 0 7.84375 ]
[-0.0125 .36788 -19 -7.84375 ]
[-0.0125 .36788 0 7.84375 ]
[-0.0125 .4856 -19 -7.84375 ]
[-0.0125 .4856 0 7.84375 ]
[-0.0125 .60332 -10 -7.84375 ]
[-0.0125 .60332 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -11.4063 ]
[-0.01875 .30902 -19 11.4063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -77.9688 0 ]
[.5 .63053 77.9688 15.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -138.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cobweb) show
105.875 15.813 moveto
(Plot) show
128.188 15.813 moveto
(for) show
142.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
148.375 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.84) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
172.375 15.813 moveto
(H) show
176.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
185.188 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
195.875 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
202.000 15.813 moveto
(L) show
208.813 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
214.938 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
.02381 .01472 m
.06244 .10269 L
.10458 .19015 L
.14415 .26423 L
.18221 .32811 L
.22272 .38818 L
.26171 .43828 L
.30316 .48322 L
.34309 .51842 L
.3815 .54478 L
.40095 .55532 L
.42237 .56476 L
.44268 .57159 L
.45178 .57398 L
.46172 .57612 L
.4671 .57708 L
.4721 .57783 L
.47727 .57849 L
.48196 .57896 L
.48658 .57933 L
.4887 .57946 L
.49093 .57957 L
.49332 .57966 L
.49438 .5797 L
.49552 .57972 L
.49675 .57975 L
.49789 .57976 L
.49859 .57977 L
.49925 .57977 L
.50049 .57977 L
.50163 .57977 L
.50286 .57975 L
.50401 .57973 L
.50508 .57971 L
.50754 .57963 L
.51014 .57952 L
.51268 .57937 L
.51504 .57921 L
.5204 .57874 L
.5293 .57763 L
.53882 .57602 L
.54906 .57378 L
.56016 .57075 L
.58032 .5637 L
.60019 .55476 L
.62123 .54315 L
.65912 .51668 L
.69946 .48063 L
.73829 .43828 L
.77956 .38502 L
Mistroke
.81932 .32568 L
.85757 .26117 L
.89827 .18452 L
.93745 .10292 L
.97619 .01472 L
Mfstroke
.48874 .30206 m
.48874 .57946 L
.93758 .57946 L
s
.93758 .57946 m
.93758 .10262 L
.16605 .10262 L
s
.16605 .10262 m
.16605 .30187 L
.48843 .30187 L
s
.48843 .30187 m
.48843 .57944 L
.93756 .57944 L
s
.93756 .57944 m
.93756 .10269 L
.16615 .10269 L
s
.16615 .10269 m
.16615 .30203 L
.4887 .30203 L
s
.4887 .30203 m
.4887 .57946 L
.93758 .57946 L
s
.93758 .57946 m
.93758 .10263 L
.16606 .10263 L
s
.16606 .10263 m
.16606 .30189 L
.48847 .30189 L
s
.48847 .30189 m
.48847 .57944 L
.93756 .57944 L
s
.93756 .57944 m
.93756 .10268 L
.16614 .10268 L
s
.16614 .10268 m
.16614 .30202 L
.48867 .30202 L
s
.48867 .30202 m
.48867 .57945 L
.93758 .57945 L
s
.93758 .57945 m
.93758 .10264 L
.16607 .10264 L
s
.16607 .10264 m
.16607 .3019 L
.48849 .3019 L
s
.48849 .3019 m
.48849 .57944 L
.93756 .57944 L
s
.93756 .57944 m
.93756 .10267 L
.16613 .10267 L
s
.16613 .10267 m
.16613 .302 L
.48865 .302 L
s
.48865 .302 m
.48865 .57945 L
.93758 .57945 L
s
.93758 .57945 m
.93758 .10264 L
.16608 .10264 L
s
.16608 .10264 m
.16608 .30192 L
.48851 .30192 L
s
.48851 .30192 m
.48851 .57945 L
.93756 .57945 L
s
.93756 .57945 m
.93756 .10267 L
.16612 .10267 L
s
.16612 .10267 m
.16612 .30199 L
.48863 .30199 L
s
.48863 .30199 m
.48863 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10265 L
.16608 .10265 L
s
.16608 .10265 m
.16608 .30193 L
.48853 .30193 L
s
.48853 .30193 m
.48853 .57945 L
.93756 .57945 L
s
.93756 .57945 m
.93756 .10267 L
.16612 .10267 L
s
.16612 .10267 m
.16612 .30198 L
.48862 .30198 L
s
.48862 .30198 m
.48862 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10265 L
.16609 .10265 L
s
.16609 .10265 m
.16609 .30193 L
.48854 .30193 L
s
.48854 .30193 m
.48854 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.16611 .10266 L
s
.16611 .10266 m
.16611 .30198 L
.48861 .30198 L
s
.48861 .30198 m
.48861 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10265 L
.16609 .10265 L
s
.16609 .10265 m
.16609 .30194 L
.48855 .30194 L
s
.48855 .30194 m
.48855 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.16611 .10266 L
s
.16611 .10266 m
.16611 .30197 L
.4886 .30197 L
s
.4886 .30197 m
.4886 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10265 L
.16609 .10265 L
s
.16609 .10265 m
.16609 .30194 L
.48855 .30194 L
s
.48855 .30194 m
.48855 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.16611 .10266 L
s
.16611 .10266 m
.16611 .30197 L
.48859 .30197 L
s
.48859 .30197 m
.48859 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10265 L
.1661 .10265 L
s
.1661 .10265 m
.1661 .30195 L
.48856 .30195 L
s
.48856 .30195 m
.48856 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.16611 .10266 L
s
.16611 .10266 m
.16611 .30197 L
.48859 .30197 L
s
.48859 .30197 m
.48859 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10265 L
.1661 .10265 L
s
.1661 .10265 m
.1661 .30195 L
.48856 .30195 L
s
.48856 .30195 m
.48856 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.16611 .10266 L
s
.16611 .10266 m
.16611 .30196 L
.48859 .30196 L
s
.48859 .30196 m
.48859 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10265 L
.1661 .10265 L
s
.1661 .10265 m
.1661 .30195 L
.48857 .30195 L
s
.48857 .30195 m
.48857 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.16611 .10266 L
s
.16611 .10266 m
.16611 .30196 L
.48858 .30196 L
s
.48858 .30196 m
.48858 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10265 L
.1661 .10265 L
s
.1661 .10265 m
.1661 .30195 L
.48857 .30195 L
s
.48857 .30195 m
.48857 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.1661 .10266 L
s
.1661 .10266 m
.1661 .30196 L
.48858 .30196 L
s
.48858 .30196 m
.48858 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.1661 .10266 L
s
.1661 .10266 m
.1661 .30195 L
.48857 .30195 L
s
.48857 .30195 m
.48857 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.1661 .10266 L
s
.1661 .10266 m
.1661 .30196 L
.48858 .30196 L
s
.48858 .30196 m
.48858 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.1661 .10266 L
s
.1661 .10266 m
.1661 .30195 L
.48857 .30195 L
s
.48857 .30195 m
.48857 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.1661 .10266 L
s
.1661 .10266 m
.1661 .30196 L
.48858 .30196 L
s
.48858 .30196 m
.48858 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.1661 .10266 L
s
.1661 .10266 m
.1661 .30195 L
.48857 .30195 L
s
.48857 .30195 m
.48857 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.1661 .10266 L
s
.1661 .10266 m
.1661 .30196 L
.48858 .30196 L
s
.48858 .30196 m
.48858 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.1661 .10266 L
s
.1661 .10266 m
.1661 .30195 L
.48857 .30195 L
s
.48857 .30195 m
.48857 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.1661 .10266 L
s
.1661 .10266 m
.1661 .30196 L
.48858 .30196 L
s
.48858 .30196 m
.48858 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.1661 .10266 L
s
.1661 .10266 m
.1661 .30196 L
.48857 .30196 L
s
.48857 .30196 m
.48857 .57945 L
.93757 .57945 L
s
.93757 .57945 m
.93757 .10266 L
.1661 .10266 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00m@3oool01@3ooml0W4P00000
0000B9`0gooo0;H0oooo003f0?ooo`030?oOW01804P0W=oo0;L0oooo003]0?ooo`050;md00000000
07Bo0?ooo`3OW4P00P0000001@00B9`0gooo0?oOW01804P0W=oo0;L0oooo003]0?ooo`0<0?oog`2L
B7@0_ooo0?ooo`3ooml0W4P00018W03Oool0oooo0?oOW01804P0W=oo]`3oool00>h0oooo00/0oono
07A8W03Oool0_g@00000M02oool0oooo0?oo_`1d0000001809cOo`2g0?ooo`00k`3oool0103ogi`0
M4Q80000001d_ol30?ooo`030?oOW01804P0W=oo0;L0oooo003_0?ooo`030?oo_`1d0000B9cO0;h0
oooo003^0?ooo`050?oog`2LB00004RL09adB02Lgol0_@3oool00>h0oooo00H0_g@00000B02Lgol0
oooO09a8M02oool20?ooo`030?oo_`1d0000M;oo0;L0oooo003/0?ooo`090?oog`2LB00000000000
0000M;l0okmd0000000007@0_ooo0;/0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001Q0?ooo`050?oOW01800000000
0000M02oool0;P3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00D0okmd0000001d_ol0oooo
0;md00060000000304RLg`3oool0oooo02@0oooo00D0omnL04P000000000001d0;ooo`030?ooo`03
0?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo9@3oool01@3ogi`0B0000000000007@0
_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3ogi`0B000000000000000M;oo02L0oooo00D0
omnL04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00<0oooo00D0gia8000000000000
000004RLg`0^0?ooo`060;md00000000000000000000B9`0gooo:03oool00600oooo00L0oono07@0
001d_ol0oooo0?noM00007@0_ooo02`0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080
oooo00<0okmd0000001d_ol00P3oool00`3OW4P0000000000003000000030018W03Oool0oooo02<0
oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol01@3oool0
103ooml0W4P00018W03OoolT0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`03
0?noM0000000M;oo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000M;oo02D0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool01`3OW4P00000
07Boo`3oool0oooO09a80018W=l0;P3oool00`3ogi`0B00007Boo`0Z0?ooo`00H03oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo02/0oooo00<0_g@00018W03Oool00P3oool00`2oM000
07Bo0?ooo`070?ooo`030=nLB018W=l0oooo0080oooo00<0giad09cOo`3oool08`3oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo00T0oooo00@0oooO09a80000B9`0gooo903oool00`2o
M00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o
_g@004RL0=ooo`0T0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3o
oml0W4P0001d_`030?ooo`030?noM000B9`0gooo02d0oooo00<0omnL04P0001d_ol0:P3oool005l0
oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0Z0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool0203oool00`3OW4P0M;oo0?ooo`0V0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool01@3oool00`2oM0000000000000050000000307Boo`3oool0oooo0200
oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol08`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0
oooo00<0_g@0001d_`3oool00P3oool00`2oM00004RL0=ooo`0]0?ooo`030?oOW0180000M;oo02X0
oooo001O0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0:P3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0_gA809cOo`3oool09@3oool00`3ogi`0B000
07Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL
0=ooob<0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol08`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00H0oooo00L0omnL04P0M02oool0oooo0;md00000000M;oo02h0oooo00<0omnL04P0001d_ol0
:P3oool005l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol02@3oool00`3ooml0W4Qd0;ooo`0U0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03O
ool08`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d
_ol00`3oool00`2oM000001809cOo`0S0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool01@3ookl0M4Q804P000000000B9cO02l0oooo00<0omnL04P0001d_ol0:P3oool005l0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol02P3oool00`3o_g@007Bo0?ooo`0T0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool08`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0oono07@000000000B9cO0?oo
o`3o_g@00000001d_b@0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`04
0?oOW01800000000001d_c00oooo00<0omnL04P0001d_ol0:P3oool005l0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol02P3oool00`3ookl0M01809cOo`0T0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool01P3ogi`0B7Bo0?oog`2LB00004RL0=ooob<0oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`060?ooo`030;md0000B9`0_ia80080000000<004RL0=ooo`3oool08`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0omnL04P0000007@0_ooo0?no
M000M;l_0?ooo`030?oOW0180000M;oo02X0oooo001O0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool0:P3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0
oono07@00018W=l0903oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00P0oooo00D0
gia807Bog`2LB00004RL0=ooo`0S0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1P3oool00`3ogi`0B00007Boo`0X0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1P3oool00`2oM000001d0;ooo`020?ooo`030;md0018W=l0oooo02d0oooo00<0omnL04P0001d_ol0
:P3oool00600oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`0[0?ooo`030=nLB000
B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW018
0000B9cO02D0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`050?oog`2L
B4P0B4P00018W03Oool0903oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo
00<0gia80000B02Lgol0:03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo
00<0_g@00018W03Oool00P3oool00`3OW4P007Bo0?ooo`0]0?ooo`030?oOW0180000M;oo02X0oooo
001P0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0/0?ooo`070?oo_`1d0000M;oo0?oo
o`3o_g@0001d0;ooo`060?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02ooolU0?ooo`07
0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0:0?ooo`040?oOW018000004RL0=ooob@0oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo00T0oooo00<0okmd00000000M;l09`3oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool01`3oool01`3o_g@0000007Boo`3oool0oono07@0001d_ol0
;03oool01@3ooml0W4P0000000000000M;oo02X0oooo001Q0?ooo`050?oo_`1d000000000000M02o
ool0;P3oool01@3ookl0M0000000000007@0_ooo00P0oooo00H0oooO09a80000000000000000M02o
oolW0?ooo`050?oo_`1d000000000000M02oool0303oool00`3OW4P004RL0=ooo`0U0?ooo`050?oo
_`1d000000000000M02oool02`3oool01@3ooml0W4P00000000007@0_ooo02D0oooo00D0oono07@0
00000000001d0;ooo`090?ooo`050?noM0000000000000000018W=l0;`3oool00`3o_g@0000007Bo
o`0Z0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00CP3oool01@3ogi`0B000
0000000007@0_ooo00T0ooooo`00000b000002<0oooo001=0?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool004d0
oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08@3oool004`0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d
0;ooo`070?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00C03o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0o`3o
ool^0?ooo`030000003oool0oooo0240oooo001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol01`3oool3000000@0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030000003oool0
oooo00<0oooo0`00000S0?ooo`00C03oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00L0oooo00<000000?ooo`3oool0103oool300000?l0oooo7`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0240oooo001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool00`000000oooo0?ooo`050?ooo`040000003oool0000000000?l0oooo703oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0240oooo001<0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool01`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`000000o`3ooolK0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool004d0
oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`3oool0oooo0P00003o0?oooaP0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0Q0?ooo`00C@3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool0203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo0P00003o0?oooaH0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`00CP3oool01@3ookl0M0000000000007@0
_ooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`800000o`3ooolD
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01P3oool200000?l0oooo403oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0240oooo001L0?ooo`8000002@3oool00`000000oooo0?ooo`080?ooo`800000
o`3oool=0?ooo`030000003oool0oooo00L0oooo0`00000S0?ooo`00G03oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`800000o`3oool:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool200000?l0
oooo1P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool200000?l0oooo0`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@
0?ooo`800000oP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0240oooo001L0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3k0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool08@3oool005`0oooo0P00000=0?ooo`03
0000003oool0oooo0180oooo0P00003k0?ooo`030000003oool0oooo00X0oooo0`00000S0?ooo`00
G03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
m`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0503oool200000?L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0240oooo001L0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05P3oool20000
0?<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0l03oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0603oool200000>l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0k03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo001L
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06P3oool200000>/0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool200000140oooo00<000000?oo
o`3oool0703oooo/00000100oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`000000j03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0200000>D0oooo0P00000B0?ooo`030000003oool0oooo0240oooo
001L0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0>80oooo0P00000B0?ooo`030000003oool0oooo0240oooo0011
0?ooo`050?oOW018000000000000M02oool00`3oool01@3o_g@0000007Boo`3oool0_g@000H00000
00<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool00`3oool200000>40oooo00<000000?ooo`0000004P3oool00`000000oooo
0?ooo`0Q0?ooo`00@03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0
000007Boo`020?ooo`030=nLB0000000000000<0000000<004RL0=ooo`3oool01@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool200000=l0
oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`2oM00004RL
0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia804RLg`3oool00P3oool00`3OW7@0W=oo
0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`070?ooo`800000g03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo0240
oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool00`3OW4P0M;oo
0?ooo`090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`090?ooo`800000fP3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo0240
oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02@3oool00`2oM4P0W=oo
0?ooo`080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0;0?ooo`800000e`3oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3o
ool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`090?ooo`030?oo
g`2LB7@0_ooo00P0oooo0`00000D0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
3@3oool200000=D0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`<000008`3oool003l0oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?noM000M;l0oooo00L0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cO
o`0:0?ooo`030?oo_`1d04P0W=oo00L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0100oooo0P00003A0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`03
0?ooo`030=nLB00007@0_ooo00X0oooo00<0oono07@00018W=l01`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3=
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q
0?ooo`00@03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oknL09cO
o`3oool00P3oool00`3ogi`0B00004RLg`070?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0<`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo00100?ooo`07
0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`060?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M000
0000M02oool70?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0D0?ooo`800000b`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool08@3oool00440oooo00D0oono07@000000000001d0;ooo`080?ooo`06
0?oog`2LB00000000000000007@0_ooo203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`380?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`360?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0603oool200000<H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`8000006P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0`P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00h0oooo0`00000S0?ooo`00G03oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06`3oool200000<80oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0M
0?ooo`800000_`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01l0oooo0P00002m0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool08@3oool200000;X0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S0?ooo`800000
^03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
8@3oool005`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo02D0oooo0P00002e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:03oool20000
0;40oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0240oooo001L0?ooo`8000007`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0
oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0:`3oool200000:d0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0:X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0^
0?ooo`800000Z@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0340oooo0P00002U0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0=03oool200000:40oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0f0?ooo`800000WP3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool0
05`0oooo0P00000S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool30000
02<0oooo001L0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0i0?ooo`800000VP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03/0oooo0P00002H0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3ogi`0B0000000
000007@0_ooo00<0oooo00<0okmd0000001d_ol01@3oool0103ooml0W4P00018W03Oool70?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0m0?ooo`80
0000U@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool08@3oool00400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000
001d_ol01@3oool0103ooml0W4P00018W03Oool70?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo00100?oo
o`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool02@3oool0103ooml0W4P00018W03Oool7
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`10
0?ooo`800000T@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool08@3oool003l0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?oo
o`030;md00000000000000D0000000<0M;oo0?ooo`3oool0103oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?oo
o`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0omnL07BLg`3o
ool0oooo0?oog`2LB00004RL0=ooo`L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo04<0oooo0P00002=0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`03
0?ooo`030?noM00004P0W=oo00H0oooo00L0gia807Boo`3oool0oooO09a80000B9`0gooo00L0oooo
0`00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`290?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03P3oool3000002<0oooo
000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3ooml0W4Qd0;oo
o`3ooml0W4P00018W03Oool01`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0AP3oool2000008T0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol01`3oool01P3ogi`0B7Bo0?oog`2LB00004RL0=ooo`L0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0Q@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool08@3oool003l0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`080?ooo`05
0=nLB01d_ml0W4P00018W03Oool01`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0B@3oool2000008D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo00100?ooo`030=nLB000B9`0gooo0080
oooo00<0_g@0001d_`3oool0203oool01@3ooml0W4Q804Q80000B9`0gooo00L0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool08@3oool002`0oooo00<0_gAd0;ooo`3oool0103oool00`2oM7@0_ooo0?ooo`0:0?ooo`07
0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0:0?ooo`040?oOW018000004RL0=ooo`L0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04`0oooo0P00
00200?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0Q0?ooo`00;03oool00`2oM000B9cO0?ooo`030?ooo`030=nLB00007@0_ooo00`0oooo00D0oono
07@000000000001d0;ooo`0<0?ooo`030=nLB000B9`0gooo00L0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04h0oooo0P00001n0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00;03oool0
2@2oM00000000000M02oool0oooO09a80018W=l0gibL0;ooo`0W0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240
oooo000/0?ooo`060;nLW03Ogi`0B0000000000004P0W=oo:P3oool00`000000oooo0?ooo`0[0?oo
o`050000003oool0oooo0?ooo`000000D`3oool2000007X0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;mdM02ogi`0B000
0080000000@0001809cOo`3OW9`0_ooo9`3oool2000002`0oooo00D000000?ooo`3oool0oooo0000
001E0?ooo`800000M`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo0`00
000S0?ooo`00;03oool00`2oM00004RL0=ooo`020?ooo`040;md00000000001d0;ooobL0oooo00<0
00000?ooo`3oool0;03oool010000000oooo0?ooo`00001G0?ooo`800000M@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool002`0oooo00<0
_gA809cOo`3oool00`3oool00`3o_g@0001d0;ooo`0W0?ooo`030000003oool0oooo02`0oooo00@0
00000?ooo`3oool00000F@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`2oW9`0gooo0?oo
o`040?ooo`030=nLW02oool0oooo02H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0000
001J0?ooo`800000L03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0;P3oool2000005`0oooo0P00001^
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q
0?ooo`00<@3oool00`2oW9`0gooo0?ooo`020?ooo`030=nLW02oool0oooo02<0oooo00<000000?oo
o`3oool0;P3oool2000005h0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool002d0oooo00D0oono07@0B02L
gol0oono07@00004000000030000M02oool0oooo02<0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`1M0?ooo`800000JP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool08@3oool003H0oooo00<0gibL0;ooo`3oool08`3oool00`000000
oooo0?ooo`0_0?ooof@00000I`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`1N0?ooo`040000003oool00000000006@0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000<P3oool00`000000oooo
0?ooo`1M0?ooo`050000003oool0oooo0?ooo`000000H`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00h0oooo0`00000S0?ooo`00<`3oool00`2oM7@0_ooo0?ooo`0V0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`020?ooo`800000
H03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
8@3oool003<0oooo00<0_gAd0;ooo`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00<`3oool0
0`2oM7@0_ooo0?ooo`0V0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`050?ooo`800000G03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool08@3oool00300oooo00<0_g@00000000000000`0000000`00
07@0_ooo0?ooo`0S0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo000c0?ooo`030;mdM02oool0oooo02H0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00P0
oooo0P00001H0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0Q0?ooo`00<`3oool00`2oM7@0_ooo0?ooo`0V0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo
000c0?ooo`030;mdM02oool0oooo02H0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`1I0?ooo`030000003oool0oooo00/0oooo0P00001D0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q
0?ooo`00;P3oool00`3ooml0W7BL0=ooo`050?ooo`030=nLW02oool0oooo02<0oooo0P00000g0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool03P3oool2000004l0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0>0?ooo`<000008`3oool002h0oooo00<0okmd00000000
00001@0000000`0007@0_ooo0?ooo`0S0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0@0?ooo`800000C@3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool003H0oooo00<0gibL0;ooo`3oool0
8`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool04`3oool2000004P0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo00110?ooo`050?oOW0180000
00000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`050?oOW018000000000000001d_ol0
203oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
5@3oool2000004H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0240oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`03
0?noM0000000M;oo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000M;oo00L0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01L0oooo0P000013
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q
0?ooo`00@03oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a8
0000M;l00`3oool00`3o_g@004RL0=ooo`060?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo000o0?ooo`03
0?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo00H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo01X0oooo0P00000o0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?no
M00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3o
ool00`3ogi`0B00007Boo`030?ooo`030;md000004P0W=oo00H0oooo0`00000m0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool07@3oool2000003X0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0>0?ooo`<000008`3oool003l0oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`050?ooo`080?oo_`1d0000000004RLg`3oool0okmd00000000M;l70?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0
1P3oool00`2oM00004RL0;nLB002000000030018W03Oool0oooo00H0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0200oooo0P00000f0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00?`3o
ool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0omnL04P0001d_ol02`3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0
oooo00L0oooo00<0gia80000B02Lgol02P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool08`3oool200000380oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo00100?ooo`070?oo_`1d0000M;oo
0?ooo`3o_g@0001d0;ooo`090?ooo`030?noM000000007Bo00T0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3o
ool00440oooo00D0oono07@000000000001d0;ooo`0;0?ooo`050?oog`2LB00000000000M02oool0
1P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
9P3oool2000002d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0X0?ooo`800000:P3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool0
05`0oooo0P0000140?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0:`3oool20000
02H0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0>0?ooo`<000008`3oool005`0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02d0
oooo0P00000S0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0;`3oool200000200oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0b
0?ooo`800000703oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo03@0oooo0P00000I0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
=`3oool2000001D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0240oooo001L0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0i0?ooo`8000004P3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool08@3oool005`0oooo0P00001:0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0>`3oool2000000l0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0>0?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool005`0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03h0
oooo0P00000;0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@@3oool2000000H0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`140?ooo`80000000<0oooo0000003oool0?@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0A@3oool010000000oooo
00000000000m0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool005`0oooo
0P00001B0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool03P3oool3000002<0oooo
001L0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo00@0oooo0P00000j0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01`3oool2000003P0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?oo
o`00@@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3O
W4P00000000000000000B9cO00P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0303oool2000003D0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M00007Boo`3oool0
okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?ooo`070=nLB0000000M;oo0?ooo`3ooml0
W4P004RLg`070?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo00l0oooo0P00000c0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool08@3oool00400oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo
0?ooo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03Oool01P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0B0?ooo`800000<@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo
000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM00007Bo0?oo
o`020?ooo`030;md0000B9`0gooo00H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL
04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`070?oOW01807@0_ooo0?ooo`2oM0000000
07Boo`070?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo01L0oooo0P00000^0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cO
o`070?ooo`050?oo_`1dB4P0B00000000018W=l0203oool3000005X0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01X0oooo0P00000/0?ooo`030000
003oool0oooo00h0oooo0`00000S0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM000
04P0W=oo00L0oooo00@0omnL04P00000000007Bo2@3oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00?`3o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0omnL04P0000007@0_ooo
0?noM000M;l80?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo01l0oooo0P00000Y0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool08@3oool003l0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d
0;ooo`060?ooo`030;md000007@0_ooo0080oooo00<0_g@004RLg`3oool01P3oool00`000000oooo
0?ooo`1M0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Q0?ooo`00@03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo00<0
_g@00018W03Oool00P3oool00`3OW4P007Bo0?ooo`060?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0f0?ooo`8000009P3oool2000002H0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M00007Boo`3o
ool0okmd0000M02oool01`3oool01`3o_g@0000007Boo`3oool0oono07@0001d_ol01`3oool00`00
0000oooo0?ooo`1O0?ooo`800000<03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
02P0oooo0P00000T0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool00440
oooo00D0oono07@000000000001d0;ooo`090?ooo`050?noM0000000000000000018W=l0203oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0]0?ooo`8000008@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240
oooo001L0?ooo`800000I@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0<P3oool2000001h0oooo00<000000?ooo`3oool03P3oool3000002<0oooo
001L0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0_0?ooo`800000=`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0IP3oool2000002T0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0h0?ooo`8000006`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo06P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`03
0000003oool0oooo06T0oooo0P00000V0?ooo`030000003oool0oooo02/0oooo0P00000o0?ooo`80
0000603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0240oooo001L0?ooo`030000003oool0oooo06`0oooo0P00000S0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0@`3oool2000001D0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool09`3oool2000004P0oooo0P00000C0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0K`3oool20000
0200oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool200000780
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0T0?ooo`800000CP3oool200000100
oooo00<000000?ooo`3oool03P3oool3000002<0oooo001L0?ooo`030000003oool0oooo0780oooo
0P00000M0?ooo`030000003oool0oooo0280oooo0P00001B0?ooo`8000003P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo07@0oooo0P00
000K0?ooo`030000003oool0oooo0200oooo0P00001F0?ooo`800000303oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo07H0oooo0P00000I
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?oo
o`3oool0N03oool2000001L0oooo00<000000?ooo`3oool07@3oool2000005`0oooo0P0000090?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3o
ool0NP3oool2000001D0oooo00<000000?ooo`3oool06`3oool200000600oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000
003oool0oooo07`0oooo0`00000B0?ooo`030000003oool0oooo01P0oooo0`00001S0?ooo`800000
1P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003o
ool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo01D0oooo0`00001X0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool0
0`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`0B0?ooo`<00000K03oool2
000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Q0?ooo`00G03oool20000
08H0oooo1@0000070?ooo`030000003oool0oooo00`0oooo1P00001a0?ooo`040000003oool0oooo
00000100oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`2:0?oooi4000004P3oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`2C0?ooo`D00000PP3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo
703oool200000100oooo00<000000?ooo`3oool08@3oool004h0oooo00H0_g@00000000000000000
0018W03Oool80?ooo`030000003oool0oooo0?l0oooo7P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0240oooo001?0?ooo`030?oOW0180000M;oo00X0oooo00<000000?ooo`3oool0
o`3ooolO0?ooo`8000003@3oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool00`3ogi`0B00007Bo
o`0:0?ooo`030000003oool0oooo0?l0oooo8@3oool2000000/0oooo00<000000?ooo`3oool08@3o
ool004l0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?ooob<0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool00`3ogi`0B00007Boo`0:0?oo
o`030000003oool0oooo0?l0oooo903oool2000000P0oooo00<000000?ooo`3oool08@3oool004l0
oooo00<0omnL04P0001d_ol02P3oool300000?l0oooo9P3oool00`000000oooo0?ooo`030?ooo`<0
00008`3oool004l0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?ooobh0oooo
00<000000?ooo`3oool08@3oool004l0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0240oooo001?0?ooo`030?oOW0180000M;oo00X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool00`3ogi`0B00007Boo`0:0?oo
ool00000<P00000S0?ooo`00C@3oool01@3ooml0W4P0000000000000M;oo0?l0ooooG`3oool004l0
oooo00<0okmd0000001d_ol0o`3ooomO0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooolZ0?ooo`030?oog`2LB4P0W=oo02H0oooo00<0omnL04Q8W03O
ool0F`3oool00?l0oooo:P3oool00`2oM4P0W=oo0?ooo`0W0?ooo`030?oOW018M;l0oooo05X0oooo
003o0?ooobT0oooo00<0gia804RLg`3oool0:@3oool00`3OW4P0B9cO0?ooo`1I0?ooo`00o`3ooolX
0?ooo`030?oo_`1d07@0_ooo02X0oooo00<0oono07@0B02Lgol0F@3oool008D0oooo00<0omnL04P0
000000000P0000000`0007@0_ooo0?ooo`030?ooo`050=nLB000000000000000001d_ol00`3oool0
1P3ooml0W4P0000000000000001809cOo`D0oooo00<0omnL07BLg`3oool00P3oool00`3OW7@0W=oo
0?ooo`040?ooo`050;md0000000000000000M02oool00P3oool01P3ooml0W4P00000000000000018
09cOo`H0oooo00<0_g@00000000000000P0000000`00M;l0oooo0?ooo`030?ooo`070=nLB0000000
00000000M02oool0oooo0=nLB0030000000807Boo`3oool0oooo0?ooo`3ogi`0B00000000018W=l5
0?ooo`030?oOW018000000000080000000@0M;oo0?ooo`3oool0gia80`000000101d_ol0oooo0?oo
o`2oM002000000060000B02Lgol0oooO09a8000007@0_ooo1P3oool00`3ookl0M000000000020000
000307Boo`3oool0oooo0080oooo00<0okmd0000001d_ol00`3oool01@3OW4P00000000000000000
B9cO00H0oooo00@0oooO09a80000B9`0gooo1P3oool00`3OW4P004RL0=ooo`040?ooo`060;md0000
0000000000000000B9`0gooo5@3oool01@2oM0000000001d_`3oool0gia80080000000L004RL0=oo
o`3oool0oooo0?oog`2LB000B9cO00D0oooo00D0_g@000000000M;l0oooo0=nLB002000000030018
W03Oool0oooo04X0oooo00240?ooo`040=nLB000000004RL0=ooo`80oooo00<0oono07@0B02Lgol0
0P3oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool01`2oM00004RL0=ooo`3oool0
omnL04P0001d_ol0103oool01`2oM000001d0;ooo`3oool0oono07@00000M;l0103oool03`2oM000
0000001d_`3oool0omnL04P0M02oool0oooo0;md0000B9`0gooo0?ooo`3ogi`0B00007Boo`060?oo
o`040?oog`2LB00004RL0=ooo`L0oooo00/0gia80000M02oool0oooo0=nLB0000000B9cO0?ooo`3o
oml0W4P004RLg`020?ooo`050=nLB00007@0_ooo0=no_`3Oool01@3oool00`3ooml0W4P0001d_`03
0?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`080=nLB00007@0_ooo0?ooo`3o
oml0W4P00000M02oool60?ooo`030?oOW0180000B9cO0080oooo00<0_g@004RLg`3oool00P3oool0
0`3o_g@0000007Boo`020?ooo`070=nLB0000000M;oo0?ooo`3ooml0W4P004RLg`050?ooo`040?oo
g`2LB00004RL0=ooo`H0oooo00<0_g@0001d_`3oool01@3oool00`3ogi`0B00007Boo`0G0?ooo`08
0?oog`2LB7@0_ooo0?ooo`3ooml0W4P00018W03Oool40?ooo`030=nLB000B9`0gooo00@0oooo00P0
oooO09a8M02oool0oooo0?oog`2LB00004RL0=oood`0oooo00230?ooo`030?noM000000007Bo00D0
oooo00H0oooO09a8M02oool0omnL04P00000M;l30?ooo`070?noM00007@0_ooo0?ooo`2oM00004RL
0=ooo`020?ooo`030?noM00007@0_ooo0080oooo00T0omnL04P00018M7@0M9cO0?ooo`3o_g@00018
04Q8B02Lgol00P3oool00`3ogi`0B00004RLg`030?ooo`060?oOW01dW=l0oooo0;md0000B9`0gooo
0P3oool00`3o_g@0001d0;ooo`050?ooo`030?oog`2LB00007Bo00P0oooo00H0gia80000M02oool0
omnL04P00000M;l30?ooo`070?noM00007@0_ooo0?ooo`3OW4P004RL0=ooo`070?ooo`030?oog`2L
B00007Bo0080oooo00<0omnL04P00000M;l00`3oool01`3o_g@0001d0;ooo`3oool0gia80000M02o
ool0403oool00`3ookl0M01809cOo`060?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03O
ool0103oool0103ooml0W4P00018W03Oool50?ooo`030?oo_`1d0000B9cO00H0oooo00<0omnL04P0
001d_ol0603oool01P3ookl0M4RL0=ooo`2oM000001d0;ooo`D0oooo00<0gia80000M02oool01@3o
ool01P3ookl0M4RL0=ooo`2oM000001d0;ooodd0oooo00220?ooo`040?oog`2LB000001d0;ooo`P0
oooo00<0okmd0000001d_ol00`3oool01`3o_g@0000007Boo`3oool0_g@00018W03Oool00P3oool0
0`3ogi`0B00007Boo`020?ooo`090=nLB00007@0_ooo0;mdM02ooml0W4P0001d_`3ogi`0M9cO0080
oooo00<0okmd0000B02Lgol01P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000M;oo00D0
oooo00<0oooO09a80000M;l0203oool01P3OW4P0001d0;ooo`3o_g@0000007Boo`<0oooo00L0okmd
0000001d_ol0oooo0=nLB000B9`0gooo00L0oooo00<0oooO09a80000M;l00P3oool00`3o_g@00000
07Boo`030?ooo`070?noM0000000M;oo0?ooo`3OW4P0001d0;ooo`0@0?ooo`030?oo_`1d0000M;oo
00L0oooo00<0_g@0001d_`3oool00P3oool0102oM00004RL0=ooo`2oM0070000000307Boo`3oool0
oooo0080oooo00<0oono07@0001d_ol01P3oool00`3ogi`0B00007Boo`0I0?ooo`040?oOW01dB4P0
000007Boo`H0oooo00<0okmd0000M02oool01P3oool0103ogi`0M4Q80000001d_om>0?ooo`00PP3o
ool0103ogi`0B0000018W03Oool80?ooo`030?noM0000000M;oo00<0oooo00L0okmd0000001d_ol0
oooo0;md0000B9`0gooo0080oooo01<0omnL04P0001d_ol0oooo0?oo_`1d0000B9cO0?ooo`3ogi`0
M7Ad04P0B02Lgol0oooo0;mdM02oool0oooo0?noM00007@0_ooo00H0oooo00<0_g@00018W03Oool0
0P3oool00`3ogi`0B00007Boo`050?ooo`030?oog`2LB00007Bo00P0oooo00H0gia80000M02oool0
okmd0000001d_ol30?ooo`070?noM0000000M;oo0?ooo`3OW4P004RL0=ooo`070?ooo`030?oog`2L
B00007Bo0080oooo00<0okmd0000001d_ol00`3oool01`3o_g@0000007Boo`3oool0gia80000M02o
ool0403oool00`3o_g@0000007Boo`070?ooo`0:0?oOW01807@0_ooo0?ooo`2oM000000007Boo`3o
ool0omnL07BLg`80oooo00@0oooO09a80000B9`0gooo1@3oool00`3ookl0M00007Boo`060?ooo`03
0?oOW0180000M;oo00L0oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?ooo`050?ooo`03
0?oo_`1d0000B9cO00L0oooo00<0okmd0000B02Lgol01P3oool00`3ookl0M00004RLg`1?0?ooo`00
PP3oool00`3o_g@00000001d_`090?ooo`030?oo_`1d0000M;oo00<0oooo00L0_g@00000B02Lgol0
oooo0;md0000B9`0gooo0080oooo00/0okmd0000B02Lgol0oooo0=nLB00004P0W=oo0?ooo`3ooml0
W4P0001d_`020?ooo`050?noM018W=l0oooo0?oOW01800001@0000001@18W=l0oooo0;md0000B9`0
gooo0080oooo00<0okmd0000B02Lgol01@3oool00`3ooml0W4P0000000040000000:07Boo`3oool0
oooo0?ooo`3OW4P0001d0;ooo`3ookl0M00007Boo`<0oooo00L0_g@00000B02Lgol0oooo0=nLB000
B9`0gooo00L0oooo00<0oooO09a80000M;l00P3oool00`3ookl0M00007Boo`030?ooo`070;md0000
04P0W=oo0?ooo`3OW4P0001809cOo`0?0?ooo`040?oOW0180000001809cOo`P0oooo00D0oono07A8
B0180000000004RLg`030?ooo`070=nLB01d_ol0oooo0?oog`2LB00004RL0=ooo`050?ooo`030?oo
_`1d0000M;oo00H0oooo00<0omnL04P0001d_ol0603oool01@3ooml0W4P00018W02LM4P0W=oo00H0
oooo00<0okmd0000M02oool01@3oool01@3ooml0W4P00018W02LM4P0W=oo04h0oooo00220?ooo`03
0?noM000000007Bo00X0oooo00L0gia80018W03Oool0oooo0?noM000000007Bo0080oooo00/0_g@0
00000000B9`0gooo0?oo_`1d000004RL0=ooo`3ookl0M000001d_`020?ooo`030?oOW0180000M;oo
0080oooo00H0oooO09a8M02oool0oooo0;md0018W=l20?ooo`0<0=nLB00004P0W=oo0?ooo`2oM000
00000018W03Oool0oono07@00000B9`0gooo1@3oool00`3ooml0W4P0001d_`020?ooo`040?oog`2L
B000000004RLg`80oooo00/0gia80000M02oool0oooo0=nLB000B9`0gooo0?ooo`3o_g@00000001d
_`020?ooo`030=nLB000B9`0gooo00L0oooo00<0oooO09a80000M;l00`3oool04@3OW4P004RL0=oo
o`3oool0okmd00000000M;l0oooO09a800000000001804QdW03O_g@0001V07A8000007@0_ooo00P0
oooo00D0okmd000000000000001809cOo`090?ooo`040?oOW01800000000001d_`@0oooo00L0oooO
09a8M02oool0oooO09a80000B9`0gooo00D0oooo00<0oono07@00018W=l01P3oool00`3ogi`0B000
07Boo`0H0?ooo`060;md000004P0W=oo0?oog`2LB7@0_ooo1@3oool00`3OW4P0001d0;ooo`050?oo
o`060;md000004P0W=oo0?oog`2LB7@0_oooC@3oool00880oooo00@0omnL04P00000B9`0gooo2P3o
ool01@3o_g@00000000000000000B9cO00<0oooo00T0_g@00018W03Ogi`0B00000000000B9`0gooo
0?oog`2LB0000P0000000`18W=l0okmd000000020000000804RLg`3oool0_g@000000000B9`0gooo
0?ooo`3OW4P20000000;0000B02Lgol0oooo0?ooo`2oM00004RL0=oOW018000000000018W03Oool0
1P3oool00`3ooml0W4P0001d_`030?ooo`080?oo_`1d0000001d0;ooo`3oool0gia80000M02oool2
0?ooo`050?noM0000000000000000018W=l00P3oool01P2oM000000000000000000004RL0=ooo`@0
oooo00<0okmd0000000000000P0000001000B9`0gooo0?ooo`3o_g@30000000<04RLg`3oool0oooo
0?ooo`2oM000001d0;oOW0180000001V07A8000007@0_ooo2P3oool00`2oM00007Bo0?ooo`080?oo
o`060?oOW0180000001d0;ooo`3o_g@007Bo103oool01P3ogi`0B7Bo0?oog`2LB00004RL0=ooo`D0
oooo00<0oooO09a80018W=l01P3oool00`3ogi`0B00007Boo`0F0?ooo`090?oog`2LB00000000000
0000M;l0okmd0000000007@0_ooo00@0oooo00<0gia80018W03Oool00`3oool02@3ooml0W4P00000
0000000007Bo0?noM0000000001d0;ooo`1<0?ooo`00PP3oool0103ooml0W4P00000B02Lgol50?oo
o`030?oog`2LM9`0gooo00X0oooo00<0_g@00018W03Oool06`3oool00`2oM00004RL0=ooo`0:0?oo
o`030?oog`2LB00007Bo00<0oooo00P0oooO09a8000004P0W=oo0?ooo`3OW4P0001d0;ooo`X0oooo
00<0_g@00018W03Oool01`3oool00`3ooml0W4P0001d_`0O0?ooo`030;md0018W=l0oooo00L0oooo
00<0_g@00000M02oool00P3oool00`2oM000B9cO0?ooo`030?ooo`050=nLB01d_ml0W4P00018W03O
ool01P3oool00`3OW4P004RL0=ooo`050?ooo`030?oOW0180000M;oo0280oooo00<0oooO09a80018
W=l0F@3oool008<0oooo00<0omnL04P00000M;l01@3oool00`3o_g@004RL0=ooo`0:0?ooo`030;md
0000B9`0gooo01/0oooo00<0_g@00018W03Oool02P3oool00`3ooml0W4P0001d_`030?ooo`080?oO
W0180000001d0;ooo`3oool0gia80000M02oool:0?ooo`030?oo_`1dB9`0gooo00P0oooo00<0_g@0
001d_`3oool06@3oool00`3ooml0W9bo0?ooo`020?ooo`030=nLB00007@0_ooo00L0oooo00<0_g@0
0018W03Oool00P3oool00`3OW4P007Bo0?ooo`030?ooo`050?oog`2LB4P0B4P00018W03Oool01P3o
ool00`3ookl0M01809cOo`050?ooo`030?oOW0180000M;oo0280oooo00<0oono07@0B02Lgol0F@3o
ool008@0oooo00<0okmd00000000M;l00`3oool00`3OW4P00000001d_`0;0?ooo`030;md0000B9`0
gooo01/0oooo00<0_g@00018W03Oool02P3oool00`3ooml0W4P0001d_`020?ooo`040?oo_`1d0000
000004RLg`80oooo00<0gia80000M02oool02P3oool00`3ooml0W7BL0=ooo`080?ooo`030=nLB000
M;l0oooo01X0oooo00H0okmd04RLg`3oool0oono07@00000M;l80?ooo`070?noM0000000M;oo0?oo
o`3ookl0M00007Boo`050?ooo`040?oOW018000004RL0=ooo`L0oooo00<0gia804RLg`3oool00P3o
ool01@3ooml0W4P0000000000000M;oo0280oooo00<0gia804RLg`3oool0F@3oool008D0oooo00<0
oooO09a8000000000P0000000`18W=l0oono07Ad_`090?ooo`050?oo_`1d000000000018W03Oool0
6@3oool01@3ookl0M00000000000B9`0gooo00T0oooo00<0_g@000000000000010000000200004P0
W=oo0?ooo`3ooml0W4P00000000007@0_ooo5@3oool01`3ookl0M01d0;ooo`3ooml0W4P00018W03O
ool05`3oool01@3OW4P000000000000007@0_ooo00T0oooo00D0okmd000000000000000004RLg`07
0?ooo`030=nLB000B9`0gooo00P0oooo00<0_g@004RLg`3oool00`3oool00`3o_g@0000007Boo`0Q
0?ooo`030?noM000M;l0oooo05X0oooo002G0?ooo`040?oog`2LB00004RL0=oooaX0oooo00@0oooO
09a80000B9`0gooo5@3oool00`2oM000001d0;ooo`0F0?ooo`050?oo_`1d000000000000B02Lgol0
?P3oool00`3OW7@0W=oo0?ooo`0U0?ooo`030?oo_`1dM;l0oooo05/0oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.344423, -0.309528, \
0.00518628, 0.00839157}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fixed points and cycles", "Section"],

Cell[TextData[{
  "Any point which is mapped upon itself, such that ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + 1\) = x\_i\)]],
  ", is called a ",
  StyleBox["fixed point",
    FontSlant->"Italic"],
  " of the map.  Similarly, points which repeat after ",
  StyleBox["n",
    FontSlant->"Italic"],
  " iterations, such that ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + n\) = x\_i\)]],
  ", are members of an ",
  StyleBox["n-cycle",
    FontSlant->"Italic"],
  ".  The dependence of these points upon the map parameter \[Mu] can be \
determined by examining the iterated function sequence ",
  Cell[BoxData[
      \(TraditionalForm\`f\_0[x] = x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f\_1[x] = f[x]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f\_2[x] = f[f[x]]\)]],
  ", \[CenterEllipsis], ",
  Cell[BoxData[
      \(TraditionalForm\`f\_n[x] = f[f\_\(n - 1\)[x]]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(f\_n_[\[Mu]_, x_] := Nest[\[Mu]\ #\ \((1 - #)\) &, x, n]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[f\_n[\[Mu], x], {n, 0, 4}] // Simplify\) // 
      TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"x"},
          {\(\(-\((\(-1\) + x)\)\)\ x\ \[Mu]\)},
          {\(\(-\((\(-1\) + x)\)\)\ x\ \[Mu]\^2\ \((1 - x\ \[Mu] + 
                  x\^2\ \[Mu])\)\)},
          {\(\((1 - x)\)\ x\ \[Mu]\^3\ \((1 - x\ \[Mu] + 
                  x\^2\ \[Mu])\)\ \((1 + \((\(-1\) + 
                        x)\)\ x\ \[Mu]\^2\ \((1 - x\ \[Mu] + 
                        x\^2\ \[Mu])\))\)\)},
          {\(\((1 - x)\)\ x\ \[Mu]\^4\ \((1 - x\ \[Mu] + 
                  x\^2\ \[Mu])\)\ \((1 + \((\(-1\) + 
                        x)\)\ x\ \[Mu]\^2\ \((1 - x\ \[Mu] + 
                        x\^2\ \[Mu])\))\)\ \((1 - \((1 - 
                        x)\)\ x\ \[Mu]\^3\ \((1 - x\ \[Mu] + 
                        x\^2\ \[Mu])\)\ \((1 + \((\(-1\) + 
                              x)\)\ x\ \[Mu]\^2\ \((1 - x\ \[Mu] + 
                              x\^2\ \[Mu])\))\))\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {x, 
        Times[ -1, 
          Plus[ -1, x], x, \[Mu]], 
        Times[ -1, 
          Plus[ -1, x], x, 
          Power[ \[Mu], 2], 
          Plus[ 1, 
            Times[ -1, x, \[Mu]], 
            Times[ 
              Power[ x, 2], \[Mu]]]], 
        Times[ 
          Plus[ 1, 
            Times[ -1, x]], x, 
          Power[ \[Mu], 3], 
          Plus[ 1, 
            Times[ -1, x, \[Mu]], 
            Times[ 
              Power[ x, 2], \[Mu]]], 
          Plus[ 1, 
            Times[ 
              Plus[ -1, x], x, 
              Power[ \[Mu], 2], 
              Plus[ 1, 
                Times[ -1, x, \[Mu]], 
                Times[ 
                  Power[ x, 2], \[Mu]]]]]], 
        Times[ 
          Plus[ 1, 
            Times[ -1, x]], x, 
          Power[ \[Mu], 4], 
          Plus[ 1, 
            Times[ -1, x, \[Mu]], 
            Times[ 
              Power[ x, 2], \[Mu]]], 
          Plus[ 1, 
            Times[ 
              Plus[ -1, x], x, 
              Power[ \[Mu], 2], 
              Plus[ 1, 
                Times[ -1, x, \[Mu]], 
                Times[ 
                  Power[ x, 2], \[Mu]]]]], 
          Plus[ 1, 
            Times[ -1, 
              Plus[ 1, 
                Times[ -1, x]], x, 
              Power[ \[Mu], 3], 
              Plus[ 1, 
                Times[ -1, x, \[Mu]], 
                Times[ 
                  Power[ x, 2], \[Mu]]], 
              Plus[ 1, 
                Times[ 
                  Plus[ -1, x], x, 
                  Power[ \[Mu], 2], 
                  Plus[ 1, 
                    Times[ -1, x, \[Mu]], 
                    Times[ 
                      Power[ x, 2], \[Mu]]]]]]]]}]]], "Output"]
}, Closed]],

Cell[TextData[{
  "Thus, fixed points are located by solving the equation ",
  Cell[BoxData[
      \(TraditionalForm\`f\_1[x] \[Equal] x\)]],
  " and ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-cycles are constructed by solving ",
  Cell[BoxData[
      \(TraditionalForm\`f\_n[x] \[Equal] x\)]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(fixedPoints[n_] := Solve[f\_n[\[Mu], x] == x, x]\)], "Input"],

Cell[TextData[
"It is instructive to display a graphical solution to this equation for a \
range of \[Mu]."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[{x, Table[f\_1[\[Mu], x], {\[Mu], 0.5, 4, 0.5}]}], {x, 0, 
          1}, Frame \[Rule] True, \ 
        FrameLabel \[Rule] {\*"\"\<\!\(x\_i\)\>\"", \ \*"\"\<\!\(x\_\(i + 1\)\
\)\>\""}, AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -9.5 -15.6875 ]
[.21429 -0.0125 9.5 0 ]
[.40476 -0.0125 -9.5 -15.6875 ]
[.40476 -0.0125 9.5 0 ]
[.59524 -0.0125 -9.5 -15.6875 ]
[.59524 -0.0125 9.5 0 ]
[.78571 -0.0125 -9.5 -15.6875 ]
[.78571 -0.0125 9.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .02381 -10 -7.84375 ]
[-0.0125 .02381 0 7.84375 ]
[-0.0125 .21429 -19 -7.84375 ]
[-0.0125 .21429 0 7.84375 ]
[-0.0125 .40476 -19 -7.84375 ]
[-0.0125 .40476 0 7.84375 ]
[-0.0125 .59524 -19 -7.84375 ]
[-0.0125 .59524 0 7.84375 ]
[-0.0125 .78571 -19 -7.84375 ]
[-0.0125 .78571 0 7.84375 ]
[-0.0125 .97619 -10 -7.84375 ]
[-0.0125 .97619 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -34.6875 -11.4063 ]
[-0.01875 .5 -19 11.4063 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .21429 m
.00625 .21429 L
s
gsave
-0.0125 .21429 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .40476 m
.00625 .40476 L
s
gsave
-0.0125 .40476 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .59524 m
.00625 .59524 L
s
gsave
-0.0125 .59524 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .78571 m
.00625 .78571 L
s
gsave
-0.0125 .78571 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .97619 m
.00625 .97619 L
s
gsave
-0.0125 .97619 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .2619 m
.00375 .2619 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .45238 m
.00375 .45238 L
s
0 .5 m
.00375 .5 L
s
0 .54762 m
.00375 .54762 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .7381 m
.00375 .7381 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -99.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .99375 m
.02381 1 L
s
.21429 .99375 m
.21429 1 L
s
.40476 .99375 m
.40476 1 L
s
.59524 .99375 m
.59524 1 L
s
.78571 .99375 m
.78571 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.07143 .99625 m
.07143 1 L
s
.11905 .99625 m
.11905 1 L
s
.16667 .99625 m
.16667 1 L
s
.2619 .99625 m
.2619 1 L
s
.30952 .99625 m
.30952 1 L
s
.35714 .99625 m
.35714 1 L
s
.45238 .99625 m
.45238 1 L
s
.5 .99625 m
.5 1 L
s
.54762 .99625 m
.54762 1 L
s
.64286 .99625 m
.64286 1 L
s
.69048 .99625 m
.69048 1 L
s
.7381 .99625 m
.7381 1 L
s
.83333 .99625 m
.83333 1 L
s
.88095 .99625 m
.88095 1 L
s
.92857 .99625 m
.92857 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .21429 m
1 .21429 L
s
.99375 .40476 m
1 .40476 L
s
.99375 .59524 m
1 .59524 L
s
.99375 .78571 m
1 .78571 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .5 m
1 .5 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.02381 .02381 m
.06244 .06244 L
.10458 .10458 L
.14415 .14415 L
.18221 .18221 L
.22272 .22272 L
.26171 .26171 L
.30316 .30316 L
.34309 .34309 L
.3815 .3815 L
.42237 .42237 L
.46172 .46172 L
.49955 .49955 L
.53984 .53984 L
.57861 .57861 L
.61984 .61984 L
.65954 .65954 L
.69774 .69774 L
.73838 .73838 L
.77751 .77751 L
.81909 .81909 L
.85916 .85916 L
.89771 .89771 L
.93871 .93871 L
.97619 .97619 L
s
.02381 .02381 m
.06244 .04234 L
.10458 .06077 L
.14415 .07638 L
.18221 .08984 L
.22272 .10249 L
.26171 .11305 L
.30316 .12251 L
.34309 .12993 L
.3815 .13548 L
.40095 .13771 L
.42237 .13969 L
.44268 .14113 L
.45178 .14164 L
.46172 .14209 L
.4671 .14229 L
.4721 .14245 L
.47727 .14259 L
.48196 .14269 L
.48658 .14276 L
.4887 .14279 L
.49093 .14281 L
.49332 .14283 L
.49438 .14284 L
.49552 .14285 L
.49675 .14285 L
.49789 .14285 L
.49859 .14286 L
.49925 .14286 L
.50049 .14286 L
.50163 .14286 L
.50286 .14285 L
.50401 .14285 L
.50508 .14284 L
.50754 .14283 L
.51014 .1428 L
.51268 .14277 L
.51504 .14274 L
.5204 .14264 L
.5293 .14241 L
.53882 .14207 L
.54906 .14159 L
.56016 .14096 L
.58032 .13947 L
.60019 .13759 L
.62123 .13514 L
.65912 .12956 L
.69946 .12197 L
.73829 .11305 L
.77956 .10183 L
Mistroke
.81932 .08932 L
.85757 .07573 L
.89827 .05958 L
.93745 .04239 L
.97619 .02381 L
Mfstroke
.02381 .02381 m
.06244 .06088 L
.10458 .09773 L
.14415 .12895 L
.18221 .15586 L
.22272 .18117 L
.26171 .20228 L
.30316 .22122 L
.34309 .23605 L
.3815 .24716 L
.40095 .2516 L
.42237 .25558 L
.44268 .25846 L
.45178 .25946 L
.46172 .26037 L
.4671 .26077 L
.4721 .26109 L
.47727 .26136 L
.48196 .26156 L
.48658 .26172 L
.4887 .26177 L
.49093 .26182 L
.49332 .26186 L
.49438 .26187 L
.49552 .26188 L
.49675 .26189 L
.49789 .2619 L
.49859 .2619 L
.49925 .2619 L
.50049 .2619 L
.50163 .2619 L
.50286 .2619 L
.50401 .26189 L
.50508 .26188 L
.50754 .26185 L
.51014 .2618 L
.51268 .26174 L
.51504 .26167 L
.5204 .26147 L
.5293 .261 L
.53882 .26032 L
.54906 .25938 L
.56016 .2581 L
.58032 .25513 L
.60019 .25136 L
.62123 .24647 L
.65912 .23532 L
.69946 .22013 L
.73829 .20229 L
.77956 .17984 L
Mistroke
.81932 .15484 L
.85757 .12766 L
.89827 .09536 L
.93745 .06098 L
.97619 .02381 L
Mfstroke
.02381 .02381 m
.06244 .07941 L
.10458 .13469 L
.14415 .18151 L
.18221 .22189 L
.22272 .25986 L
.26171 .29152 L
.30316 .31992 L
.34309 .34217 L
.3815 .35884 L
.40095 .3655 L
.42237 .37146 L
.44268 .37578 L
.45178 .37729 L
.46172 .37864 L
.4671 .37925 L
.4721 .37973 L
.47727 .38014 L
.48196 .38044 L
.48658 .38067 L
.4887 .38075 L
.49093 .38082 L
.49332 .38088 L
.49438 .3809 L
.49552 .38092 L
.49675 .38094 L
.49789 .38095 L
.49859 .38095 L
.49925 .38095 L
.50049 .38095 L
.50163 .38095 L
.50286 .38094 L
.50401 .38093 L
.50508 .38091 L
.50754 .38086 L
.51014 .38079 L
.51268 .3807 L
.51504 .3806 L
.5204 .3803 L
.5293 .3796 L
.53882 .37858 L
.54906 .37716 L
.56016 .37525 L
.58032 .37079 L
.60019 .36514 L
.62123 .3578 L
.65912 .34107 L
.69946 .31829 L
.73829 .29152 L
.77956 .25786 L
Mistroke
.81932 .22035 L
.85757 .17958 L
.89827 .13113 L
.93745 .07956 L
.97619 .02381 L
Mfstroke
.02381 .02381 m
.06244 .09795 L
.10458 .17165 L
.14415 .23408 L
.18221 .28792 L
.22272 .33854 L
.26171 .38076 L
.30316 .41863 L
.34309 .44829 L
.3815 .47051 L
.40095 .4794 L
.42237 .48734 L
.44268 .4931 L
.45178 .49512 L
.46172 .49692 L
.4671 .49773 L
.4721 .49836 L
.47727 .49892 L
.48196 .49932 L
.48658 .49962 L
.4887 .49973 L
.49093 .49983 L
.49332 .49991 L
.49438 .49993 L
.49552 .49996 L
.49675 .49998 L
.49789 .49999 L
.49859 .5 L
.49925 .5 L
.50049 .5 L
.50163 .49999 L
.50286 .49998 L
.50401 .49997 L
.50508 .49995 L
.50754 .49988 L
.51014 .49978 L
.51268 .49966 L
.51504 .49952 L
.5204 .49913 L
.5293 .4982 L
.53882 .49684 L
.54906 .49495 L
.56016 .4924 L
.58032 .48645 L
.60019 .47892 L
.62123 .46913 L
.65912 .44683 L
.69946 .41645 L
.73829 .38076 L
.77956 .33587 L
Mistroke
.81932 .28587 L
.85757 .2315 L
.89827 .16691 L
.93745 .09814 L
.97619 .02381 L
Mfstroke
.02381 .02381 m
.06244 .11648 L
.10458 .20861 L
.14415 .28665 L
.18221 .35394 L
.22272 .41722 L
.26171 .46999 L
.30316 .51733 L
.34309 .55441 L
.3815 .58219 L
.40095 .59329 L
.42237 .60323 L
.44268 .61042 L
.45178 .61294 L
.46172 .6152 L
.4671 .61621 L
.4721 .617 L
.47727 .61769 L
.48196 .61819 L
.48658 .61857 L
.4887 .61871 L
.49093 .61883 L
.49332 .61893 L
.49438 .61896 L
.49552 .61899 L
.49675 .61902 L
.49789 .61904 L
.49859 .61904 L
.49925 .61905 L
.50049 .61905 L
.50163 .61904 L
.50286 .61903 L
.50401 .61901 L
.50508 .61898 L
.50754 .6189 L
.51014 .61878 L
.51268 .61863 L
.51504 .61845 L
.5204 .61796 L
.5293 .61679 L
.53882 .61509 L
.54906 .61273 L
.56016 .60955 L
.58032 .60211 L
.60019 .5927 L
.62123 .58047 L
.65912 .55258 L
.69946 .51461 L
.73829 .47 L
.77956 .41389 L
Mistroke
.81932 .35138 L
.85757 .28343 L
.89827 .20268 L
.93745 .11673 L
.97619 .02381 L
Mfstroke
.02381 .02381 m
.06244 .13501 L
.10458 .24557 L
.14415 .33922 L
.18221 .41997 L
.22272 .4959 L
.26171 .55923 L
.30316 .61604 L
.34309 .66054 L
.3815 .69386 L
.40095 .70719 L
.42237 .71911 L
.44268 .72775 L
.45178 .73077 L
.46172 .73348 L
.4671 .73469 L
.4721 .73564 L
.47727 .73647 L
.48196 .73707 L
.48658 .73753 L
.4887 .73769 L
.49093 .73784 L
.49332 .73795 L
.49438 .738 L
.49552 .73803 L
.49675 .73806 L
.49789 .73808 L
.49859 .73809 L
.49925 .73809 L
.50049 .73809 L
.50163 .73809 L
.50286 .73807 L
.50401 .73804 L
.50508 .73801 L
.50754 .73792 L
.51014 .73777 L
.51268 .73759 L
.51504 .73738 L
.5204 .73678 L
.5293 .73539 L
.53882 .73335 L
.54906 .73051 L
.56016 .72669 L
.58032 .71778 L
.60019 .70647 L
.62123 .6918 L
.65912 .65834 L
.69946 .61277 L
.73829 .55924 L
.77956 .49191 L
Mistroke
.81932 .4169 L
.85757 .33535 L
.89827 .23846 L
.93745 .13531 L
.97619 .02381 L
Mfstroke
.02381 .02381 m
.06244 .15355 L
.10458 .28253 L
.14415 .39179 L
.18221 .486 L
.22272 .57459 L
.26171 .64847 L
.30316 .71474 L
.34309 .76666 L
.3815 .80554 L
.40095 .82108 L
.42237 .83499 L
.44268 .84507 L
.45178 .8486 L
.46172 .85176 L
.4671 .85316 L
.4721 .85428 L
.47727 .85524 L
.48196 .85595 L
.48658 .85648 L
.4887 .85667 L
.49093 .85684 L
.49332 .85698 L
.49438 .85703 L
.49552 .85707 L
.49675 .8571 L
.49789 .85713 L
.49859 .85714 L
.49925 .85714 L
.50049 .85714 L
.50163 .85713 L
.50286 .85711 L
.50401 .85708 L
.50508 .85705 L
.50754 .85693 L
.51014 .85676 L
.51268 .85655 L
.51504 .85631 L
.5204 .85561 L
.5293 .85399 L
.53882 .85161 L
.54906 .8483 L
.56016 .84384 L
.58032 .83344 L
.60019 .82025 L
.62123 .80313 L
.65912 .76409 L
.69946 .71093 L
.73829 .64848 L
.77956 .56992 L
Mistroke
.81932 .48241 L
.85757 .38728 L
.89827 .27423 L
.93745 .15389 L
.97619 .02381 L
Mfstroke
.02381 .02381 m
.06244 .17208 L
.10458 .31949 L
.14415 .44435 L
.18221 .55203 L
.22272 .65327 L
.26171 .73771 L
.30316 .81345 L
.34309 .87278 L
.3815 .91721 L
.40095 .93498 L
.42237 .95088 L
.44268 .96239 L
.45178 .96643 L
.46172 .97003 L
.4671 .97164 L
.4721 .97292 L
.47727 .97402 L
.48196 .97482 L
.48658 .97543 L
.4887 .97565 L
.49093 .97584 L
.49332 .976 L
.49438 .97606 L
.49552 .97611 L
.49675 .97615 L
.49789 .97617 L
.49859 .97618 L
.49925 .97619 L
.50049 .97619 L
.50163 .97618 L
.50286 .97616 L
.50401 .97612 L
.50508 .97608 L
.50754 .97595 L
.51014 .97576 L
.51268 .97552 L
.51504 .97524 L
.5204 .97444 L
.5293 .97258 L
.53882 .96986 L
.54906 .96608 L
.56016 .96099 L
.58032 .9491 L
.60019 .93403 L
.62123 .91446 L
.65912 .86985 L
.69946 .80909 L
.73829 .73771 L
.77956 .64794 L
Mistroke
.81932 .54793 L
.85757 .4392 L
.89827 .31 L
.93745 .17248 L
.97619 .02381 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{275.938, 275.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006M0001WB000`400?l00000o`00003oo`3ooonN
0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN
0?ooo`00k@3oool01@3ooml0W4P000000000B9`0gooo0:/0oooo003^0?ooo`030?oOW01804P0W=oo
0:`0oooo003T0?ooo`050;md0000000007Bo0?ooo`3OW4P00P0000001P00B9`0gooo0?ooo`3ogi`0
B01809cOoj`0oooo003T0?ooo`080?oog`2LB7@0_ooo0?ooo`3ooml0W4P00018W03Oool20?ooo`03
0?oOW01804P0W=oo0:`0oooo003U0?ooo`060?oo_`1dB9`0gooo0;md000007@0_ooo0P3oool0103o
okl0M0000000B02Lgon/0?ooo`00iP3oool0103ogi`0M4Q80000001d_ol40?ooo`030?oOW01804P0
W=oo0:`0oooo003V0?ooo`030?oo_`1d0000B9cO0;@0oooo003U0?ooo`050?oog`2LB00004RL09ad
B02Lgol0/`3oool00>D0oooo00H0_g@00000B02Lgol0oooO09a8M02oool30?ooo`030?oo_`1d0000
M;oo0:`0oooo003S0?ooo`090?oog`2LB000000000000000M;l0okmd0000000007@0_ooo0;40oooo
003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo
003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo
003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo
003o0?oooih0oooo00100?ooo`050?oOW018000000000000M02oool0>03oool01@3ogi`0B0000000
000007@0_ooo00<0oooo00D0okmd0000001d_ol0oooo0;md00060000000304RLg`3oool0oooo02d0
oooo00D0omnL04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a8
0000B9`0gooo<03oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol00`3o
ool01@3ogi`0B000000000000000M;oo0300oooo00D0omnL04P000000000001d0;ooo`030?ooo`03
0?noM0000000M;oo00<0oooo00D0gia8000000000000000004RLg`0g0?ooo`060;md000000000000
00000000B9`0gooo1P3oool003l0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo03H0oooo
00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool00`3O
W4P0000000000003000000030018W03Oool0oooo02`0oooo00L0oono07@0001d_ol0oooo0?noM000
07@0_ooo0080oooo00<0okmd0000001d_ol01@3oool0103ooml0W4P00018W03Oool_0?ooo`070?oo
_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM0000000M;oo0080oooo00L0omnL04P0
0018W=l0oooo0?oo_`1d0000M;oo02h0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080
oooo00<0okmd0000001d_ol00P3oool01`3OW4P0000007Boo`3oool0oooO09a80018W=l0=`3oool0
0`3ogi`0B00007Boo`080?ooo`00?`3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo
03D0oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030=nLB018W=l0oooo
0080oooo00<0giad09cOo`3oool0;03oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo
00T0oooo00@0oooO09a80000B9`0gooo;`3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0
oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL0=ooo`0]0?ooo`030;md0000B9`0
gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3ooml0W4P0001d_`030?ooo`030?noM000B9`0
gooo03H0oooo00<0omnL04P0001d_ol0203oool003h0oooo00<0oono07@00018W=l00`3oool00`3O
W4P0001d0;ooo`0d0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool00`3O
W4P0M;oo0?ooo`0_0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`2o
M0000000000000050000000307Boo`3oool0oooo02/0oooo00<0oono07@00018W=l00`3oool00`3O
W4P0001d0;ooo`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0;03oool00`3o
okl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0_g@0001d_`3oool00P3oool00`2o
M00004RL0=ooo`0f0?ooo`030?oOW0180000M;oo00P0oooo000n0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol0=03oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0
oooo00<0_gA809cOo`3oool0;P3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0
oooo00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL0=ooobh0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0;03o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0omnL04P0M02oool0oooo
0;md00000000M;oo03L0oooo00<0omnL04P0001d_ol0203oool003h0oooo00<0omnL04P0001d_ol0
0`3oool00`3o_g@0001809cOo`0d0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0
2@3oool00`3ooml0W4Qd0;ooo`0^0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0
1P3oool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03Oool0;P3oool00`3ogi`0B00007Boo`030?oo
o`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool00`2oM000001809cOo`0/0?oo
o`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool01@3ookl0M4Q804P000000000
B9cO03P0oooo00<0omnL04P0001d_ol0203oool003h0oooo00<0omnL04P0001d_ol00`3oool00`3o
_g@0001809cOo`0d0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3o
_g@007Bo0?ooo`0]0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3o
oml0W4Qd0;ooo`3ooml0W4P00018W03Oool0;P3oool00`3ogi`0B00007Boo`030?ooo`030?noM000
04P0W=oo00D0oooo00P0oono07@000000000B9cO0?ooo`3o_g@00000001d_bd0oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`040?oOW01800000000001d_cT0oooo00<0omnL
04P0001d_ol0203oool003h0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0d0?oo
o`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3ookl0M01809cOo`0]0?oo
o`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool01P3ogi`0B7Bo0?oog`2LB000
04RL0=ooobh0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`030;md0000
B9`0_ia80080000000<004RL0=ooo`3oool0;03oool00`3ogi`0B00007Boo`030?ooo`030?noM000
04P0W=oo00H0oooo00H0omnL04P0000007@0_ooo0?noM000M;lh0?ooo`030?oOW0180000M;oo00P0
oooo000n0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0=03oool00`3ookl0M000
04RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0oono07@00018W=l0;@3oool00`3ookl0M000
04RLg`030?ooo`030=nLB00007@0_ooo00P0oooo00D0gia807Bog`2LB00004RL0=ooo`0^0?ooo`03
0?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`3ogi`0B00007Boo`0a0?ooo`03
0?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM000001d0;ooo`020?ooo`03
0;md0018W=l0oooo03H0oooo00<0omnL04P0001d_ol0203oool003l0oooo00<0gia80018W03Oool0
0P3oool00`2oM00007Bo0?ooo`0e0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool0
1@3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW0180000B9cO02h0oooo00<0gia80018W03Oool0
0P3oool00`2oM00007Bo0?ooo`080?ooo`050?oog`2LB4P0B4P00018W03Oool0;`3oool00`3OW4P0
04RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000B02Lgol0<@3oool00`3OW4P0
04RL0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo00<0_g@00018W03Oool00P3oool00`3OW4P0
07Bo0?ooo`0f0?ooo`030?oOW0180000M;oo00P0oooo000o0?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`0f0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`060?ooo`080?oog`2L
B4P0W=oo0?ooo`3ookl0M0000000M02oool^0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;oo
o`0:0?ooo`040?oOW018000004RL0=ooobl0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo
00T0oooo00<0okmd00000000M;l0<03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool01`3o
ool01`3o_g@0000007Boo`3oool0oono07@0001d_ol0=@3oool01@3ooml0W4P0000000000000M;oo
00P0oooo00100?ooo`050?oo_`1d000000000000M02oool0>03oool01@3ookl0M0000000000007@0
_ooo00P0oooo00H0oooO09a80000000000000000M02oool`0?ooo`050?oo_`1d000000000000M02o
ool0303oool00`3OW4P004RL0=ooo`0`0?ooo`050?oo_`1d000000000000M02oool02`3oool01@3o
oml0W4P00000000007@0_ooo02h0oooo00D0oono07@000000000001d0;ooo`090?ooo`050?noM000
0000000000000018W=l0>03oool00`3o_g@0000007Boo`080?ooo`00o`3ooonN0?ooo`00o`3ooonN
0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00o`3ooonN
0?ooo`00o`3ooonN0?ooo`00o`3ooonN0?ooo`00>P3ooooo000006@00000000j0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00D0oooo0@00000003X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool01@3oool100000000>P3oool00`00
0000oooo0?ooo`3o0?ooof00oooo0@00000002`0oooo00D0omnL04P000000000001d0;ooo`090?oo
o`030000003oool0oooo0?l0ooooH03oool100000000:`3oool01`3ookl0M00007Boo`3oool0okmd
0000M02oool0203oool00`000000oooo0?ooo`3o0?ooof00oooo0@00000002/0oooo00<0_g@00018
W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo0?l0ooooH03oool10000
0000:P3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00L0oooo00<000000?ooo`3o
ool0o`3ooomP0?ooo`400000000Z0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0
1`3oool00`000000oooo0?ooo`3o0?ooof00oooo0@00000002X0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`070?ooo`<000001P3oool200000?l0ooooC`3oool2000000D0oooo0`00
000002X0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`030000003oool0
oooo00H0oooo1000003o0?oood/0oooo100000070?ooo`400000000Z0?ooo`030?oOW0180000M;oo
00<0oooo00<0okmd0000B02Lgol01`3oool00`000000oooo0?ooo`060?ooo`<0000000<0oooo0000
00000000o`3ooom70?ooo`80000000<0oooo000000000000203oool100000000:P3oool00`3ookl0
M00004RLg`030?ooo`030=nLB00007@0_ooo00L0oooo00<000000?ooo`3oool01`3oool300000080
oooo0P00003o0?oood80oooo0`0000020?ooo`<00000203oool100000000:`3oool00`3OW4P004RL
0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<000000?ooo`3oool01`3oool4000000<0oooo
0P00003o0?oooch0oooo0P0000040?ooo`@00000203oool100000000:`3oool01`3ookl0M00007Bo
o`3oool0okmd0000M02oool0203oool00`000000oooo0?ooo`070?ooo`<0000000<0oooo0000003o
ool00`3oool200000?l0oooo>P3oool2000000D0oooo1@0000080?ooo`400000000/0?ooo`050?oo
_`1d000000000000M02oool02@3oool00`000000oooo0?ooo`070?ooo`@0000000<0oooo0000003o
ool0103oool300000?l0oooo=03oool3000000H0oooo00<000000?ooo`0000000P0000090?ooo`40
0000000j0?ooo`030000003oool0oooo00P0oooo0P000000103oool000000?ooo`0000070?ooo`80
0000o`3oool`0?ooo`8000001`3oool2000000030?ooo`0000000000008000002@3oool100000000
>P3oool00`000000oooo0?ooo`080?ooo`@000000P3oool00`000000oooo0?ooo`060?ooo`800000
o`3oool/0?ooo`800000203oool01@000000oooo0?ooo`000000oooo00<000002@3oool100000000
>P3oool00`000000oooo0?ooo`080?ooo`<0000000D0oooo0000003oool0oooo000000090?ooo`80
0000o`3ooolW0?ooo`<000002@3oool01@000000oooo0?ooo`000000oooo00@000002@3oool10000
0000>P3oool00`000000oooo0?ooo`080?ooo`@0000000D0oooo0000003oool0oooo0000000:0?oo
o`800000o`3ooolS0?ooo`8000002`3oool01P000000oooo0?ooo`3oool000000?ooo`<000002P3o
ool100000000>P3oool00`000000oooo0?ooo`090?ooo`<000000P3oool010000000oooo0?ooo`00
000;0?ooo`800000o`3ooolO0?ooo`800000303oool01P000000oooo0?ooo`3oool000000?ooo`@0
00002P3oool100000000>P3oool00`000000oooo0?ooo`090?ooo`@0000000<0oooo0000003oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`800000o`3ooolJ0?ooo`<000003@3oool01@000000oooo
0?ooo`3oool000000080oooo1000000:0?ooo`400000000j0?ooo`030000003oool0oooo00T0oooo
100000020?ooo`050000003oool0oooo0?ooo`0000003@3oool300000?l0oooo5@3oool2000000l0
oooo00D000000?ooo`3oool0oooo000000020?ooo`@000002`3oool100000000>P3oool00`000000
oooo0?ooo`090?ooo`D000000P3oool01@000000oooo0?ooo`3oool0000000l0oooo0`00003o0?oo
oa00oooo0P00000@0?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000oooo0`00000;
0?ooo`400000000j0?ooo`030000003oool0oooo00X0oooo100000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03`3oool200000?l0oooo2`3oool300000140oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`02000000030?ooo`000000000000/0oooo0@00000003X0
oooo0`00000:0?ooo`<0000000D0oooo0000003oool0oooo000000040?ooo`8000004@3oool30000
0?l0oooo1P3oool200000180oooo0P0000040?ooo`050000003oool0oooo0000003oool01000000:
0?ooo`800000000j0?ooo`030000003oool0oooo00X0oooo1@0000030?ooo`030000003oool0oooo
0080oooo0P00000C0?ooo`<00000o`3oool10?ooo`8000004`3oool00`000000oooo0?ooo`030?oo
o`060000003oool0oooo0?ooo`000000oooo0`00000<0?ooo`400000000j0?ooo`030000003oool0
oooo00X0oooo100000001@3oool000000?ooo`3oool0000000D0oooo0P00000E0?ooo`<00000nP3o
ool3000001@0oooo00<000000?ooo`3oool0103oool01`000000oooo0?ooo`000000oooo0000003o
ool00P00000<0?ooo`400000000j0?ooo`030000003oool0oooo00/0oooo0P0000000`3oool00000
000000030?ooo`030000003oool0oooo00<0oooo0P00000G0?ooo`<00000m03oool3000001H0oooo
00<000000?ooo`3oool0103oool01P000000oooo0?ooo`3oool000000?ooo`@00000303oool10000
0000>P3oool00`000000oooo0?ooo`0;0?ooo`@0000000<0oooo0000003oool00P3oool00`000000
oooo0?ooo`030?ooo`8000006@3oool200000?00oooo0P00000H0?ooo`030000003oool0oooo00@0
oooo00P000000?ooo`3oool0oooo0000003oool000000?ooo`<00000303oool100000000>P3oool0
0`000000oooo0?ooo`0;0?ooo`<0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`04
0?ooo`8000006P3oool300000>X0oooo0`00000I0?ooo`030000003oool0oooo00D0oooo00H00000
0?ooo`3oool0oooo0000003oool2000000030?ooo`000000oooo00`0oooo0@00000003X0oooo00<0
00000?ooo`3oool02`3oool3000000040?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0
103oool2000001`0oooo0`00003T0?ooo`<000006P3oool2000000L0oooo00P000000?ooo`3oool0
oooo0000003oool000000?ooo`<000003@3oool100000000>P3oool00`000000oooo0?ooo`0<0?oo
o`@0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`040?ooo`<000007@3oool30000
0=h0oooo0`00000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0000003oool3000000d0oooo0@00000003X0oooo00<000000?ooo`3oool0303oool30000
00040?ooo`000000oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000O
0?ooo`@00000eP3oool4000001h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`060000003oool000000?ooo`000000oooo0P00000=0?ooo`400000000j0?ooo`030000003o
ool0oooo00`0oooo0`000000103oool000000?ooo`0000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`0000008P3oool300000=00oooo0`00000Q0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool010000000oooo0000003oool3000000h0oooo0@00000003X0oooo
00<000000?ooo`3oool0303oool020000000oooo000000000000oooo0000003oool00000103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0000002@0oooo100000380?ooo`@000008`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool000000?oo
o`03000000h0oooo0@00000003X0oooo00<000000?ooo`3oool03@3oool3000000050?ooo`000000
oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0000002L0oooo0`00
00320?ooo`<000009@3oool2000000T0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?oo
o`000000oooo0000003oool00P00000>0?ooo`400000000j0?ooo`030000003oool0oooo00d0oooo
0`0000001@3oool000000?ooo`3oool0000000D0oooo00<000000?ooo`3oool01@3oool010000000
oooo00000000000X0?ooo`@00000^P3oool4000002L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool00`00000?0?ooo`400000000j0?oo
o`030000003oool0oooo00d0oooo0P000000103oool000000?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000[0?ooo`<00000]03o
ool3000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo0`00000?0?ooo`400000000j0?ooo`030000003oool0oooo00d0oooo00H0
00000?ooo`00000000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool010000000oooo0?ooo`00000]0?ooo`@00000[03oool4000002`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`070000003oool0oooo0000003oool000000?oo
o`02000000l0oooo0@00000003X0oooo00<000000?ooo`3oool03P3oool300000080oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000300oooo
1000002T0?ooo`@00000;P3oool2000000/0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool00000000000l0oooo0@00000003X0oooo00<000000?ooo`3o
ool03P3oool2000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00800000<P3oool4000009`0oooo1000000a0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
00000080oooo0`00000@0?ooo`400000000j0?ooo`<000003P3oool01P000000oooo000000000000
oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`050000003o
ool0oooo0?ooo`000000=@3oool500000980oooo1@00000d0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool020000000oooo0?ooo`3oool000000?ooo`000000oooo0P00000?
0?ooo`800000000j0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`00000000000P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?oo
o`3oool0000003T0oooo1@0000280?ooo`D00000=`3oool2000000d0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`0000000000403oool10000
0000>P3oool00`000000oooo0?ooo`0?0?ooo`80000000@0oooo0000003oool000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0oooo0P00000l
0?ooo`D00000O`3oool4000003/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`04
0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000403oool10000
0000>P3oool00`000000oooo0?ooo`0?0?ooo`80000000D0oooo0000003oool0oooo000000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03h0oooo1@00001e0?ooo`D00000?P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
000000000140oooo0@00000003X0oooo00<000000?ooo`3oool03`3oool010000000oooo00000000
00020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@P3oool6000006T0oooo1P0000110?ooo`800000
3`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo00000000000A0?ooo`400000000j0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo0P0000180?ooo`H00000G03oool7000004H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0000003oool000000140oooo0@00000003X0oooo00<000000?ooo`3oool0403o
ool2000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;0?ooo`L00000
CP3oool7000004`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool000000?ooo`0200000180oooo0@00000003X0oooo
00<000000?ooo`3oool0403oool010000000oooo0000000000030?ooo`050000003oool0oooo0?oo
o`0000001`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P00001B0?oo
o`L00000@03oool700000540oooo0P00000@0?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0000000000180oooo0@00000003X0oooo00<00000
0?ooo`3oool0403oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1F0?oooa<000006@3ooolD000005L0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool200000180oooo0@00000003X0oooo00<000000?ooo`3oool0403oool01@000000oooo0000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0103oool2000006T0oooo6@00001Y0?ooo`8000004P3oool00`000000
oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0000003oool0
00000180oooo0@00000003X0oooo00<000000?ooo`3oool04@3oool200000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01@3oool200000>P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool2000001<0oooo0@00
000003X0oooo00<000000?ooo`3oool04@3oool01@000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo
0P00000C0?ooo`400000000j0?ooo`030000003oool0oooo0140oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo0P00003R0?ooo`8000004`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000004`3oool100000000>P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool00000
0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3N0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`0000004`3oool100000000>P3oool00`000000oooo0?ooo`0B
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`800000g03o
ool2000001D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool2000001@0oooo0@00000003X0oooo00<000000?ooo`3oool04P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3H0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000001@0oooo0@000000
03X0oooo00<000000?ooo`3oool04P3oool00`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool200000=H0oooo0P00000F0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`000000503o
ool100000000>P3oool300000180oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`0000004`3oool200000000>P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool000000080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`800000d03oool2000001L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0000000E0?ooo`400000000j0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo0P00003<0?oo
o`800000603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0000001D0oooo0@00000003X0oooo00<000000?oo
o`3oool04`3oool01P000000oooo0?ooo`000000oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`380?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0000000E0?ooo`400000000j0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo0P0000360?ooo`8000006P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0000001H0oooo0@00000003X0oooo00<000000?ooo`3oool0503oool00`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`320?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0000000F0?ooo`400000000j0?ooo`03
0000003oool0oooo01@0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00`0oooo0P0000300?ooo`8000006`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000001H0oooo
0@00000003X0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool03@3oool200000;`0oooo0P00000L0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000005P3oool100000000>P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`800000^03oool20000
01d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00H000000?ooo`3oool000000?ooo`00000G0?ooo`400000000j0?ooo`030000003oool0
oooo01D0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
00005`3oool100000000>P3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`800000/P3oool2000001h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0E0?ooo`400000000j0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0100oooo0P00002^0?ooo`8000007`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo
000001P0oooo0@00000001h0oooo00D0omnL04P000000000001d0;ooo`030?ooo`050?noM0000000
M;oo0?ooo`2oM0001P0000000`18W=l0oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo
0P00002Z0?ooo`800000803oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000603oool10000
00007@3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`02
0?ooo`030=nLB0000000000000<0000000<004RL0=ooo`3oool01P3oool00`000000oooo0?ooo`0F
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0B0?ooo`800000YP3oool200000240oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0F0?ooo`400000000M0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030=nLM02Lgol0oooo00H0oooo00<000000?ooo`3oool05P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
4`3oool200000:80oooo0P00000R0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool05P3oool100000000703oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00P0oooo
00<0gia807Boo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`800000WP3oool2000002<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00L000000?ooo`3oool0oooo0000003oool0000001T0oooo0@00000001`0oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@0001809cOo`090?ooo`030;mdB02Lgol0oooo00T0oooo00<000000?oo
o`3oool05`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool05@3oool3000009P0oooo0`00000T0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool05`3oool100000000703oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00T0oooo00<0oooO09a8M02oool02@3oool3000001L0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo0P00002D0?ooo`8000009P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool05@3oool300000000703o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo00<0okmd001d_`3oool0203o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0H0?ooo`800000T03oool2000002L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo
0000003oool0000001X0oooo0@00000001`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`0:0?ooo`030?oo_`1d04P0W=oo00P0oooo00<000000?ooo`3oool0603oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06@3oool3000008X0
oooo0`00000X0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0603oool10000
0000703oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00X0oooo00<0oono07@00018
W=l0203oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0K0?ooo`800000Q@3oool3000002X0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01P0oooo0@00000001d0oooo00<0gia80018
W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?noW02Lgol0oooo0080oooo00<0omnL04P0
0018W=l0203oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`<00000P03oool2000002`0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01P0oooo0@00000001d0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo00H0oooo00P0oooO09a8B02Lgol0oooo0?oo_`1d0000001d
0;ooo`P0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool07P3oool2000007/0oooo0`00000]0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool06@3oool1000000007P3oool01@3ookl0M0000000
000007@0_ooo00P0oooo00H0oooO09a80000000000000000M02oool90?ooo`030000003oool0oooo
01T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01l0oooo0`00001e0?ooo`<00000;`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool06@3oool100000000>P3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Q0?ooo`800000L03o
ool300000340oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01T0oooo
0@00000003X0oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool08P3oool3000006T0oooo1000000c0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0J0?ooo`400000000j0?ooo`030000
003oool0oooo01X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02@0oooo0`00001S0?ooo`<00000=@3oool200000180oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0J0?ooo`400000000j0?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0403oool2000000`0oooo00<000000?ooo`3oool09P3oool4000005/0oooo1000000g0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0J0?ooo`400000000j0?oo
o`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0:@3oool3000005D0oooo0`00000j0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0J0?ooo`400000000j0?ooo`030000003oool0
oooo01/0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02/0oooo1@00001<0?ooo`@00000?03oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool06`3oool100000000>P3oool00`000000oooo0?ooo`0K0?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0_0?ooo`D00000
@P3oool5000003l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000M0?ooo`40
0000000j0?ooo`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool4000003L0oooo1`0000130?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0K0?ooo`400000000j0?ooo`03
0000003oool0oooo01`0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo03H0oooo1P00000[0?ooo`H00000B@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0703oool100000000>P3oool00`000000oooo0?ooo`0L0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0k
0?ooo`d000005`3oool7000004h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000N0?ooo`400000000j0?ooo`<00000703oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`170?oooaL00000E03oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool06`3oool200000000>P3oool00`000000oooo0?oo
o`0M0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo01<0oooo0P00000;0?ooo`030000003oool0oooo0:l0oooo
0P00000E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000007P3oool100000000>P3oool00`000000oooo
0?ooo`0M0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000007`3oool10000
0000>P3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000001l0oooo0@00000003X0oooo00<000000?ooo`3oool07@3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2Y
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000O0?ooo`400000000j
0?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool2000000X0oooo00<0
00000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000200oooo
0@00000003X0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo0000000P0?ooo`400000000j0?ooo`030000003oool0oooo01h0oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0XP3oool2000001P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000P0?ooo`400000000j0?ooo`03
0000003oool0oooo01l0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool05`3oool2000000T0oooo00<000000?oo
o`3oool0X03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000803oool1
00000000>P3oool00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool000000240oooo0@00000003X0oooo00<000000?ooo`3oool07`3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`2L0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`400000
000j0?ooo`030000003oool0oooo01l0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0H0?ooo`800000
203oool00`000000oooo0?ooo`2I0?ooo`8000006P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000240
oooo0@00000003X0oooo00<000000?ooo`3oool0803oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo0000000R0?ooo`400000000j0?ooo`030000003oool0oooo0200
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0U@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000008P3oool1
00000000>P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool06P3oool2000000L0oooo00<000000?ooo`3oool0TP3oool2000001/0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`400000000j0?ooo`030000003oool0oooo0240
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0803oool100000000>P3oool00`000000oooo0?ooo`0Q0?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0703oool2000000H0oooo00<000000?ooo`3oool0S@3oool2000001d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo0000000S0?ooo`400000000j0?ooo`<000008@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?oo
o`800000000j0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0R@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool100000000
>P3oool00`000000oooo0?ooo`0R0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool07@3oool2000000D0
oooo00<000000?ooo`3oool0QP3oool2000001h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000T0?oo
o`400000000j0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Q03oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool100000000
>P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
7`3oool2000000@0oooo00<000000?ooo`3oool0P@3oool200000200oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0R0?ooo`400000000j0?ooo`030000003oool0oooo02<0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0P0?ooo`8000000`3oool00`000000oooo0?ooo`1n0?ooo`800000
8@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000002D0oooo0@00000003X0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0240oooo0P0000020?ooo`030000
003oool0oooo07/0oooo0P00000R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
8`3oool100000000>P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool08P3oool2000000030?ooo`000000oooo07X0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo0@00000003X0oooo00<00000
0?ooo`3oool0903oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02@0oooo0`00001h0?ooo`800000903o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo0@00000003X0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02D0oooo0P00001e
0?ooo`8000009@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo0@000000
03X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
02H0oooo0P00001a0?ooo`8000009P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02@0oooo0@00000003X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo02H0oooo0`00001]0?ooo`8000009`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02@0oooo0@00000003X0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`0000000000J@3oool2000002P0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`400000000j0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00800000I@3oool2000002T0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0U0?ooo`400000000j0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo0?ooo`800000H03oool3000002/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`400000000j0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0080oooo0P00001L0?ooo`800000;@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02H0oooo0@00000003X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00`3oool2000005P0oooo0P00000^
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool100000000>P3oool30000
02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00@0oooo0`00001B0?ooo`<00000;`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02D0oooo0P00000003X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool01P3oool2000004`0oooo1000000a0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool09P3oool100000000>P3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`070?ooo`800000A`3oool3000003@0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0W0?ooo`400000000j0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo0`0000100?ooo`@00000=P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo0@00000003X0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool02P3oool4000003T0oooo0`00000i0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09`3oool100000000>P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0=0?ooo`H00000;`3oool40000
03`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`400000000j0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0180oooo1@00000V0?ooo`@00000?`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02P0oooo0@00000003X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool05P3oool8000001L0oooo
1`0000120?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool100000000>P3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0M0?oooaL00000B03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02T0oooo0@00000003X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02T0oooo0@00000003X0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo0@00000001h0oooo00D0omnL04P00000
0000001d0;ooo`030?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo203oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:P3oool1
000000007@3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Bo
o`050?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02X0oooo0@00000001d0oooo00<0_g@00018W03Oool00P3o
ool00`2oM00007Bo0?ooo`090?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
LP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02X0oooo0@00000001`0oooo00<0
oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030;md00000000000000D0000000<0
M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0:P3oool100000000703oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00D0oooo00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL0=ooo`P0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0F0?ooo`800000:03oool00`000000oooo0?ooo`1]0?ooo`80
00005`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0[0?ooo`400000000L0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol01P3oool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03Oool0203oool30000
02`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`<00000000L0?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P0
0018W03Oool0203oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0:`3oool100000000703oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00L0oooo00H0omnL04Qd_`3ooml0W4P00018W03Oool80?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0/0?ooo`400000000L0?ooo`030?oo_`1d0000
B9cO00<0oooo00<0gia80000M02oool0203oool01@3OW4P0M;oO09a80000B9`0gooo00P0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02`0oooo0@00
000001d0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`050?oog`2LB4P0
B4P00018W03Oool0203oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0;03oool1000000007@3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool0
2P3oool0103ogi`0B0000018W03Oool80?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0]0?ooo`400000000N0?ooo`050?oo_`1d000000000000M02o
ool0303oool00`3OW4P004RL0=ooo`080?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool06@3oool2000002L0oooo00<000000?ooo`3oool0GP3oool2000001/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0;@3oool100000000>P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0;@3oool100000000>P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0;@3oool100000000>P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo01/0oooo0P00000V0?ooo`030000003oool0oooo05L0oooo0P00000L
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02h0oooo0@00000003X0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo0@00000003X0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0DP3oool2000001h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0;P3oool100000000>P3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01d0oooo0P00000U0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0_0?ooo`400000000j0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0_0?ooo`400000000j
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo04/0oooo0P00000P0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02l0oooo0@000000
03X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0O0?ooo`800000903oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<03oool10000
0000>P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`160?ooo`8000008P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0`0?ooo`40
0000000j0?ooo`<00000<@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0P0?ooo`8000008`3oool00`000000oooo
0?ooo`130?ooo`8000008`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0_0?ooo`800000000j0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool08@3oool200000280oooo00<000000?ooo`3oool0@03o
ool2000002@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0<@3oool100000000>P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<@3oool100000000>P3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0oooo0P00000Q0?ooo`030000003oool0oooo
03/0oooo0P00000V0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0380oooo0@00000000T0oooo00<0_gAd0;ooo`3o
ool0103oool00`2oM7@0_ooo0?ooo`0W0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03P0oooo0P00000W0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0380oooo0@00000000T0oooo00<0_g@004RLg`3oool00`3oool00`3OW4P0001d
0;ooo`0X0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0903oool200000200oooo
00<000000?ooo`3oool0=@3oool2000002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0<P3oool1000000002@3o
ool02@2oM00000000000M02oool0oooO09a80018W=l0gibL0;ooo`0X0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool09P3oool2000001l0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo03<0oooo0@00000000T0oooo00H0_ibL0=oOW018
000000000000B02Lgol[0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09`3oool2
000001h0oooo00<000000?ooo`3oool0<03oool2000002X0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<`3oool1
000000002@3oool00`2oM7@0_mnL04P00002000000040000B02Lgol0gibL0;ooobP0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0X0?ooo`8000007@3oool00`000000oooo0?ooo`0]
0?ooo`800000:`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0c0?ooo`40000000090?ooo`030;md0000B9`0gooo
0080oooo00@0_g@00000000007@0_ooo:03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo02T0oooo0P00000L0?ooo`030000003oool0oooo02X0oooo0P00000/0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo03@0oooo0@00000000T0oooo00<0_gA809cOo`3oool00`3oool00`3o_g@0001d0;ooo`0X0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0:P3oool3000001X0oooo00<000000?oo
o`3oool09`3oool2000002d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=03oool1000000002@3oool00`2oW9`0
gooo0?ooo`040?ooo`030=nLW02oool0oooo02L0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0]0?ooo`8000006@3oool00`000000oooo0?ooo`0R0?ooo`@00000;P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0e0?ooo`400000000j0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
;P3oool3000001L0oooo00<000000?ooo`3oool07P3oool300000340oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
=@3oool1000000003P3oool00`2oW9`0gooo0?ooo`020?ooo`030=nLW02oool0oooo02@0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0`0?ooo`<000005@3oool00`000000oooo0?oo
o`0I0?ooo`@00000<`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0e0?ooo`400000000:0?ooo`050?oo_`1d04P0
W=oo0?oo_`1d0000100000000`0007@0_ooo0?ooo`0T0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0<P3oool400000180oooo00<000000?ooo`3oool0503oool4000003H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0=P3oool1000000004`3oool00`3OW9`0_ooo0?ooo`0T0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0=@3oool6000000d0oooo00<000000?ooo`3oool0403oool3
000003X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0=P3oool100000000>P3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo03X0oooo1@0000090?ooo`030000003oool0oooo00P0oooo1`00000l0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo03H0oooo0@00000003X0oooo0`00000g0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03h0
oooo500000120?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo03H0oooo0P0000000100oooo00<0_gAd0;ooo`3oool0
9`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0g0?ooo`400000000@0?ooo`030;mdM02oool0oooo02L0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0=`3oool100000000403oool00`2oM7@0_ooo0?ooo`0W0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo03P0oooo0@00000000d0oooo00<0_g@00000000000000`0000000`0007@0_ooo0?ooo`0T0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo03P0oooo0@0000000100oooo00<0_gAd0;ooo`3oool09`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0i0?ooo`400000000@0?ooo`030;mdM02oool0oooo02L0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
>@3oool100000000403oool00`2oM7@0_ooo0?ooo`0W0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03T0oooo0@00
000003X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0>P3oool1000000002`3oool00`3ooml0W7BL0=ooo`050?oo
o`030=nLW02oool0oooo02@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool05P3oool2000004X0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0j0?ooo`400000000;0?ooo`030?noM0000000000000D0
000000<0001d0;ooo`3oool0903oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0j0?ooo`400000000C0?ooo`030=nL
W02oool0oooo02@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0>`3oool100000000>P3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0k0?ooo`400000000j0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo03`0oooo0@00000003X0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0?03oool100000000>P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0l0?ooo`400000000j0?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo01T0oooo0P0000190?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
?@3oool100000000>P3oool3000003d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo03`0oooo0P00000003X0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0?@3oool1
00000000>P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0n0?ooo`400000000j0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0P0?ooo`8000007@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0?P3oool100000000
>P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0L0?ooo`800000B03oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo03l0oooo0@00000003X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0?`3oool100000000>P3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool06@3oool2
000001l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo03l0oooo0@00000003X0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool2000004L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`100?ooo`400000000j0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`800000803oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@03oool100000000
>P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`110?ooo`400000000j0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0200oooo0P00
00160?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@@3oool100000000>P3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03@3oool2
00000280oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0440oooo0@00000001h0oooo00D0omnL04P000000000001d0;ooo`030?ooo`030?noM0000000
M;oo00<0oooo00D0omnL04P000000000000007Boo`090?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0480oooo0@00
000001d0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol0
0P3oool01`3ogi`0B00004RLg`3oool0oono07@0001d_ol0203oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0R0?oo
o`800000A@3oool00`000000oooo0?ooo`080?ooo`8000008`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@P3oool1000000007@3oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@0
04RL0=ooo`070?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo02<0oooo0P0000140?ooo`030000003oool0oooo00D0
oooo0P00000U0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`120?ooo`400000000L0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
903oool2000004<0oooo00<000000?ooo`3oool00P3oool2000002H0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04<0oooo0@00000001`0oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol01`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0440oooo00@0
00000?ooo`00000000009`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0@`3oool100000000703oool00`3ogi`0B00007Boo`030?ooo`030?noM000
04P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool00`2oM000001809cOo`070?ooo`<00000A03o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09P3o
ool200000440oooo0P00000X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`120?ooo`<00000000L0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol01@3oool0203ookl0M00000000018W=l0oooo0?noM000000007Bo203oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0W0?ooo`800000?@3oool200000080oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A03oool100000000
703oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00<0_g@00018W02oW4P0
0P0000000`00B9`0gooo0?ooo`070?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02T0oooo0P00000h0?ooo`<00000
1@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`140?ooo`400000000L0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool01P3oool00`3ogi`0B00007Boo`0<0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02X0oooo0`00
000c0?ooo`8000002@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`150?ooo`400000000M0?ooo`030=nLB000B9`0
gooo0080oooo00<0_g@0001d_`3oool01`3oool00`3OW4P0001809cOo`0;0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo02`0oooo1000000/0?ooo`<00000303oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`150?ooo`400000000M0?oo
o`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`090?ooo`030?noM000000007Bo00X0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0;`3oool3000002H0oooo0`00000@0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04H0oooo0@00
000001h0oooo00D0oono07@000000000001d0;ooo`0;0?ooo`050?oog`2LB00000000000M02oool0
1`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0b0?ooo`<00000803oool3000001@0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
AP3oool100000000>P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`D00000503oool7000001P0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0AP3oool100000000>P3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0h0?oooa@00000803oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`170?ooo`400000000j0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0A`3oool100000000>P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04P0
oooo0@00000003X0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`180?ooo`400000
000j0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B03oool100000000>P3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04T0oooo0@00000003X0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0K03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`190?ooo`400000000j0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo06d0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0B@3oool100000000>P3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo04X0oooo0@00000003X0oooo0`00001;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04T0oooo0P00
000003X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1;0?ooo`400000000j0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo06d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B`3oool100000000>P3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo04/0oooo0@00000003X0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
K@3oool010000000oooo0?ooo`00000I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0C03oool100000000>P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1]0?ooo`8000006@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo04`0oooo0@00000003X0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0K03o
ool2000001P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1=0?ooo`400000000j
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo06X0oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo04d0oooo0@00000003X0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0I`3oool2
000000@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo04h0oooo0@00000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?oo
o`400000000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0C`3oool100000000
>P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04l0oooo0@00000003X0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo0P00
001P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0500oooo0@00000003X0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`1@0?ooo`400000000j0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05T0oooo0P00000A0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1@0?oo
o`400000000j0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0D@3oool100000000
>P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0540oooo0@00000003X0oooo0`00
001C0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0540oooo0P00000003X0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0D03oool2
000001X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0580oooo0@00000003X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01h0oooo0P00001?0?ooo`030000003oool0oooo01/0oooo00D000000?oo
o`3oool0oooo0000000@0?ooo`030000003oool0oooo05<0oooo0@00000003X0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01l0oooo0P00001<0?oo
o`030000003oool0oooo01d0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`1C
0?ooo`400000000j0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0P0?ooo`800000B03oool200000240oooo0P00000@0?ooo`030000003oool0oooo
05@0oooo0@00000003X0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0Q0?ooo`80
0000403oool00`000000oooo0?ooo`1D0?ooo`400000000j0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0R0?ooo`800000@P3oool2000002@0oooo
00<000000?ooo`0000003`3oool00`000000oooo0?ooo`1D0?ooo`400000000j0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo03d0oooo0P00000U0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo
0?ooo`1E0?ooo`400000000j0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0T0?ooo`800000>`3oool2000002H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05D0oooo0@00000003X0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02D0oooo0P00000g
0?ooo`800000:03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0EP3oool100000000>P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool09P3oool2000003<0oooo0P00000Y0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1F0?ooo`400000000j0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`80
0000;P3oool3000002X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo05L0oooo0@00000003X0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo02T0oooo0P00000Z0?ooo`800000;03oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0E`3oool100000000>P3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0:P3o
ool3000002D0oooo0P00000^0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1H0?ooo`400000000j0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0/0?ooo`<00000803oool2000002l0oooo00<00000
0?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000005X0oooo0@00000003X0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02h0oooo1@00000D
0?ooo`L00000<03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000005/0oooo0@000000
03X0oooo0`00001J0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<`3ooolD0000
03H0oooo00<000000?ooo`3oool04@3oool2000005X0oooo0P00000003X0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool04@3oool2000005/0oooo0@00000003X0oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0000001J0?ooo`400000000j0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo
0000001I0?ooo`400000000j0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1F0?ooo`400000000j0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1E0?ooo`400000000j0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`400000000j0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1C0?ooo`40
0000000j0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1B0?ooo`400000000j0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`1A0?ooo`400000000j0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1@0?ooo`400000000j0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1?0?ooo`400000000N0?ooo`05
0?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`050=nLB00000000000
00000018W=l02@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0CP3oool1000000007@3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3o
ool00`3o_g@0000007Boo`020?ooo`070=nLB0000000M;oo0?ooo`3ooml0W4P004RLg`080?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1=0?ooo`40
0000000M0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3ooml0W4P0
001d_`030?ooo`030?noM000B9`0gooo00L0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo04`0oooo0@00000001`0oooo00<0oono07@00018W=l00`3o
ool00`3OW4P0001d0;ooo`060?ooo`030;md0000M;l0oooo0080oooo00<0_g@00018W03Oool01`3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B`3o
ool100000000703oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0omnL
04P0M02oool0oooo0;md00000000M;oo00P0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04X0oooo0@00000001`0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`070?ooo`050?oo_`1dB4P0B00000000018W=l02@3oool3000006<0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1O0?ooo`8000006@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo04L0oooo0`00000001`0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`070?ooo`040?oOW01800000000001d_`X0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04P0oooo0@00000001`0oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`060?oOW0180000001d0;ooo`3o_g@0
07Bo2@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0A`3oool100000000703oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo
00<0_g@00000M02oool00P3oool00`2oM000B9cO0?ooo`070?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`160?ooo`400000000M0?ooo`030=nLB000
B9`0gooo0080oooo00<0_g@0001d_`3oool01P3oool00`2oM00004RL0=ooo`020?ooo`030=nLB000
M;l0oooo00L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo04D0oooo0@00000001d0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00L0oooo
00L0okmd0000001d_ol0oooo0?oo_`1d0000M;oo00P0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo04@0oooo0@00000001h0oooo00D0oono07@00000
0000001d0;ooo`090?ooo`050?noM0000000000000000018W=l02@3oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0@`3oool100000000>P3oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0@P3oool10000
0000>P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0@@3oool100000000>P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0@03oool100000000>P3oool00`000000oooo0?ooo`1X0?ooo`030000003o
ool0oooo01`0oooo0P00001<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0o0?ooo`400000000j0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0n0?ooo`400000000j0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0m0?ooo`400000000j0?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0l0?ooo`40
0000000j0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool07P3oool200000480oooo
0P00000P0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0>`3oool100000000>P3o
ool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0?@3o
ool200000240oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0j0?ooo`400000000j
0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0803oool2000003/0oooo0P00000R
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0>@3oool100000000>P3oool30000
06d0oooo00<000000?ooo`3oool08@3oool2000003P0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo03L0oooo0P00000003X0oooo00<000000?ooo`3o
ool0KP3oool00`000000oooo0?ooo`0R0?ooo`800000=03oool2000002@0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0g0?ooo`400000000j0?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool0903oool200000300oooo0P00000U0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0=P3oool100000000>P3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo02D0oooo0P00000/0?ooo`8000009`3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo03D0oooo0@00000003X0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0V
0?ooo`8000009`3oool3000002P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0d
0?ooo`400000000j0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool09`3oool20000
02<0oooo0P00000Z0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0<`3oool10000
0000>P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo02T0oooo0P00000O0?ooo`80
0000;03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0380oooo0@00000003X0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0Z0?ooo`D00000503oool6000002d0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0a0?ooo`400000000j0?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool0;P3oool8000000D0oooo1`00000b0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0<03oool100000000>P3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo03H0oooo1@00000i0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0;`3oool100000000>P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0^0?ooo`400000000j0?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02d0oooo0@00000003X0oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0;03oool100000000>P3o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`0[0?ooo`400000000j0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0K03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02X0oooo0@000000
03X0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0:@3oool100000000>P3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0X0?ooo`40
0000000j0?ooo`<00000N@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool09P3oool200000000>P3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0V0?ooo`400000000j
0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo02D0oooo0@00000003X0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0903oool10000
0000>P3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0S0?ooo`400000000j0?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0280oooo
0@00000003X0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool08@3oool100000000>P3oool00`000000oooo0?ooo`1o
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0P
0?ooo`400000000j0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo01l0oooo0@00000003X0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool07P3oool100000000>P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0M0?ooo`400000000j0?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo01`0oooo0@00000003X0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool06`3oool100000000>P3oool00`00
0000oooo0?ooo`240?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`0J0?ooo`400000000j0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo01T0oooo0@00000003X0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo06/0oooo
00<000000?ooo`3oool0603oool100000000>P3oool00`000000oooo0?ooo`270?ooo`800000C03o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01L0oooo0@00000003X0oooo0`000029
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0E
0?ooo`800000000j0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo01D0oooo0@00000003X0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool0503oool100000000>P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0440oooo
0P00001g0?ooo`030000003oool0oooo01<0oooo0@00000003X0oooo00<000000?ooo`3oool0S@3o
ool200000400oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0B0?ooo`400000000j
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo0140oooo0@00000003X0oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`0i0?ooo`800000OP3oool00`000000oooo0?ooo`0@0?ooo`400000000j0?ooo`03
0000003oool0oooo0940oooo0P00000h0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3o
ool03`3oool100000000>P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03<0oooo
0P0000230?ooo`030000003oool0oooo00h0oooo0@00000003X0oooo00<000000?ooo`3oool0U03o
ool200000340oooo0P0000260?ooo`030000003oool0oooo00d0oooo0@00000003X0oooo00<00000
0?ooo`3oool0UP3oool2000002d0oooo0P0000290?ooo`030000003oool0oooo00`0oooo0@000000
03X0oooo00<000000?ooo`3oool0V03oool2000002T0oooo0P00002<0?ooo`030000003oool0oooo
00/0oooo0@00000002`0oooo00H0_g@000000000000000000018W03Oool80?ooo`030000003oool0
oooo09X0oooo0P00000U0?ooo`800000S`3oool00`000000oooo0?ooo`0:0?ooo`400000000]0?oo
o`030?oOW0180000M;oo00X0oooo00<000000?ooo`3oool0W03oool200000240oooo0P00002B0?oo
o`030000003oool0oooo00T0oooo0@00000002d0oooo00<0omnL04P0001d_ol02P3oool00`000000
oooo0?ooo`2N0?ooo`8000006`3oool4000009D0oooo00<000000?ooo`3oool0203oool100000000
;@3oool00`3ogi`0B00007Boo`0:0?ooo`030000003oool0oooo0:00oooo1000000D0?ooo`<00000
VP3oool00`000000oooo0?ooo`070?ooo`400000000]0?ooo`030?oOW0180000M;oo00X0oooo00<0
00000?ooo`3oool0Y03oool6000000T0oooo1@00002N0?ooo`030000003oool0oooo00H0oooo0@00
000002d0oooo00<0omnL04P0001d_ol02P3oool300000:X0oooo2@00002T0?ooo`030000003oool0
oooo00<0oooo0`00000002d0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?oo
of00oooo0@00000002d0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?ooof00
oooo0@00000002d0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?ooof00oooo
0@00000002d0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?ooof00oooo0@00
000002/0oooo00D0oooO09a800000000000007Boo`0:0?ooo`030000003oool0oooo0?l0ooooH03o
ool100000000;@3oool00`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00D0oooo0@000000
03X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01@3oool100000000>P3ooooo000006@00000003o0?oooih0oooo
003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo003o0?oooih0oooo0000\
\>"],
  ImageRangeCache->{{{0, 412.875}, {412.875, 0}} -> {-0.199016, -0.183696, \
0.00444897, 0.00444897}}]
}, Closed]],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] \[LessEqual] 1\)]],
  ", the only solution is ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " corresponding to the situation in which a population that fails to \
replace itself becomes extinct.  For larger \[Mu] a new fixed point emerges."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1 = fixedPoints[1]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 0}, {x \[Rule] \(\(-1\) + \[Mu]\)\/\[Mu]}}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear stability analysis", "Section"],

Cell[TextData[{
  "A fixed point is described as stable if points in its neighborhood are \
attracted toward the fixed point or as unstable if small displacements from \
the fixed point are driven away as the map is iterated.  The property of the \
mapping function which distinguishes between these behaviors is the slope, \
\[Lambda], of the map function at the fixed point.  By visualizing the cobweb \
process, it becomes apparent that ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\[Lambda]\[RightBracketingBar] < 
        1\)]],
  " yields a stable approach toward the fixed point while ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\[Lambda]\[RightBracketingBar] > 
        1\)]],
  " results in repulsion from the fixed point.  More formally, suppose that \
",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " is a fixed point of the mapping ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + 1\) = f[\[Mu], x\_i]\)]],
  ", such that ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0 = f[\[Mu], x\_0]\)]],
  ".  Consider a nearby point ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0 + \[Delta]\[VeryThinSpace]x\)]],
  " for which ",
  Cell[BoxData[
      \(TraditionalForm\`f[\[Mu], 
          x\_0 + \[Delta]\[VeryThinSpace]x] \[TildeTilde] 
        x\_0 + \(f\^\[Prime]\)[\[Mu], x\_0] \[Delta]\[VeryThinSpace]x\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \(f\^\[Prime]\)[\[Mu], x\_0]\)]],
  " is the slope of ",
  Cell[BoxData[
      \(TraditionalForm\`f[\[Mu], x]\)]],
  " at the fixed point.  Hence, the iteration produces ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + 1\) \[TildeTilde] 
            x\_0 + \[Lambda]\ \[Delta]\[VeryThinSpace]x\_i\  \
\[DoubleRightArrow] \ \[Delta]\[VeryThinSpace]x\_\(i + 1\) = \[Lambda]\ \
\[Delta]\[VeryThinSpace]x\_i\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[VeryThinSpace]x\_i = x\_i - x\_0\)]],
  "is the distance from the fixed point.  Thus, near a fixed point each \
iteration multiplies the distance from the fixed point by a factor of \
\[Lambda].  The slope at the fixed point is known as its  ",
  StyleBox["eigenvalue",
    FontSlant->"Italic"],
  " by analogy with discrete multidimensional mappings effected by matrix \
multiplication.  Clearly, if ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\[Lambda]\[RightBracketingBar] < 
        1\)]],
  " nearby points are driven toward the fixed point as the mapping is \
iterated,  if ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\[Lambda]\[RightBracketingBar] > 
        1\)]],
  " nearby points are driven away from the fixed point, while if ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\[Lambda]\[RightBracketingBar] = 
        1\)]],
  " nearby points orbit the fixed point at constant distance.  Therefore, the \
nature of a fixed point is determined by its eigenvalue and is classified as \
stable if the magnitude of the eigenvalue is less than unity, unstable if \
greater than unity, or neutrally stable if exactly equal to unity.  \
Furthermore, if the eigenvalue is positive the mapping approaches or recedes \
monotonically, while for negative eigenvalues it oscillates (orbits) around \
the fixed point."
}], "Text"],

Cell[TextData[{
  "This type of analysis is known as ",
  StyleBox["linear stability analysis",
    FontSlant->"Italic"],
  " and can be applied not only to arbitrary discrete mappings but to many \
continuous models of dynamical systems.  Many of the features characteristic \
of discrete maps, such as period doubling, chaos, order within chaos, and \
self-similarity are found in other dynamical systems governed by nonlinear \
differential equations also."
}], "Text"],

Cell["\<\
Thus, we define a function which evaluates the slope of the mapping function \
at the fixed points \
\>", "Text"],

Cell[BoxData[
    \(\[Lambda]\_n_[\[Mu]_] := 
      D[f\_n[\[Mu], x], x] /. fixedPoints[n] // Simplify\)], "Input"],

Cell["and for the first iteration of the logistic map we find", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Lambda]\_1[\[Mu]]\)], "Input"],

Cell[BoxData[
    \({\[Mu], 2 - \[Mu]}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Therefore, stability for the first fixed point with ",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  " requires ",
  Cell[BoxData[
      \(TraditionalForm\`1 < \[Mu] < 3\)]],
  ", which is consistent with our earlier numerical investigations.  To \
illustrate this behavior, consider the following cobweb plots near the \
critical value \[Mu]=3.  We use ",
  StyleBox["PlotRange", "InlineInput",
    FontWeight->"Bold"],
  " to zoom in upon the vicinity of a fixed point and use ",
  StyleBox["AspectRatio\[Rule]Automatic", "InlineInput",
    FontWeight->"Bold"],
  " to obtain a faithful picture of the slope of the mapping function at this \
point."
}], "Text"],

Cell[TextData[
"For \[Mu] just below the critical point we observe that nearby points are \
attracted toward the fixed point."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(x /. 
        sol1\[LeftDoubleBracket]2\[RightDoubleBracket]\) /. \[Mu] \[Rule] 
        2.8\)], "Input"],

Cell[BoxData[
    \(0.6428571428571428`\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(logisticCobweb[2.8, 0.6, 10, 0, 
        PlotRange \[Rule] {{0.5, 0.7}, {0.5, 0.7}}, 
        AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.5 5 -2.5 5 [
[.125 -0.0125 -15.5 -15.6875 ]
[.125 -0.0125 15.5 0 ]
[.25 -0.0125 -12.5 -15.6875 ]
[.25 -0.0125 12.5 0 ]
[.375 -0.0125 -15.5 -15.6875 ]
[.375 -0.0125 15.5 0 ]
[.5 -0.0125 -9.5 -15.6875 ]
[.5 -0.0125 9.5 0 ]
[.625 -0.0125 -15.5 -15.6875 ]
[.625 -0.0125 15.5 0 ]
[.75 -0.0125 -12.5 -15.6875 ]
[.75 -0.0125 12.5 0 ]
[.875 -0.0125 -15.5 -15.6875 ]
[.875 -0.0125 15.5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .125 -31 -7.84375 ]
[-0.0125 .125 0 7.84375 ]
[-0.0125 .25 -25 -7.84375 ]
[-0.0125 .25 0 7.84375 ]
[-0.0125 .375 -31 -7.84375 ]
[-0.0125 .375 0 7.84375 ]
[-0.0125 .5 -19 -7.84375 ]
[-0.0125 .5 0 7.84375 ]
[-0.0125 .625 -31 -7.84375 ]
[-0.0125 .625 0 7.84375 ]
[-0.0125 .75 -25 -7.84375 ]
[-0.0125 .75 0 7.84375 ]
[-0.0125 .875 -31 -7.84375 ]
[-0.0125 .875 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -46.6875 -11.4063 ]
[-0.01875 .5 -31 11.4063 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -74.9688 0 ]
[.5 1.0125 74.9688 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -76.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.525) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -73.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -76.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.575) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -76.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.625) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -73.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -76.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.675) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .125 m
.00625 .125 L
s
gsave
-0.0125 .125 -92 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.525) show
1.000 setlinewidth
grestore
0 .25 m
.00625 .25 L
s
gsave
-0.0125 .25 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
1.000 setlinewidth
grestore
0 .375 m
.00625 .375 L
s
gsave
-0.0125 .375 -92 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.575) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .625 m
.00625 .625 L
s
gsave
-0.0125 .625 -92 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.625) show
1.000 setlinewidth
grestore
0 .75 m
.00625 .75 L
s
gsave
-0.0125 .75 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
1.000 setlinewidth
grestore
0 .875 m
.00625 .875 L
s
gsave
-0.0125 .875 -92 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.675) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -111.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -135.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cobweb) show
105.875 15.813 moveto
(Plot) show
128.188 15.813 moveto
(for) show
142.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
148.375 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.375 15.813 moveto
(H) show
170.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
179.188 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
189.875 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
196.000 15.813 moveto
(L) show
202.813 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
208.938 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.20916 .20916 L
.41271 .41271 L
.62914 .62914 L
.83761 .83761 L
s
.83761 .83761 m
1 1 L
s
0 .99999 m
.00256 1 L
.00854 .99996 L
.01499 .99987 L
.02107 .99975 L
.02665 .9996 L
.03961 .99912 L
.05325 .99841 L
.06657 .99752 L
.07896 .99651 L
.10709 .99358 L
.15384 .98675 L
.20379 .97674 L
.25757 .96285 L
.31586 .94413 L
.42166 .90043 L
.52601 .84506 L
.63648 .77314 L
.83539 .60919 L
s
.83539 .60919 m
1 .43565 L
s
.5 .5 m
.5 .86 L
.86 .86 L
s
.86 .86 m
.86 .58582 L
.58582 .58582 L
s
.58582 .58582 m
.58582 .80781 L
.80781 .80781 L
s
.80781 .80781 m
.80781 .63456 L
.63456 .63456 L
s
.63456 .63456 m
.63456 .7745 L
.7745 .7745 L
s
.7745 .7745 m
.7745 .66408 L
.66408 .66408 L
s
.66408 .66408 m
.66408 .75304 L
.75304 .75304 L
s
.75304 .75304 m
.75304 .68244 L
.68244 .68244 L
s
.68244 .68244 m
.68244 .73919 L
.73919 .73919 L
s
.73919 .73919 m
.73919 .69401 L
.69401 .69401 L
s
.69401 .69401 m
.69401 .73027 L
.73027 .73027 L
s
.03 w
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{306.375, 306.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007;0001bb000`400?l00000o`00003oo`3oooo<
0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oool>0?ooo`050?oog`2L
B00000000018W03Oool0^@3oool00?l0oooo3`3oool00`3ogi`0B01809cOo`2j0?ooo`00o`3oool?
0?ooo`030?oOW01804P0W=oo0;X0oooo003o0?ooo`H0oooo00D0_g@000000000M;l0oooo0=nLB002
000000050018W03Oool0omnL04P0B02Lgol0^P3oool00?l0oooo1P3oool0303ooml0W4Qd0;ooo`3o
ool0oooO09a80000B9`0gooo0?oo_`1d0000001809cOokX0oooo003o0?ooo`L0oooo00H0oono07A8
W03Oool0_g@00000M02oool20?ooo`030?oOW01804P0W=oo0;X0oooo003o0?ooo`P0oooo00@0omnL
07A8B0000000M;oo`03oool00?l0oooo203oool00`3ookl0M00004RLg`310?ooo`00o`3oool70?oo
o`050?oog`2LB00004RL09adB02Lgol00`3oool00`3ookl0M00007Boo`2j0?ooo`00o`3oool70?oo
o`060;md000004P0W=oo0?oog`2LB7@0_ooo_`3oool00?l0oooo1@3oool02@3ooml0W4P000000000
000007Bo0?noM0000000001d0;ooo`2n0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<
0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<
0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<
0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00J`3oool01@3ogi`0B0000000000007@0_ooo00<0
oooo00H0okmd0000001d_ol0oooo0?oog`2LB0030000000507Boo`3oool0oooo0?ooo`2oM0001P00
00001018W=l0oooo0?oog`2LB0030000000307Boo`3oool0oooo00h0oooo00D0omnL04P000000000
001d0;ooo`030?ooo`060?noM0000000M;oo0?ooo`3ooml0W4P00`0000001P1d_ol0oooo0?ooo`3o
ool0oooO09a800<0000000<0M;oo0?ooo`3oool03P3oool01@3ogi`0B0000000000007@0_ooo00<0
oooo00H0okmd0000001d_ol0oooo0?oog`2LB0030000000307Boo`3oool0oooo00@0oooo00<0gia8
04RLg`3oool00`3oool00`3ooml0W4P0000000020000000307Boo`3oool0oooo0180oooo00D0omnL
04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00<0oooo00D0omnL04P0000000000000
07Boo`0C0?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`05
0?oOW018000000000000001d_ol00P3oool00`2oM0000000000000040000000404RLg`3oool0oooO
09a800<0000000<0M;oo0?ooo`3oool03P3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0
okmd0000001d_ol00`3oool01@3ogi`0B000000000000000M;oo0080oooo00<0oooO09a800000000
0P0000000`1d_ol0oooo0?ooo`0>0?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@0
000007Boo`030?ooo`050?oOW018000000000000001d_ol01@3oool00`3OW4P0B9cO0?ooo`030?oo
o`030?oog`2LB00000000080000000<0M;oo0?ooo`3oool07P3oool006X0oooo00L0oono07@0001d
_ol0oooo0?noM00007@0_ooo0080oooo00L0okmd0000001d_ol0oooo0?oog`2LB7@0_ooo0080oooo
00<0_g@007Boo`3oool00P3oool00`3OW4P0000000000003000000050018W03Oool0oooO09a8M02o
ool00P3oool00`2oM000M;oo0?ooo`0=0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`02
0?ooo`070?noM0000000M;oo0?ooo`3ooml0W4Qd0;ooo`020?ooo`070;md001d_ol0oooo0?ooo`3o
oml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo00d0oooo00L0oono07@0001d_ol0oooo0?noM000
07@0_ooo0080oooo00L0okmd0000001d_ol0oooo0?oog`2LB7@0_ooo0080oooo00<0_g@007Boo`3o
ool0103oool00`3ogi`0B4RL0=ooo`030?ooo`030?oog`2LB7@0_ooo0080oooo00<0_g@007Boo`3o
ool04@3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`02
0?ooo`070?oOW0180000B9cO0?ooo`3ookl0M00007Boo`0A0?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`020?ooo`030?noM0000000M;oo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d
0000M;oo0080oooo00<0gia80000000000000`0000001@00B9`0gooo0?oog`2LB7@0_ooo0080oooo
00<0_g@007Boo`3oool03@3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o
_g@0000007Boo`020?ooo`0;0?oOW0180000B9cO0?ooo`3ookl0M00007Boo`3oool0oooO09a8M02o
ool00P3oool00`2oM000M;oo0?ooo`0=0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`02
0?ooo`030?noM0000000M;oo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000M;oo00@0oooo
00<0omnL04Q8W03Oool00`3oool00`3ooml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo01h0oooo
001Z0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool02P3oool00`3ooml0W4Qd0;oo
o`030?ooo`030=nLB018W=l0oooo0080oooo00<0giad09cOo`3oool0103oool00`3ooml0W4Qd0;oo
o`0=0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool02P3oool00`3ooml0W4Qd0;oo
o`060?ooo`030?oog`2LB7@0_ooo00d0oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?oo
o`0:0?ooo`030?oog`2LB7@0_ooo00@0oooo00<0oooO09a8B02Lgol0203oool00`3ooml0W4Qd0;oo
o`0A0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3ooml0W4P0001d
_`030?ooo`030?noM000B9`0gooo0100oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?oo
o`050?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03Oool00P3oool00`3OW4P0B9cO0?oo
o`020?ooo`030=nLM02Lgol0oooo00@0oooo00<0oooO09a8M02oool03@3oool00`2oM00004RL0=oo
o`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL0=oo
o`050?ooo`030?oog`2LB7@0_ooo00d0oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?oo
o`050?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03Oool00`3oool00`3ooml0W4Q809cO
o`080?ooo`030?oog`2LB7@0_ooo01h0oooo001Y0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia8
0000M02oool02`3oool00`2oM000M;oo0?ooo`030?ooo`030=nLB01d_ol0oooo00T0oooo00<0_g@0
07Boo`3oool02`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00/0oooo00<0_g@0
07Boo`3oool01P3oool00`2oM000M;oo0?ooo`0;0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia8
0000M02oool02`3oool00`2oM000M;oo0?ooo`040?ooo`030=nLB018W=l0oooo00P0oooo00<0_g@0
07Boo`3oool03`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00D0oooo00<0omnL
04P0001d_ol00`3oool00`3o_g@0001809cOo`0?0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia8
0000M02oool01@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00<0oooo00<0gia8
07Boo`3oool02@3oool00`2oM000M;oo0?ooo`0;0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia8
0000M02oool01@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00<0_g@0
07Boo`3oool02`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00D0oooo00<0omnL
04P0001d_ol00`3oool00`3o_g@0001809cOo`040?ooo`030=nLB018W=l0oooo00P0oooo00<0_g@0
07Boo`3oool07@3oool006T0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?oo
o`030?oog`2LB000B9cO00D0oooo00<0_gA809cOo`3oool01`3oool00`3ooml0W4P004RLg`0<0?oo
o`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3ooml0W4P004RLg`060?oo
o`030?oog`2LB000B9cO00`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?oo
o`030?oog`2LB000B9cO00D0oooo00<0omnL04Q8W03Oool01`3oool00`3ooml0W4P004RLg`0@0?oo
o`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0B00007Boo`030?oo
o`030?noM00004P0W=oo00l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?oo
o`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0103oool00`2oM4P0W=oo0?ooo`070?oo
o`030?oog`2LB000B9cO00`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?oo
o`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ooml0W4P004RLg`0<0?oo
o`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0B00007Boo`030?oo
o`030?noM00004P0W=oo00@0oooo00<0omnL04Q8W03Oool01`3oool00`3ooml0W4P004RLg`0N0?oo
o`00J@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo00<0gia80000001d
_ol01@3oool00`3ooml0W4Qd0;ooo`070?ooo`030=nLB0000000M;oo00`0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030=nLB0000000M;oo00H0oooo00<0gia80000001d
_ol0303oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo00<0gia80000001d
_ol01@3oool00`3ooml0W4Q809cOo`070?ooo`030=nLB0000000M;oo0100oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0_g@00000B02L
gol03`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d
_ol00`3oool00`2oM000001809cOo`040?ooo`030?oog`2LB7@0_ooo00L0oooo00<0gia80000001d
_ol0303oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d
_ol00`3oool00`2oM000001809cOo`050?ooo`030=nLB0000000M;oo00`0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0_g@00000B02L
gol0103oool00`3ooml0W4Q809cOo`070?ooo`030=nLB0000000M;oo01h0oooo001Y0?ooo`030?oO
W0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3Ogml0oooo0?oo_`1d000000000000
M02oool01P3oool00`3o_g@007Bo0?ooo`020?ooo`070=oOg`3oool0oono07@000000000001d0;oo
o`0<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3Ogml0oooo0?oo
_`1d000000000000M02oool00P3oool01`3Ogml0oooo0?oo_`1d000000000000M02oool0303oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0gmoO0?ooo`3ookl0M0000000
000007@0_ooo00H0oooo00<0gia8001d_`3oool00P3oool01`3Ogml0oooo0?oo_`1d000000000000
M02oool0403oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0oono07@0
00000000B9cO0?ooo`3o_g@00000001d_a00oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`050?ooo`080?oo_`1d0000000004RLg`3oool0okmd00000000M;l60?ooo`030?noM000M;l0
oooo0080oooo00L0gmoO0?ooo`3ookl0M0000000000007@0_ooo00`0oooo00<0omnL04P0001d_ol0
0`3oool00`3o_g@0001809cOo`050?ooo`080?oo_`1d0000000004RLg`3oool0okmd00000000M;l2
0?ooo`070=oOg`3oool0oono07@000000000001d0;ooo`0<0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol01@3oool0203ookl0M00000000018W=l0oooo0?noM000000007Bo1P3oool0
0`3OW4P007Bo0?ooo`020?ooo`070=oOg`3oool0oono07@000000000001d0;ooo`0N0?ooo`00J@3o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0gia80000000000000000
0000B02Lgol70?ooo`030?oo_`1d04P0W=oo0080oooo00H0gia800000000000000000000B02Lgol=
0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01P3OW4P0000000000000
0000001809cOo`<0oooo00H0gia800000000000000000000B02Lgol=0?ooo`030?oOW0180000M;oo
00<0oooo00<0okmd0000B02Lgol01P3oool01P3OW4P00000000000000000001809cOo`L0oooo00<0
oono07@0M02oool00P3oool01P3OW4P00000000000000000001809cOoa40oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`060?ooo`030;md0000B9`0_ia80080000000<004RL0=ooo`3o
ool03`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00<0_g@00018W02o
W4P00P0000000`00B9`0gooo0?ooo`050?ooo`030?oo_`1d04P0W=oo0080oooo00H0gia800000000
000000000000B02Lgol=0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool0
0`2oM00004RL0;nLB002000000050018W03Oool0oooo0?ooo`3OW4P00`0000000`0004P0W=oo0?oo
o`0<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool00`2oM00004RL0;nL
B002000000030018W03Oool0oooo00D0oooo00<0oono07@0M02oool00P3oool01P3OW4P000000000
00000000001809cOoal0oooo001Y0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0
1P3oool0103ookl0M00000000018W=l90?ooo`030?oo_`1d0000B9cO0080oooo00@0oono07@00000
0000B9cO3`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00@0oono07@0
00000000B9cO1@3oool0103ookl0M00000000018W=l?0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool01P3oool0103ookl0M00000000018W=l40?ooo`030?oOg`3Oool0oooo00<0oooo
00P0_g@007Boo`3oool0oooo0?oo_`1d0000000004RLga<0oooo00<0oono07@00018W=l00`3oool0
0`3OW4P0001d0;ooo`060?ooo`030?oOW0180000M;oo01@0oooo00<0oono07@00018W=l00`3oool0
0`3OW4P0001d0;ooo`060?ooo`030?oOW0180000M;oo00X0oooo00<0oono07@00018W=l00P3oool0
103ookl0M00000000018W=l?0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3o
ool00`3ogi`0B00007Boo`060?ooo`040?oo_`1d0000000004RLg`l0oooo00<0oono07@00018W=l0
0`3oool00`3OW4P0001d0;ooo`060?ooo`030?oOW0180000M;oo00D0oooo00<0omoO0=ooo`3oool0
0`3oool0202oM000M;oo0?ooo`3oool0oono07@000000000B9cO8@3oool006X0oooo00<0gia80018
W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030;md001d_ol0oooo00@0oooo00<0oknL09cO
o`3oool00P3oool00`3ogi`0B00004RLg`030?ooo`030;md001d_ol0oooo0100oooo00<0gia80018
W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030;md001d_ol0oooo00H0oooo00<0_g@007Bo
o`3oool0403oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0_g@007Bo
o`3oool0103oool00`3ookl0M4RL0=ooo`030?ooo`030?noM000M;l0oooo0080oooo00<0_g@007Bo
o`3oool0503oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000
B02Lgol0503oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000
B02Lgol0103oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW0180000B9cO00<0oooo00<0_g@007Bo
o`3oool0403oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000
B02Lgol01P3oool00`2oM000M;oo0?ooo`0@0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d
_`3oool01`3oool00`3OW4P0001809cOo`040?ooo`030?oo_`1dB9`0gooo00<0oooo00<0okmd001d
_`3oool00P3oool00`2oM000M;oo0?ooo`0Q0?ooo`00JP3oool01`3ookl0M00007Boo`3oool0okmd
0000M02oool0203oool03`3ogi`0B000000000000000001809cOo`3oool0oooO09a8B02Lgol0oooo
0?oo_`1d0000001d0;ooo`030?ooo`060?oOW018000000000000000004P0W=oo3@3oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool0203oool01P3ogi`0B000000000000000001809cOo`<0oooo
00H0omnL04P00000000000000000B02Lgol=0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;oo
o`080?ooo`060?oOW018000000000000000004P0W=oo0P3oool00`2oM00000000000000300000006
0000M02oool0oooo0?ooo`3ogi`0B0000P0000000`0004P0W=oo0?ooo`0@0?ooo`070?oo_`1d0000
M;oo0?ooo`3o_g@0001d0;ooo`090?ooo`030?noM000000007Bo01<0oooo00L0oono07@0001d_ol0
oooo0?noM00007@0_ooo00T0oooo00<0okmd00000000M;l00`3oool0203ooml0W4Q809cOo`3oool0
oono07@0000007@0_ooo0`3oool01P3ogi`0B000000000000000001809cOo`d0oooo00L0oono07@0
001d_ol0oooo0?noM00007@0_ooo00T0oooo00<0okmd00000000M;l01@3oool01P3ogi`0B0000000
00000000001809cOo`d0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00T0oooo00<0okmd
00000000M;l0103oool00`2oM000000000000003000000060000M02oool0oooo0?ooo`3ogi`0B000
0P0000000`0004P0W=oo0?ooo`0M0?ooo`00J`3oool01@3ookl0M0000000000007@0_ooo00X0oooo
00D0_g@0000000000000000004RLg`020?ooo`060?oog`2LB00000000000000007@0_ooo1@3oool0
1@2oM0000000000000000000B9cO00h0oooo00D0oono07@000000000001d0;ooo`0:0?ooo`050;md
00000000000000000018W=l0103oool01@2oM0000000000000000000B9cO00h0oooo00D0oono07@0
00000000001d0;ooo`0:0?ooo`050;md00000000000000000018W=l00P3oool00`3o_g@000000000
00040000000507Boo`3oool0oooo0?ooo`2oM0000`0000000`18W=l0oooo0?ooo`0@0?ooo`050?oo
_`1d000000000000M02oool02`3oool01@3ooml0W4P00000000007@0_ooo0140oooo00D0oono07@0
00000000001d0;ooo`0;0?ooo`080?oog`2LB00000000000M02oool0oooo0?oog`2LB00200000003
0000M02oool0oooo00@0oooo00D0_g@0000000000000000004RLg`0>0?ooo`050?oo_`1d00000000
0000M02oool02`3oool01@3ooml0W4P00000000007@0_ooo00<0oooo00D0_g@00000000000000000
04RLg`0>0?ooo`050?oo_`1d000000000000M02oool02`3oool01`3ooml0W4P00000000007@0_ooo
0?ooo`3o_g@01P0000001@1d_ol0oooo0?ooo`3oool0_g@000<0000000<0B9cO0?ooo`3oool0703o
ool00?l0ooooc03oool00?l0ooooc03oool00?l0ooooc03oool00?l0ooooc03oool00?l0ooooc03o
ool00?l0ooooc03oool00?l0ooooc03oool00?l0ooooc03oool00?l0ooooc03oool00?l0ooooc03o
ool004h0ooooo`00001m00000040oooo001>0?ooo`8000001`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool100000040oooo001>0?ooo`03
0000003oool0000002`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool100000040oooo001>0?ooo`040000
003oool0oooo00000?l0ooooN03oool100000040oooo001>0?ooo`050000003oool0oooo0?ooo`00
0000o`3ooomg0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`3o0?ooog@0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?l0ooooL`3oool100000040oooo001>0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3ooomb0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?ooog40oooo0@0000010?ooo`00CP3oool2000000L0oooo00<000000?ooo`3o
ool0o`3ooom^0?ooo`<000000@3oool004h0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3o0?ooofl0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0?l0ooooKP3oool100000040oooo001>0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0o`3ooom]0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`3o0?ooof`0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0?l0ooooJ`3oool100000040oooo001>0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3ooomZ0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`3o0?ooofT0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0?l0ooooJ03oool100000040oooo001>0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`4000000@3oool004h0oooo0P00000A0?ooo`03
0000003oool0oooo0?l0ooooI03oool300000040oooo001>0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0o`3ooomU0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`3o0?ooof@0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0?l0ooooH`3oool100000040oooo001>0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`4000000@3oool004h0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`3o0?ooof40oooo0@0000010?ooo`00CP3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooH03oool100000040oooo001>0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`4000000@3oool004h0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`3o0?oooeh0oooo0@0000010?ooo`00CP3oool20000
01X0oooo00<000000?ooo`3oool0o`3ooomK0?ooo`<000000@3oool004h0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00CP3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooF`3oool100000040oooo001>0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`4000000@3oool004h0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?oooeT0oooo0@0000010?ooo`00CP3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0ooooF03oool100000040oooo001>0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`4000000@3oool004h0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3o0?oooeH0oooo0@0000010?ooo`00CP3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooE@3oool100000040oooo001>
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooomD0?ooo`4000000@3oool0
04h0oooo0P00000T0?ooo`030000003oool0oooo0?l0ooooD@3oool300000040oooo001>0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`4000000@3oool004h0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?oooe40oooo0@0000010?ooo`00CP3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooD03oool100000040oooo000P
0?ooo`050?oOW018000000000000M02oool00`3oool01P3o_g@0000007Boo`3oool0oooO09a800<0
000000D0M;oo0?ooo`3oool0oooo0;md00060000000404RLg`3oool0oooO09a800<0000000<0M;oo
0?ooo`3oool0203oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0ooooC`3oool1
00000040oooo000O0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`070?noM000
0000M;oo0?ooo`3ooml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo0080oooo00<0gia800000000
00000`0000001@00B9`0gooo0?oog`2LB7@0_ooo0080oooo00<0_g@007Boo`3oool0203oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000O0?ooo`03
0;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool02P3oool00`3ooml0W4Qd0;ooo`030?ooo`03
0=nLB018W=l0oooo0080oooo00<0giad09cOo`3oool0103oool00`3ooml0W4Qd0;ooo`080?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`4000000@3oool001h0oooo
00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0;0?ooo`030;md001d_ol0oooo00<0oooo
00<0gia807Boo`3oool02@3oool00`2oM000M;oo0?ooo`070?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0o`3ooom<0?ooo`4000000@3oool001h0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`0:0?ooo`030?oog`2LB000B9cO00D0oooo00<0_gA809cOo`3oool01`3o
ool00`3ooml0W4P004RLg`080?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3o
oom;0?ooo`4000000@3oool001h0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:
0?ooo`030=nLB0000000M;oo00D0oooo00<0oooO09a8M02oool01`3oool00`3OW4P0000007Boo`08
0?ooo`<00000;03oool00`000000oooo0?ooo`3o0?ooodL0oooo100000010?ooo`007P3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0gmoO0?ooo`3ookl0M00000000000
07@0_ooo00H0oooo00<0okmd001d_`3oool00P3oool01`3Ogml0oooo0?oo_`1d000000000000M02o
ool0203oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooB@3oool100000040
oooo000N0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01P3OW4P00000
000000000000001809cOo`L0oooo00<0oono07@0B02Lgol00P3oool01P3OW4P00000000000000000
001809cOo`T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?ooodP0oooo0@00
00010?ooo`007P3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00@0oono
07@000000000B9cO2@3oool00`3ookl0M00004RLg`020?ooo`040?oo_`1d0000000004RLg`/0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?ooodL0oooo0@0000010?ooo`007`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0_g@007Boo`3oool0103o
ool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW0180000B9cO00<0oooo00<0_g@007Boo`3oool02`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooAP3oool100000040oooo000O
0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`080?ooo`0?0?oOW0180000000000000000
04P0W=oo0?ooo`3ooml0W4Q809cOo`3oool0oono07@0000007@0_ooo00<0oooo00H0omnL04P00000
000000000000B02Lgol80?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0o`3ooom5
0?ooo`4000000@3oool00200oooo00D0oono07@000000000001d0;ooo`0:0?ooo`050;md00000000
000000000018W=l00P3oool01P3ooml0W4P0000000000000001d0;ooo`D0oooo00D0_g@000000000
0000000004RLg`080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3ooom40?oo
o`4000000@3oool004h0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?oood<0
oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0oooo
@P3oool100000040oooo001>0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3o
oom10?ooo`4000000@3oool004h0oooo0P00000g0?ooo`030000003oool0oooo0?l0oooo?P3oool3
00000040oooo001>0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooolo0?oo
o`4000000@3oool004h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?oooch0
oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0oooo
?@3oool100000040oooo001>0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0o`3o
ooll0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o
0?oooc/0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
0?l0oooo>P3oool100000040oooo001>0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`3o0?ooocP0oooo0@0000010?ooo`00CP3oool200000400oooo00<000000?ooo`3oool0o`3o
oole0?ooo`<000000@3oool004h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3o
0?ooocH0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0?l0oooo=@3oool100000040oooo001>0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0o`3ooold0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`3o0?oooc<0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo0?l0oooo<P3oool100000040oooo001>0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0o`3ooola0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`3o0?oooc00oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0?l0oooo;`3oool100000040oooo001>0?ooo`800000B@3oool00`000000oooo
0?ooo`3o0?ooob`0oooo0`0000010?ooo`00CP3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0?l0oooo;@3oool100000040oooo001>0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0o`3oool/0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`3o0?ooob/0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo0?l0oooo:P3oool100000040oooo001>0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0o`3ooolY0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0?l0oooo9`3oool100000040oooo001>0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool0o`3ooolV0?ooo`4000000@3oool004h0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`3o0?ooobD0oooo0@0000010?ooo`00CP3oool2000005<0oooo
00<000000?ooo`3oool0o`3ooolR0?ooo`<000000@3oool004h0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`3o0?ooob<0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0?l0oooo8P3oool100000040oooo001>0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`4000000@3oool002T0oooo00D0omnL04P00000
0000001d0;ooo`030?ooo`060?noM0000000M;oo0?ooo`3ooml0W4P00`0000001P1d_ol0oooo0?oo
o`3oool0oooO09a800<0000000<0M;oo0?ooo`3oool0203oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0?l0oooo803oool100000040oooo000X0?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`020?ooo`070?noM0000000M;oo0?ooo`3ooml0W4Qd0;ooo`020?ooo`070;md001d
_ol0oooo0?ooo`3ooml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`3o0?oooal0oooo0@0000010?ooo`00:03oool00`2oM00004RL
0=ooo`020?ooo`030;md0000M;l0oooo00X0oooo00<0oooO09a8M02oool01P3oool00`3ooml0W4Qd
0;ooo`080?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`400000
0@3oool002L0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0;0?ooo`030;md001d
_ol0oooo00H0oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`1I0?ooo`030000003o
ool0oooo0?l0oooo7@3oool100000040oooo000W0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol02P3oool00`3ooml0W4P004RLg`060?ooo`030?oog`2LB000B9cO00P0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`009`3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo00<0gia80000001d_ol01P3oool00`3O
W4P0000007Boo`080?ooo`<00000F`3oool00`000000oooo0?ooo`3o0?oooaP0oooo100000010?oo
o`009`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0gmoO0?ooo`3o
okl0M0000000000007@0_ooo0080oooo00L0gmoO0?ooo`3ookl0M0000000000007@0_ooo00P0oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3o0?oooaX0oooo0@0000010?ooo`009`3o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0gia80000000000000000
0000B02Lgol30?ooo`060=nLB000000000000000000004P0W=oo2@3oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo0?l0oooo6@3oool100000040oooo000W0?ooo`030?oo_`1d0000B9cO
00<0oooo00<0gia80000M02oool01P3oool0103ookl0M00000000018W=l50?ooo`040?oo_`1d0000
000004RLg`/0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3o0?oooaP0oooo0@00
00010?ooo`00:03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0_g@0
07Boo`3oool01P3oool00`2oM000M;oo0?ooo`0;0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool0o`3ooolG0?ooo`4000000@3oool002P0oooo00L0oono07@0001d_ol0oooo0?noM000
07@0_ooo00P0oooo00H0omnL04P00000000000000000B02Lgol30?ooo`060?oOW018000000000000
000004P0W=oo203oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0oooo5P3oool1
00000040oooo000Y0?ooo`050?oo_`1d000000000000M02oool02P3oool01@2oM000000000000000
0000B9cO00@0oooo00D0_g@0000000000000000004RLg`080?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool0o`3ooolE0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`3o0?oooa@0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo0?l0oooo4`3oool100000040oooo001>0?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`4000000@3oool004h0oooo0P00001V0?ooo`03
0000003oool0oooo0?l0oooo3`3oool300000040oooo001>0?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`3o0?ooo`l0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo0?l0oooo3P3oool100000040oooo001>0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool0o`3oool=0?ooo`4000000@3oool004h0oooo00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`3o0?ooo``0oooo0@0000010?ooo`00CP3oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo0?l0oooo2`3oool100000040oooo001>0?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0o`3oool:0?ooo`4000000@3oool004h0oooo00<00000
0?ooo`3oool0K@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo0@0000010?ooo`00CP3oool20000
06l0oooo00<000000?ooo`3oool0o`3oool60?ooo`<000000@3oool004h0oooo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0@0000010?ooo`00CP3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0?l0oooo1P3oool100000040oooo001>0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0o`3oool50?ooo`4000000@3oool004h0oooo00<00000
0?ooo`3oool0LP3oool00`000000oooo0?ooo`3o0?ooo`@0oooo0@0000010?ooo`00CP3oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo0?l0oooo0`3oool100000040oooo001>0?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool0o`3oool20?ooo`4000000@3oool004h0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`00CP3o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0?l0oooo0@0000010?ooo`00CP3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0?h0oooo0@0000010?ooo`00CP3oool20000
07T0oooo00<000000?ooo`3oool0n`3oool300000040oooo001>0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0o03oool100000040oooo001>0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0n`3oool100000040oooo001>0?ooo`030000003oool0oooo07/0oooo00<0
00000?ooo`3oool0nP3oool100000040oooo001>0?ooo`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool0n@3oool100000040oooo001>0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool0n03oool100000040oooo001>0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool0m`3oool100000040oooo001>0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0
mP3oool100000040oooo001>0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0m@3o
ool100000040oooo001>0?ooo`800000PP3oool00`000000oooo0?ooo`3b0?ooo`<000000@3oool0
04h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3c0?ooo`4000000@3oool004h0
oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`3b0?ooo`4000000@3oool004h0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`3a0?ooo`4000000@3oool004h0oooo00<0
00000?ooo`3oool0Q@3oool00`000000oooo0?ooo`3`0?ooo`4000000@3oool00200oooo00D0omnL
04P000000000001d0;ooo`030?ooo`060?noM0000000M;oo0?ooo`3ooml0W4P00`0000000`1d_ol0
oooo0?ooo`040?ooo`030=nLB018W=l0oooo00<0oooo00<0oooO09a8000000000P0000000`1d_ol0
oooo0?ooo`080?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0k`3oool100000040
oooo000O0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`070?noM0000000M;oo
0?ooo`3ooml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo00@0oooo00<0omnL04Q8W03Oool00`3o
ool00`3ooml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`3^0?ooo`4000000@3oool001l0oooo00<0_g@00018W03Oool00P3oool0
0`2oM00007Bo0?ooo`0:0?ooo`030?oog`2LB7@0_ooo00@0oooo00<0oooO09a8B02Lgol0203oool0
0`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0k@3oool1
00000040oooo000N0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool02`3oool00`2o
M000M;oo0?ooo`040?ooo`030=nLB018W=l0oooo00P0oooo00<0_g@007Boo`3oool01`3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo0>`0oooo0@0000010?ooo`007P3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo00<0oooO09a80018W=l01@3oool00`3ogi`0
B4RL0=ooo`070?ooo`030?oog`2LB000B9cO00P0oooo00<000000?ooo`3oool0RP3oool00`000000
oooo0?ooo`3[0?ooo`4000000@3oool001h0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`0:0?ooo`030=nLB0000000M;oo00D0oooo00<0oooO09a8B02Lgol01`3oool00`3OW4P00000
07Boo`080?ooo`<00000R`3oool00`000000oooo0?ooo`3W0?ooo`@000000@3oool001h0oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`070=oOg`3oool0oono07@000000000
001d0;ooo`060?ooo`030=nLB000M;l0oooo0080oooo00L0gmoO0?ooo`3ookl0M0000000000007@0
_ooo00P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3Y0?ooo`4000000@3oool0
01h0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`060=nLB00000000000
0000000004P0W=oo1`3oool00`3ookl0M01d0;ooo`020?ooo`060=nLB000000000000000000004P0
W=oo2@3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0>P0oooo0@0000010?ooo`00
7P3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00@0oono07@000000000
B9cO103oool00`3ogml0gooo0?ooo`030?ooo`080;md001d_ol0oooo0?ooo`3ookl0M00000000018
W=l;0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0i`3oool100000040oooo000O
0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`2oM000M;oo0?ooo`04
0?ooo`030?oo_`1dB9`0gooo00<0oooo00<0okmd001d_`3oool00P3oool00`2oM000M;oo0?ooo`0;
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0iP3oool100000040oooo000O0?oo
o`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`080?ooo`060?oOW018000000000000000004P0
W=oo0P3oool00`2oM000000000000003000000060000M02oool0oooo0?ooo`3ogi`0B0000P000000
0`0004P0W=oo0?ooo`070?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0i@3oool1
00000040oooo000P0?ooo`050?oo_`1d000000000000M02oool02P3oool01@2oM000000000000000
0000B9cO0080oooo00<0okmd000000000000100000001@1d_ol0oooo0?ooo`3oool0_g@000<00000
00<0B9cO0?ooo`3oool01P3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0>@0oooo
0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0><0oooo0@00
00010?ooo`00CP3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0>80oooo0@000001
0?ooo`00CP3oool2000009D0oooo00<000000?ooo`3oool0g`3oool300000040oooo001>0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0h03oool100000040oooo001>0?ooo`030000
003oool0oooo09H0oooo00<000000?ooo`3oool0g`3oool100000040oooo001>0?ooo`030000003o
ool0oooo09L0oooo00<000000?ooo`3oool0gP3oool100000040oooo001>0?ooo`030000003oool0
oooo09P0oooo00<000000?ooo`3oool0g@3oool100000040oooo001>0?ooo`030000003oool0oooo
09T0oooo00<000000?ooo`3oool0g03oool100000040oooo001>0?ooo`030000003oool0oooo09X0
oooo00<000000?ooo`3oool0f`3oool100000040oooo001>0?ooo`030000003oool0oooo09/0oooo
00<000000?ooo`3oool0fP3oool100000040oooo001>0?ooo`030000003oool0oooo09`0oooo00<0
00000?ooo`3oool0f@3oool100000040oooo001>0?ooo`030000003oool0oooo09d0oooo00<00000
0?ooo`3oool0f03oool100000040oooo001>0?ooo`800000W`3oool00`000000oooo0?ooo`3E0?oo
o`<000000@3oool004h0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`3F0?ooo`40
00000@3oool004h0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`3E0?ooo`400000
0@3oool004h0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`3D0?ooo`4000000@3o
ool004h0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`3C0?ooo`4000000@3oool0
04h0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`3A0?ooo`8000000@3oool004h0
oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`3?0?ooo`030000003oool000000040
oooo001>0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0c@3oool010000000oooo
0?ooo`0000010?ooo`00CP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0</0oooo
00D000000?ooo`3oool0oooo000000010?ooo`00CP3oool200000:P0oooo00<000000?ooo`3oool0
b@3oool00`000000oooo0?ooo`0300000040oooo001>0?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool0a`3oool00`000000oooo0?ooo`030?ooo`4000000@3oool004h0oooo00<00000
0?ooo`3oool0Z@3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00@0oooo0@000001
0?ooo`00CP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0<<0oooo00<000000?oo
o`3oool01@3oool100000040oooo001>0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool0`@3oool00`000000oooo0?ooo`060?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0
[03oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`002`3o
ool00`2oM7@0_ooo0?ooo`040?ooo`030;mdM02oool0oooo03T0oooo00<000000?ooo`3oool0[@3o
ool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`002`3oool0
0`2oM000B9cO0?ooo`030?ooo`030=nLB00007@0_ooo03X0oooo00<000000?ooo`3oool0[P3oool0
0`000000oooo0?ooo`2k0?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`002`3oool02@2o
M00000000000M02oool0oooO09a80018W=l0gibL0;ooo`0j0?ooo`030000003oool0oooo0:l0oooo
00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool000/0oooo00H0
_ibL0=oOW018000000000000B02Lgolm0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool000/0oooo00<0_gAd0;oOW0180000
0P000000100004P0W=oo0=nLW02ooolj0?ooo`800000/P3oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo00X0oooo0`0000010?ooo`002`3oool00`2oM00004RL0=ooo`020?ooo`040;md
00000000001d0;ooocX0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo00d0oooo0@0000010?ooo`002`3oool00`2oM4P0W=oo0?ooo`030?ooo`030?no
M00007@0_ooo03X0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`2b0?ooo`030000
003oool0oooo00d0oooo0@0000010?ooo`002`3oool00`2oW9`0gooo0?ooo`040?ooo`030=nLW02o
ool0oooo03T0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo00h0oooo0@0000010?ooo`00<P3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0
okmd0000001d_ol00`3oool01@3ogi`0B000000000000000M;oo00T0oooo00<000000?ooo`3oool0
]@3oool010000000oooo0?ooo`3oool300000:X0oooo00<000000?ooo`3oool03`3oool100000040
oooo000?0?ooo`030;nLW03Oool0oooo0080oooo00<0gibL0;ooo`3oool06P3oool01`3ookl0M000
07Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?ooo`070?oOW0180000B9cO
0?ooo`3ookl0M00007Boo`080?ooo`030000003oool0oooo0;H0oooo2000002W0?ooo`030000003o
ool0oooo0100oooo0@0000010?ooo`002`3oool01@3ookl0M01809cOo`3ookl0M00000@0000000<0
001d0;ooo`3oool06P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0
oooO09a80000M;l00`3oool00`3o_g@004RL0=ooo`070?ooo`030000003oool0oooo0;H0oooo2@00
002U0?ooo`030000003oool0oooo0140oooo0@0000010?ooo`00503oool00`3OW9`0_ooo0?ooo`0I
0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`3ogi`0B00007Boo`03
0?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0]P3oool900000:@0oooo00<00000
0?ooo`3oool04P3oool100000040oooo000`0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000
B02Lgol01@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00<000000?oo
o`3oool0]@3oool;00000:80oooo00<000000?ooo`3oool04`3oool100000040oooo000`0?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0B00007Boo`030?ooo`03
0;md000004P0W=oo00L0oooo0`00002e0?ooo`/00000X@3oool00`000000oooo0?ooo`0A0?ooo`@0
00000@3oool00140oooo00<0_gAd0;ooo`3oool0703oool00`3ogi`0B00007Boo`030?ooo`030?no
M00004P0W=oo00D0oooo00P0oono07@000000000B9cO0?ooo`3o_g@00000001d_`P0oooo00<00000
0?ooo`3oool0]@3oool;00000:00oooo00<000000?ooo`3oool05@3oool100000040oooo000A0?oo
o`030;mdM02oool0oooo01`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?oo
o`030;md0000B9`0_ia80080000000<004RL0=ooo`3oool01`3oool00`000000oooo0?ooo`2f0?oo
o`T00000X03oool00`000000oooo0?ooo`0F0?ooo`4000000@3oool00140oooo00<0_gAd0;ooo`3o
ool0703oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0omnL04P0001d
_ol0303oool00`000000oooo0?ooo`2f0?ooo`T00000W`3oool00`000000oooo0?ooo`0G0?ooo`40
00000@3oool000h0oooo00<0_g@00000000000000`0000000`0007@0_ooo0?ooo`0J0?ooo`030=nL
B000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`3OW4P0001809cOo`0;0?ooo`030000
003oool0oooo0;L0oooo2000002N0?ooo`030000003oool0oooo01P0oooo0@0000010?ooo`004@3o
ool00`2oM7@0_ooo0?ooo`0M0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`090?ooo`03
0?noM000000007Bo00X0oooo00<000000?ooo`3oool0^@3oool3000000<0oooo00<000000?ooo`3o
ool0VP3oool00`000000oooo0?ooo`0I0?ooo`4000000@3oool00140oooo00<0_gAd0;ooo`3oool0
7P3oool01@3ookl0M0000000000007@0_ooo00/0oooo00D0oooO09a800000000001d0;ooo`070?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2H0?oo
o`030000003oool0oooo01X0oooo0@0000010?ooo`004@3oool00`2oM7@0_ooo0?ooo`0j0?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2F0?ooo`03
0000003oool0oooo01/0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0L0?ooo`400000
0@3oool000`0oooo00<0oooO09adW03Oool01@3oool00`3OW9`0_ooo0?ooo`0g0?ooo`800000^`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool06`3o
ool300000040oooo000<0?ooo`030?noM0000000000000D0000000<0001d0;ooo`3oool0=`3oool0
0`000000oooo0?ooo`2j0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0N0?ooo`4000000@3oool001@0oooo00<0gibL0;ooo`3oool0=`3oool00`00
0000oooo0?ooo`2j0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0O0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0803oool100000040
oooo001>0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`2:0?ooo`030000003oool0oooo0240oooo0@0000010?ooo`00CP3oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`0R0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool08`3oool100000040oooo001>0?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo02@0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0U0?ooo`40
00000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0800oooo00<000000?ooo`3oool09P3oool100000040oooo001>0?ooo`800000^`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool09@3o
ool300000040oooo001>0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo02P0oooo0@0000010?ooo`00CP3oool00`00
0000oooo0?ooo`2j0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`0Y0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0:P3oool100000040
oooo001>0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo02/0oooo0@0000010?ooo`00CP3oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`0/0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0;03oool100000040oooo001>0?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo02d0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0^0?ooo`40
00000@3oool004h0oooo0P00002k0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`0]0?ooo`<000000@3oool004h0oooo00<000000?ooo`3oool0^P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0<03o
ool100000040oooo001>0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0340oooo0@0000010?ooo`00CP3oool00`00
0000oooo0?ooo`2j0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`0b0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000
oooo0?ooo`0M0?ooofX00000=03oool100000040oooo001>0?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0000003@0oooo
0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01h0oooo0P00
001S0?ooo`040000003oool0oooo000003@0oooo0@0000010?ooo`00CP3oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`000000H@3oool01@000000oooo0?oo
o`3oool0000003@0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo01h0oooo00@000000?ooo`3oool00000G`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0380oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo01h0oooo00D000000?ooo`3oool0oooo0000001M0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0<P3oool100000040oooo001>0?ooo`800000^`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0300oooo0`0000010?ooo`00CP3oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<P3oool100000040oooo001>0?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0b0?oo
o`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0380oooo0@0000010?ooo`00803oool01@3ogi`0B0000000000007@0_ooo00<0
oooo00<0okmd0000001d_ol00`3oool01@3ogi`0B000000000000000M;oo0080oooo00<0_g@00000
00000000100000001018W=l0oooo0?oog`2LB0030000000307Boo`3oool0oooo00P0oooo00<00000
0?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0380oooo0@000001
0?ooo`007`3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Bo
o`020?ooo`070?oOW0180000B9cO0?ooo`3ookl0M00007Boo`020?ooo`030=nLB0000000000000<0
000000D004RL0=ooo`3ooml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo00P0oooo00<000000?oo
o`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0CP3oool2000000/0oooo00<000000?ooo`3oool0<P3oool100000040oooo000O0?ooo`03
0;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3ooml0W4P0001d_`030?ooo`03
0?noM000B9`0gooo0080oooo00<0gia804RLg`3oool00P3oool00`3OW7@0W=oo0?ooo`040?ooo`03
0?oog`2LB7@0_ooo00P0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0380oooo0@0000010?ooo`007P3oool00`3ookl0M00004RLg`030?ooo`030=nL
B00007@0_ooo00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`030?ooo`030=nL
B01d_ol0oooo00T0oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`2j0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0<P3oool100000040oooo000N0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0B00007Boo`030?ooo`030?noM000
04P0W=oo00@0oooo00<0_gA809cOo`3oool01`3oool00`3ooml0W4P004RLg`080?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0b0?ooo`4000000@3o
ool001h0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000
M;oo00<0oooo00<0_g@00000B02Lgol0103oool00`3ooml0W4Qd0;ooo`070?ooo`030=nLB0000000
M;oo00P0oooo0`00002j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;`3oool4
00000040oooo000N0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool0203o
okl0M00000000018W=l0oooo0?noM000000007Bo1P3oool00`3o_g@007Bo0?ooo`020?ooo`070=oO
g`3oool0oono07@000000000001d0;ooo`080?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04<0oooo0P00000A0?oo
o`030000003oool0oooo0380oooo0@0000010?ooo`007P3oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo00H0oooo00<0_g@00018W02oW4P00P0000000`00B9`0gooo0?ooo`050?ooo`03
0?oo_`1d04P0W=oo0080oooo00H0gia800000000000000000000B02Lgol90?ooo`030000003oool0
oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool0
01h0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030?oOW0180000M;oo
00X0oooo00<0oono07@00018W=l00P3oool0103ookl0M00000000018W=l;0?ooo`030000003oool0
oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool0
01l0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030=nLB00004P0W=oo
00@0oooo00<0oknL09cOo`3oool00P3oool00`3ogi`0B00004RLg`030?ooo`030;md001d_ol0oooo
00/0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00l0oooo@`00000C0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`007`3oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool02@3oool00`3o_g@00000001d_`030?ooo`080?oog`2LB4P0
W=oo0?ooo`3ookl0M0000000M02oool30?ooo`060?oOW018000000000000000004P0W=oo203oool0
0`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool2
000003d0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`0b0?ooo`4000000@3o
ool00200oooo00D0oono07@000000000001d0;ooo`0;0?ooo`080?oog`2LB00000000000M02oool0
oooo0?oog`2LB002000000030000M02oool0oooo00@0oooo00D0_g@0000000000000000004RLg`08
0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0000003X0oooo0P0000030?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0<P3oool100000040oooo001>0?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000003P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo0@000001
0?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool03`3oool01@000000oooo0?ooo`3oool0000003H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00CP3oool00`00
0000oooo0?ooo`2j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00CP3oool200000;/0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0<03oool300000040oooo001>0?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0;@3oool2000000T0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0b0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0b0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b
0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?oo
o`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool[000000`0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0
^P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
203oool2000002@0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0<P3oool100000040oooo001>0?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`0000008P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool004h0oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0203oool010000000oooo0?ooo`00000P0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo
0@0000010?ooo`00CP3oool200000;/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0300oooo0`0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool06@3oool2000000L0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00CP3oool0
0`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0b0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?oooa`000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0<P3oool100000040oooo001>0?ooo`030000003oool0oooo0;X0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0103oool2000001D0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?oo
o`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`03
0000003oool0000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`40
00000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo00000100oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00
CP3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
oooo4`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00CP3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`40
00000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo0P00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool004h0oooo0P00002k0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0`0?ooo`<000000@3o
ool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000001@3oool2000000H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0b0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0b0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo00000009
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<P3oool100000040oooo001>0?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0380oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`40
00000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool004h0oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0<P3oool100000040oooo001>0?ooo`030000003oool0oooo0;X0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`800000203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<P3oool100000040oooo001>0?oo
o`800000^`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0<03oool300000040oooo001>0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`03000000/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00CP3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool>000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool004h0oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`8000004@3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00CP3oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00:@3oool01@3ogi`0B00000000000
07@0_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3ogi`0B000000000000000M;oo0080oooo
00<0oooO09a8000000000P0000000`1d_ol0oooo0?ooo`080?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00`3oool2000001@0oooo0P0000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo
0@0000010?ooo`00:03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0
000007Boo`020?ooo`0;0?oOW0180000B9cO0?ooo`3ookl0M00007Boo`3oool0oooO09a8M02oool0
0P3oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0
oooo0P0000000`3oool000000000000E000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<P3oool100000040
oooo000X0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3ooml0W4P0
001d_`030?ooo`030?noM000B9`0gooo00D0oooo00<0oooO09a8M02oool0203oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`080?ooo`040000003oool0oooo000001X0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?oo
o`4000000@3oool002L0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool00`2oM000M;oo0?ooo`070?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`000000703oool010000000oooo0?ooo`0000070?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?oo
o`4000000@3oool002L0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ooml0W4P004RLg`080?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00P0oooo0P00000N0?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00
9`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol0
0`3oool00`2oM000001809cOo`050?ooo`030=nLB0000000M;oo00P0oooo0`00002j0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01h0oooo0P0000070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0_0?ooo`@000000@3oool002L0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`050?ooo`080?oo_`1d0000000004RLg`3oool0okmd00000000M;l20?oo
o`070=oOg`3oool0oono07@000000000001d0;ooo`080?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo9@00
00070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0b0?ooo`4000000@3oool002L0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`06
0?ooo`030;md0000B9`0_ia80080000000D004RL0=ooo`3oool0oooo0=nLB003000000030000B02L
gol0oooo00P0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0380oooo0@0000010?ooo`009`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0
_ooo00H0oooo00<0omnL04P0001d_ol01P3oool0103ookl0M00000000018W=l;0?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`4000000@3o
ool002P0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030=nLB00004P0
W=oo00H0oooo00<0_g@007Boo`3oool02`3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0<P3oool100000040oooo000X0?ooo`070?oo_`1d0000M;oo
0?ooo`3o_g@0001d0;ooo`090?ooo`030?noM000000007Bo00D0oooo00H0omnL04P0000000000000
0000B02Lgol80?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool01@000000
oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?oo
o`4000000@3oool002T0oooo00D0oono07@000000000001d0;ooo`0;0?ooo`050?oog`2LB0000000
0000M02oool00`3oool01@2oM0000000000000000000B9cO00P0oooo00<000000?ooo`3oool0^P3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P00
000]0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0b0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`000000<03oool00`000000oooo0000
000<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<P3oool100000040oooo001>
0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0?
0?ooo`800000<P3oool2000000`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b
0?ooo`4000000@3oool004h0oooo0P00002k0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool03P3ooolg000000`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0`0?oo
o`<000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0<P3oool100000040oooo001>0?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0;0?ooo`800000
>@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
<P3oool100000040oooo001>0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00CP3oool0
0`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool2
000003h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0380oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool004h0
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00D0
oooo0P0000130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0b0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<P3oool100000040oooo
001>0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`020?ooo`800000B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0<P3oool100000040oooo001>0?ooo`030000003oool0oooo0;X0oooo00<00000
0?ooo`3oool07P3oool01@000000oooo0?ooo`3oool0000004/0oooo00D000000?ooo`3oool0oooo
0000000C0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00CP3oool200000;/0oooo00<0
00000?ooo`3oool07P3oool010000000oooo00000000001=0?ooo`040000003oool0oooo000001<0
oooo00<000000?ooo`3oool0<03oool300000040oooo001>0?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool07P3oool200000500oooo00<000000?ooo`0000004`3oool00`000000oooo
0?ooo`0b0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?oo
o`0M0?oooeH000004`3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool004h0oooo00<00000
0?ooo`3oool0^P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool004h0oooo00<000000?oo
o`3oool0^P3oool00`000000oooo0?ooo`0J0?ooo`800000E`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0380oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0380oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`030000
003oool0oooo01L0oooo0P00001L0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
<P3oool100000040oooo001>0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<P3o
ool100000040oooo001>0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0503oool2
00000640oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool0
04h0oooo0P00002k0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0300oooo0`0000010?ooo`00CP3oool00`000000
oooo0?ooo`2j0?ooo`030000003oool0oooo0140oooo0P00001V0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0<P3oool100000040oooo001>0?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0<P3oool100000040oooo001>0?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool03P3oool2000006/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0b0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0b
0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0;0?oo
o`800000L03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0380oooo0@0000010?oo
o`00CP3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00
CP3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo00P0oooo0P00001e0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0<P3oool100000040oooo001>0?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0<P3oool100000040oooo001>0?ooo`800000^`3oool0
0`000000oooo0?ooo`050?ooo`800000NP3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0300oooo0`0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo
00<0oooo0P00001m0?ooo`050000003oool0oooo0?ooo`000000=03oool100000040oooo001>0?oo
o`030000003oool0oooo0;X0oooo00@000000?ooo`3oool0oooo0P0000200?ooo`040000003oool0
oooo000003@0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2j0?ooo`040000003oool0
0000000008<0oooo00<000000?ooo`000000=03oool100000040oooo001>0?ooo`030000003oool0
oooo0;X0ooooRP00000d0?ooo`4000000@3oool00200oooo00D0omnL04P000000000001d0;ooo`03
0?ooo`030?noM0000000M;oo00<0oooo00D0omnL04P000000000000007Boo`050?ooo`030=nLB018
W=l0oooo00<0oooo00<0oooO09a8000000000P0000000`1d_ol0oooo0?ooo`080?ooo`030000003o
ool0oooo0;P0oooo0P0000290?ooo`030000003oool0oooo0380oooo0@0000010?ooo`007`3oool0
1`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?ooo`070?oO
W0180000B9cO0?ooo`3ookl0M00007Boo`040?ooo`030?oOW018B9`0gooo00<0oooo00<0oooO09a8
M02oool00P3oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo0;L0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`0a0?ooo`4000000@3oool001l0oooo00<0_g@00018W03O
ool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03O
ool00`3oool00`3ooml0W4Q809cOo`080?ooo`030?oog`2LB7@0_ooo00P0oooo00<000000?ooo`3o
ool0]@3oool2000008h0oooo00<000000?ooo`3oool0<03oool100000040oooo000N0?ooo`030?oo
_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`3ogi`0B00007Boo`030?ooo`030?no
M00004P0W=oo00@0oooo00<0gia804RLg`3oool0203oool00`2oM000M;oo0?ooo`070?ooo`030000
003oool0oooo0;<0oooo0P00002A0?ooo`030000003oool0oooo02l0oooo0@0000010?ooo`007P3o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`040?ooo`030?oOW018B9`0gooo00L0oooo00<0oooO09a80018W=l0203o
ool00`000000oooo0?ooo`2a0?ooo`800000U03oool00`000000oooo0?ooo`0^0?ooo`4000000@3o
ool001h0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000
M;oo00<0oooo00<0_g@00000B02Lgol0103oool00`3ooml0W4Q809cOo`070?ooo`030=nLB0000000
M;oo00P0oooo0`00002_0?ooo`800000U`3oool00`000000oooo0?ooo`0Z0?ooo`@000000@3oool0
01h0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`080?oo_`1d00000000
04RLg`3oool0okmd00000000M;l60?ooo`030=nLB000M;l0oooo0080oooo00L0gmoO0?ooo`3ookl0
M0000000000007@0_ooo00P0oooo00<000000?ooo`3oool0[@3oool2000009X0oooo00<000000?oo
o`3oool0;03oool100000040oooo000N0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01P3oool00`2oM00004RL0;nLB002000000030018W03Oool0oooo00D0oooo00<0oono07@0M02o
ool00P3oool01P3OW4P00000000000000000001809cOo`T0oooo00<000000?ooo`3oool0Z`3oool2
000009d0oooo00<000000?ooo`3oool0:`3oool100000040oooo000N0?ooo`030?oo_`1d0000B9cO
00<0oooo00<0gia80000M02oool01P3oool00`3ogi`0B00007Boo`050?ooo`030?oOg`3Oool0oooo
00<0oooo00P0_g@007Boo`3oool0oooo0?oo_`1d0000000004RLg`/0oooo00<000000?ooo`3oool0
ZP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02X0oooo0@0000010?ooo`007`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000B02Lgol0103o
ool00`3ookl0M4RL0=ooo`030?ooo`030?noM000M;l0oooo0080oooo00<0_g@007Boo`3oool02`3o
ool00`000000oooo0?ooo`2X0?ooo`800000XP3oool00`000000oooo0?ooo`0Y0?ooo`4000000@3o
ool001l0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00T0oooo00<0okmd00000000M;l0
103oool00`2oM000000000000003000000060000M02oool0oooo0?ooo`3ogi`0B0000P0000000`00
04P0W=oo0?ooo`070?ooo`030000003oool0oooo0:H0oooo0P00002U0?ooo`030000003oool0oooo
02P0oooo0@0000010?ooo`00803oool01@3ookl0M0000000000007@0_ooo00/0oooo00L0oooO09a8
00000000001d0;ooo`3oool0okmd00H0000000D0M;oo0?ooo`3oool0oooo0;md00030000000304RL
g`3oool0oooo00H0oooo00<000000?ooo`3oool0Y03oool200000:P0oooo00<000000?ooo`3oool0
9`3oool100000040oooo001>0?ooo`030000003oool0oooo0:80oooo0P00002[0?ooo`030000003o
ool0oooo02H0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`2P0?ooo`800000[P3oool0
0`000000oooo0?ooo`0U0?ooo`4000000@3oool004h0oooo0P00002O0?ooo`800000/@3oool00`00
0000oooo0?ooo`0R0?ooo`<000000@3oool004h0oooo00<000000?ooo`3oool0W03oool200000;@0
oooo00<000000?ooo`3oool08`3oool100000040oooo001>0?ooo`030000003oool0oooo09X0oooo
0P00002g0?ooo`030000003oool0oooo0280oooo0@0000010?ooo`00CP3oool00`000000oooo0?oo
o`2G0?ooo`<00000^P3oool00`000000oooo0?ooo`0Q0?ooo`4000000@3oool004h0oooo00<00000
0?ooo`3oool0U@3oool200000;h0oooo00<000000?ooo`3oool0803oool100000040oooo001>0?oo
o`030000003oool0oooo0980oooo0`0000310?ooo`030000003oool0oooo01l0oooo0@0000010?oo
o`00CP3oool00`000000oooo0?ooo`2@0?ooo`800000a@3oool00`000000oooo0?ooo`0N0?ooo`40
00000@3oool004h0oooo00<000000?ooo`3oool0S@3oool300000<P0oooo00<000000?ooo`3oool0
7@3oool100000040oooo001>0?ooo`030000003oool0oooo08/0oooo0P00003<0?ooo`8000007@3o
ool100000040oooo001>0?ooo`030000003oool0oooo08P0oooo0`00003@0?ooo`030000003oool0
oooo01X0oooo0@0000010?ooo`00CP3oool2000008L0oooo0P00003D0?ooo`030000003oool0oooo
01L0oooo0`0000010?ooo`00CP3oool00`000000oooo0?ooo`230?ooo`<00000e`3oool00`000000
oooo0?ooo`0H0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0P@3oool200000=/0oooo
00<000000?ooo`3oool05`3oool100000040oooo001>0?ooo`030000003oool0oooo07h0oooo0`00
003N0?ooo`030000003oool0oooo01H0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`1l
0?ooo`800000hP3oool00`000000oooo0?ooo`0E0?ooo`4000000@3oool004h0oooo00<000000?oo
o`3oool0N@3oool300000>D0oooo00<000000?ooo`3oool0503oool100000040oooo001>0?ooo`03
0000003oool0oooo07L0oooo0P00003Y0?ooo`030000003oool0oooo01<0oooo0@0000010?ooo`00
CP3oool00`000000oooo0?ooo`1d0?ooo`<00000k03oool00`000000oooo0?ooo`0B0?ooo`400000
0@3oool004h0oooo00<000000?ooo`3oool0L@3oool300000?00oooo00<000000?ooo`3oool04@3o
ool100000040oooo001>0?ooo`800000KP3oool400000?@0oooo00<000000?ooo`3oool03P3oool3
00000040oooo001>0?ooo`030000003oool0oooo06X0oooo0`00003i0?ooo`030000003oool0oooo
00l0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`1W0?ooo`<00000o@3oool00`000000
oooo0?ooo`0>0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0H`3oool400000?l0oooo
0P3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0H03o
ool300000?l0oooo1`3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool004h0oooo00<00000
0?ooo`3oool0G@3oool300000?l0oooo2`3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool0
04h0oooo00<000000?ooo`3oool0F@3oool400000?l0oooo3`3oool00`000000oooo0?ooo`0:0?oo
o`4000000@3oool004h0oooo00<000000?ooo`3oool0E@3oool400000?l0oooo503oool00`000000
oooo0?ooo`090?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0D@3oool400000?l0oooo
6@3oool00`000000oooo0?ooo`080?ooo`4000000@3oool004h0oooo00<000000?ooo`3oool0C@3o
ool400000?l0oooo7P3oool00`000000oooo0?ooo`070?ooo`4000000@3oool004h0oooo0P000019
0?ooo`D00000o`3ooolS0?ooo`030000003oool0oooo00@0oooo0`0000010?ooo`00CP3oool00`00
0000oooo0?ooo`130?ooo`D00000o`3ooolY0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`00CP3oool00`000000oooo0?ooo`0o0?ooo`@00000o`3oool_0?ooo`030000003oool0oooo00@0
oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`0j0?ooo`D00000o`3ooold0?ooo`030000
003oool0oooo00<0oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`0e0?ooo`D00000o`3o
oolj0?ooo`030000003oool0oooo0080oooo0@0000010?ooo`00CP3oool00`000000oooo0?ooo`0_
0?ooo`H00000o`3ooom00?ooo`050000003oool0oooo0?ooo`0000000@3oool004h0oooo00<00000
0?ooo`3oool0:@3oool600000?l0ooooA`3oool010000000oooo0?ooo`0000010?ooo`00CP3oool0
0`000000oooo0?ooo`0Q0?ooo`P000000`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
00000040oooo001>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`3oool=00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo0P0000010?ooo`00CP3ooooo000007d000000@3oool00?l0
ooooc03oool00?l0ooooc03oool00?l0ooooc03oool00?l0ooooc03oool00?l0ooooc03oool00?l0
ooooc03oool00?l0ooooc03oool00?l0oooo?@3oool00`3ooml0W4Q809cOo`0V0?ooo`030?oOW018
B9`0gooo06<0oooo003o0?ooocd0oooo00<0_gA809cOo`3oool09`3oool00`3ogi`0B7Bo0?ooo`1R
0?ooo`00o`3oooll0?ooo`030=nLB018W=l0oooo02T0oooo00<0gia804RLg`3oool0H@3oool00?l0
oooo>`3oool00`3ookl0M01d0;ooo`0Z0?ooo`030?oo_`1d04P0W=oo0640oooo002Q0?ooo`030?oO
W018000000000080000000<0001d0;ooo`3oool00`3oool01@3OW4P00000000000000000M;oo00<0
oooo00H0oooO09a80000000000000000B02Lgol50?ooo`030?oOW01dW=l0oooo0080oooo00<0giad
09cOo`3oool0103oool01@2oM00000000000000007@0_ooo0080oooo00H0oooO09a8000000000000
0000B02Lgol60?ooo`030;md0000000000000080000000<007Bo0?ooo`3oool00`3oool01`3OW4P0
00000000000007@0_ooo0?ooo`3OW4P00`000000201d_ol0oooo0?ooo`3oool0omnL04P000000000
B9cO1@3oool00`3ogi`0B000000000020000000407Boo`3oool0oooo0=nLB0<0000000@0M;oo0?oo
o`3oool0_g@00P0000001P0004P0W=oo0?oog`2LB000001d0;ooo`H0oooo00<0_g@0000000000000
100000001P18W=l0oooo0?ooo`3o_g@0000007Boo`<0oooo00D0gia8000000000000000004RLg`07
0?ooo`030=nLB000B9`0gooo00@0oooo00H0_g@000000000000000000018W03OoolE0?ooo`050;md
0000000007Bo0?ooo`3OW4P00P0000001`00B9`0gooo0?ooo`3oool0oooO09a80018W=l01@3oool0
1@2oM0000000001d_`3oool0gia80080000000<004RL0=ooo`3oool0DP3oool00:00oooo00@0gia8
00000000B9`0gooo0P3oool00`3ookl0M01809cOo`020?ooo`070=nLB0000000B9cO0?ooo`3ooml0
W4P004RLg`020?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B00007Boo`040?ooo`070;md000007@0
_ooo0?ooo`3ookl0M000001d_`040?ooo`0?0;md0000000007Bo0?ooo`3ogi`0B01d0;ooo`3oool0
_g@00018W03Oool0oooo0?oOW0180000M;oo00H0oooo00@0oooO09a80000B9`0gooo1`3oool02`3O
W4P0001d0;ooo`3oool0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00D0gia80000M02o
ool0gkno0=ooo`050?ooo`030?oog`2LB00007Bo00<0oooo00L0gia800000018W=l0oooo0?oog`2L
B000B9cO0080oooo00P0gia80000M02oool0oooo0?oog`2LB000001d0;ooo`L0oooo00<0gia80000
000000000`0000001P00B9`0gooo0?ooo`3o_g@0000007Boo`80oooo00L0gia80000001d_ol0oooo
0?oog`2LB000B9cO00H0oooo00<0_g@0001d_`3oool01@3oool00`3ogi`0B00007Boo`0G0?ooo`08
0?oog`2LB7@0_ooo0?ooo`3ooml0W4P00018W03Oool40?ooo`030=nLB000B9`0gooo00@0oooo00P0
oooO09a8M02oool0oooo0?oog`2LB00004RL0=oooe@0oooo002O0?ooo`030?noM000000007Bo00D0
oooo00H0oooO09a8M02oool0omnL04P00000M;l30?ooo`070?noM00007@0_ooo0?ooo`2oM00004RL
0=ooo`020?ooo`030?noM00007@0_ooo0080oooo00T0omnL04P00018M7@0M9cO0?ooo`3o_g@00018
04Q8B02Lgol00P3oool00`3ogi`0B00004RLg`030?ooo`060?oOW01dW=l0oooo0;md0000B9`0gooo
0P3oool00`3o_g@0001d0;ooo`050?ooo`030?oog`2LB00007Bo00P0oooo00H0gia80000M02oool0
omnL04P00000M;l30?ooo`070?noM00007@0_ooo0?ooo`3OW4P004RL0=ooo`070?ooo`030?oog`2L
B00007Bo0080oooo00<0omnL04P00000M;l00`3oool01`3o_g@0001d0;ooo`3oool0gia80000M02o
ool03@3oool00`3OW4P0B9cO0?ooo`020?ooo`030=nLM02Lgol0oooo00@0oooo00<0oooO09a80000
M;l00`3oool00`3o_g@004RL0=ooo`040?ooo`030?oo_`1d0000B9cO00H0oooo00<0omnL04P0001d
_ol0603oool01P3ookl0M4RL0=ooo`2oM000001d0;ooo`D0oooo00<0gia80000M02oool01@3oool0
1P3ookl0M4RL0=ooo`2oM000001d0;oooeD0oooo002N0?ooo`040?oog`2LB000001d0;ooo`P0oooo
00<0okmd0000001d_ol00`3oool01`3o_g@0000007Boo`3oool0_g@00018W03Oool00P3oool00`3o
gi`0B00007Boo`020?ooo`090=nLB00007@0_ooo0;mdM02ooml0W4P0001d_`3ogi`0M9cO0080oooo
00<0okmd0000B02Lgol01P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000M;oo00D0oooo
00<0oooO09a80000M;l0203oool01P3OW4P0001d0;ooo`3o_g@0000007Boo`<0oooo00L0okmd0000
001d_ol0oooo0=nLB000B9`0gooo00L0oooo00<0oooO09a80000M;l00P3oool00`3o_g@0000007Bo
o`030?ooo`070?noM0000000M;oo0?ooo`3OW4P0001d0;ooo`0>0?ooo`030=nLB01d_ol0oooo00T0
oooo00<0_g@0001d_`3oool00P3oool00`2oM00004RL0=ooo`040?ooo`030?oo_`1d0000M;oo00H0
oooo00<0omnL04P0001d_ol06@3oool0103ogi`0M4Q80000001d_ol60?ooo`030?noM00007@0_ooo
00H0oooo00@0omnL07A8B0000000M;ooEP3oool009h0oooo00@0omnL04P00000B9`0gooo203oool0
0`3o_g@0000007Boo`030?ooo`070?noM0000000M;oo0?ooo`2oM00004RL0=ooo`020?ooo`0C0?oO
W0180000M;oo0?ooo`3ookl0M00004RLg`3oool0omnL07AdM01804P0W=oo0?ooo`2oM7@0_ooo0?oo
o`3o_g@0001d0;ooo`060?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P0001d_ol01@3oool0
0`3ooml0W4P0001d_`080?ooo`060=nLB00007@0_ooo0?noM0000000M;oo0`3oool01`3o_g@00000
07Boo`3oool0gia80018W03Oool01`3oool00`3ooml0W4P0001d_`020?ooo`030?noM0000000M;oo
00<0oooo00L0okmd0000001d_ol0oooo0=nLB00007@0_ooo00l0oooo00<0_gA809cOo`3oool0203o
ool01`3ogi`0B01d0;ooo`3oool0_g@00000001d_ol01@3oool00`3ookl0M00007Boo`060?ooo`03
0?oOW0180000M;oo00L0oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?ooo`050?ooo`03
0?oo_`1d0000B9cO00L0oooo00<0okmd0000B02Lgol01P3oool00`3ookl0M00004RLg`1G0?ooo`00
WP3oool00`3o_g@00000001d_`090?ooo`030?oo_`1d0000M;oo00<0oooo00L0_g@00000B02Lgol0
oooo0;md0000B9`0gooo0080oooo00/0okmd0000B02Lgol0oooo0=nLB00004P0W=oo0?ooo`3ooml0
W4P0001d_`020?ooo`050?noM018W=l0oooo0?oOW01800001@0000001@18W=l0oooo0;md0000B9`0
gooo0080oooo00<0okmd0000B02Lgol01@3oool00`3ooml0W4P0000000040000000:07Boo`3oool0
oooo0?ooo`3OW4P0001d0;ooo`3ookl0M00007Boo`<0oooo00L0_g@00000B02Lgol0oooo0=nLB000
B9`0gooo00L0oooo00<0oooO09a80000M;l00P3oool00`3ookl0M00007Boo`030?ooo`070;md0000
04P0W=oo0?ooo`3OW4P0001809cOo`0?0?ooo`030?oog`2LB7@0_ooo00T0oooo00D0oono07A8B018
0000000004RLg`060?ooo`030?oo_`1d0000M;oo00H0oooo00<0omnL04P0001d_ol0603oool01@3o
oml0W4P00018W02LM4P0W=oo00H0oooo00<0okmd0000M02oool01@3oool01@3ooml0W4P00018W02L
M4P0W=oo05H0oooo002N0?ooo`030?noM000000007Bo00X0oooo00L0gia80018W03Oool0oooo0?no
M000000007Bo0080oooo00/0_g@000000000B9`0gooo0?oo_`1d000004RL0=ooo`3ookl0M000001d
_`020?ooo`030?oOW0180000M;oo0080oooo00H0oooO09a8M02oool0oooo0;md0018W=l20?ooo`0<
0=nLB00004P0W=oo0?ooo`2oM00000000018W03Oool0oono07@00000B9`0gooo1@3oool00`3ooml0
W4P0001d_`020?ooo`040?oog`2LB000000004RLg`80oooo00/0gia80000M02oool0oooo0=nLB000
B9`0gooo0?ooo`3o_g@00000001d_`020?ooo`030=nLB000B9`0gooo00L0oooo00<0oooO09a80000
M;l00`3oool04@3OW4P004RL0=ooo`3oool0okmd00000000M;l0oooO09a800000000001804QdW03O
_g@0001V07A8000007@0_ooo00/0oooo00<0okmd001d_`3oool0203oool0103ogi`0B00000000000
M;l70?ooo`030?oo_`1d0000B9cO00H0oooo00<0omnL04P0001d_ol0603oool01P2oM000001809cO
o`3ooml0W4Qd0;ooo`D0oooo00<0gia80000M02oool01@3oool01P2oM000001809cOo`3ooml0W4Qd
0;oooeD0oooo002N0?ooo`040?oOW018000004RL0=ooo`X0oooo00D0okmd000000000000000004RL
g`030?ooo`090;md0000B9`0gmnL04P00000000004RL0=ooo`3ooml0W4P00080000000<0B9cO0?no
M00000000P0000002018W=l0oooo0;md0000000004RL0=ooo`3oool0gia80P0000002`0004P0W=oo
0?ooo`3oool0_g@00018W03Ogi`0B00000000000B9`0gooo00H0oooo00<0oooO09a80000M;l00`3o
ool0203ookl0M0000000M02oool0oooo0=nLB00007@0_ooo0P3oool01@3o_g@00000000000000000
B9cO0080oooo00H0_g@000000000000000000018W03Oool40?ooo`030?noM0000000000000800000
00@004RL0=ooo`3oool0okmd0`0000003018W=l0oooo0?ooo`3oool0_g@00000M02ogi`0B0000000
IP1dB000001d0;ooo`/0oooo00<0oono07@0B02Lgol01`3oool01P3ogi`0B0000000M02oool0okmd
001d_`H0oooo00<0oooO09a80018W=l01P3oool00`3ogi`0B00007Boo`0F0?ooo`090?oog`2LB000
000000000000M;l0okmd0000000007@0_ooo00@0oooo00<0gia80018W03Oool00`3oool02@3ooml0
W4P000000000000007Bo0?noM0000000001d0;ooo`1D0?ooo`00WP3oool0103ooml0W4P00000B02L
gol50?ooo`030?oog`2LM9`0gooo00X0oooo00<0_g@00018W03Oool06`3oool00`2oM00004RL0=oo
o`0:0?ooo`030?oog`2LB00007Bo00<0oooo00P0oooO09a8000004P0W=oo0?ooo`3OW4P0001d0;oo
o`X0oooo00<0_g@00018W03Oool01`3oool00`3ooml0W4P0001d_`0O0?ooo`030?oo_`1d0000B9cO
00L0oooo00<0_g@00000M02oool00P3oool00`2oM000B9cO0?ooo`050?ooo`030=nLB000B9`0gooo
00D0oooo00<0omnL04P0001d_ol08P3oool00`3ooml0W4P004RLg`1Q0?ooo`00W`3oool00`3ogi`0
B000001d_`050?ooo`030?noM000B9`0gooo00X0oooo00<0_g@00018W03Oool06`3oool00`2oM000
04RL0=ooo`0:0?ooo`030?oog`2LB00007Bo00<0oooo00P0omnL04P0000007@0_ooo0?ooo`3OW4P0
001d0;ooo`X0oooo00<0oono07A8W03Oool0203oool00`2oM00007Bo0?ooo`0I0?ooo`030?noW02L
gol0oooo0080oooo00<0omnL04P00018W=l01`3oool00`2oM00004RL0=ooo`020?ooo`030=nLB000
M;l0oooo00D0oooo00<0oono07@0B02Lgol01@3oool00`3ogi`0B00007Boo`0R0?ooo`030?oo_`1d
04P0W=oo0640oooo002P0?ooo`030?noM000000007Bo00<0oooo00<0gia800000000M;l02`3oool0
0`2oM00004RL0=ooo`0K0?ooo`030;md0000B9`0gooo00X0oooo00<0oooO09a80000M;l00P3oool0
103ookl0M00000000018W=l20?ooo`030=nLB00007@0_ooo00X0oooo00<0oooO09adW03Oool0203o
ool00`3OW4P007Bo0?ooo`0I0?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02oool70?oo
o`070?noM0000000M;oo0?ooo`3ookl0M00007Boo`070?ooo`030=nLB018W=l0oooo0080oooo00D0
oooO09a800000000000007Boo`0R0?ooo`030=nLB018W=l0oooo0640oooo002Q0?ooo`030?oog`2L
B00000000080000000<0B9cO0?oo_`1dM;l02@3oool01@3ookl0M00000000000B9`0gooo01T0oooo
00D0oono07@00000000004RL0=ooo`090?ooo`030;md00000000000000@0000000P0001809cOo`3o
ool0oooO09a800000000001d0;oooaD0oooo00L0oono07@0M02oool0oooO09a80000B9`0gooo01H0
oooo00H0oooO09a80000000000000000M02oool90?ooo`050?noM0000000000000000018W=l02@3o
ool00`2oM000B9cO0?ooo`030?ooo`030?noM0000000M;oo0240oooo00<0okmd001d_`3oool0HP3o
ool00;<0oooo00@0oooO09a80000B9`0gooo6P3oool0103ooml0W4P00018W03OoolE0?ooo`030;md
000007@0_ooo01H0oooo00D0oono07@000000000001809cOo`0e0?ooo`030=nLM02Lgol0oooo02D0
oooo00<0oono07Ad_`3oool0H`3oool00?l0ooooc03oool00?l0ooooc03oool00?l0ooooc03oool0
0?l0ooooc03oool00001\
\>"],
  ImageRangeCache->{{{0, 458.563}, {458.563, 0}} -> {0.458521, 0.472631, \
0.000792598, 0.000792598}}]
}, Closed]],

Cell[TextData[
"Conversely, for \[Mu] just above the critical point we observe that nearby \
points are repelled by the fixed point."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(x /. 
        sol1\[LeftDoubleBracket]2\[RightDoubleBracket]\) /. \[Mu] \[Rule] 
        3.2\)], "Input"],

Cell[BoxData[
    \(0.6875`\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(logisticCobweb[3.2, 0.7, 10, 0, 
        PlotRange \[Rule] {{0.6, 0.8}, {0.6, 0.8}}, 
        AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3 5 -3 5 [
[0 -0.0125 -9.5 -15.6875 ]
[0 -0.0125 9.5 0 ]
[.25 -0.0125 -12.5 -15.6875 ]
[.25 -0.0125 12.5 0 ]
[.5 -0.0125 -9.5 -15.6875 ]
[.5 -0.0125 9.5 0 ]
[.75 -0.0125 -12.5 -15.6875 ]
[.75 -0.0125 12.5 0 ]
[1 -0.0125 -9.5 -15.6875 ]
[1 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 0 -19 -7.84375 ]
[-0.0125 0 0 7.84375 ]
[-0.0125 .25 -25 -7.84375 ]
[-0.0125 .25 0 7.84375 ]
[-0.0125 .5 -19 -7.84375 ]
[-0.0125 .5 0 7.84375 ]
[-0.0125 .75 -25 -7.84375 ]
[-0.0125 .75 0 7.84375 ]
[-0.0125 1 -19 -7.84375 ]
[-0.0125 1 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -40.6875 -11.4063 ]
[-0.01875 .5 -25 11.4063 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -74.9688 0 ]
[.5 1.0125 74.9688 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
gsave
0 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -73.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -73.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
gsave
-0.0125 0 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .25 m
.00625 .25 L
s
gsave
-0.0125 .25 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
0 .75 m
.00625 .75 L
s
gsave
-0.0125 .75 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 1 m
.00625 1 L
s
gsave
-0.0125 1 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .2 m
.00375 .2 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .45 m
.00375 .45 L
s
0 .55 m
.00375 .55 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .8 m
.00375 .8 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -105.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.25 .99375 m
.25 1 L
s
.5 .99375 m
.5 1 L
s
.75 .99375 m
.75 1 L
s
.125 Mabswid
.05 .99625 m
.05 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.3 .99625 m
.3 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.7 .99625 m
.7 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .25 m
1 .25 L
s
.99375 .5 m
1 .5 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .05 m
1 .05 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .2 m
1 .2 L
s
.99625 .3 m
1 .3 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .45 m
1 .45 L
s
.99625 .55 m
1 .55 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .7 m
1 .7 L
s
.99625 .8 m
1 .8 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .95 m
1 .95 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -135.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cobweb) show
105.875 15.813 moveto
(Plot) show
128.188 15.813 moveto
(for) show
142.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
148.375 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.375 15.813 moveto
(H) show
170.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
179.188 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
189.875 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
196.000 15.813 moveto
(L) show
202.813 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
208.938 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.12914 .12914 L
.33761 .33761 L
.53812 .53812 L
.75151 .75151 L
.95694 .95694 L
s
.95694 .95694 m
1 1 L
s
0 .8387 m
.02601 .82292 L
.13648 .74073 L
.33539 .55336 L
.54717 .29819 L
s
.54717 .29819 m
.74991 0 L
s
.5 .5 m
.5 .36 L
.36 .36 L
s
.36 .36 m
.36 .52666 L
.52666 .52666 L
s
.52666 .52666 m
.52666 .32543 L
.32543 .32543 L
s
.32543 .32543 m
.32543 .56395 L
.56395 .56395 L
s
.56395 .56395 m
.56395 .27553 L
.27553 .27553 L
s
.27553 .27553 m
.27553 .61508 L
.61508 .61508 L
s
.61508 .61508 m
.61508 .20422 L
.20422 .20422 L
s
.20422 .20422 m
.20422 .6826 L
.6826 .6826 L
s
.6826 .6826 m
.6826 .10493 L
.10493 .10493 L
s
.10493 .10493 m
.10493 .7658 L
.7658 .7658 L
s
.7658 .7658 m
0 0 rlineto s
.7658 .7658 m
.7658 0 L
s
.03 w
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00l`3oool01@3ooml0W4P000000000B9`0gooo0;P0oooo003d0?ooo`030?oOW01804P0W=oo
0;T0oooo003d0?ooo`030?oOW01804P0W=oo0;T0oooo003[0?ooo`050;md0000000007Bo0?ooo`3O
W4P00P0000001@00B9`0gooo0?oOW01804P0W=oo0;T0oooo003[0?ooo`0<0?oog`2LB7@0_ooo0?oo
o`3ooml0W4P00018W03Oool0oono07@0000004P0W=oo^@3oool00>`0oooo00H0oono07A8W03Oool0
_g@00000M02oool20?ooo`030?oOW01804P0W=oo0;T0oooo003]0?ooo`040?oOW01dB4P0000007Bo
okl0oooo003]0?ooo`030?oo_`1d0000B9cO0<00oooo003/0?ooo`050?oog`2LB00004RL09adB02L
gol00`3oool00`3ookl0M00007Boo`2i0?ooo`00k03oool01P2oM000001809cOo`3ooml0W4Qd0;oo
okh0oooo003Z0?ooo`090?oog`2LB000000000000000M;l0okmd0000000007@0_ooo0;d0oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo000j
0?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`050?oOW018
000000000000001d_ol0@03oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d
_ol00`3oool01@3ogi`0B000000000000000M;oo0080oooo00<0oooO09a8000000000P0000000`1d
_ol0oooo0?ooo`0n0?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`04
0?ooo`030=nLB018W=l0oooo0440oooo00D0omnL04P000000000001d0;ooo`030?ooo`030?noM000
0000M;oo00@0oooo00<0gia804RLg`3oool00`3oool00`3ooml0W4P0000000020000000307Boo`3o
ool0oooo03l0oooo00D0omnL04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00<0oooo
00D0gia8000000000000000004RLg`060?ooo`00>@3oool01`3ookl0M00007Boo`3oool0okmd0000
M02oool00P3oool00`3o_g@0000007Boo`020?ooo`070?oOW0180000B9cO0?ooo`3ookl0M00007Bo
o`0n0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM0000000M;oo0080
oooo00/0omnL04P00018W=l0oooo0?oo_`1d0000M;oo0?ooo`3ooml0W4Qd0;ooo`020?ooo`030;md
001d_ol0oooo03d0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000
001d_ol0103oool00`3ogi`0B4RL0=ooo`100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;oo
o`020?ooo`030?noM0000000M;oo00@0oooo00<0omnL04Q8W03Oool00`3oool00`3ooml0W4Qd0;oo
o`020?ooo`030;md001d_ol0oooo03h0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080
oooo00<0okmd0000001d_ol00P3oool01`3OW4P0000007Boo`3oool0oooO09a80018W=l01@3oool0
03T0oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo
00<0oooo00<0okmd0018W03Oool0?@3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo
00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL0=ooo`050?ooo`030?oog`2LB7@0_ooo
03d0oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`030?oog`2LB4P0W=oo
0400oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`030?oog`2LB4P0W=oo
00P0oooo00<0oooO09a8M02oool0?P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo
00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL0=ooo`040?ooo`00>03oool00`3ookl0
M00004RLg`030?ooo`030=nLB00007@0_ooo00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`0l0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00<0_g@007Boo`3oool0>`3oool00`3ookl0
M00004RLg`030?ooo`030=nLB00007@0_ooo00T0oooo00<0gia804RLg`3oool0?P3oool00`3ookl0
M00004RLg`030?ooo`030=nLB00007@0_ooo00T0oooo00<0gia804RLg`3oool0203oool00`2oM000
M;oo0?ooo`0l0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM000
07Bo0?ooo`020?ooo`030;md0000B9`0gooo00@0oooo000h0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol01@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo03`0oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol01@3oool00`3ooml0W4P004RLg`0l0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol02@3oool00`3ogi`0B4RL0=ooo`0n0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol02@3oool00`3ogi`0B4RL0=ooo`070?ooo`030?oog`2LB000B9cO03d0oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`070?oOW01807@0_ooo0?ooo`2o
M000000007Boo`050?ooo`00>03oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0
oooo00<0omnL04P0001d_ol00`3oool00`2oM000001809cOo`0l0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0B00007Boo`030?ooo`030;md000004P0W=oo00D0
oooo00<0gia80000001d_ol0?03oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0
oooo00<0oooO09a8B02Lgol0?P3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0
oooo00<0oooO09a8B02Lgol01`3oool00`3OW4P0000007Boo`0m0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01`3oool01@3ookl0M4Q804P000000000B9cO00H0oooo000h0?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool0203ookl0M00000000018W=l0oooo
0?noM000000007Bo?@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0
oono07@000000000B9cO0?ooo`3o_g@00000001d_`80oooo00L0gmoO0?ooo`3ookl0M00000000000
07@0_ooo03`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030=nLB000
M;l0oooo03d0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030=nLB000
M;l0oooo0080oooo00L0gmoO0?ooo`3ookl0M0000000000007@0_ooo03d0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`070?ooo`040?oOW01800000000001d_`L0oooo000h0?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool00`2oM00004RL0;nLB00200000003
0018W03Oool0oooo03`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`03
0;md0000B9`0_ia80080000000D004RL0=ooo`3oool0oooo0=nLB003000000030000B02Lgol0oooo
03`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?oo_`1d07@0_ooo
03d0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?oo_`1d07@0_ooo
0080oooo00H0gia800000000000000000000B02Lgoln0?ooo`030?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol01P3oool01P3ogi`0B0000000M02oool0okmd001d_`H0oooo000h0?ooo`030?oo
_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`3ogi`0B00007Boo`110?ooo`030?oo
_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`3ogi`0B00007Boo`060?ooo`040?oo
_`1d0000000004RLgcl0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`03
0?oOg`3Oool0oooo00<0oooo00<0_g@007Boo`3oool0?03oool00`3ookl0M00004RLg`030?ooo`03
0=nLB00007@0_ooo00D0oooo00<0omoO0=ooo`3oool00`3oool0202oM000M;oo0?ooo`3oool0oono
07@000000000B9cO@03oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0
_g@00000M02oool00P3oool00`2oM000B9cO0?ooo`040?ooo`00>@3oool00`3OW4P004RL0=ooo`02
0?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000B02Lgol0@@3oool00`3OW4P004RL0=ooo`02
0?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000B02Lgol01P3oool00`2oM000M;oo0?ooo`10
0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3ookl0M4RL0=ooo`03
0?ooo`030?noM000M;l0oooo03d0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`05
0?ooo`030?oo_`1dB9`0gooo00<0oooo00<0okmd001d_`3oool00P3oool00`2oM000M;oo0?ooo`11
0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01P3oool00`2oM00004RL0=ooo`02
0?ooo`030=nLB000M;l0oooo00@0oooo000i0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;oo
o`090?ooo`030?noM000000007Bo0400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00T0
oooo00<0okmd00000000M;l01@3oool01P3ogi`0B000000000000000001809cOocd0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo00L0oooo00<0_g@00000000000000`0000000`0007@0_ooo
0?ooo`0l0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`070?ooo`030;md000000000000
00<0000000H0001d0;ooo`3oool0oooo0?oOW0180002000000030000B02Lgol0oooo03d0oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo00L0oooo00L0okmd0000001d_ol0oooo0?oo_`1d0000
M;oo00D0oooo000j0?ooo`050?oo_`1d000000000000M02oool02`3oool01@3ooml0W4P000000000
07@0_ooo03h0oooo00D0oono07@000000000001d0;ooo`0;0?ooo`050?oog`2LB00000000000M02o
ool00`3oool01@2oM0000000000000000000B9cO03h0oooo00D0oono07@000000000001d0;ooo`08
0?ooo`030?noM0000000000000@0000000<0M;oo0?ooo`3oool0?03oool01@3ookl0M00000000000
07@0_ooo00P0oooo00<0okmd000000000000100000001@1d_ol0oooo0?ooo`3oool0_g@000<00000
00<0B9cO0?ooo`3oool0?@3oool01@3ookl0M0000000000007@0_ooo00T0oooo00D0okmd00000000
0000000004RLg`060?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`009`3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol00`3oool0
1@3ogi`0B000000000000000M;oo0?l0ooooM`3oool002H0oooo00L0oono07@0001d_ol0oooo0?no
M00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool01`3ogi`0B00004RLg`3oool0oono07@0
001d_ol0o`3ooomf0?ooo`009P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0
oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL0=ooo`3o0?ooogD0oooo000U0?ooo`030?oo
_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`3ogi`0B00007Boo`030?ooo`030?no
M00004P0W=oo0?l0ooooM@3oool002D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cO
o`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0o`3ooome0?ooo`009@3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool0
0`2oM000001809cOo`070?ooool00000G`00000?0?ooo`009@3oool00`3ogi`0B00007Boo`030?oo
o`030?noM00004P0W=oo00D0oooo00P0oono07@000000000B9cO0?ooo`3o_g@00000001d_`P0oooo
0P00000@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool2000000@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
000U0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool00`2oM00004RL0;nL
B002000000030018W03Oool0oooo00L0oooo00<000000?ooo`000000E03oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo05<0oooo0P0000040?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool03@3oool002D0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`06
0?ooo`030?oOW0180000M;oo00`0oooo00@000000?ooo`3oool00000o`3oool10?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`009P3oool0
0`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000B02Lgol02`3oool0
1@000000oooo0?ooo`3oool000000?h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00d0oooo000V0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d
0;ooo`090?ooo`030?noM000000007Bo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`3k0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0=0?ooo`009`3oool01@3ookl0M0000000000007@0_ooo00/0oooo00D0oooO09a800000000
001d0;ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0n@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3g0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0m03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3b0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?oo
o`00@`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`3]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0>/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo00d0oooo00130?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0jP3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3X0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`800000403oool00`000000oooo0?oo
o`3U0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0CP3oool2000000l0oooo0013
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0h`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0>00oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
gP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
3@3oool004<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3L0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`3G0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0=H0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo
00130?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0=40oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0c`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool03@3oool004<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3=0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo0P00000Q0?ooo`030000003oool0oooo
0<P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1>0?ooo`8000003`3oool004<0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo
0?ooo`0R0?ooolX00000703oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo
00130?ooo`030000003oool0oooo0280oooo0P0000350?ooo`030000003oool0000001`0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool000000<<0oooo00@000000?ooo`3oool00000703oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00@00000
0?ooo`3oool00000`P3oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool01@000000oooo0?oo
o`3oool000000<00oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0;H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
3@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0;80oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool0
04<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0:l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool03@3oool004<0oooo0P00000S0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0CP3oool2000000l0oooo00130?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2V0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`2N0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0
oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`2K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo0013
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2G
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`2D0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`8000008`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo04h0oooo0P00000?0?ooo`00@`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01l0ooooT@00000F0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo01l0oooo0P00002<0?ooo`030000003oool0000001H0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo
00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0000
002:0?ooo`040000003oool0oooo000001H0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool07`3oool010000000oooo0?ooo`0000280?ooo`050000003oool0oooo0?ooo`00
00005P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`050000
003oool0oooo0?ooo`000000Q`3oool01@000000oooo0?ooo`3oool0000001H0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo08<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00
@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
3@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0N`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool01@3ogi`0B0000000
000007@0_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3ogi`0B000000000000000M;oo0080
oooo00<0oooO09a8000000000P0000000`1d_ol0oooo0?ooo`080?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`007@3oool01`3ookl0M000
07Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?ooo`0;0?oOW0180000B9cO
0?ooo`3ookl0M00007Boo`3oool0oooO09a8M02oool00P3oool00`2oM000M;oo0?ooo`080?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00
7@3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l0
0`3oool00`3o_g@004RL0=ooo`050?ooo`030?oog`2LB7@0_ooo00P0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo000L0?ooo`030?oo_`1d
0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`3ogi`0B00007Boo`030?ooo`030?noM000
04P0W=oo00H0oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool03@3oool001`0oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool0
0`3ooml0W4P004RLg`080?ooo`<000008P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1=0?ooo`<000003`3oool0
01`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo
00<0oooo00<0_g@00000B02Lgol01@3oool00`3OW4P0000007Boo`080?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00703oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0oono07@000000000B9cO0?ooo`3o_g@0
0000001d_`80oooo00L0gmoO0?ooo`3ookl0M0000000000007@0_ooo00P0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo000L0?ooo`030?oO
W0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool00`2oM00004RL0;nLB002000000050018
W03Oool0oooo0?ooo`3OW4P00`0000000`0004P0W=oo0?ooo`080?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00703oool00`3ookl0M000
04RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0omnL04P0001d_ol01P3oool0103ookl0M000
00000018W=l;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0=0?ooo`007@3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo
00<0gia80000B02Lgol01P3oool00`2oM000M;oo0?ooo`0;0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`007@3oool01`3ookl0M00007Bo
o`3oool0okmd0000M02oool02@3oool00`3o_g@00000001d_`050?ooo`060?oOW018000000000000
000004P0W=oo203oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool03@3oool001h0oooo00D0oono07@000000000001d0;ooo`0;0?ooo`050?oog`2LB000
00000000M02oool00`3oool01@2oM0000000000000000000B9cO00P0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3ooomV
00000140oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo0P00001R0?ooo`8000004@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0000001P0?ooo`030000003oool000000140
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000GP3oool010000000
oooo0?ooo`00000A0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?oo
o`000000G@3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0F@3oool01@000000oooo0?ooo`3oool0
00000140oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0
oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo0P00
000S0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1>0?ooo`8000003`3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=
0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool0
04<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo
A`00000<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool03`3oool200000480oooo00<000000?ooo`000000303oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`000000@03oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00
000n0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo
0000000l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo0013
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`80
00008`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04h0oooo0P00000?0?ooo`00
@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00T0oooo<P0000080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0
oooo0P00000/0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000Z0?ooo`050000003oool0oooo0?oo
o`000000203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`04
0000003oool0oooo000002P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?oo
o`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3o
ool0oooo0000000V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0
oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool0
04<0oooo0P00000S0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo04h0oooo0P00000?0?ooo`00@`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo
00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool01000
0000oooo0?ooo`00000E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`8000005P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool05P3oool2000001H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo
00@000000?ooo`3oool000005@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo0013
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=
0?ooo`00@`3oool2000002<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0CP3oool2000000l0oooo00130?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00
@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
3@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0=0?ooo`002@3oool00`2oM7@0_ooo0?ooo`040?ooo`030;mdM02oool0oooo
0300oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
00d0oooo00090?ooo`030;md0018W=l0oooo00<0oooo00<0gia80000M02oool0<@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool000T0oooo
00T0_g@00000000007@0_ooo0?oog`2LB000B9cO0=nLW02oool0<@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool000T0oooo00H0_ibL0=oO
W018000000000000B02Lgold0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0=0?ooo`002@3oool00`2oM7@0_mnL04P00002000000040000B02Lgol0
gibL0;oooc40oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo00d0oooo00090?ooo`030;md0000B9`0gooo0080oooo00@0_g@00000000007@0_ooo<@3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3o
ool000T0oooo00<0_gA809cOo`3oool00`3oool00`3o_g@0001d0;ooo`0a0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`002@3oool00`2o
W9`0gooo0?ooo`040?ooo`030=nLW02oool0oooo0300oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo000W0?ooo`050?oOW018000000000000
M02oool00`3oool00`3o_g@0000007Boo`040?ooo`030=nLB018W=l0oooo00X0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool07`3oool010000000oooo0?ooo`3oool2000000P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo000>0?ooo`030;nLW03Oool0oooo
0080oooo00<0gibL0;ooo`3oool0403oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3o
ool00`3o_g@0000007Boo`040?ooo`030?oOW018B9`0gooo00X0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3o
ool7000000H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo00d0oooo000:0?ooo`050?oo_`1d04P0W=oo0?oo_`1d0000100000000`0007@0_ooo0?oo
o`0@0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool0203oool00`3ooml0W4Q809cO
o`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0280oooo200000050?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`004`3oool00`3OW9`0_ooo0?ooo`0?
0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool02@3oool00`3OW4P0B9cO0?ooo`09
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0280oooo200000050?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`009@3oool00`3ogi`0B00007Boo`030?oo
o`030?noM00004P0W=oo00T0oooo00<0omnL04Q8W03Oool02@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?oo
o`X00000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool03@3oool00100oooo00<0_gAd0;ooo`3oool04P3oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo00T0oooo00<0oooO09a8B02Lgol02@3oool300000280oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo2P0000040?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0C@3oool3000000l0oooo000@0?ooo`030;md
M02oool0oooo0180oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030=nL
B000M;l0oooo00P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool09@3oool8000000D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo000@0?ooo`030;mdM02o
ool0oooo0180oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?oo_`1d
07@0_ooo00P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`050000003o
ool0oooo0?ooo`000000:03oool8000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00d0oooo000=0?ooo`030;md00000000000000<0000000<0
001d0;ooo`3oool03`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00D0oooo00<0
omoO0=ooo`3oool00`3oool00`2oM000M;oo0?ooo`070?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`00000Z0?ooo`L000001@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool00100oooo00<0
_gAd0;ooo`3oool04`3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0
oono07A8W03Oool00`3oool00`3o_g@007Bo0?ooo`070?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`00000/0?ooo`8000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0=0?ooo`00403oool00`2oM7@0_ooo0?ooo`0C0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0
001d0;ooo`070?ooo`030;md00000000000000<0000000<0001d0;ooo`3oool01P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000<`3oool01@000000
oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?oo
o`00403oool00`2oM7@0_ooo0?ooo`0D0?ooo`050?oo_`1d000000000000M02oool0203oool00`3o
_g@00000000000040000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`090?ooo`800000=@3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo03D0oooo00<000000?ooo`000000303oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0203oool2000003P0oooo0P00000<0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool03@3oool000/0oooo00<0oooO09adW03Oool01@3oool00`3OW9`0_ooo
0?ooo`0]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0000000j000000`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`002`3o
ool00`3o_g@0000000000005000000030000M02oool0oooo02d0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo000C0?ooo`030=nLW02oool0
oooo02d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo0P00000S0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?oo
o`050000003oool0oooo0?ooo`000000B@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo04h0oooo0P00000?0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo
000004/0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo0013
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`000000C@3oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo0P00001?
0?ooo`030000003oool000000140oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1?0?ooo`8000004@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?oo
o`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0>0?oooeD000004@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00
@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05d0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`060?ooo`800000H@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo0013
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
J03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`050000003o
ool0oooo0?ooo`000000K03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo
00130?ooo`8000008`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00@0
00000?ooo`3oool00000KP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1>0?ooo`8000003`3oool004<0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`000000L03oool01@000000oooo0?ooo`3oool0000001H0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`800000LP3o
ool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0000001H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0E0?ooo`800000M@3oool2000001H0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool00000
07L000005P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00
@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?oo
o`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0203oool2000008d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo0P00000S0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1>0?ooo`800000
3`3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
09@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0UP3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo
00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool01@000000oooo0?oo
o`3oool0000009`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000009h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
3@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool000000:00oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0O0?ooo`800000XP3oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`000000703oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool07P3oool200000:D0oooo0P00000L0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool000000:L00000703oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo0P00000S0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04h0oooo0P00000?0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool04`3oool200000;X0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0_@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool004<0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo
00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`310?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0``3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0<D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool001h0oooo00D0omnL04P000000000001d
0;ooo`030?ooo`030?noM0000000M;oo00@0oooo00<0gia804RLg`3oool00`3oool00`3ooml0W4P0
000000020000000307Boo`3oool0oooo00P0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00d0oooo000M0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0
001d0;ooo`020?ooo`030?noM0000000M;oo00@0oooo00<0omnL04Q8W03Oool00`3oool00`3ooml0
W4Qd0;ooo`020?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo000M0?ooo`030;md0000B9`0gooo0080oooo
00<0_g@0001d_`3oool0203oool00`3ooml0W4Q809cOo`080?ooo`030?oog`2LB7@0_ooo00P0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0<l0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00d0oooo
000L0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool02@3oool00`3OW4P0B9cO0?oo
o`080?ooo`030;md001d_ol0oooo00L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`060?ooo`800000d`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool03@3oool001`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`09
0?ooo`030?oOW018B9`0gooo00L0oooo00<0oooO09a80018W=l0203oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool001`0oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@0001809cOo`090?ooo`030?oog`2LB4P0W=oo00L0oooo00<0gia80000
001d_ol0203oool300000280oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C@3oool3000000l0oooo000L0?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3OW4P007Bo0?ooo`020?ooo`07
0=oOg`3oool0oono07@000000000001d0;ooo`080?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool00P3oool200000=X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo00d0oooo000L0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000
B02Lgol02P3oool00`3ookl0M01d0;ooo`020?ooo`060=nLB000000000000000000004P0W=oo2@3o
ool00`000000oooo0?ooo`0R0?ooo`050000003oool0oooo0?ooo`000000g@3oool01@000000oooo
0?ooo`3oool000000540oooo00<000000?ooo`3oool03@3oool001`0oooo00<0oono07@00018W=l0
0`3oool00`3OW4P0001d0;ooo`050?ooo`030?oOg`3Oool0oooo00<0oooo00P0_g@007Boo`3oool0
oooo0?oo_`1d0000000004RLg`/0oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`00
003O0?ooo`040000003oool0oooo00000540oooo00<000000?ooo`3oool03@3oool001d0oooo00<0
gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oo_`1dB9`0gooo00<0oooo00<0
okmd001d_`3oool00P3oool00`2oM000M;oo0?ooo`0;0?ooo`030000003oool0oooo0280oooo0`00
003Q0?ooo`030000003oool000000540oooo00<000000?ooo`3oool03@3oool001d0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo00L0oooo00<0_g@00000000000000`0000001P0007@0_ooo
0?ooo`3oool0omnL04P00080000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0>80oooo0`00001@0?ooo`030000003oool0oooo00d0oooo000N0?ooo`05
0?oo_`1d000000000000M02oool0203oool00`3o_g@00000000000040000000507Boo`3oool0oooo
0?ooo`2oM0000`0000000`18W=l0oooo0?ooo`060?ooo`030000003oool0oooo0240ooooj000001A
0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo01l0oooo0P00003X0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool03@3oool004<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3[0?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool06`3o
ool200000>l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0?80oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000
oooo0?ooo`0G0?ooo`800000mP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00d0
oooo00130?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0m`3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0n@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00d0oooo0013
0?ooo`030000003oool0oooo01<0oooo0P00003m0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3n0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool03@3oool004<0oooo0P00000B0?ooo`03
0000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`120?ooo`8000003`3oool004<0oooo
00<000000?ooo`3oool03`3oool200000?l0oooo1@3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00d0oooo00130?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3o
ool60?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03@3oool004<0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`0;0?ooo`800000o`3oool<0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?ooo`d0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo
3`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003o
ool0oooo00L0oooo0P00003o0?oooa<0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0=0?ooo`00@`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo503oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo
00@0oooo0P00003o0?oooaP0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0=0?oo
o`00@`3oool00`000000oooo0?ooo`020?ooo`800000o`3ooolK0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool00P00003o0?oooah0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`00@`3oool300000?l0oooo8@3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0
oooo0?l0oooo8P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00d0oooo00130?oo
o`030000003oool0oooo0?l0oooo8`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00d0oooo00130?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0?l0oooo9@3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo00d0oooo00130?ooo`800000o`3ooolW0?ooo`030000003o
ool0oooo0340oooo0P00000?0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oo
obP0oooo0P00000a0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0?l0
oooo:P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000
003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00d0oooo
00130?ooo`030000003oool0oooo0?l0oooo;03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00d0oooo00130?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0?l0oooo;P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0?l0
oooo;`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000
003oool0oooo0?l0oooo<03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00d0oooo
00130?ooo`030000003oool0oooo0?l0oooo<@3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00d0oooo00130?ooo`030000003oool0oooo0?l0oooo<P3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0?l0oooo<`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000003oool0oooo0?l0
oooo=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00d0oooo00130?ooo`030000
003oool0oooo0?l0oooo=@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo
00130?ooo`030000003oool0oooo0?l0oooo=P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00d0oooo00130?ooo`030000003oool0oooo0?l0oooo=`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00d0oooo00130?ooo`800000o`3oooli0?ooo`030000003oool0oooo
01l0oooo0P00000?0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooocX0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?oo
o`3o0?oooc/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool0
0`000000oooo0?ooo`3o0?oooc`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0=
0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooocd0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooch0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooocl0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?oo
o`3o0?oood00oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0=0?ooo`00@`3oool0
0`000000oooo0?ooo`3o0?oood40oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0=
0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oood80oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oood@0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?oo
o`3o0?ooodD0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool0
0`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=
0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooodP0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooodT0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`00@`3oool200000?l0ooooB`3o
ool00`000000oooo0?ooo`0=0?ooo`8000003`3oool004<0oooo00<000000?ooo`3oool0o`3ooom;
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool004<0
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool03@3oool004<0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool0o`3ooom@
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?oo
o`3oool0o`3ooomA0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool004<0
oooo00<000000?ooo`3oool0o`3ooomB0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool03@3oool004<0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03@3oool004<0oooo00<000000?ooo`3oool0o`3ooomE
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool002L0oooo00D0omnL04P0
00000000001d0;ooo`030?ooo`030?noM0000000M;oo00<0oooo00D0gia8000000000000000004RL
g`090?ooo`030000003oool0oooo0?l0ooooEP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo000V0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?no
M0000000M;oo0080oooo00L0gia80000001d_ol0oooo0?oog`2LB000B9cO00P0oooo00<000000?oo
o`3oool0o`3ooomG0?ooo`050000003oool0oooo0?ooo`0000003`3oool002H0oooo00<0_g@00018
W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018
W03Oool01`3oool00`000000oooo0?ooo`3o0?oooeP0oooo00@000000?ooo`3oool000003`3oool0
02D0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030;md0000M;l0oooo
0080oooo00<0_g@00018W03Oool01`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1B0?ooo`030000003oool00000
00l0oooo000U0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3ogi`0
B01d0;ooo`3oool0_g@00000001d_ol0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00d0oooo0P00000?0?ooo`009@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00L0oooo00D0oono07A8B0180000000004RLg`090?ooool00000G`00000?0?ooo`009@3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00@0omnL04P00000000007Boo`3ooomh
0?ooo`009@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0omnL04P0
000007@0_ooo0?noM000M;oo0?ooogL0oooo000U0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia8
0000M02oool01P3oool00`2oM000001d0;ooo`020?ooo`030;md0018W=l0oooo0?l0ooooM@3oool0
02H0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`060?ooo`030;md0000B9`0gooo
0080oooo00<0gia8001d_`3oool0o`3ooome0?ooo`009P3oool01`3ookl0M00007Boo`3oool0okmd
0000M02oool01`3oool01`3o_g@0000007Boo`3oool0oono07@0001d_ol0o`3ooomf0?ooo`009`3o
ool01@3ookl0M0000000000007@0_ooo00T0oooo00D0okmd000000000000000004RLg`3o0?ooogL0
oooo003o0?oook40oooo003o0?ooob<0oooo00<0oooO09a8B02Lgol09`3oool00`3ogi`0B4RL0=oo
o`1Q0?ooo`00o`3ooolS0?ooo`030;mdB02Lgol0oooo02P0oooo00<0omnL04Qd_`3oool0H03oool0
0?l0oooo8P3oool00`3OW4P0B9cO0?ooo`0Z0?ooo`030=nLB018W=l0oooo05l0oooo003o0?ooob40
oooo00<0oono07@0M02oool0:`3oool00`3ookl0M01809cOo`1O0?ooo`00Q`3oool00`3ogi`0B000
00000002000000030000M02oool0oooo00<0oooo00D0gia8000000000000000007Boo`030?ooo`06
0?oog`2LB00000000000000004P0W=oo1@3oool00`3ogi`0M9cO0?ooo`020?ooo`030=nLM02Lgol0
oooo00@0oooo00D0_g@0000000000000001d0;ooo`020?ooo`060?oog`2LB00000000000000004P0
W=oo1`3oool00`2oM00000000000000200000003001d_`3oool0oooo00<0oooo00L0gia800000000
0000001d0;ooo`3oool0gia800<0000000P0M;oo0?ooo`3oool0oooo0?oOW0180000000004RLg`@0
oooo00<0omnL04P0000000000P000000101d_ol0oooo0?ooo`3OW4P30000000407Boo`3oool0oooo
0;md0080000000L0001809cOo`3oool0oooO09a8000007@0_ooo00D0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`020?ooo`050?noM0000000M;oo0?ooo`2oM0001P0000000`18W=l0
oooo0?ooo`040?ooo`030=nLB000B9`0gooo00@0oooo00H0_g@000000000000000000018W03OoolF
0?ooo`050;md0000000007Bo0?ooo`3OW4P00P0000001`00B9`0gooo0?ooo`3oool0oooO09a80018
W=l01@3oool01@2oM0000000001d_`3oool0gia80080000000<004RL0=ooo`3oool0D03oool008H0
oooo00@0gia800000000B9`0gooo0P3oool00`3ookl0M01809cOo`020?ooo`070=nLB0000000B9cO
0?ooo`3ooml0W4P004RLg`020?ooo`070;md0000B9`0gooo0?ooo`3ogi`0B00007Boo`040?ooo`07
0;md000007@0_ooo0?ooo`3ookl0M000001d_`040?ooo`0?0;md0000000007Bo0?ooo`3ogi`0B01d
0;ooo`3oool0_g@00018W03Oool0oooo0?oOW0180000M;oo00L0oooo00@0oooO09a80000B9`0gooo
1`3oool02`3OW4P0001d0;ooo`3oool0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00D0
gia80000M02oool0gkno0=ooo`040?ooo`030?oog`2LB00007Bo00<0oooo00L0gia800000018W=l0
oooo0?oog`2LB000B9cO0080oooo00<0gia80000M02oool00P3oool0103ooml0W4P00000M02oool5
0?ooo`030?oOW0180000B9cO0080oooo00<0_g@004RLg`3oool00P3oool00`3o_g@0000007Boo`02
0?ooo`030=nLB0000000000000<0000000<004RL0=ooo`3oool0103oool00`2oM00007Bo0?ooo`05
0?ooo`030?oOW0180000M;oo01P0oooo00P0oooO09a8M02oool0oooo0?oog`2LB00004RL0=ooo`@0
oooo00<0gia80018W03Oool0103oool0203ooml0W4Qd0;ooo`3oool0oooO09a80000B9`0goooDP3o
ool008D0oooo00<0okmd00000000M;l01@3oool01P3ooml0W4Qd0;ooo`3ogi`0B000001d_`<0oooo
00L0okmd0000M02oool0oooo0;md0000B9`0gooo0080oooo00<0okmd0000M02oool00P3oool02@3o
gi`0B00004QdM01dW=l0oooo0?noM00004P0B4Q809cOo`020?ooo`030?oOW0180000B9cO00<0oooo
00H0omnL07BLg`3oool0_g@00018W03Oool20?ooo`030?noM00007@0_ooo00H0oooo00<0oooO09a8
0000M;l0203oool01P3OW4P0001d0;ooo`3ogi`0B000001d_`<0oooo00L0okmd0000M02oool0oooo
0=nLB000B9`0gooo00H0oooo00<0oooO09a80000M;l00P3oool00`3ogi`0B000001d_`030?ooo`07
0?noM00007@0_ooo0?ooo`3OW4P0001d0;ooo`0@0?ooo`030?oo_`1d04P0W=oo00P0oooo00<0gia8
04RLg`3oool00P3oool00`3OW7@0W=oo0?ooo`030?ooo`030?oo_`1d0000B9cO00H0oooo00<0omnL
04P0001d_ol06@3oool01P3ookl0M4RL0=ooo`2oM000001d0;ooo`D0oooo00<0gia80000M02oool0
1@3oool01P3ookl0M4RL0=ooo`2oM000001d0;oooe<0oooo00240?ooo`040?oog`2LB000001d0;oo
o`P0oooo00<0okmd0000001d_ol00`3oool01`3o_g@0000007Boo`3oool0_g@00018W03Oool00P3o
ool00`3ogi`0B00007Boo`020?ooo`090=nLB00007@0_ooo0;mdM02ooml0W4P0001d_`3ogi`0M9cO
0080oooo00<0okmd0000B02Lgol01P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000M;oo
00H0oooo00<0oooO09a80000M;l0203oool01P3OW4P0001d0;ooo`3o_g@0000007Boo`<0oooo00L0
okmd0000001d_ol0oooo0=nLB000B9`0gooo00H0oooo00<0oooO09a80000M;l00P3oool00`3o_g@0
000007Boo`030?ooo`070?noM0000000M;oo0?ooo`3OW4P0001d0;ooo`0@0?ooo`030?oo_`1d0000
M;oo00T0oooo00<0gia807Boo`3oool01`3oool00`3ookl0M00007Boo`060?ooo`030?oOW0180000
M;oo01X0oooo00@0omnL07A8B0000000M;oo1P3oool00`3o_g@0001d0;ooo`060?ooo`040?oOW01d
B4P0000007Booe@0oooo00240?ooo`040?oOW018000004RL0=ooo`P0oooo00<0okmd0000001d_ol0
0`3oool01`3o_g@0000007Boo`3oool0_g@00018W03Oool00P3oool04`3ogi`0B00007Boo`3oool0
oono07@00018W=l0oooo0?oOW01dM7@0B01809cOo`3oool0_gAd0;ooo`3oool0okmd0000M02oool0
1P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000M;oo00H0oooo00<0oooO09a80000M;l0
203oool01P3OW4P0001d0;ooo`3o_g@0000007Boo`<0oooo00L0okmd0000001d_ol0oooo0=nLB000
B9`0gooo00H0oooo00<0oooO09a80000M;l00P3oool00`3o_g@0000007Boo`030?ooo`070?noM000
0000M;oo0?ooo`3OW4P0001d0;ooo`0@0?ooo`030?noM0000000M;oo00X0oooo00<0_gA809cOo`3o
ool01P3oool00`3ookl0M00007Boo`060?ooo`030?oOW0180000M;oo00L0oooo00<0oooO09a80000
00001`0000000`18W=l0oooo0?ooo`060?ooo`030?oo_`1d0000B9cO00L0oooo00<0okmd0000B02L
gol01P3oool00`3ookl0M00004RLg`1E0?ooo`00Q03oool00`3o_g@00000001d_`090?ooo`030?oo
_`1d0000M;oo00<0oooo00L0_g@00000B02Lgol0oooo0;md0000B9`0gooo0080oooo00/0okmd0000
B02Lgol0oooo0=nLB00004P0W=oo0?ooo`3ooml0W4P0001d_`020?ooo`050?noM018W=l0oooo0?oO
W01800001@0000001@18W=l0oooo0;md0000B9`0gooo0080oooo00<0okmd0000B02Lgol01P3oool0
0`3ooml0W4P0000000040000000:07Boo`3oool0oooo0?ooo`3OW4P0001d0;ooo`3ookl0M00007Bo
o`<0oooo00L0_g@00000B02Lgol0oooo0=nLB000B9`0gooo00H0oooo00<0oooO09a80000M;l00P3o
ool00`3ookl0M00007Boo`030?ooo`070;md000004P0W=oo0?ooo`3OW4P0001809cOo`0?0?ooo`04
0?oOW0180000001809cOo`X0oooo00<0oooO09a8M02oool01P3oool00`3ookl0M00007Boo`060?oo
o`030?oOW0180000M;oo01T0oooo00D0oooO09a80000B9`0W7A809cOo`060?ooo`030?noM00007@0
_ooo00D0oooo00D0oooO09a80000B9`0W7A809cOo`1D0?ooo`00Q03oool00`3o_g@00000001d_`0:
0?ooo`070=nLB000B9`0gooo0?ooo`3o_g@00000001d_`020?ooo`0;0;md0000000004RL0=ooo`3o
okl0M0000018W03Oool0oono07@00000M;l00P3oool00`3ogi`0B00007Boo`020?ooo`060?oog`2L
B7@0_ooo0?ooo`2oM000B9cO0P3oool0303OW4P0001809cOo`3oool0_g@000000000B9`0gooo0?oo
_`1d000004RL0=ooo`H0oooo00<0oooO09a80000M;l00P3oool0103ooml0W4P000000018W=l20?oo
o`0;0=nLB00007@0_ooo0?ooo`3OW4P004RL0=ooo`3oool0okmd00000000M;l00P3oool00`3OW4P0
04RL0=ooo`060?ooo`030?oog`2LB00007Bo00<0oooo0180gia80018W03Oool0oooo0?noM0000000
07Bo0?oog`2LB00000000000B018M9`0gkmd0000M02ooml0W4P00000M02oool70?ooo`050?noM000
000000000000B02Lgol0303oool00`3o_g@007Bo0?ooo`050?ooo`030?oo_`1d0000B9cO00H0oooo
00<0omnL04P0001d_ol06@3oool01P2oM000001809cOo`3ooml0W4Qd0;ooo`D0oooo00<0gia80000
M02oool01@3oool01P2oM000001809cOo`3ooml0W4Qd0;oooe<0oooo00240?ooo`040?oOW0180000
04RL0=ooo`X0oooo00D0okmd000000000000000004RLg`030?ooo`090;md0000B9`0gmnL04P00000
000004RL0=ooo`3ooml0W4P00080000000<0B9cO0?noM00000000P0000002018W=l0oooo0;md0000
000004RL0=ooo`3oool0gia80P0000002`0004P0W=oo0?ooo`3oool0_g@00018W03Ogi`0B0000000
0000B9`0gooo00L0oooo00<0oooO09a80000M;l00`3oool0203ookl0M0000000M02oool0oooo0=nL
B00007@0_ooo0P3oool01@3o_g@00000000000000000B9cO0080oooo00H0_g@00000000000000000
0018W03Oool30?ooo`030?noM000000000000080000000@004RL0=ooo`3oool0okmd0`0000003@18
W=l0oooo0?ooo`3oool0_g@00000M02ogi`0B0000000M02ooml0W4P00000M02oool02@3oool00`2o
M00007Bo0?ooo`0<0?ooo`030?oo_`1d04P0W=oo00D0oooo00<0oooO09a80018W=l01P3oool00`3o
gi`0B00007Boo`0G0?ooo`090?oog`2LB000000000000000M;l0okmd0000000007@0_ooo00@0oooo
00<0gia80018W03Oool00`3oool02@3ooml0W4P000000000000007Bo0?noM0000000001d0;ooo`1B
0?ooo`00Q03oool0103ooml0W4P00000B02Lgol50?ooo`030?oog`2LM9`0gooo00X0oooo00<0_g@0
0018W03Oool06`3oool00`2oM00004RL0=ooo`0;0?ooo`030?oog`2LB00007Bo00<0oooo00P0oooO
09a8000004P0W=oo0?ooo`3OW4P0001d0;ooo`X0oooo00<0_g@00018W03Oool01P3oool00`3ooml0
W4P0001d_`0O0?ooo`030;md0018W=l0oooo00/0oooo00<0oono07@00018W=l01P3oool00`3OW4P0
04RL0=ooo`050?ooo`030?oOW0180000M;oo02<0oooo00<0oooO09a80018W=l0G`3oool008D0oooo
00<0omnL04P00000M;l01@3oool00`3o_g@004RL0=ooo`0:0?ooo`030;md0000B9`0gooo01/0oooo
00<0_g@00018W03Oool02`3oool00`3ooml0W4P0001d_`030?ooo`080?oOW0180000001d0;ooo`3o
ool0gia80000M02oool:0?ooo`030?oo_`1dB9`0gooo00L0oooo00<0_g@0001d_`3oool06@3oool0
0`3ooml0W9bo0?ooo`020?ooo`030=nLB00007@0_ooo00H0oooo00<0oknL09cOo`3oool00P3oool0
0`3ogi`0B00004RLg`060?ooo`030?oo_`1d04P0W=oo00D0oooo00<0omnL04P0001d_ol08`3oool0
0`3ookl0M01809cOo`1O0?ooo`00QP3oool00`3o_g@00000001d_`030?ooo`030=nLB000000007Bo
00/0oooo00<0_g@00018W03Oool06`3oool00`2oM00004RL0=ooo`0;0?ooo`030?oog`2LB00007Bo
0080oooo00@0oono07@000000000B9cO0P3oool00`3OW4P0001d0;ooo`0:0?ooo`030?oog`2LM9`0
gooo00L0oooo00<0gia8001d_`3oool06P3oool01P3o_g@0B9cO0?ooo`3ookl0M000001d_`L0oooo
00P0oooO09a8B02Lgol0oooo0?oo_`1d0000001d0;ooo`L0oooo00<0gia804RLg`3oool00P3oool0
1@3ooml0W4P0000000000000M;oo02<0oooo00<0gia804RLg`3oool0G`3oool008L0oooo00<0oooO
09a8000000000P0000000`18W=l0oono07Ad_`090?ooo`050?oo_`1d000000000018W03Oool06@3o
ool01@3ookl0M00000000000B9`0gooo00X0oooo00<0_g@000000000000010000000200004P0W=oo
0?ooo`3ooml0W4P00000000007@0_ooo503oool01`3ookl0M01d0;ooo`3ooml0W4P00018W03Oool0
5`3oool01@3OW4P000000000000007@0_ooo00P0oooo00H0oooO09a80000000000000000M02oool9
0?ooo`030;md0018W=l0oooo00<0oooo00<0okmd0000001d_ol08P3oool00`3o_g@007Bo0?ooo`1P
0?ooo`00V@3oool0103ooml0W4P00018W03OoolJ0?ooo`040?oog`2LB00004RL0=oooaH0oooo00<0
_g@00000M02oool05@3oool01@3ookl0M0000000000004P0W=oo03D0oooo00<0giad09cOo`3oool0
9P3oool00`3ookl0M7Bo0?ooo`1Q0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {0.561291, 0.569825, 0.000859185, \
0.000859185}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Pitchfork bifurcation mechanism", "Section"],

Cell[TextData[{
  "Our numerical investigations also suggested that for \[Mu] not too far \
above 3 the system settles upon a stable oscillation between two values, a \
2-cycle.  These two values must be found among the solutions to the equation \
",
  Cell[BoxData[
      FormBox[
        StyleBox[\(f\_2[\[Mu], x] \[Equal] x\),
          FontWeight->"Plain"], TraditionalForm]], "InlineInput"],
  ",  which has the same structure as the original mapping except that the \
step size is 2.  Once again it is instructive to examine this equation \
graphically. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[{x, Table[f\_2[\[Mu], x], {\[Mu], 2.8, 3.6, 0.2}]}], {x, 0, 
          1}, Frame \[Rule] True, 
        FrameLabel \[Rule] {\*"\"\<\!\(x\_i\)\>\"", \*"\"\<\!\(x\_\(i + 2\)\)\
\>\""}, AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -9.5 -15.6875 ]
[.21429 -0.0125 9.5 0 ]
[.40476 -0.0125 -9.5 -15.6875 ]
[.40476 -0.0125 9.5 0 ]
[.59524 -0.0125 -9.5 -15.6875 ]
[.59524 -0.0125 9.5 0 ]
[.78571 -0.0125 -9.5 -15.6875 ]
[.78571 -0.0125 9.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .02381 -10 -7.84375 ]
[-0.0125 .02381 0 7.84375 ]
[-0.0125 .21429 -19 -7.84375 ]
[-0.0125 .21429 0 7.84375 ]
[-0.0125 .40476 -19 -7.84375 ]
[-0.0125 .40476 0 7.84375 ]
[-0.0125 .59524 -19 -7.84375 ]
[-0.0125 .59524 0 7.84375 ]
[-0.0125 .78571 -19 -7.84375 ]
[-0.0125 .78571 0 7.84375 ]
[-0.0125 .97619 -10 -7.84375 ]
[-0.0125 .97619 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -34.6875 -11.4063 ]
[-0.01875 .5 -19 11.4063 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .21429 m
.00625 .21429 L
s
gsave
-0.0125 .21429 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .40476 m
.00625 .40476 L
s
gsave
-0.0125 .40476 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .59524 m
.00625 .59524 L
s
gsave
-0.0125 .59524 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .78571 m
.00625 .78571 L
s
gsave
-0.0125 .78571 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .97619 m
.00625 .97619 L
s
gsave
-0.0125 .97619 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .2619 m
.00375 .2619 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .45238 m
.00375 .45238 L
s
0 .5 m
.00375 .5 L
s
0 .54762 m
.00375 .54762 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .7381 m
.00375 .7381 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -99.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .99375 m
.02381 1 L
s
.21429 .99375 m
.21429 1 L
s
.40476 .99375 m
.40476 1 L
s
.59524 .99375 m
.59524 1 L
s
.78571 .99375 m
.78571 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.07143 .99625 m
.07143 1 L
s
.11905 .99625 m
.11905 1 L
s
.16667 .99625 m
.16667 1 L
s
.2619 .99625 m
.2619 1 L
s
.30952 .99625 m
.30952 1 L
s
.35714 .99625 m
.35714 1 L
s
.45238 .99625 m
.45238 1 L
s
.5 .99625 m
.5 1 L
s
.54762 .99625 m
.54762 1 L
s
.64286 .99625 m
.64286 1 L
s
.69048 .99625 m
.69048 1 L
s
.7381 .99625 m
.7381 1 L
s
.83333 .99625 m
.83333 1 L
s
.88095 .99625 m
.88095 1 L
s
.92857 .99625 m
.92857 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .21429 m
1 .21429 L
s
.99375 .40476 m
1 .40476 L
s
.99375 .59524 m
1 .59524 L
s
.99375 .78571 m
1 .78571 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .5 m
1 .5 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.02381 .02381 m
.06244 .06244 L
.10458 .10458 L
.14415 .14415 L
.18221 .18221 L
.22272 .22272 L
.26171 .26171 L
.30316 .30316 L
.34309 .34309 L
.3815 .3815 L
.42237 .42237 L
.46172 .46172 L
.49955 .49955 L
.53984 .53984 L
.57861 .57861 L
.61984 .61984 L
.65954 .65954 L
.69774 .69774 L
.73838 .73838 L
.77751 .77751 L
.81909 .81909 L
.85916 .85916 L
.89771 .89771 L
.93871 .93871 L
.97619 .97619 L
s
.02381 .02381 m
.04262 .16052 L
.06244 .28275 L
.08426 .39378 L
.10458 .4774 L
.12414 .54183 L
.14264 .58987 L
.16305 .63009 L
.18163 .65649 L
.19132 .66685 L
.2016 .67553 L
.21038 .68121 L
.22004 .68578 L
.22524 .68756 L
.23018 .68884 L
.23461 .68967 L
.23712 .69 L
.23945 .69023 L
.24076 .69033 L
.24145 .69037 L
.24218 .6904 L
.24282 .69043 L
.24352 .69045 L
.24475 .69047 L
.24595 .69047 L
.24724 .69046 L
.24845 .69042 L
.24956 .69037 L
.25093 .69028 L
.25221 .69018 L
.25509 .68989 L
.25763 .68955 L
.26033 .6891 L
.2697 .68697 L
.2798 .68372 L
.29808 .67582 L
.33922 .65195 L
.37885 .62667 L
.41695 .60531 L
.43656 .59665 L
.45751 .58967 L
.46776 .58721 L
.47315 .58617 L
.47886 .58528 L
.48385 .58467 L
.4865 .58441 L
.48935 .58418 L
.49196 .58402 L
.49434 .58392 L
.49549 .58388 L
Mistroke
.49674 .58384 L
.49792 .58382 L
.49901 .58381 L
.5003 .58381 L
.50095 .58381 L
.50167 .58382 L
.50293 .58384 L
.50411 .58387 L
.5055 .58391 L
.50676 .58396 L
.50961 .58411 L
.51206 .58429 L
.51473 .58452 L
.51958 .58507 L
.52925 .58661 L
.53819 .58856 L
.5569 .5942 L
.57751 .60268 L
.61777 .62459 L
.65651 .64922 L
.67619 .66154 L
.6977 .67369 L
.70765 .67854 L
.71827 .683 L
.72822 .68637 L
.73738 .68867 L
.74237 .68955 L
.74488 .68989 L
.74765 .69017 L
.7491 .69029 L
.75042 .69037 L
.75115 .6904 L
.75195 .69043 L
.7527 .69045 L
.75339 .69047 L
.75463 .69048 L
.75533 .69047 L
.756 .69046 L
.75669 .69045 L
.75733 .69042 L
.75803 .69039 L
.75876 .69036 L
.76117 .69018 L
.76252 .69004 L
.76375 .6899 L
.76839 .68914 L
.77099 .68858 L
.77381 .68784 L
.77893 .68617 L
.78838 .6819 L
Mistroke
.79878 .67525 L
.80964 .66591 L
.81981 .65475 L
.84008 .62473 L
.8586 .58701 L
.8776 .53667 L
.89833 .4665 L
.91967 .3755 L
.939 .27457 L
.97619 .02381 L
Mfstroke
.02381 .02381 m
.04262 .1801 L
.06244 .31847 L
.08426 .44246 L
.10458 .53418 L
.12297 .59959 L
.14264 .65318 L
.15285 .67501 L
.16394 .69449 L
.17353 .70806 L
.18408 .71976 L
.18902 .72415 L
.19432 .72813 L
.19891 .731 L
.20392 .73354 L
.20684 .73474 L
.20955 .73569 L
.21236 .7365 L
.2149 .73708 L
.2174 .73752 L
.21976 .73782 L
.22106 .73794 L
.22225 .73802 L
.22356 .73807 L
.22422 .73809 L
.22495 .7381 L
.22625 .73808 L
.22746 .73804 L
.22809 .73801 L
.22878 .73797 L
.23019 .73785 L
.23142 .73772 L
.23275 .73755 L
.23515 .73717 L
.24001 .7361 L
.24446 .73479 L
.25465 .73069 L
.26537 .72491 L
.28511 .71106 L
.30348 .69538 L
.34253 .65747 L
.38402 .61742 L
.40483 .59976 L
.42401 .58577 L
.44269 .57471 L
.45223 .57014 L
.46247 .56612 L
.46772 .56441 L
.4727 .56303 L
.47755 .5619 L
Mistroke
.48205 .56104 L
.48629 .56041 L
.48846 .56015 L
.49081 .55992 L
.49215 .55981 L
.49339 .55973 L
.49455 .55966 L
.49582 .55961 L
.49696 .55957 L
.49803 .55954 L
.49915 .55953 L
.50036 .55952 L
.50158 .55954 L
.50228 .55955 L
.50293 .55956 L
.50425 .55961 L
.50566 .55968 L
.50822 .55984 L
.51056 .56005 L
.51596 .56073 L
.52164 .56173 L
.53126 .56411 L
.54177 .56767 L
.56142 .5769 L
.58239 .59015 L
.62394 .62473 L
.66397 .66397 L
.70249 .70071 L
.72201 .71648 L
.73236 .72352 L
.74346 .72978 L
.74893 .7323 L
.75412 .73431 L
.75918 .73588 L
.7614 .73645 L
.76386 .73698 L
.76598 .73736 L
.76828 .73769 L
.76954 .73783 L
.7707 .73793 L
.77181 .738 L
.77298 .73806 L
.77417 .73809 L
.77544 .73809 L
.77663 .73807 L
.77772 .73802 L
.779 .73794 L
.78039 .73781 L
.7817 .73765 L
.78291 .73747 L
Mistroke
.78758 .73651 L
.7902 .73577 L
.79259 .73495 L
.80165 .73067 L
.80671 .72741 L
.81223 .7231 L
.82229 .71309 L
.83261 .69971 L
.84197 .68463 L
.86295 .63956 L
.88221 .58274 L
.90304 .50232 L
.92299 .40434 L
.94406 .2759 L
.97619 .02381 L
Mfstroke
.02381 .02381 m
.04262 .2009 L
.06244 .35611 L
.08426 .49325 L
.10458 .59275 L
.12297 .66195 L
.14264 .71663 L
.15285 .73797 L
.16394 .75618 L
.17441 .76903 L
.18408 .77744 L
.18874 .78039 L
.19131 .78172 L
.19375 .78281 L
.19601 .78365 L
.19848 .7844 L
.20072 .78494 L
.20281 .7853 L
.2041 .78547 L
.20478 .78554 L
.2055 .78561 L
.20613 .78565 L
.20683 .78568 L
.20804 .78571 L
.20923 .78571 L
.2105 .78566 L
.2117 .78558 L
.21279 .78547 L
.21415 .7853 L
.21541 .78509 L
.21826 .7845 L
.22077 .78382 L
.22343 .78294 L
.2328 .77866 L
.2429 .77211 L
.26118 .75597 L
.30232 .7056 L
.34195 .64891 L
.38006 .59639 L
.40131 .57067 L
.42062 .55058 L
.44093 .53348 L
.45966 .52183 L
.46898 .5176 L
.47885 .51431 L
.48396 .51309 L
.48875 .51224 L
.49149 .5119 L
.494 .51166 L
.49539 .51157 L
Mistroke
.49612 .51153 L
.4969 .51149 L
.49764 .51146 L
.49832 .51145 L
.49964 .51143 L
.50085 .51143 L
.50198 .51145 L
.50321 .5115 L
.50453 .51156 L
.50592 .51165 L
.50723 .51177 L
.50969 .51203 L
.51412 .51271 L
.51893 .51374 L
.52418 .51519 L
.52976 .51711 L
.53976 .52153 L
.55927 .53363 L
.57757 .54887 L
.6163 .59175 L
.6575 .64811 L
.69717 .7049 L
.73533 .75236 L
.75498 .77051 L
.76064 .77462 L
.76597 .77797 L
.77073 .78048 L
.77595 .78272 L
.77838 .78356 L
.78099 .78431 L
.78324 .78484 L
.78569 .78527 L
.78713 .78546 L
.78776 .78553 L
.78846 .78559 L
.78973 .78567 L
.79043 .7857 L
.79108 .78571 L
.79232 .78571 L
.79345 .78567 L
.79469 .78559 L
.796 .78546 L
.79716 .78531 L
.79821 .78514 L
.80057 .78465 L
.80275 .78405 L
.80482 .78336 L
.80944 .78135 L
.81447 .77843 L
.82391 .77071 L
Mistroke
.82929 .76495 L
.83432 .7586 L
.8451 .7417 L
.85535 .7212 L
.87561 .66653 L
.89414 .59816 L
.91396 .50299 L
.93236 .39185 L
.97151 .07079 L
.97619 .02381 L
Mfstroke
.02381 .02381 m
.04262 .22291 L
.06244 .39561 L
.08255 .53562 L
.10458 .65282 L
.12415 .72898 L
.13511 .76137 L
.14509 .785 L
.15504 .80346 L
.16424 .81627 L
.16904 .82144 L
.17432 .826 L
.17698 .82786 L
.17985 .82954 L
.18256 .83084 L
.18502 .83178 L
.18755 .83251 L
.18895 .83281 L
.19026 .83303 L
.19148 .83318 L
.1926 .83328 L
.19382 .83333 L
.19512 .83333 L
.19644 .83327 L
.19717 .83321 L
.19784 .83314 L
.19915 .83296 L
.20038 .83274 L
.20315 .83208 L
.20615 .83109 L
.21121 .82881 L
.21659 .82559 L
.22624 .81788 L
.24571 .79583 L
.26399 .76876 L
.30268 .69851 L
.34382 .61685 L
.38344 .5437 L
.42155 .48723 L
.44116 .46553 L
.45206 .45595 L
.46211 .44877 L
.47236 .44313 L
.47775 .44086 L
.48346 .43899 L
.48585 .43837 L
.48842 .43781 L
.49064 .43741 L
.49306 .43708 L
.49452 .43692 L
Mistroke
.49589 .43681 L
.49719 .43673 L
.49791 .4367 L
.49857 .43668 L
.49982 .43667 L
.50052 .43667 L
.50117 .43668 L
.50236 .43671 L
.50361 .43678 L
.50484 .43687 L
.50617 .43699 L
.50859 .43729 L
.51094 .43768 L
.51312 .43813 L
.51805 .43943 L
.52329 .44126 L
.53202 .44533 L
.54164 .45126 L
.56102 .46767 L
.58189 .4916 L
.62308 .55494 L
.66276 .62982 L
.70092 .70552 L
.72221 .74528 L
.74153 .77749 L
.76189 .80538 L
.77082 .81508 L
.78063 .82361 L
.78514 .82671 L
.78997 .82941 L
.79265 .83061 L
.79508 .83153 L
.79739 .83223 L
.79985 .83279 L
.80112 .833 L
.80179 .83309 L
.80251 .83318 L
.80378 .83328 L
.80497 .83333 L
.80564 .83333 L
.80638 .83332 L
.80715 .83329 L
.80787 .83324 L
.80916 .83311 L
.80988 .83301 L
.81054 .83291 L
.81303 .83236 L
.81444 .83195 L
.81574 .83151 L
.82067 .82927 L
Mistroke
.82533 .82626 L
.83034 .82204 L
.83941 .81166 L
.85018 .79439 L
.86004 .77353 L
.87904 .71823 L
.88979 .67728 L
.89976 .63248 L
.91993 .52012 L
.93891 .38491 L
.97619 .02381 L
Mfstroke
.02381 .02381 m
.04262 .24609 L
.06244 .4369 L
.08255 .58933 L
.10458 .71413 L
.12415 .79245 L
.13511 .82439 L
.14509 .84671 L
.14992 .85535 L
.15504 .86304 L
.15947 .86851 L
.16424 .87323 L
.1669 .87536 L
.16934 .877 L
.17182 .87837 L
.17413 .87937 L
.1768 .88022 L
.17821 .88054 L
.17893 .88067 L
.17971 .88078 L
.18046 .88086 L
.18114 .88091 L
.1818 .88094 L
.18249 .88095 L
.1837 .88092 L
.18502 .88082 L
.18632 .88064 L
.18753 .88042 L
.18885 .8801 L
.19026 .87969 L
.19262 .87881 L
.19522 .87759 L
.20002 .87466 L
.20453 .87114 L
.21459 .86078 L
.22544 .84611 L
.24548 .81095 L
.26658 .76518 L
.30469 .66906 L
.34525 .5621 L
.3843 .46844 L
.40421 .42773 L
.42579 .39069 L
.4359 .3762 L
.4466 .36299 L
.45662 .35268 L
.46578 .34506 L
.47521 .33905 L
.48041 .33655 L
.48535 .33471 L
Mistroke
.48755 .33407 L
.4899 .33349 L
.49192 .33309 L
.49411 .33276 L
.49546 .33261 L
.4967 .3325 L
.49788 .33243 L
.49913 .33239 L
.50025 .33238 L
.50129 .3324 L
.50244 .33245 L
.50366 .33253 L
.50489 .33264 L
.50624 .3328 L
.50897 .33326 L
.51149 .33382 L
.51386 .33447 L
.5192 .33639 L
.52494 .33913 L
.53545 .34598 L
.54508 .35428 L
.56404 .37612 L
.58475 .40779 L
.62537 .49014 L
.66446 .58733 L
.70601 .69713 L
.74605 .79349 L
.7644 .82948 L
.77483 .84651 L
.78457 .85977 L
.79417 .87 L
.79956 .87437 L
.80448 .87743 L
.80717 .87872 L
.80966 .87966 L
.81106 .88008 L
.81239 .8804 L
.81377 .88066 L
.8145 .88076 L
.81529 .88085 L
.81653 .88093 L
.81724 .88095 L
.81789 .88095 L
.81859 .88092 L
.81922 .88088 L
.81995 .88082 L
.82063 .88073 L
.82186 .88053 L
.82299 .88028 L
.82554 .8795 L
Mistroke
.82797 .87847 L
.8302 .87727 L
.83522 .8737 L
.83986 .86924 L
.84428 .86394 L
.85414 .84817 L
.86491 .82433 L
.87524 .79444 L
.8846 .76097 L
.90557 .66173 L
.92484 .53784 L
.94566 .36401 L
.97619 .02381 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00mP3oool01@3ooml0W4P000000000B9`0gooo0;D0oooo003g0?ooo`03
0?oOW01804P0W=oo0;H0oooo003g0?ooo`030?oOW01804P0W=oo0;H0oooo003^0?ooo`050;md0000
000007Bo0?ooo`3OW4P00P0000001@00B9`0gooo0?oOW01804P0W=oo0;H0oooo003^0?ooo`0<0?oo
g`2LB7@0_ooo0?ooo`3ooml0W4P00018W03Oool0oono07@0000004P0W=oo]P3oool00>l0oooo00H0
oono07A8W03Oool0_g@00000M02oool20?ooo`030?oOW01804P0W=oo0;H0oooo003`0?ooo`040?oO
W01dB4P0000007Book`0oooo003`0?ooo`030?oo_`1d0000B9cO0;d0oooo003_0?ooo`050?oog`2L
B00004RL09adB02Lgol00`3oool00`3ookl0M00007Boo`2f0?ooo`00k`3oool01P2oM000001809cO
o`3ooml0W4Qd0;oook/0oooo003]0?ooo`090?oog`2LB000000000000000M;l0okmd0000000007@0
_ooo0;X0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo00110?ooo`050?oOW018000000000000M02oool0>`3oool01@3ogi`0B00000000000
07@0_ooo00<0oooo00D0okmd0000001d_ol0oooo0;md00060000000304RLg`3oool0oooo0340oooo
00D0omnL04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000
B9`0gooo<`3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol00`3oool0
1@3ogi`0B000000000000000M;oo03<0oooo00D0omnL04P000000000001d0;ooo`030?ooo`030?no
M0000000M;oo00<0oooo00D0gia8000000000000000004RLg`0k0?ooo`060;md0000000000000000
0000B9`0gooo1`3oool00400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo03T0oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool00`3OW4P0
000000000003000000030018W03Oool0oooo0300oooo00L0oono07@0001d_ol0oooo0?noM00007@0
_ooo0080oooo00<0okmd0000001d_ol01@3oool0103ooml0W4P00018W03Ooolb0?ooo`070?oo_`1d
0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM0000000M;oo0080oooo00L0omnL04P00018
W=l0oooo0?oo_`1d0000M;oo0340oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo
00<0okmd0000001d_ol00P3oool01`3OW4P0000007Boo`3oool0oooO09a80018W=l0>`3oool00`3o
gi`0B00007Boo`090?ooo`00@03oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo03P0
oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030=nLB018W=l0oooo0080
oooo00<0giad09cOo`3oool0<03oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00T0
oooo00@0oooO09a80000B9`0gooo<P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo
00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL0=ooo`0`0?ooo`030;md0000B9`0gooo
0080oooo00<0_g@0001d_`3oool01@3oool00`3ooml0W4P0001d_`030?ooo`030?noM000B9`0gooo
03X0oooo00<0omnL04P0001d_ol02@3oool003l0oooo00<0oono07@00018W=l00`3oool00`3OW4P0
001d0;ooo`0g0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool00`3OW4P0
M;oo0?ooo`0c0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`2oM000
0000000000050000000307Boo`3oool0oooo02h0oooo00<0oono07@00018W=l00`3oool00`3OW4P0
001d0;ooo`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0;`3oool00`3ookl0
M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0_g@0001d_`3oool00P3oool00`2oM000
04RL0=ooo`0j0?ooo`030?oOW0180000M;oo00T0oooo000o0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol0=`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0oooo
00<0_gA809cOo`3oool0<P3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo
00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL0=oooc40oooo00<0omnL04P0001d_ol00`3oool0
0`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0;`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0omnL04P0M02oool0oooo0;md
00000000M;oo03/0oooo00<0omnL04P0001d_ol02@3oool003l0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`0g0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02@3o
ool00`3ooml0W4Qd0;ooo`0b0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3o
ool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03Oool0<@3oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool00`2oM000001809cOo`0_0?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool01@3ookl0M4Q804P000000000B9cO
03`0oooo00<0omnL04P0001d_ol02@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`0g0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3o_g@0
07Bo0?ooo`0a0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3ooml0
W4Qd0;ooo`3ooml0W4P00018W03Oool0<@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00D0oooo00P0oono07@000000000B9cO0?ooo`3o_g@00000001d_c00oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`070?ooo`040?oOW01800000000001d_cd0oooo00<0omnL04P0
001d_ol02@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0g0?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3ookl0M01809cOo`0a0?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool01P3ogi`0B7Bo0?oog`2LB00004RL
0=oooc40oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`030;md0000B9`0
_ia80080000000<004RL0=ooo`3oool0;`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00H0oooo00H0omnL04P0000007@0_ooo0?noM000M;ll0?ooo`030?oOW0180000M;oo00T0oooo
000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0=`3oool00`3ookl0M00004RL
g`030?ooo`030=nLB00007@0_ooo00X0oooo00<0oono07@00018W=l0<@3oool00`3ookl0M00004RL
g`030?ooo`030=nLB00007@0_ooo00P0oooo00D0gia807Bog`2LB00004RL0=ooo`0a0?ooo`030?oo
_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`3ogi`0B00007Boo`0d0?ooo`030?oo
_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM000001d0;ooo`020?ooo`030;md
0018W=l0oooo03X0oooo00<0omnL04P0001d_ol02@3oool00400oooo00<0gia80018W03Oool00P3o
ool00`2oM00007Bo0?ooo`0h0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3o
ool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW0180000B9cO0380oooo00<0gia80018W03Oool00P3o
ool00`2oM00007Bo0?ooo`080?ooo`050?oog`2LB4P0B4P00018W03Oool0<P3oool00`3OW4P004RL
0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000B02Lgol0=03oool00`3OW4P004RL
0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo00<0_g@00018W03Oool00P3oool00`3OW4P007Bo
0?ooo`0j0?ooo`030?oOW0180000M;oo00T0oooo00100?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0
001d0;ooo`0i0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`060?ooo`080?oog`2LB4P0
W=oo0?ooo`3ookl0M0000000M02ooolb0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0:
0?ooo`040?oOW018000004RL0=oooc80oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00T0
oooo00<0okmd00000000M;l0<`3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool01`3oool0
1`3o_g@0000007Boo`3oool0oono07@0001d_ol0>@3oool01@3ooml0W4P0000000000000M;oo00T0
oooo00110?ooo`050?oo_`1d000000000000M02oool0>`3oool01@3ookl0M0000000000007@0_ooo
00P0oooo00H0oooO09a80000000000000000M02ooold0?ooo`050?oo_`1d000000000000M02oool0
303oool00`3OW4P004RL0=ooo`0c0?ooo`050?oo_`1d000000000000M02oool02`3oool01@3ooml0
W4P00000000007@0_ooo0340oooo00D0oono07@000000000001d0;ooo`090?ooo`050?noM0000000
000000000018W=l0?03oool00`3o_g@0000007Boo`090?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00>`3ooooo000007D000000@3oool003/0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01P3oool100000040oooo000k0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo0@0000010?oo
o`00>`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool002`0oooo00D0omnL04P000000000
001d0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooL@3oool100000040oooo000[0?ooo`070?oo
_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`090?ooo`030000003oool0oooo0?l0ooooL@3oool10000
0040oooo000[0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool0203oool00`000000
oooo0?ooo`3o0?ooog40oooo0@0000010?ooo`00:P3oool00`3ookl0M00004RLg`030?ooo`030=nL
B00007@0_ooo00P0oooo00<000000?ooo`3oool0o`3oooma0?ooo`4000000@3oool002X0oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo0?l0ooooL@3o
ool100000040oooo000Z0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0203oool3
000000D0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`030000003oool0oooo00@0oooo0`000001
0?ooo`00:P3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00P0oooo00<000000?oo
o`3oool01@3oool200000?l0ooooH@3oool00`000000oooo0?ooo`060?ooo`4000000@3oool002X0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`000000o`3ooomP0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00
:P3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00P0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`00003o0?oooel0oooo00<000000?ooo`3oool01P3oool100000040
oooo000[0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool0203oool00`000000oooo
0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`3o0?oooe/0oooo0P0000080?ooo`400000
0@3oool002/0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00T0oooo00<000000?ooo`3o
ool01@3oool2000000<0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`800000203oool100000040
oooo000/0?ooo`050?oo_`1d000000000000M02oool02P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooomI0?ooo`800000203oool100000040
oooo000k0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3o0?oooeP0oooo0P0000080?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooE`3oool2000000P0oooo0@00
00010?ooo`00>`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0o`3ooomF0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`00>`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomE0?oo
o`030000003oool0oooo00L0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`060?ooo`80
0000203oool00`000000oooo0?ooo`3o0?oooe<0oooo0P0000090?ooo`4000000@3oool003/0oooo
00<000000?ooo`3oool01P3oool2000000T0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`800000
2@3oool100000040oooo000k0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`030000003o
ool0oooo0?l0ooooD@3oool2000000T0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`06
0?ooo`8000002`3oool00`000000oooo0?ooo`3o0?oooe00oooo0P0000090?ooo`4000000@3oool0
03/0oooo00<000000?ooo`3oool01P3oool2000000`0oooo00<000000?ooo`3oool0o`3ooom?0?oo
o`8000002@3oool100000040oooo000k0?ooo`030000003oool0oooo00H0oooo0P00000=0?ooo`03
0000003oool0oooo0?l0ooooCP3oool2000000T0oooo0@0000010?ooo`00>`3oool00`000000oooo
0?ooo`060?ooo`8000003P3oool00`000000oooo0?ooo`3o0?ooodd0oooo0P0000090?ooo`400000
0@3oool003/0oooo0P0000080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`800000203oool200000040oooo000k0?ooo`030000003oool0oooo00L0oooo0P00000?
0?ooo`030000003oool0oooo0?l0ooooBP3oool3000000T0oooo0@0000010?ooo`00>`3oool00`00
0000oooo0?ooo`070?ooo`800000403oool00`000000oooo0?ooo`3o0?ooodT0oooo0`0000090?oo
o`4000000@3oool003/0oooo00<000000?ooo`3oool01`3oool200000140oooo00<000000?ooo`3o
ool0o`3ooom80?ooo`<000002@3oool100000040oooo000k0?ooo`030000003oool0oooo00L0oooo
0P00000B0?ooo`030000003oool0oooo0?l0ooooA`3oool2000000X0oooo0@0000010?ooo`00>`3o
ool00`000000oooo0?ooo`070?ooo`8000004`3oool00`000000oooo0?ooo`3o0?ooodH0oooo0P00
000:0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool01`3oool2000001@0oooo00<00000
0?ooo`3oool0o`3ooom50?ooo`8000002P3oool100000040oooo000k0?ooo`030000003oool0oooo
00L0oooo0P00000E0?ooo`030000003oool0oooo0?l0ooooA03oool2000000X0oooo0@0000010?oo
o`00>`3oool00`000000oooo0?ooo`070?ooo`<000005@3oool00`000000oooo0?ooo`3o0?oood80
oooo0`00000:0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool01`3oool3000001H0oooo
00<000000?ooo`3oool0o`3ooom10?ooo`<000002P3oool100000040oooo000k0?ooo`030000003o
ool0oooo00L0oooo0`00000G0?ooo`030000003oool0oooo0?l0oooo@03oool3000000X0oooo0@00
00010?ooo`00>`3oool00`000000oooo0?ooo`070?ooo`<00000603oool00`000000oooo0?ooo`3o
0?ooocl0oooo0`00000:0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0203oool20000
01T0oooo00<000000?ooo`3oool0o`3oooln0?ooo`8000002`3oool100000040oooo000k0?ooo`03
0000003oool0oooo00P0oooo0P00000J0?ooo`030000003oool0oooo0?l0oooo?@3oool2000000/0
oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`080?ooo`8000006`3oool00`000000oooo
0?ooo`3o0?oooc`0oooo0P00000;0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0203o
ool3000001/0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`<000002`3oool100000040oooo000k
0?ooo`030000003oool0oooo00P0oooo0`00000L0?ooo`030000003oool0oooo0?l0oooo>@3oool3
000000/0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`080?ooo`<000007@3oool00`00
0000oooo0?ooo`3o0?ooocP0oooo0`00000;0?ooo`4000000@3oool003/0oooo0P0000090?ooo`<0
00007P3oool00`000000oooo0?ooo`3o0?ooocL0oooo0`00000:0?ooo`8000000@3oool003/0oooo
00<000000?ooo`3oool0203oool3000001l0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`<00000
2`3oool100000040oooo000k0?ooo`030000003oool0oooo00P0oooo0`00000P0?ooo`030000003o
ool0oooo0?l0oooo=@3oool3000000/0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`08
0?ooo`<000008@3oool00`000000oooo0?ooo`3o0?oooc@0oooo0`00000;0?ooo`4000000@3oool0
03/0oooo00<000000?ooo`3oool0203oool300000280oooo00<000000?ooo`3oool0o`3ooolb0?oo
o`@000002`3oool100000040oooo000k0?ooo`030000003oool0oooo00P0oooo1000000R0?ooo`03
0000003oool0oooo0?l0oooo<@3oool3000000`0oooo0@0000010?ooo`00>`3oool00`000000oooo
0?ooo`090?ooo`<000008`3oool00`000000oooo0?ooo`3o0?oooc00oooo0`00000<0?ooo`400000
0@3oool003/0oooo00<000000?ooo`3oool02@3oool3000002@0oooo00<000000?ooo`3oool0o`3o
ool_0?ooo`<00000303oool100000040oooo000k0?ooo`030000003oool0oooo00T0oooo0`00000U
0?ooo`030000003oool0oooo0?l0oooo;P3oool3000000`0oooo0@0000010?ooo`00>`3oool00`00
0000oooo0?ooo`090?ooo`<000009P3oool00`000000oooo0?ooo`3o0?ooobd0oooo0`00000<0?oo
o`4000000@3oool003/0oooo00<000000?ooo`3oool02@3oool3000002L0oooo00<000000?ooo`3o
ool0o`3oool/0?ooo`<00000303oool100000040oooo000k0?ooo`030000003oool0oooo00T0oooo
0`00000X0?ooo`030000003oool0oooo0?l0oooo:P3oool4000000`0oooo0@0000010?ooo`00>`3o
ool00`000000oooo0?ooo`090?ooo`@00000:03oool00`000000oooo0?ooo`3o0?ooobT0oooo1000
000<0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool02@3oool4000002T0oooo00<00000
0?ooo`3oool0o`3ooolX0?ooo`@00000303oool100000040oooo000k0?ooo`030000003oool0oooo
00T0oooo1000000Z0?ooo`030000003oool0oooo0?l0oooo9`3oool4000000`0oooo0@0000010?oo
o`00>`3oool00`000000oooo0?ooo`090?ooo`@00000:`3oool00`000000oooo0?ooo`3o0?ooobH0
oooo1000000<0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool02@3oool4000002`0oooo
00<000000?ooo`3oool0o`3ooolU0?ooo`<000003@3oool100000040oooo000k0?ooo`8000002P3o
ool4000002d0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`<00000303oool200000040oooo000k
0?ooo`030000003oool0oooo00X0oooo1000000]0?ooo`030000003oool0oooo0?l0oooo8`3oool3
000000d0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0:0?ooo`@00000;P3oool00`00
0000oooo0?ooo`3o0?ooob40oooo00@000000?ooo`00000000003@3oool100000040oooo000k0?oo
o`030000003oool0oooo00X0oooo1000000_0?ooo`030000003oool0oooo0?l0oooo803oool40000
00d0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0:0?ooo`@00000<03oool00`000000
oooo0?ooo`3o0?oooal0oooo1000000=0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0
2P3oool400000340oooo00<000000?ooo`3oool0o`3ooolN0?ooo`@000003@3oool100000040oooo
000k0?ooo`030000003oool0oooo00X0oooo1000000b0?ooo`030000003oool0oooo0?l0oooo7@3o
ool4000000d0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0:0?ooo`<0000000<0oooo
0000003oool0<@3oool00`000000oooo0?ooo`3o0?oooa`0oooo1000000=0?ooo`4000000@3oool0
03/0oooo00<000000?ooo`3oool02P3oool3000000030?ooo`000000oooo0380oooo00<000000?oo
o`3oool0o`3ooolK0?ooo`@000003@3oool100000040oooo000k0?ooo`030000003oool0oooo00X0
oooo1@00000d0?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo00000002000000d0
oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0:0?ooo`D00000=@3oool00`000000oooo
0?ooo`3o0?oooaP0oooo00<000000?ooo`0000000P00000=0?ooo`4000000@3oool003/0oooo00<0
00000?ooo`3oool02P3oool5000003H0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`040000003o
ool00000000000h0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0:0?ooo`D00000=`3o
ool00`000000oooo0?ooo`3o0?oooaH0oooo1000000>0?ooo`4000000@3oool001h0oooo00D0omnL
04P000000000001d0;ooo`030?ooo`050?noM0000000M;oo0?ooo`2oM0001P0000000`18W=l0oooo
0?ooo`070?ooo`030000003oool0oooo00/0oooo0`0000000`3oool000000?ooo`0f0?ooo`030000
003oool0oooo0?l0oooo5@3oool4000000h0oooo0@0000010?ooo`007@3oool01`3ookl0M00007Bo
o`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?ooo`030=nLB0000000000000<0
000000<004RL0=ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`<0000000<0oooo0000003o
ool0=`3oool00`000000oooo0?ooo`3o0?oooa@0oooo1000000>0?ooo`4000000@3oool001d0oooo
00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030=nLB018W=l0oooo0080oooo
00<0giad09cOo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo000000000000
>@3oool00`000000oooo0?ooo`3o0?oooa<0oooo1000000>0?ooo`4000000@3oool001`0oooo00<0
oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`080?ooo`030=nLB01d_ol0oooo00/0oooo00<0
00000?ooo`3oool02`3oool2000000030?ooo`000000000003X0oooo00<000000?ooo`3oool0o`3o
oolA0?ooo`030000003oool00000008000003P3oool100000040oooo000L0?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol02@3oool00`2oM4P0W=oo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo1@00000k0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo00000002
000000h0oooo0@0000010?ooo`00703oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00T0oooo00<0oooO09a8M02oool02P3oool3000000/0oooo1@00000l0?ooo`030000003oool0oooo
0?l0oooo3`3oool00`000000oooo00000002000000`0oooo0`0000010?ooo`00703oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo00<0okmd001d_`3oool02@3oool00`000000
oooo0?ooo`0;0?ooo`@0000000<0oooo0000003oool0>`3oool00`000000oooo0?ooo`3o0?ooo`h0
oooo00<000000?ooo`0000000P00000>0?ooo`4000000@3oool001`0oooo00<0omnL04P0001d_ol0
0`3oool00`3o_g@0001809cOo`0:0?ooo`030?oo_`1d04P0W=oo00T0oooo00<000000?ooo`3oool0
2`3oool4000000030?ooo`000000oooo03`0oooo00<000000?ooo`3oool0o`3oool=0?ooo`D00000
3P3oool100000040oooo000L0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool02P3o
ool00`3ookl0M00004RLg`090?ooo`030000003oool0oooo00/0oooo100000000`3oool000000?oo
o`0m0?ooo`030000003oool0oooo0?l0oooo303oool5000000h0oooo0@0000010?ooo`007@3oool0
0`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oknL09cOo`3oool00P3oool0
0`3ogi`0B00004RLg`090?ooo`030000003oool0oooo00/0oooo0`0000000`3oool000000000000o
0?ooo`030000003oool0oooo0?l0oooo2`3oool5000000h0oooo0@0000010?ooo`007@3oool01`3o
okl0M00007Boo`3oool0okmd0000M02oool01P3oool0203ooml0W4Q809cOo`3oool0oono07@00000
07@0_ooo2@3oool00`000000oooo0?ooo`0;0?ooo`<0000000<0oooo000000000000@03oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`0000000P00000?0?ooo`4000000@3oool001h0
oooo00D0oono07@000000000001d0;ooo`080?ooo`060?oog`2LB00000000000000007@0_ooo2P3o
ool00`000000oooo0?ooo`0;0?ooo`80000000D0oooo000000000000oooo000000100?ooo`030000
003oool0oooo0?l0oooo203oool00`000000oooo00000002000000l0oooo0@0000010?ooo`00>`3o
ool00`000000oooo0?ooo`0<0?ooo`060000003oool000000000003oool00000@@3oool00`000000
oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`0000000P00000?0?ooo`4000000@3oool003/0oooo
00<000000?ooo`3oool0303oool4000000030?ooo`000000oooo0440oooo00<000000?ooo`3oool0
o`3oool60?ooo`030000003oool00000008000003`3oool100000040oooo000k0?ooo`030000003o
ool0oooo00`0oooo100000000`3oool000000?ooo`120?ooo`030000003oool0oooo0?l0oooo1@3o
ool00`000000oooo00000002000000l0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0<
0?ooo`<0000000<0oooo000000000000A03oool00`000000oooo0?ooo`3o0?ooo`@0oooo00<00000
0?ooo`0000000P00000?0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0303oool30000
00030?ooo`000000000004D0oooo00<000000?ooo`3oool0o`3oool30?ooo`D000003`3oool10000
0040oooo000k0?ooo`030000003oool0oooo00`0oooo0`000000103oool000000?ooo`0000150?oo
o`030000003oool0oooo0?l0oooo0P3oool5000000l0oooo0@0000010?ooo`00>`3oool00`000000
oooo0?ooo`0<0?ooo`<0000000@0oooo0000003oool00000AP3oool00`000000oooo0?ooo`3o0?oo
o`030000003oool0000000<000003`3oool100000040oooo000k0?ooo`030000003oool0oooo00`0
oooo0P0000001@3oool000000000003oool0000004L0oooo00<000000?ooo`3oool0oP3oool00`00
0000oooo00000003000000l0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0<0?ooo`80
000000D0oooo000000000000oooo000000180?ooo`030000003oool0oooo0?d0oooo00@000000?oo
o`000000oooo0P00000?0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo00000002000000030?ooo`000000oooo04P0oooo00<000000?ooo`3oool0o03oool01@00
0000oooo0000003oool000000100oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0=0?oo
o`<0000000<0oooo000000000000BP3oool00`000000oooo0?ooo`3k0?ooo`050000003oool00000
0?ooo`000000403oool100000040oooo000k0?ooo`8000003P3oool3000000040?ooo`000000oooo
000004X0oooo00<000000?ooo`3oool0nP3oool00`000000oooo00000002000000l0oooo0P000001
0?ooo`00>`3oool00`000000oooo0?ooo`0=0?ooo`<0000000@0oooo0000003oool00000B`3oool0
0`000000oooo0?ooo`3i0?ooo`D00000403oool100000040oooo000k0?ooo`030000003oool0oooo
00d0oooo0`000000103oool000000?ooo`00001<0?ooo`030000003oool0oooo0?L0oooo00<00000
0?ooo`0000000`00000@0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool03@3oool20000
00050?ooo`00000000000?ooo`000000C@3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0
000000<00000403oool100000040oooo000k0?ooo`030000003oool0oooo00d0oooo0P0000001@3o
ool000000000003oool0000004h0oooo00<000000?ooo`3oool0m@3oool00`000000oooo00000003
00000100oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0=0?ooo`80000000<0oooo0000
003oool00P00001?0?ooo`030000003oool0oooo0?@0oooo00@000000?ooo`000000oooo0P00000@
0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool03@3oool020000000oooo000000000000
oooo0000003oool00000C`3oool00`000000oooo0?ooo`3c0?ooo`040000003oool000000?ooo`80
0000403oool100000040oooo000k0?ooo`030000003oool0oooo00d0oooo00P000000?ooo`000000
00000?ooo`000000oooo00000500oooo00<000000?ooo`3oool0lP3oool010000000oooo0000003o
ool200000100oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0>0?ooo`<0000000@0oooo
0000003oool00000D@3oool00`000000oooo0?ooo`3`0?ooo`050000003oool000000000003oool0
0P00000@0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool03P3oool3000000040?ooo`00
0000oooo00000580oooo00<000000?ooo`3oool0k`3oool01@000000oooo000000000000oooo0080
0000403oool100000040oooo000k0?ooo`030000003oool0oooo00h0oooo0P0000001@3oool00000
0000003oool0000005<0oooo00<000000?ooo`3oool0kP3oool00`000000oooo0000000300000140
oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0>0?ooo`80000000<0oooo000000000000
0P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`000000
0`00000A0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool03P3oool2000000060?ooo`00
0000oooo0000003oool00000E03oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo00@0
00004@3oool100000040oooo000k0?ooo`030000003oool0oooo00h0oooo0P0000001P3oool00000
0?ooo`000000oooo000005D0oooo00<000000?ooo`3oool0jP3oool01@000000oooo0?ooo`000000
oooo008000004@3oool100000040oooo000k0?ooo`030000003oool0oooo00h0oooo00P000000?oo
o`00000000000?ooo`000000oooo000005H0oooo00<000000?ooo`3oool0j@3oool01@000000oooo
000000000000oooo008000004@3oool100000040oooo000k0?ooo`030000003oool0oooo00h0oooo
00P000000?ooo`00000000000?ooo`000000oooo000005L0oooo00<000000?ooo`3oool0j03oool0
1@000000oooo000000000000oooo008000004@3oool100000040oooo000k0?ooo`030000003oool0
oooo00h0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0i`3oool01@000000oooo000000000000oooo008000004@3oool100000040
oooo000k0?ooo`030000003oool0oooo00l0oooo0P0000000`3oool00000000000020?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`02000000030?oo
o`00000000000140oooo0@0000010?ooo`00>`3oool200000100oooo0P0000001P3oool000000?oo
o`000000oooo000005T0oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`0200000003
0?ooo`00000000000100oooo0P0000010?ooo`00>`3oool00`000000oooo0?ooo`0?0?ooo`800000
00H0oooo0000003oool000000?ooo`00001J0?ooo`030000003oool0oooo0><0oooo00<000000?oo
o`3oool00P0000000`3oool000000000000A0?ooo`4000000@3oool003/0oooo00<000000?ooo`3o
ool03`3oool2000000060?ooo`000000oooo0000003oool00000F`3oool00`000000oooo0?ooo`3R
0?ooo`060000003oool000000?ooo`000000oooo0P00000A0?ooo`4000000@3oool003/0oooo00<0
00000?ooo`3oool03`3oool2000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`3Q0?ooo`050000003oool000000000003oool00P00000B0?ooo`40
00000@3oool003/0oooo00<000000?ooo`3oool03`3oool01P000000oooo000000000000oooo0000
0080oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo
0080000000<0oooo0000000000004P3oool100000040oooo000k0?ooo`030000003oool0oooo00l0
oooo00H000000?ooo`00000000000?ooo`0000020?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool0gP3oool00`000000oooo0?ooo`02000000030?ooo`00000000000180oooo0@000001
0?ooo`00>`3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0000000000080oooo00<00000
0?ooo`000000GP3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo0080000000<0oooo
0000000000004P3oool100000040oooo000k0?ooo`030000003oool0oooo00l0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`000000G`3oool00`000000oooo0?ooo`3L0?ooo`030000
003oool0oooo0080000000<0oooo0000000000004P3oool100000040oooo000k0?ooo`030000003o
ool0oooo0100oooo0P000000103oool000000?ooo`0000020?ooo`030000003oool0oooo05d0oooo
00<000000?ooo`3oool0>03oool8000009X0oooo00L000000?ooo`3oool000000?ooo`000000oooo
008000004P3oool100000040oooo000k0?ooo`030000003oool0oooo0100oooo0P000000103oool0
00000?ooo`0000020?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0=@3oool20000
00P0oooo0P00002H0?ooo`070000003oool0oooo0000003oool000000?ooo`0200000180oooo0@00
00010?ooo`00>`3oool00`000000oooo0?ooo`0@0?ooo`80000000@0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0380oooo0P00000<0?ooo`800000UP3o
ool01`000000oooo0?ooo`000000oooo0000003oool00P00000B0?ooo`4000000@3oool003/0oooo
00<000000?ooo`3oool0403oool2000000040?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`0_0?ooo`800000403oool2000009@0oooo00<000000?ooo`3o
ool00P0000020?ooo`8000004P3oool100000040oooo000k0?ooo`030000003oool0oooo0100oooo
00@000000?ooo`00000000000P3oool00`000000oooo0000001S0?ooo`030000003oool0oooo02`0
oooo0P00000D0?ooo`800000TP3oool00`000000oooo0?ooo`0200000080oooo0P00000B0?ooo`40
00000@3oool003/0oooo00<000000?ooo`3oool0403oool010000000oooo0000000000020?ooo`03
0000003oool0000006@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0F0?ooo`80
0000S`3oool010000000oooo0?ooo`3oool2000000040?ooo`000000oooo00000180oooo0@000001
0?ooo`00>`3oool00`000000oooo0?ooo`0@0?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo08`0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000
003oool000004P3oool100000040oooo000k0?ooo`030000003oool0oooo0100oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`0U0?ooo`8000007@3oool00`000000oooo0?ooo`2;0?ooo`070000003oool0oooo0000003oool0
00000?ooo`02000001<0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0A0?ooo`800000
00@0oooo0000003oool000000P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2:0?ooo`070000003oool0oooo0000
003oool000000?ooo`02000001<0oooo0@0000010?ooo`00>`3oool200000180oooo0P000000103o
ool000000?ooo`0000020?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo08T0oooo00L000000?ooo`3oool000000?oo
o`000000oooo008000004P3oool200000040oooo000k0?ooo`030000003oool0oooo0140oooo0P00
00001`3oool000000?ooo`3oool000000?ooo`000000J03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0Q`3oool020000000oooo0?ooo`3oool00000
0?ooo`000000oooo0P00000C0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool04@3oool2
000000050?ooo`000000oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`260?ooo`040000003o
ool0oooo0?ooo`8000000P3oool2000001<0oooo0@0000010?ooo`00>`3oool00`000000oooo0?oo
o`0A0?ooo`040000003oool0000000000080oooo00@000000?ooo`3oool00000J@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0QP3oool01P000000
oooo0?ooo`000000oooo00000080oooo0P00000C0?ooo`4000000@3oool003/0oooo00<000000?oo
o`3oool04@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`250?ooo`060000003oool0oooo0000003oool000000P3oool2000001<0oooo0@0000010?ooo`00
>`3oool00`000000oooo0?ooo`0A0?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo08<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo0P00
000C0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool04@3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`0;0000003oool0oooo0?ooo`00
0000oooo0000003oool000000?ooo`0000004`3oool100000040oooo000k0?ooo`030000003oool0
oooo0140oooo00D000000?ooo`000000oooo000000020?ooo`040000003oool0oooo000006`0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0840oooo
00P000000?ooo`3oool0oooo0000003oool000000?ooo`800000503oool100000040oooo000k0?oo
o`030000003oool0oooo0180oooo0P0000001@3oool000000?ooo`3oool000000080oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0P03oool020000000oooo0?ooo`3oool000000?ooo`000000oooo0P00000D0?ooo`40
00000@3oool003/0oooo00<000000?ooo`3oool04P3oool2000000050?ooo`000000oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`200?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`0000000000503oool100000040oooo000k0?ooo`030000003oool0oooo0180oooo0P0000020?oo
o`030000003oool000000080oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0OP3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool2000001@0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0B
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo07d0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo0P00000D0?ooo`4000000@3oool003/0
oooo00<000000?ooo`3oool04P3oool01@000000oooo0000003oool000000080oooo00@000000?oo
o`3oool00000L03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0O@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool2000001@0oooo
0@0000010?ooo`007P3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol0
1@3oool0103ooml0W4P00018W03Oool90?ooo`030000003oool0oooo0180oooo00D000000?ooo`00
0000oooo000000020?ooo`040000003oool0oooo00000740oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo07`0oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo0P00000D0?ooo`4000000@3oool001d0oooo00L0oono07@0001d_ol0oooo
0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol01@3oool0103ooml0W4P00018W03Oool90?oo
o`030000003oool0oooo0180oooo00D000000?ooo`000000oooo000000020?ooo`040000003oool0
oooo00000780oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo07/0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo0P00000D0?ooo`40
00000@3oool001d0oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`090?ooo`040?oo
g`2LB00004RL0=ooo`T0oooo00<000000?ooo`3oool04P3oool01@000000oooo0000003oool00000
0080oooo00@000000?ooo`3oool00000L`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0NP3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`00000000005@3oool100000040oooo000L0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool01@3oool00`2oM0000000000000050000000307Boo`3oool0oooo00H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo000000020?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0N@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool2000001D0
oooo0@0000010?ooo`00703oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo
00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL0=ooo`T0oooo00<000000?ooo`3oool04`3oool2
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1h0?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`8000005@3oool100000040oooo000L0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03O
ool02@3oool3000001<0oooo0P0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0N03oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool2000001<0oooo0`00
00010?ooo`00703oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0oooO
09a8M02oool0oooO09a80000B9`0gooo00T0oooo00<000000?ooo`3oool04`3oool01@000000oooo
0000003oool000000080oooo00@000000?ooo`3oool00000MP3oool01@000000oooo0?ooo`3oool0
000003d0oooo00<000000?ooo`3oool0M`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool2000001D0oooo0@0000010?ooo`00703oool00`3ogi`0B00007Boo`030?ooo`030?noM000
04P0W=oo00L0oooo00H0omnL04Qd_`3ooml0W4P00018W03Oool90?ooo`030000003oool0oooo01<0
oooo00D000000?ooo`000000oooo000000020?ooo`040000003oool0oooo000007L0oooo00<00000
0?ooo`000000?P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000P3oool2000001D0oooo0@0000010?ooo`00703oool00`3ookl0M00004RLg`030?oo
o`030=nLB00007@0_ooo00P0oooo00D0gia807Bog`2LB00004RL0=ooo`090?ooo`030000003oool0
oooo01<0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
M`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo07D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo008000005@3oool100000040oooo000M0?ooo`030=nL
B000B9`0gooo0080oooo00<0_g@0001d_`3oool0203oool01@3ooml0W4Q804Q80000B9`0gooo00T0
oooo00<000000?ooo`3oool04`3oool01@000000oooo0000003oool000000080oooo00D000000?oo
o`3oool0oooo0000001g0?ooo`800000?`3oool00`000000oooo0?ooo`1e0?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`030000003oool0000001D0oooo0@0000010?ooo`007@3o
ool01`3ookl0M00007Boo`3oool0okmd0000M02oool02P3oool0103ogi`0B0000018W03Oool90?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0oooo07@0oooo00@000000?ooo`3oool00000?`3oool00`000000oooo0?ooo`1d
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`8000005P3oool100000040oooo
000N0?ooo`050?oo_`1d000000000000M02oool0303oool00`3OW4P004RL0=ooo`090?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo07@0oooo00D000000?ooo`3oool0oooo0000000n0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000020?ooo`8000005P3oool10000
0040oooo000k0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo0780oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo008000005P3oool100000040oooo000k0?ooo`030000003oool0oooo
01@0oooo0P0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0LP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0LP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000F0?ooo`4000000@3o
ool003/0oooo00<000000?ooo`3oool0503oool01@000000oooo0000003oool000000080oooo00D0
00000?ooo`3oool0oooo0000001c0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`1a0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`02000001H0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0D0?ooo`050000
003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000780oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0740oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo0P00000F0?ooo`4000000@3oool003/0oooo00<00000
0?ooo`3oool0503oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo00<00000
0?ooo`0000005P3oool100000040oooo000k0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`/000007`3oool00`000000oooo0?ooo`1_
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000001H0
oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool000000080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool3000000/0oooo0P00000N0?ooo`030000003oool0oooo06h0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo008000005`3oool10000
0040oooo000k0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`080?ooo`800000403oool3000001/0oooo00<000000?ooo`3oool0KP3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00000G0?ooo`4000000@3oool0
03/0oooo00<000000?ooo`3oool0503oool00`000000oooo000000020?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00D0oooo0P00000E0?ooo`8000006P3oool00`000000oooo0?ooo`1]0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000001L0oooo0@0000010?ooo`00>`3oool0
0`000000oooo0?ooo`0D0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`020?ooo`8000006@3oool2000001P0oooo00<000000?ooo`3oool0K03oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`4000000@3oool003/0
oooo00<000000?ooo`3oool05@3oool01@000000oooo0000003oool0000000<0oooo00D000000?oo
o`3oool0oooo0000001]0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000007@3o
ool2000001L0oooo00<000000?ooo`3oool0J`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool0oooo0P00000G0?ooo`4000000@3oool003/0oooo0P00000F0?ooo`030000
003oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo01@0oooo0P00000P0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0J`3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`00
000F0?ooo`8000000@3oool003/0oooo00<000000?ooo`3oool05@3oool00`000000oooo00000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`0D0?ooo`8000008@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo06X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0000003oool000005`3oool10000
0040oooo000k0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`0000000P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0503oool01000
0000oooo0?ooo`00000Q0?ooo`800000503oool00`000000oooo0?ooo`1Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000001L0oooo0@0000010?ooo`00
>`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool000000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0J03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P00000H0?oo
o`4000000@3oool000T0oooo00<0_gAd0;ooo`3oool0103oool00`2oM7@0_ooo0?ooo`0X0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
06P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`800000603o
ool100000040oooo00090?ooo`030;md0018W=l0oooo00<0oooo00<0gia80000M02oool0:@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1W0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000001P0
oooo0@0000010?ooo`002@3oool02@2oM00000000000M02oool0oooO09a80018W=l0gibL0;ooo`0Y
0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`1W0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool20000
01P0oooo0@0000010?ooo`002@3oool01P2oW9`0gmnL04P000000000001809cOob`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06D0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0?ooo`800000603oool100000040
oooo00090?ooo`030;mdM02ogi`0B0000080000000@0001809cOo`3OW9`0_ooo:@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0I@3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00H000000?ooo`3oool000000?ooo`00000H0?ooo`400000
0@3oool000T0oooo00<0_g@00018W03Oool00P3oool0102oM00000000000M02ooolY0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06@0
oooo00D000000?ooo`3oool0oooo000000030?ooo`060000003oool0oooo0000003oool00000603o
ool100000040oooo00090?ooo`030;mdB02Lgol0oooo00<0oooo00<0okmd0000M02oool0:@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0000000H0?ooo`4000000@3oool000T0oooo00<0_ibL0=ooo`3oool0103oool00`3OW9`0_ooo0?oo
o`0X0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`80
00006@3oool100000040oooo000k0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`000000
0`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`1R0?ooo`050000003oool0oooo0?ooo`0000000`3oool01000
0000oooo0?ooo`3oool2000001T0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0F0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0H@3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool0oooo0P00000I0?ooo`4000000@3oool000h0oooo
00<0_ibL0=ooo`3oool00P3oool00`3OW9`0_ooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo
00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P00000I0?ooo`4000000@3oool0
00X0oooo00D0oono07@0B02Lgol0oono07@00004000000030000M02oool0oooo02D0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0000000I0?ooo`4000000@3oool001<0oooo00<0gibL0;ooo`3oool09@3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1O0?ooo`050000
003oool0oooo0?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000006@3oool1
00000040oooo000k0?ooo`800000603oool00`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0000000H0?ooo`8000000@3oool00100oooo00<0_gAd0;ooo`3oool0:03oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`1M0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0000001T0oooo0@0000010?ooo`00403oool00`2oM7@0_ooo0?ooo`0X0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05d0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P00000J0?ooo`40
00000@3oool00100oooo00<0_gAd0;ooo`3oool0:03oool00`000000oooo0?ooo`0G0?ooo`040000
003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000006P3oool100000040oooo000=0?oo
o`030;md00000000000000<0000000<0001d0;ooo`3oool09@3oool00`000000oooo0?ooo`0G0?oo
o`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000001X0oooo
0@0000010?ooo`00403oool00`2oM7@0_ooo0?ooo`0X0?ooo`030000003oool0oooo01L0oooo00@0
00000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo3@00000M0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000000J0?ooo`4000000@3oool00100
oooo00<0_gAd0;ooo`3oool0:03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0I0?ooo`800000303oool4000001/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0000001X0oooo0@0000010?ooo`00403oool00`2o
M7@0_ooo0?ooo`0X0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01H0oooo0`00000?0?ooo`030000003oool0oooo00<00000603oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000006P3oool100000040oooo000<
0?ooo`030=nLB000M;l0oooo00@0oooo00<0_gAd0;ooo`3oool09@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`8000004`3o
ool00`000000oooo0?ooo`020?ooo`<000005P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`070000003o
ool0oooo0?ooo`000000oooo0000000J0?ooo`4000000@3oool000/0oooo00<0okmd04RLg`3oool0
0`3oool0103ookl0M0000000M02ooolV0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo0P00000F0?ooo`030000003oool0oooo
00@0oooo0P00000D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003o
ool0000001X0oooo0@0000010?ooo`002`3oool00`3OW4P0B9cO0?ooo`020?ooo`050?oOW01807@0
_ono07@0M02oool09P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0B0?ooo`8000006@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000006`3oool100000040
oooo000;0?ooo`0:0?noM000B9`0gooo0?ooo`2oM00004RL0=ooo`3ookl0M01d0;ooobH0oooo00<0
00000?ooo`3oool0603oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool04@3oool2000001`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000000K0?ooo`40
00000@3oool000`0oooo00@0_g@0000000000000M;oo0P3oool00`2oM00004RL0=ooo`0V0?ooo`03
0000003oool0oooo01P0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0100oooo0P00000O0?ooo`030000003oool0oooo00D0oooo0P00000B0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000001/0oooo0@0000010?ooo`00>`3o
ool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0
000001/0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`3oool0oooo0000003oool0000001/0oooo0@0000010?ooo`00>`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000000K0?ooo`400000
0@3oool003/0oooo00<000000?ooo`3oool06@3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool03@3oool2000002P0oooo00<000000?ooo`3oool01P3o
ool200000100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool06@3oool100000040oooo000k0?ooo`030000003oool0oooo01T0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06@3oool10000
0040oooo000k0?ooo`8000006P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo
0000000K0?ooo`8000000@3oool003/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000000L0?ooo`4000000@3oool003/0
oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`000000703oool100000040oooo000k0?ooo`030000003oool0oooo01T0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001`0oooo0@000001
0?ooo`00>`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01X0oooo0@0000010?ooo`00>`3oool00`00
0000oooo0?ooo`0J0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo4P00000=0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0J0?ooo`4000000@3oool003/0oooo00<00000
0?ooo`3oool06P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`@000004P3oool3000000/0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01X0oooo0@0000010?ooo`00>`3o
ool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo0`00000I0?ooo`800000
2P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001d0oooo0@0000010?ooo`00>`3o
ool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo0P00000N0?ooo`<00000
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001d0oooo0@0000010?ooo`00>`3o
ool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo0P00000S0?ooo`800000
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06`3oool100000040
oooo000k0?ooo`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`80
00009`3oool2000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
01/0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0303oool2000002/0oooo0P0000050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0K0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool06`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0;0?ooo`800000;`3oool2000000@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`00000M0?ooo`4000000@3oool001h0oooo00D0omnL04P000000000001d0;oo
o`030?ooo`030?noM0000000M;oo00<0oooo00D0omnL04P000000000000007Boo`0:0?ooo`030000
003oool0oooo01/0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool2000003<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001h0oooo0@0000010?ooo`00
7@3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?oo
o`070?oOW0180000B9cO0?ooo`3ookl0M00007Boo`090?ooo`030000003oool0oooo01/0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?oooa@000004@3oool2000000<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01`0oooo0@0000010?ooo`00
7@3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l0
0`3oool00`3o_g@004RL0=ooo`080?ooo`030000003oool0oooo01/0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`8000003`3oool3000001@0oooo1`00000<0?ooo`8000000P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool100000040oooo000L0?ooo`03
0?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo00P0oooo00<000000?ooo`3oool06`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0303oool3000001h0oooo1000000:0?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0L0?ooo`4000000@3oool001`0oooo00<0omnL
04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol0203oool00`000000oooo0?ooo`0K0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`@000009@3oool2000000T0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000N0?ooo`4000000@3oool001`0oooo00<0omnL04P0001d_ol0
0`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0_g@00000B02Lgol0
203oool3000001/0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`8000002@3oool3000002/0
oooo0P0000080?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000703oool3
00000040oooo000L0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool0203o
okl0M00000000018W=l0oooo0?noM000000007Bo2@3oool00`000000oooo0?ooo`0L0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool200000300oooo0P0000070?ooo`80
000000<0oooo0000003oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo01`0oooo0@0000010?oo
o`00703oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00<0_g@00018W02o
W4P00P0000000`00B9`0gooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`800000=03oool2000000L0oooo00<000000?oo
o`0000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01d0oooo0@0000010?ooo`00703oool00`3o
okl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0omnL04P0001d_ol03@3oool00`00
0000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`800000>03oool00`000000oooo0?ooo`050?ooo`030000003oool0000000L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000007`3oool100000040oooo000M0?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0
001d_`3oool01`3oool00`3OW4P0001809cOo`0<0?ooo`030000003oool0oooo01`0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo0P00000k0?ooo`8000001P3o
ool00`000000oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001l0oooo0@0000010?ooo`007@3o
ool01`3ookl0M00007Boo`3oool0okmd0000M02oool02@3oool00`3o_g@00000001d_`0;0?ooo`03
0000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`8000001@3oool20000
03l0oooo0P0000050?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000007`3oool1
00000040oooo000N0?ooo`050?oo_`1d000000000000M02oool02`3oool01@3ooml0W4P000000000
07@0_ooo00P0oooo00<000000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool2000004<0oooo0P0000040?ooo`030000003oool0000000H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000007`3oool100000040oooo000k0?ooo`030000003oool0oooo01d0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`800000A`3oool2000000<0
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000001l0oooo0@0000010?oo
o`00>`3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`3oool2000004/0oooo0P0000020?ooo`<000001P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000001l0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`02000004l0oooo0P0000020?ooo`8000001@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`00000P0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool07@3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0000000000D`3oool200000003
0?ooo`000000000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000803oool100000040oooo000k0?ooo`03
0000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`<00000E`3oool01000
0000oooo0000000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000200oooo0@0000010?ooo`00>`3oool0
0`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000005X0oooo1000
00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000803oool100000040oooo000k0?ooo`030000003o
ool0oooo01h0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05`0oooo
0`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000803oool100000040oooo000k0?ooo`030000
003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05l0
oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000803oool100000040oooo000k0?ooo`03
0000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000006<0oooo0P000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo00000240oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0N
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P00001U0?ooo`<000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000240oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0N0?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000000P00001W0?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000240
oooo0@0000010?ooo`00>`3oool2000001l0oooo00D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool00000
06T0oooo100000000`3oool000000?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool000000200oooo0P0000010?ooo`00>`3oool00`00
0000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo0P0000000`3oool000000?ooo`1[0?ooo`030000003oool0
000000800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo0000000Q0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool07`3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`80000000<0oooo0000003oool0K@3oool00`000000oooo0?ooo`02000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool07`3oool100000040oooo000k0?ooo`030000003oool0oooo01l0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`00001`0?ooo`030000003oool0oooo008000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0O0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool07`3oool01@000000oooo0?oo
o`3oool0000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool300000003
0?ooo`000000oooo0740oooo00<000000?ooo`3oool00`0000000`3oool000000?ooo`040?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000R0?ooo`4000000@3oool003/0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000040?ooo`000000oooo0000
07@0oooo00D000000?ooo`3oool000000?ooo`03000000D0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000280oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0P
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`<000000P3o
ool00`000000oooo0000001f0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0803o
ool100000040oooo000k0?ooo`030000003oool0oooo0200oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool2000002/0oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`030000003oool0000007P0oooo00<000000?ooo`000000
0`3oool2000000<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0200oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0P0?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool09`3oool010000000oooo0?ooo`3oool2000000@0oooo0P00001j0?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0803oool100000040oooo000k0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0000000800000103oool2000007`0oooo0P0000030?ooo`060000003oool000000000003o
ool00000:@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo0@0000010?oo
o`00>`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool09P3oool200000080oooo00@000000?ooo`3oool0oooo0P00001n0?ooo`8000000P3oool01000
0000oooo0?ooo`3oool2000002L0oooo0P00000?0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo0@000001
0?ooo`00>`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool08`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1n0?oo
o`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`4000000@3oool003/0oooo00<000000?ooo`3o
ool08@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0200000880oooo00@000000?ooo`3oool00000103oool300000280oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`4000000@3oool003/0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`8000007`3oool2000000030?ooo`000000oooo
0080oooo00<000000?ooo`3oool00P0000240?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00`00000M0?ooo`8000004P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`4000000@3oool0
03/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`<000006P3oool20000
00<0oooo00H000000?ooo`3oool0oooo0000003oool2000008H0oooo0`0000040?ooo`030000003o
ool0oooo0080oooo0`00000I0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3o
ool100000040oooo000k0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool2
000001D0oooo0`0000050?ooo`080000003oool0oooo0000003oool000000?ooo`0000270?ooo`<0
00000`3oool00`000000oooo0?ooo`050?ooo`8000005@3oool2000001@0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool08P3oool100000040oooo000k0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
5@3oool2000000l0oooo100000070?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003o
ool0Q`3oool3000000@0oooo00<000000?ooo`3oool01P3oool2000000l0oooo1000000E0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0280oooo0@0000010?ooo`00>`3oool200000280oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
5P3oool?000000/0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`290?ooo`<00000
0`3oool00`000000oooo0?ooo`080?ooo`l000006@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`800000
0@3oool003/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0_0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`290?ooo`<000000P3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0280oooo0@0000010?ooo`00>`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`2:0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0S0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0]0?ooo`060000003oool000000000003oool00000SP3oool4000000030?ooo`000000oooo
02h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool08`3oool100000040oooo000k0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0:`3oool01P000000oooo000000000000oooo00000900oooo1@00000^
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02<0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo02/0oooo0P000000103oool000000?ooo`00002@0?ooo`80000000@0oooo
0000000000000000;03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`4000000@3oool003/0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0Z0?ooo`050000003oool000000?ooo`000000TP3o
ool2000000030?ooo`000000000002/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0903oool100000040oooo000k
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`02
000009@0oooo0P000000103oool0000000000000000Y0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo0@00
00010?ooo`00>`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo0P000000
0`3oool000000000002F0?ooo`060000003oool0oooo0000003oool000009`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0T0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0S0?ooo`<000000P3oool2000009H0oooo0P0000001@3oool000000000003oool0000002D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0903oool100000040oooo000k0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool08@3oool01@000000oooo0?ooo`000000oooo00800000V03oool00`000000oooo
0?ooo`02000000030?ooo`000000oooo0280oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool100000040oooo
000k0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool07P3oool2000000<0oooo00<0
00000?ooo`000000VP3oool01`000000oooo0000003oool000000?ooo`000000803oool2000000h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0
oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0oooo
0P0000040?ooo`030000003oool0000009/0oooo0P0000001@3oool000000?ooo`000000oooo0080
00007@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0U0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo0`00002L0?ooo`<00000
0P3oool010000000oooo0?ooo`00000K0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02D0oooo0@0000010?ooo`00
>`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0>0?ooo`8000005`3oool2000000H0oooo00<000000?ooo`000000
W@3oool010000000oooo0000000000020?ooo`030000003oool0oooo00800000603oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0U0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0B0?ooo`800000203oool3000009h0oooo0`0000030?ooo`040000003oool0oooo0?ooo`80
00005@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0V0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
403oool200000100oooo0P00000:0?ooo`800000W`3oool00`000000oooo000000040?ooo`030000
003oool0oooo0080oooo0P00000A0?ooo`8000004P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool09P3oool100000040oooo000k0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0140oooo0`00000:0?ooo`<000002`3oool200000:40oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`D00000203oool4000001<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo0@0000010?ooo`00>`3oool2
000002H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01@0oooo2P00000>0?ooo`800000X@3oool010000000oooo0000000000040?ooo`030000003o
ool0oooo00L0oooo2000000G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0U0?ooo`8000000@3oool003/0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:P3oool2
00000:<0oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0V0?ooo`4000000@3o
ool003/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0:@3oool300000:<0oooo00D000000?ooo`000000oooo0000
00040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02L0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool000000:D0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02L0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0V0?ooo`040000003oool00000
00000:H0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02L0oooo0@000001
0?ooo`00>`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool000000:L0oooo0P0000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool100000040oooo000k0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo02@0oooo00@000000?ooo`3oool00000Z03oool200000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0X0?ooo`4000000@3oool003/0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool08P3oool010000000oooo0?ooo`00002Y0?ooo`8000000`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02P0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`05
0000003oool0oooo0?ooo`000000ZP3oool2000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0X0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool01@000000
oooo0?ooo`3oool000000:/0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0:03oool100000040oooo000k0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01/0oooo0P0000040?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02P0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00<0oooo0P00002]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0Y0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`030?ooo`800000[P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0:@3oool100000040oooo000N0?ooo`050?oOW0180000
00000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`050=nLB0000000000000000018W=l0
2P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo0P00002_0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`400000
0@3oool001d0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d
_ol00P3oool01`3OW4P0000007Boo`3oool0oooO09a80018W=l02@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B
0?ooo`8000001P3oool200000;00oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0:@3oool100000040oooo000M0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d
_`3oool01@3oool00`3ooml0W4P0001d_`030?ooo`030?noM000B9`0gooo00P0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03`3oool2000000L0oooo00<000000?ooo`000000/03oool2000000L0oooo0P0000040?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02X0oooo0@0000010?ooo`00703oool00`3ookl0M00004RLg`030?ooo`03
0=nLB00007@0_ooo00H0oooo00<0_g@0001d_`3oool00P3oool00`2oM00004RL0=ooo`080?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`<0
0000303oool2000000P0oooo00<000000?ooo`000000/P3oool2000000P0oooo0P0000030?ooo`03
0000003oool0oooo00L0oooo0P00000@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0:P3oool100000040oooo000L0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0
1P3oool01`3ogi`0B01d0;ooo`3oool0_g@00000001d_ol02@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool4000000<0oooo1@00000:0?oo
o`030000003oool000000;80oooo00<000000?ooo`0000002@3oool6000000<0oooo1000000A0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:P3oool100000040oooo000L0?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool01@3ookl0M4Q804P000000000B9cO
00X0oooo0`00000Z0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool50000
00d0oooo00<000000?ooo`000000]03oool2000000h0oooo1000000E0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0:03oool300000040oooo000L0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01`3oool0103ogi`0B00000000000M;l;0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo
00000;@0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0:`3oool100000040oooo000L0?ooo`030?oOW0180000M;oo
00<0oooo00<0okmd0000B02Lgol01P3oool01P3ogi`0B0000000M02oool0okmd001d_`X0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`000000]P3oool00`000000oooo0000000>0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0[0?ooo`4000000@3oool001`0oooo00<0oono
07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030;md000007@0_ooo0080oooo00<0_g@0
04RLg`3oool0203oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool08@3oool010000000oooo0?ooo`00002f0?ooo`040000003oool0oooo000000h0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02/0oooo
0@0000010?ooo`007@3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo00<0
_g@00018W03Oool00P3oool00`3OW4P007Bo0?ooo`080?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo00000;P0oooo
00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0:`3oool100000040oooo000M0?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`070?ooo`070?noM0000000M;oo0?ooo`3ookl0M00007Boo`090?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0N0?ooo`050000003o
ool0oooo0?ooo`000000^03oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0/0?ooo`4000000@3oool001h0oooo
00D0oono07@000000000001d0;ooo`090?ooo`050?noM0000000000000000018W=l02P3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool01000
0000oooo0?ooo`00002j0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02`0oooo0@0000010?ooo`00>`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool0
1@000000oooo0?ooo`3oool000000;X0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0/0?ooo`400000
0@3oool003/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01T0oooo00D000000?ooo`3oool0oooo0000002l0?ooo`050000003oool0oooo0?ooo`00
00003`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0;@3oool100000040oooo000k0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
^P3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02d0oooo0@0000010?ooo`00>`3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool01@000000oooo
0?ooo`3oool000000;h0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0^0?ooo`4000000@3oool003/0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0;P3oool100000040oooo000k0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02h0oooo
0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04@3oool2000000D0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?oo
o`030?ooo`8000003`3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo02l0oooo
0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03P3oool2000000H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00d0oooo0P00000=0?ooo`030000003oool0oooo02l0oooo0@00
00010?ooo`00>`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00/0oooo0P00000=
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00`0oooo0P00000=0?ooo`030000003oool0oooo02l0oooo0@000001
0?ooo`00>`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00`0oooo0P0000080?oo
o`<00000203oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo00D0oooo0`00000:0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0<03oool100000040oooo000k0?oo
o`800000<@3oool00`000000oooo0?ooo`0>0?ooo`P000002P3oool00`000000oooo0?ooo`340?oo
o`030000003oool0oooo00L0oooo2P0000040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0;`3oool200000040oooo000k0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0a0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0340oooo0@0000010?ooo`00>`3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0b03o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<P3o
ool100000040oooo000k0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`380?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0b0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool05`3oool01000
0000oooo0?ooo`00000e0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0000000e0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0d0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool05`3oool2000003D0oooo
0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0c`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000003@0oooo
0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0d03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0<@3oool100000040oooo000k0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0`0?ooo`4000000@3oool003/0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0=@0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02l0oooo0@0000010?oo
o`00>`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0eP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0;P3oool100000040oooo000k0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0]0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool02`3o
ool2000000`0oooo00<000000?ooo`3oool0;03oool100000040oooo000k0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0[0?ooo`4000000@3oool0
03/0oooo00<000000?ooo`3oool0>`3oool3000000H0oooo0`00003P0?ooo`<000001@3oool30000
0140oooo00<000000?ooo`3oool0:P3oool100000040oooo000k0?ooo`800000?`3oool600000>H0
oooo1@00000E0?ooo`030000003oool0oooo02P0oooo0P0000010?ooo`00>`3oool00`000000oooo
0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0:03oool100000040oooo000k0?ooo`030000003o
ool0oooo0?l0ooooA`3oool00`000000oooo0?ooo`0W0?ooo`4000000@3oool003/0oooo00<00000
0?ooo`3oool0o`3ooom80?ooo`030000003oool0oooo02H0oooo0@0000010?ooo`00>`3oool00`00
0000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool09@3oool100000040oooo000k0?ooo`03
0000003oool0oooo0?l0ooooBP3oool00`000000oooo0?ooo`0T0?ooo`4000000@3oool003/0oooo
00<000000?ooo`3oool0o`3ooom;0?ooo`030000003oool0oooo02<0oooo0@0000010?ooo`00>`3o
ool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool08P3oool100000040oooo000k
0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0Q0?ooo`4000000@3oool0
03/0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo0200oooo0@0000010?oo
o`00>`3oool00`000000oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool07`3oool100000040
oooo000k0?ooo`030000003oool0oooo0?l0ooooD03oool00`000000oooo0?ooo`0N0?ooo`400000
0@3oool003/0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`030000003oool0oooo01d0oooo0@00
00010?ooo`00>`3oool00`000000oooo0?ooo`3o0?oooe80oooo00<000000?ooo`3oool0703oool1
00000040oooo000k0?ooo`030000003oool0oooo0?l0ooooD`3oool00`000000oooo0?ooo`0K0?oo
o`4000000@3oool003/0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo01X0
oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0
6@3oool100000040oooo000k0?ooo`030000003oool0oooo0?l0ooooEP3oool00`000000oooo0?oo
o`0H0?ooo`4000000@3oool003/0oooo0P00003o0?oooeP0oooo00<000000?ooo`3oool05P3oool2
00000040oooo000k0?ooo`030000003oool0oooo0?l0ooooF03oool00`000000oooo0?ooo`0F0?oo
o`4000000@3oool003/0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo01D0
oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool0
503oool100000040oooo000k0?ooo`030000003oool0oooo0?l0ooooF`3oool00`000000oooo0?oo
o`0C0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`030000003oool0
oooo0180oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`3o0?oooed0oooo00<000000?oo
o`3oool04@3oool100000040oooo000k0?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000
oooo0?ooo`0@0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`030000
003oool0oooo00l0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`3o0?ooof00oooo00<0
00000?ooo`3oool03P3oool100000040oooo000k0?ooo`030000003oool0oooo0?l0ooooH@3oool0
0`000000oooo0?ooo`0=0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0o`3ooomR0?oo
o`030000003oool0oooo00`0oooo0@0000010?ooo`00;03oool01P2oM000000000000000000004RL
0=ooo`T0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`030000003oool0oooo00/0oooo0@000001
0?ooo`00;@3oool00`3ogi`0B00007Boo`0;0?ooo`030000003oool0oooo0?l0ooooI03oool00`00
0000oooo0?ooo`0:0?ooo`4000000@3oool002d0oooo00<0omnL04P0001d_ol02`3oool00`000000
oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool02@3oool100000040oooo000]0?ooo`030?oO
W0180000M;oo00/0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`030000003oool0oooo00P0oooo
0@0000010?ooo`00;@3oool00`3ogi`0B00007Boo`0;0?ooo`030000003oool0oooo0?l0ooooI`3o
ool00`000000oooo0?ooo`070?ooo`4000000@3oool002d0oooo00<0omnL04P0001d_ol02`3oool3
00000?l0ooooJ03oool00`000000oooo0?ooo`040?ooo`<000000@3oool002d0oooo00<0omnL04P0
001d_ol02`3oool00`000000oooo0?ooo`3o0?ooog40oooo0@0000010?ooo`00;@3oool00`3ogi`0
B00007Boo`0;0?ooo`030000003oool0oooo0?l0ooooL@3oool100000040oooo000]0?ooo`030?oO
W0180000M;oo00/0oooo00<000000?ooo`3oool0o`3oooma0?ooo`4000000@3oool002d0oooo00<0
omnL04P0001d_ol02`3oool00`000000oooo0?ooo`3o0?ooog40oooo0@0000010?ooo`00:`3oool0
1@3ooml0W4P0000000000000M;oo00/0oooo00<000000?ooo`3oool0o`3oooma0?ooo`4000000@3o
ool002d0oooo00<0okmd0000001d_ol02`3oool00`000000oooo0?ooo`3o0?ooog40oooo0@000001
0?ooo`00>`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool003/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01P3oool100000040oooo000k0?ooool00000M@0000010?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-0.191632, -0.177486, \
0.00423608, 0.00423608}}]
}, Closed]],

Cell[TextData[{
  "We can apply the same analytical techniques to a cobweb plot for a \
two-step map as we did for a one-step map.  Thus, we identify the \
intersections of the quartic curve with the line as the fixed points of a \
2-cycle and recognize that stability of such points can be classified \
according to their slopes, where again ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\[Lambda]\[RightBracketingBar] < 
        1\)]],
  " corresponds to stable and ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\[Lambda]\[RightBracketingBar] > 
        1\)]],
  " to unstable fixed points."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol2 = fixedPoints[2] // Simplify\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 
          0}, {x \[Rule] \(\(-1\) + \[Mu]\)\/\[Mu]}, {x \[Rule] \(1 + \[Mu] - \
\@\(\(-3\) - 2\ \[Mu] + \[Mu]\^2\)\)\/\(2\ \[Mu]\)}, {x \[Rule] \(1 + \[Mu] + \
\@\(\(-3\) - 2\ \[Mu] + \[Mu]\^2\)\)\/\(2\ \[Mu]\)}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "One observes that the fixed points of the first iterate remain fixed \
points of the second iterate \[LongDash] if a point is mapped into itself by \
one iteration it will surely be mapped into itself for two iterations also!  \
The point at the origin is the only stable fixed point for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] < 1\)]],
  ", representing extinction for small growth parameters.  The second fixed \
point is stable only for growth parameters in the range ",
  Cell[BoxData[
      \(TraditionalForm\`1 < \[Mu] < 3\)]],
  ".  The third and fourth solutions of ",
  Cell[BoxData[
      \(TraditionalForm\`f\_2 \[Equal] x\)]],
  " are complex for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] < 3\)]],
  ", degenerate with the second solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] = 3\)]],
  ", and real for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] > 3\)]],
  ".  Examining the slopes,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(slopes[2] = \[Lambda]\_2[\[Mu]] // Simplify\)], "Input"],

Cell[BoxData[
    \({\[Mu]\^2, \((\(-2\) + \[Mu])\)\^2, 4 + 2\ \[Mu] - \[Mu]\^2, 
      4 + 2\ \[Mu] - \[Mu]\^2}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(slopes[2] /. \[Mu] \[Rule] 3\)], "Input"],

Cell[BoxData[
    \({9, 1, 1, 1}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "we find that the three degenerate fixed points are neutrally stable, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 1\)]],
  ", at the critical point ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] = 3\)]],
  ".  For larger \[Mu], the previously stable parent becomes unstable while \
two stable offspring emerge and diverge from it as \[Mu] increases.  Thus, \
the previously stable fixed passes through a ",
  StyleBox["pitchfork bifurcation",
    FontSlant->"Italic"],
  " as it gives birth to a stable 2-cycle."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{Plot[Evaluate[x /. sol1], {\[Mu], 1, 4}, 
            DisplayFunction \[Rule] Identity], 
          Plot[Evaluate[x /. sol2], {\[Mu], 3, 4}, 
            DisplayFunction \[Rule] Identity]}, 
        PlotRange \[Rule] {{2.5, 4.0}, {0.2, 1.0}}, 
        PlotLabel \[Rule] "\<First Pitchfork Bifurcation\>", 
        Frame \[Rule] True, \ 
        FrameLabel \[Rule] {"\<\[Mu]\>", "\<fixed point\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.66667 0.666667 -0.154508 0.772542 [
[.06667 -0.0125 -9.5 -15.6875 ]
[.06667 -0.0125 9.5 0 ]
[.2 -0.0125 -9.5 -15.6875 ]
[.2 -0.0125 9.5 0 ]
[.33333 -0.0125 -5 -15.6875 ]
[.33333 -0.0125 5 0 ]
[.46667 -0.0125 -9.5 -15.6875 ]
[.46667 -0.0125 9.5 0 ]
[.6 -0.0125 -9.5 -15.6875 ]
[.6 -0.0125 9.5 0 ]
[.73333 -0.0125 -9.5 -15.6875 ]
[.73333 -0.0125 9.5 0 ]
[.86667 -0.0125 -9.5 -15.6875 ]
[.86667 -0.0125 9.5 0 ]
[1 -0.0125 -5 -15.6875 ]
[1 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.5 -31.375 ]
[.5 -0.0125 5.5 -15.6875 ]
[-0.0125 .07725 -19 -7.84375 ]
[-0.0125 .07725 0 7.84375 ]
[-0.0125 .15451 -19 -7.84375 ]
[-0.0125 .15451 0 7.84375 ]
[-0.0125 .23176 -19 -7.84375 ]
[-0.0125 .23176 0 7.84375 ]
[-0.0125 .30902 -19 -7.84375 ]
[-0.0125 .30902 0 7.84375 ]
[-0.0125 .38627 -19 -7.84375 ]
[-0.0125 .38627 0 7.84375 ]
[-0.0125 .46353 -19 -7.84375 ]
[-0.0125 .46353 0 7.84375 ]
[-0.0125 .54078 -19 -7.84375 ]
[-0.0125 .54078 0 7.84375 ]
[-0.0125 .61803 -10 -7.84375 ]
[-0.0125 .61803 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -28.125 ]
[-0.01875 .30902 -19 28.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -65.25 0 ]
[.5 .63053 65.25 15.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06667 0 m
.06667 .00625 L
s
gsave
.06667 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
1.000 setlinewidth
grestore
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.46667 0 m
.46667 .00625 L
s
gsave
.46667 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
1.000 setlinewidth
grestore
.73333 0 m
.73333 .00625 L
s
gsave
.73333 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
1.000 setlinewidth
grestore
.86667 0 m
.86667 .00625 L
s
gsave
.86667 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.5 0 m
.5 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7 0 m
.7 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.03333 0 m
.03333 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.563 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
70.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
gsave
-0.0125 .07725 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .15451 m
.00625 .15451 L
s
gsave
-0.0125 .15451 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .23176 m
.00625 .23176 L
s
gsave
-0.0125 .23176 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .38627 m
.00625 .38627 L
s
gsave
-0.0125 .38627 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
0 .46353 m
.00625 .46353 L
s
gsave
-0.0125 .46353 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .54078 m
.00625 .54078 L
s
gsave
-0.0125 .54078 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -115.969 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
89.125 11.8438 translate
90 rotate
-89.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(fixed) show
90.625 15.813 moveto
(point) show
115.250 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.06667 .61178 m
.06667 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.46667 .61178 m
.46667 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.73333 .61178 m
.73333 .61803 L
s
.86667 .61178 m
.86667 .61803 L
s
.125 Mabswid
.1 .61428 m
.1 .61803 L
s
.13333 .61428 m
.13333 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.23333 .61428 m
.23333 .61803 L
s
.26667 .61428 m
.26667 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.43333 .61428 m
.43333 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.53333 .61428 m
.53333 .61803 L
s
.56667 .61428 m
.56667 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.76667 .61428 m
.76667 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.93333 .61428 m
.93333 .61803 L
s
.96667 .61428 m
.96667 .61803 L
s
.03333 .61428 m
.03333 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -126.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(First) show
87.813 15.813 moveto
(Pitchfork) show
135.250 15.813 moveto
(Bifurcation) show
189.500 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30901 m
.08366 .32379 L
.16508 .33687 L
.25165 .34956 L
.33504 .36074 L
.41525 .37065 L
.5006 .38039 L
.58278 .38908 L
.6701 .39763 L
.75424 .40529 L
.83519 .41218 L
.9213 .41903 L
1 .4249 L
s
.33333 .36052 m
.36038 .36396 L
.38987 .3676 L
.41757 .37093 L
.44421 .37405 L
.47257 .37728 L
.49986 .38031 L
.52888 .38345 L
.55683 .3864 L
.58372 .38917 L
.61232 .39204 L
.63987 .39474 L
.66635 .39728 L
.69455 .39991 L
.72169 .40239 L
.75055 .40497 L
.77835 .40739 L
.80508 .40967 L
.83353 .41204 L
.86093 .41427 L
.89003 .41659 L
.91808 .41878 L
.94506 .42084 L
.97377 .42298 L
1 .4249 L
s
.33333 .36047 m
.33416 .35142 L
.33491 .34792 L
.33659 .34234 L
.33962 .33517 L
.3465 .32364 L
.35363 .31457 L
.36038 .30737 L
.38987 .28328 L
.41676 .26656 L
.44537 .25165 L
.47291 .23913 L
.4994 .22834 L
.5276 .21788 L
.55474 .20864 L
.5836 .19954 L
.61139 .19137 L
.63813 .184 L
.66658 .1766 L
.69397 .16988 L
.72308 .1631 L
.75113 .15691 L
.77811 .15123 L
.80681 .14545 L
.83445 .14014 L
.86103 .13523 L
.88933 .13022 L
.91657 .12558 L
.94552 .12084 L
.97341 .11644 L
1 .1124 L
s
.33333 .36057 m
.33416 .36951 L
.33491 .37292 L
.33577 .37592 L
.33659 .37828 L
.33962 .38507 L
.34292 .39069 L
.3465 .39572 L
.36038 .41024 L
.37571 .42193 L
.38987 .43068 L
.41742 .44446 L
.4439 .45519 L
.4721 .46485 L
.49924 .47292 L
.5281 .48048 L
.5559 .48699 L
.58263 .49267 L
.61108 .49818 L
.63848 .50305 L
.66758 .50781 L
.69563 .51206 L
.72261 .51587 L
.75132 .51966 L
.77896 .52306 L
.80554 .52615 L
.83384 .52924 L
.86107 .53205 L
.89002 .53487 L
.91792 .53744 L
.94475 .53978 L
.97329 .54215 L
1 .54426 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00jP3oool0103ooml0W4P00018W03Oooo20?ooo`00j`3oool00`3o_g@0
001d0;ooo`320?ooo`00j`3oool00`3ookl0M00007Boo`320?ooo`00k03oool00`2oM00007Bo0?oo
o`310?ooo`00k03oool02P3OW4P004Qd07A800000000001809cOo`2oM00000000000B02Lgonj0?oo
o`00k03oool02P3ogi`0B000001d_`3oool0oooO09a800000000B9cO0?oog`2o_mnj0?ooo`00k03o
ool00`3ookl0M00004RLg`020?ooo`030?oog`2LB00007Bo0;`0oooo003]0?ooo`030;md0000M;l0
oooo0080oooo00<0_g@00000M02oool0^`3oool00>d0oooo00<0okmd0018W03Oool00P3oool00`3o
_g@0001809cOo`2k0?ooo`00k@3oool00`3ogi`0B01809cOo`020?ooo`030?oo_`1d0000B9cO0;/0
oooo003]0?ooo`030?oog`2LB000M;oo0080oooo00<0oooO09a80000M;l0^`3oool00>h0oooo00<0
_g@0001d_`3oool00P3oool00`3OW4P0001d0;ooo`2j0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00H@3oool00`2o
M0000000000000040000000604RLg`3oool0oooo0?noM0000000M;oo0`3oool01@3ogi`0B0000000
00000000M;oo01@0oooo00<0_g@0000000000000100000001P18W=l0oooo0?ooo`3o_g@0000007Bo
o`<0oooo00D0gia8000000000000000004RLg`0J0?ooo`030?oo_`1d000000000080000000<0M;oo
0?ooo`3oool06P3oool00`3ookl0M000000000020000000307Boo`3oool0oooo0080oooo00D0okmd
0000001d_ol0oooo0;md00060000000304RLg`3oool0oooo0100oooo00<0oono07@0000000000P00
00000`1d_ol0oooo0?ooo`020?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo
4`3oool00`3ookl0M000000000020000000307Boo`3oool0oooo0080oooo00<0okmd0000001d_ol0
0`3oool01@3ogi`0B000000000000000M;oo01<0oooo00<0oono07@0000000000P0000000`1d_ol0
oooo0?ooo`020?ooo`030?noM0000000M;oo00<0oooo00D0gia8000000000000000004RLg`0N0?oo
o`040?oog`2LB00004RL0=ooobD0oooo001R0?ooo`030=nLB0000000000000<0000000H004RL0=oo
o`3oool0okmd0000001d_ol20?ooo`070?oOW0180000B9cO0?ooo`3ookl0M00007Boo`0D0?ooo`03
0=nLB0000000000000<0000000H004RL0=ooo`3oool0okmd0000001d_ol20?ooo`070=nLB0000000
M;oo0?ooo`3ooml0W4P004RLg`0I0?ooo`030?oOW0180000B9cO0080oooo00<0_g@004RLg`3oool0
6P3oool00`3ogi`0B00004RLg`020?ooo`030;md0018W=l0oooo0080oooo00<0okmd0000001d_ol0
0P3oool00`3OW4P0000000000003000000030018W03Oool0oooo0100oooo00<0omnL04P00018W=l0
0P3oool00`2oM000B9cO0?ooo`020?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0
gooo4`3oool00`3ogi`0B00004RLg`020?ooo`030;md0018W=l0oooo0080oooo00<0okmd0000001d
_ol00P3oool01`3ogi`0B00004RLg`3oool0oono07@0001d_ol04P3oool00`3ogi`0B00004RLg`02
0?ooo`030;md0018W=l0oooo0080oooo00<0okmd0000001d_ol00P3oool01`3OW4P0000007Boo`3o
ool0oooO09a80018W=l07@3oool0103ooml0W4P00018W03OoolU0?ooo`00H`3oool00`3OW4P0B9cO
0?ooo`020?ooo`030=nLM02Lgol0oooo00@0oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL
0=ooo`0D0?ooo`030=nLB018W=l0oooo0080oooo00<0giad09cOo`3oool0103oool00`3ooml0W4P0
001d_`030?ooo`030?noM000B9`0gooo01d0oooo00<0oono07@0B02Lgol07`3oool00`3ookl0M018
09cOo`080?ooo`030=nLB018W=l0oooo0080oooo00<0giad09cOo`3oool05@3oool00`3ookl0M018
09cOo`0:0?ooo`040?oog`2LB00004RL0=oooaP0oooo00<0oono07@0B02Lgol01P3oool00`3ooml0
W4P0001d_`030?ooo`030?noM000B9`0gooo01H0oooo00<0oono07@0B02Lgol01P3oool00`3ooml0
W4P0001d_`030?ooo`030?noM000B9`0gooo01`0oooo00@0oooO09a80000B9`0gooo9@3oool006@0
oooo00<0gia807Boo`3oool0203oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo01D0
oooo00<0gia807Boo`3oool02@3oool00`2oM00007Bo0?ooo`020?ooo`030;md0000B9`0gooo01d0
oooo00<0oono07@0001d_ol07`3oool00`3ookl0M00007Boo`090?ooo`030=nLB01d_ol0oooo01T0
oooo00<0oono07@0001d_ol01P3oool00`2oM0000000000000050000000307Boo`3oool0oooo01D0
oooo00<0oono07@0001d_ol01P3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo01H0
oooo00<0oono07@0001d_ol01`3oool00`2oM00007Bo0?ooo`020?ooo`030;md0000B9`0gooo01P0
oooo00<0_g@00000000000001@0000000`1d_ol0oooo0?ooo`0R0?ooo`00I@3oool00`2oM4P0W=oo
0?ooo`070?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol05P3oool00`2oM4P0W=oo
0?ooo`080?ooo`070?oOW01807@0_ooo0?ooo`2oM000000007Boo`0N0?ooo`030?noM0000000M;oo
01l0oooo00<0okmd0000001d_ol02P3oool00`2oM4P0W=oo0?ooo`0H0?ooo`030?noM0000000M;oo
00H0oooo00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL0=oooaP0oooo00<0okmd0000001d_ol0
1P3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo01H0oooo00<0okmd0000001d_ol0
1`3oool01`3ogi`0B01d0;ooo`3oool0_g@00000001d_ol06@3oool0203ogi`0M9cO0?ooo`3oool0
oooO09a80000B9`0gooo9@3oool006D0oooo00<0oooO09a8M02oool01`3oool00`3ogi`0B00007Bo
o`030?ooo`030;md000004P0W=oo01H0oooo00<0oooO09a8M02oool02@3oool01@3ookl0M4Q804P0
00000000B9cO01h0oooo00@0omnL04P0000004P0W=oo7P3oool0103ogi`0B0000000B02Lgol:0?oo
o`030?oog`2LB7@0_ooo01L0oooo00@0omnL04P0000004P0W=oo1`3oool01`3OW4P0M;oo0?ooo`3o
oml0W4P00018W03Oool05`3oool0103ogi`0B0000000B02Lgol60?ooo`030?oOW0180000M;oo00<0
oooo00<0_g@00000B02Lgol05@3oool0103ogi`0B0000000B02Lgol80?ooo`050?oo_`1dB4P0B000
00000018W=l06`3oool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03Oool09@3oool006H0oooo00<0
okmd001d_`3oool01P3oool0203ookl0M00000000018W=l0oooo0?noM000000007Bo603oool00`3o
_g@007Bo0?ooo`080?ooo`040?oOW01800000000001d_ad0oooo00D0okmd000000000000001809cO
o`0M0?ooo`050?noM000000000000000B02Lgol0303oool00`3o_g@007Bo0?ooo`0D0?ooo`050?no
M000000000000000B02Lgol0203oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool05@3oool0
1@3o_g@000000000000004P0W=oo00L0oooo00P0oono07@000000000B9cO0?ooo`3o_g@00000001d
_a@0oooo00D0okmd000000000000001809cOo`090?ooo`040?oOW01800000000001d_a`0oooo00L0
oooO09a8M02oool0oooO09a80000B9`0gooo02D0oooo001V0?ooo`030?oo_`1d04P0W=oo00L0oooo
00<0_g@00018W02oW4P00P0000000`00B9`0gooo0?ooo`0G0?ooo`030?oo_`1d04P0W=oo00L0oooo
00H0omnL04P0000007@0_ooo0?noM000M;lN0?ooo`030;md0000M;l0oooo01l0oooo00<0_g@0001d
_`3oool0303oool00`3ookl0M01809cOo`0F0?ooo`030;md0000M;l0oooo00T0oooo00H0omnL04Qd
_`3ooml0W4P00018W03OoolG0?ooo`030;md0000M;l0oooo00P0oooo00<0_g@00018W02oW4P00P00
00000`00B9`0gooo0?ooo`0E0?ooo`030;md0000M;l0oooo00P0oooo00H0omnL04P0000007@0_ooo
0?noM000M;lL0?ooo`060?oOW018M;l0oooO09a80000B9`0gooo9@3oool006H0oooo00<0oono07@0
0018W=l01`3oool00`3ogi`0B00007Boo`0L0?ooo`030?oo_`1d0000B9cO00L0oooo00<0_g@00000
M02oool00P3oool00`2oM000B9cO0?ooo`0M0?ooo`030;md0018W=l0oooo01l0oooo00<0_g@004RL
g`3oool02`3oool00`3ookl0M00004RLg`0G0?ooo`030;md0018W=l0oooo00T0oooo00D0gia807Bo
g`2LB00004RL0=ooo`0H0?ooo`030;md0018W=l0oooo00L0oooo00<0omnL04P0001d_ol06`3oool0
0`2oM000B9cO0?ooo`070?ooo`030;md000007@0_ooo0080oooo00<0_g@004RLg`3oool06`3oool0
1@3OW4P0M;oO09a80000B9`0gooo02D0oooo001Q0?ooo`030?noW02Lgol0oooo0080oooo00<0omnL
04P00018W=l0203oool00`3OW4P0001809cOo`0F0?ooo`030?noW02Lgol0oooo0080oooo00<0omnL
04P00018W=l01`3oool00`2oM00004RL0=ooo`020?ooo`030=nLB000M;l0oooo01P0oooo00<0oooO
09bL_`3oool00P3oool00`3OW4P0001d0;ooo`0J0?ooo`030?oog`2LW;l0oooo0080oooo00<0gia8
0000M02oool01P3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW0180000B9cO0180oooo00<0oooO
09bL_`3oool00P3oool00`3OW4P0001d0;ooo`090?ooo`050?oog`2LB4P0B4P00018W03Oool04`3o
ool00`3ooml0W9bo0?ooo`020?ooo`030=nLB00007@0_ooo00P0oooo00<0gia80000B02Lgol05@3o
ool00`3ooml0W9bo0?ooo`020?ooo`030=nLB00007@0_ooo00L0oooo00<0_g@00018W03Oool00P3o
ool00`3OW4P007Bo0?ooo`0K0?ooo`050?oog`2LB4P0B4P00018W03Oool09@3oool00640oooo00P0
oooO09a8B02Lgol0oooo0?oo_`1d0000001d0;ooo`T0oooo00<0okmd00000000M;l05@3oool0203o
oml0W4Q809cOo`3oool0oono07@0000007@0_ooo1`3oool01`3o_g@0000007Boo`3oool0oono07@0
001d_ol06P3oool01P3o_g@0B9cO0?ooo`3ookl0M000001d_a`0oooo00H0okmd04RLg`3oool0oono
07@00000M;l70?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02ooolC0?ooo`060?noM018
W=l0oooo0?oo_`1d000007Bo2`3oool0103ogi`0B0000018W03OoolD0?ooo`060?noM018W=l0oooo
0?oo_`1d000007Bo2P3oool00`3o_g@00000001d_`0E0?ooo`060?noM018W=l0oooo0?oo_`1d0000
07Bo203oool01`3o_g@0000007Boo`3oool0oono07@0001d_ol07@3oool0103ogi`0B0000018W03O
oolU0?ooo`00HP3oool01P3ooml0W4P0000000000000001d0;ooo`/0oooo00D0oooO09a800000000
001d0;ooo`0C0?ooo`060?oog`2LB00000000000000007@0_ooo2@3oool01@3o_g@0000000000000
0000B9cO01`0oooo00D0gia8000000000000001d0;ooo`0M0?ooo`050=nLB000000000000000M02o
ool0203oool01P3ooml0W4P0000000000000001d0;oooaD0oooo00D0gia8000000000000001d0;oo
o`0<0?ooo`030=nLB000B9`0gooo01D0oooo00D0gia8000000000000001d0;ooo`0;0?ooo`050?oo
g`2LB00000000000M02oool04`3oool01@3OW4P000000000000007@0_ooo00T0oooo00D0okmd0000
00000000000004RLg`0O0?ooo`030=nLB000B9`0gooo02D0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo001H0?ooool00000<P00000W0?ooo`00F03oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0U
0?ooo`00F03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`3o0?ooobh0
oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000
003oool0oooo02D0oooo001H0?ooo`800000o`3oool^0?ooo`8000009`3oool005P0oooo00<00000
0?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo
0?l0oooo;P3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`3o0?ooobh0
oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000
003oool0oooo02D0oooo001H0?ooo`800000o`3oool^0?ooo`8000009`3oool005P0oooo00<00000
0?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo
0?l0oooo;P3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`3o0?ooobh0
oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000
003oool0oooo02D0oooo001H0?ooo`800000o`3oool^0?ooo`8000009`3oool005P0oooo00<00000
0?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo
0?l0oooo;P3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`3o0?ooobh0
oooo00<000000?ooo`3oool09@3oool003d0oooo00D0omnL04P000000000001d0;ooo`030?ooo`06
0?noM0000000M;oo0?ooo`3ookl0M0000`0000000`1d_ol0oooo0?ooo`070?ooo`800000o`3oool^
0?ooo`8000009`3oool003`0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00L0
okmd0000001d_ol0oooo0?oOW0180000B9cO0080oooo00<0_g@004RLg`3oool01`3oool00`000000
oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool09@3oool003`0oooo00<0_g@00018W03Oool0
0P3oool00`2oM00007Bo0?ooo`0:0?ooo`030?oo_`1d04P0W=oo00L0oooo00<000000?ooo`3oool0
o`3oool^0?ooo`030000003oool0oooo02D0oooo000k0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool02P3oool00`3ookl0M00007Boo`070?ooo`030000003oool0oooo0?l0oooo;P3o
ool00`000000oooo0?ooo`0U0?ooo`00>`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00X0oooo00<0okmd0000001d_ol01`3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<00000
0?ooo`3oool09@3oool003/0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`090?oo
o`040?oOW0180000001809cOo`L0oooo0`00003o0?ooob`0oooo0`00000W0?ooo`00>`3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00D0okmd000000000000001809cOo`08
0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0U0?ooo`00>`3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0_g@0001d_`3oool0203oool00`00
0000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool09@3oool003/0oooo00<0oono07@00018
W=l00`3oool00`3OW4P0001d0;ooo`0:0?ooo`030;md0018W=l0oooo00L0oooo00<000000?ooo`3o
ool0o`3oool^0?ooo`030000003oool0oooo02D0oooo000l0?ooo`030=nLB000B9`0gooo0080oooo
00<0_g@0001d_`3oool01@3oool00`3ooml0W9bo0?ooo`020?ooo`030=nLB00007@0_ooo00L0oooo
00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo02D0oooo000l0?ooo`070?oo_`1d
0000M;oo0?ooo`3o_g@0001d0;ooo`070?ooo`060?noM018W=l0oooo0?oo_`1d000007Bo203oool2
00000?l0oooo;P3oool2000002L0oooo000m0?ooo`050?oo_`1d000000000000M02oool02@3oool0
1@3OW4P000000000000007@0_ooo00P0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003o
ool0oooo02D0oooo001H0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0U
0?ooo`00F03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool09@3oool005P0
oooo0P00003o0?ooobh0oooo0P00000W0?ooo`00F03oool00`000000oooo0?ooo`3o0?ooobh0oooo
00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0o`3oool[0?ooo`@000009`3o
ool005P0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`T000000`3oool00`000000oooo0?ooo`0U
0?ooo`00F03oool00`000000oooo0?ooo`3o0?oooa`0oooo1P00000<0?ooo`030000003oool0oooo
02D0oooo001H0?ooo`800000o`3ooolI0?ooo`@000004@3oool2000002L0oooo001H0?ooo`030000
003oool0oooo0?l0oooo4@3oool7000001H0oooo00<000000?ooo`3oool09@3oool005P0oooo00<0
00000?ooo`3oool0o`3oool;0?ooo`H000007@3oool00`000000oooo0?ooo`0U0?ooo`00F03oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo1000000S0?ooo`030000003oool0oooo02D0oooo000m0?oo
o`050?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`050?ooo`040?oog`2LB000
04RL0=ooo`L0oooo00<000000?ooo`3oool0o`3oool10?ooo`H000009`3oool00`000000oooo0?oo
o`0U0?ooo`00?03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@00000
07Boo`050?ooo`040?oog`2LB00004RL0=ooo`L0oooo0P00003j0?ooo`L00000;03oool2000002L0
oooo000l0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool02@3oool0103ooml0W4P0
0018W03Oool70?ooo`030000003oool0oooo0?D0oooo1000000d0?ooo`030000003oool0oooo02D0
oooo000k0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`2oM0000000
000000050000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool0k`3oool6000003P0oooo
00<000000?ooo`3oool09@3oool003/0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cO
o`050?ooo`080?oOW01dW=l0oooo0?ooo`3ooml0W4P00018W03Oool70?ooo`030000003oool0oooo
0>P0oooo1`00000n0?ooo`030000003oool0oooo02D0oooo000k0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01P3oool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03Oool01`3oool3
00000>@0oooo100000130?ooo`<000009`3oool003/0oooo00<0omnL04P0001d_ol00`3oool00`3o
_g@0001809cOo`060?ooo`070?oog`2LB7@0_ooo0?oog`2LB00004RL0=ooo`070?ooo`030000003o
ool0oooo0>00oooo100000190?ooo`030000003oool0oooo02D0oooo000k0?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol01`3oool01P3ogi`0B7Bo0?oog`2LB00004RL0=ooo`L0oooo
00<000000?ooo`3oool0g03oool4000004d0oooo00<000000?ooo`3oool09@3oool003/0oooo00<0
oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`080?ooo`050=nLB01d_ml0W4P00018W03Oool0
1`3oool00`000000oooo0?ooo`3G0?ooo`D00000D@3oool00`000000oooo0?ooo`0U0?ooo`00?03o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00P0oooo00D0oooO09a8B018B00004RL
0=ooo`070?ooo`030000003oool0oooo0=<0oooo1000001F0?ooo`030000003oool0oooo02D0oooo
000l0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0:0?ooo`040?oOW018000004RL0=oo
o`L0oooo0P00003@0?ooo`@00000F@3oool2000002L0oooo000m0?ooo`050?oo_`1d000000000000
M02oool0303oool00`3OW4P004RL0=ooo`070?ooo`030000003oool0oooo0</0oooo1000001N0?oo
o`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo0<H0oooo1@00001R0?ooo`03
0000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo0<80oooo1000001W0?ooo`030000
003oool0oooo02D0oooo000X0?ooo`030;mdM02oool0oooo00@0oooo00<0gibL0;ooo`3oool09P3o
ool00`000000oooo0?ooo`2n0?ooo`@00000J`3oool00`000000oooo0?ooo`0U0?ooo`00:03oool0
0`2oM7@0_ooo0?ooo`040?ooo`030;mdM02oool0oooo02H0oooo0P00002m0?ooo`800000KP3oool2
000002L0oooo000T0?ooo`030?oo_`1d0000000000P0000000<0001d0;ooo`3oool09P3oool00`00
0000oooo0?ooo`2i0?ooo`<00000L@3oool00`000000oooo0?ooo`0U0?ooo`008`3oool00`3ogi`0
B00000000009000000030000M02oool0oooo02H0oooo00<000000?ooo`3oool0]P3oool3000007@0
oooo00<000000?ooo`3oool09@3oool00280oooo00<0oooO09adW03Oool00`3oool00`2oM7@0_ooo
0?ooo`040?ooo`030;mdM02oool0oooo02H0oooo00<000000?ooo`3oool0/P3oool4000007L0oooo
00<000000?ooo`3oool09@3oool00280oooo00<0oono07Ad_`3oool00`3oool00`2oM7@0_ooo0?oo
o`040?ooo`030=nLW02oool0oooo02H0oooo0P00002_0?ooo`@00000NP3oool2000002L0oooo000R
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oono07Ad_`3oool0103oool00`3OW9`0_ooo0?oo
o`0V0?ooo`030000003oool0oooo0:/0oooo0`00001o0?ooo`030000003oool0oooo02D0oooo000R
0?ooo`040?oog`2L=P00000004RLg`80oooo00<0okmd000000000000100000000`0007@0_ooo0?oo
o`0V0?ooo`030000003oool0oooo0:P0oooo0`0000220?ooo`030000003oool0oooo02D0oooo000R
0?ooo`030?oog`2LB00007Bo00<0oooo00<0_g@0000000000000100000000`0007@0_ooo0?ooo`0V
0?ooo`030000003oool0oooo0:D0oooo0`0000250?ooo`030000003oool0oooo02D0oooo000_0?oo
o`030=nLW02oool0oooo02H0oooo00<000000?ooo`3oool0XP3oool3000008P0oooo00<000000?oo
o`3oool09@3oool003d0oooo00D0omnL04P000000000001d0;ooo`030?ooo`060?noM0000000M;oo
0?ooo`3ooml0W4P00`0000000`1d_ol0oooo0?ooo`070?ooo`800000X03oool3000008X0oooo0P00
000W0?ooo`00:03oool00`2oM7@0_ooo0?ooo`040?ooo`030;mdM02oool0oooo00X0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00L0okmd0000001d_ol0oooo0?oog`2LB7@0_ooo
0080oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`2L0?ooo`<00000SP3oool00`00
0000oooo0?ooo`0U0?ooo`00:03oool00`2oM000B9cO0?ooo`030?ooo`030=nLB00007@0_ooo00/0
oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`0:0?ooo`030?oog`2LB7@0_ooo00L0
oooo00<000000?ooo`3oool0VP3oool200000940oooo00<000000?ooo`3oool09@3oool002P0oooo
00T0_g@00000000007@0_ooo0?oog`2LB000B9cO0=nLW02oool02P3oool00`3ookl0M00004RLg`03
0?ooo`030=nLB00007@0_ooo00/0oooo00<0_g@007Boo`3oool01P3oool00`000000oooo0?ooo`2G
0?ooo`<00000T`3oool00`000000oooo0?ooo`0U0?ooo`00:03oool01P2oW9`0gmnL04P000000000
001809cOo`d0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?oog`2L
B000B9cO00L0oooo00<000000?ooo`3oool0U03oool3000009H0oooo00<000000?ooo`3oool09@3o
ool002P0oooo00<0_gAd0;oOW01800000P000000100004P0W=oo0=nLW02oool:0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3OW4P0000007Boo`070?ooo`<00000TP3o
ool2000009L0oooo0`00000W0?ooo`00:03oool00`2oM00004RL0=ooo`020?ooo`040;md00000000
001d0;ooo`X0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`070=oOg`3o
ool0oono07@000000000001d0;ooo`070?ooo`030000003oool0oooo08l0oooo0`00002K0?ooo`03
0000003oool0oooo02D0oooo000X0?ooo`030;mdB02Lgol0oooo00<0oooo00<0okmd0000M02oool0
2P3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0gia8000000000000
00000000B02Lgol80?ooo`030000003oool0oooo08d0oooo0P00002N0?ooo`030000003oool0oooo
02D0oooo000X0?ooo`030;nLW03Oool0oooo00@0oooo00<0gibL0;ooo`3oool02@3oool00`3ookl0
M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00@0oono07@000000000B9cO2P3oool00`00
0000oooo0?ooo`2;0?ooo`800000X03oool00`000000oooo0?ooo`0U0?ooo`00?03oool00`3OW4P0
04RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0_g@007Boo`3oool02P3oool00`000000
oooo0?ooo`290?ooo`800000XP3oool00`000000oooo0?ooo`0U0?ooo`00?03oool01`3ookl0M000
07Boo`3oool0okmd0000M02oool0203oool01P3ogi`0B000000000000000001809cOo`L0oooo0P00
00280?ooo`800000X`3oool2000002L0oooo000Y0?ooo`030?oo_`1d000000000080000000<0B9cO
0?ooo`3oool0303oool01@3ookl0M0000000000007@0_ooo00X0oooo00D0_g@00000000000000000
04RLg`070?ooo`030000003oool0oooo08@0oooo0`00002V0?ooo`030000003oool0oooo02D0oooo
000X0?ooo`030?oOW0180000000000@0000000<0B9cO0?ooo`3oool09P3oool00`000000oooo0?oo
o`220?ooo`800000Z@3oool00`000000oooo0?ooo`0U0?ooo`00:03oool02@3OW7@0W=oo0?noM01d
_ol0oooo0?noM0000000001d0;ooo`0W0?ooo`030000003oool0oooo0800oooo0P00002[0?ooo`03
0000003oool0oooo02D0oooo000X0?ooo`040;mdB02Lgol0okmd07Boo`80oooo00<0gia80000M02o
ool09`3oool2000007l0oooo0P00002/0?ooo`8000009`3oool002P0oooo00@0okmd000000000000
M;oo0P3oool00`2oM00007Bo0?ooo`0W0?ooo`030000003oool0oooo07`0oooo0P00002_0?ooo`03
0000003oool0oooo02D0oooo000Y0?ooo`060=nLB0000000M;oo0?noM000000007Bo:@3oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool09@3oool005P0
oooo00<000000?ooo`3oool0N@3oool200000;80oooo00<000000?ooo`3oool09@3oool005P0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo02D0oooo
000Z0?ooo`050;md00000000000000000018W=l0:@3oool2000007P0oooo00<000000?ooo`3oool0
/P3oool2000002L0oooo000X0?ooo`030?oo_`1d0000000000@0000000<0B9cO0?ooo`3oool09P3o
ool00`000000oooo0?ooo`1e0?ooo`800000]P3oool00`000000oooo0?ooo`0U0?ooo`00:03oool0
0`3OW4P007Bo0?ooo`020?ooo`040?oo_`1d0000001d0;ooobL0oooo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo02D0oooo000X0?ooo`030;mdM02oool0
oooo00<0oooo00<0oono07@0M02oool09`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo0;L0oooo00<000000?ooo`3oool09@3oool002<0oooo00<0oknL09cOo`3oool00P3oool00`3o
gi`0W;oo0?ooo`030?ooo`030?noW02Lgol0oooo00`0oooo00D0omnL04P000000000001d0;ooo`03
0?ooo`030?noM0000000M;oo00<0oooo00D0omnL04P000000000000007Boo`080?ooo`030000003o
ool0oooo0740oooo0P00002j0?ooo`030000003oool0oooo02D0oooo000S0?ooo`030;md00000000
000000T0000000<0001d0;ooo`3oool02P3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool0
0P3oool00`3o_g@0000007Boo`020?ooo`070?oOW0180000B9cO0?ooo`3ookl0M00007Boo`070?oo
o`800000L@3oool00`000000oooo0?ooo`2i0?ooo`8000009`3oool00280oooo00<0oono07@00000
00002P0000000`00M;l0oooo0?ooo`0:0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3o
ool01@3oool00`3ooml0W4P0001d_`030?ooo`030?noM000B9`0gooo00H0oooo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo02D0oooo000^0?ooo`030?oO
W02L_ol0oooo00X0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030?oO
W0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool00`000000oooo0?ooo`1]0?ooo`800000
_P3oool00`000000oooo0?ooo`0U0?ooo`00>`3oool00`3ogi`0B00007Boo`030?ooo`030?noM000
04P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0U0?ooo`00>`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool0
0`2oM000001809cOo`060?ooo`<00000J`3oool00`000000oooo0?ooo`2m0?ooo`<000009`3oool0
03/0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`080?oo_`1d00000000
04RLg`3oool0okmd00000000M;l70?ooo`030000003oool0oooo00D00000I@3oool00`000000oooo
0?ooo`300?ooo`030000003oool0oooo02D0oooo000k0?ooo`030?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol01P3oool00`2oM00004RL0;nLB002000000030018W03Oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool5000005l0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?oo
o`0U0?ooo`00>`3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0omnL
04P0001d_ol02`3oool00`000000oooo0?ooo`0:0?ooo`H00000F03oool00`000000oooo0?ooo`32
0?ooo`030000003oool0oooo02D0oooo000X0?ooo`030?oog`2LW;l0oooo00P0oooo00<0_ibL0=oo
o`3oool01P3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia80000
B02Lgol02P3oool00`000000oooo0?ooo`0@0?ooo`D00000DP3oool00`000000oooo0?ooo`330?oo
o`030000003oool0oooo02D0oooo000X0?ooo`030?oOW0180000000000P0000000<004RL0=ooo`3o
ool01P3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool02@3oool00`3o_g@00000001d_`09
0?ooo`8000005P3oool5000004`0oooo00<000000?ooo`3oool0``3oool2000002L0oooo000X0?oo
o`030=nLB0000000000000P0000000<004RL0=ooo`3oool01`3oool01@3ookl0M0000000000007@0
_ooo00/0oooo00D0oooO09a800000000001d0;ooo`060?ooo`030000003oool0oooo01X0oooo1P00
00150?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool09@3oool002T0oooo00<0_gAd
0;ooo`3oool00P3oool00`3ooml0W9bo0?ooo`020?ooo`030;nLW03Oool0oooo0280oooo00<00000
0?ooo`3oool0803oool6000003l0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0U
0?ooo`00:03oool00`3OW4P007Bo0?ooo`040?ooo`030=nLW02oool0oooo02H0oooo00<000000?oo
o`3oool09P3oool6000003P0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0U0?oo
o`00:03oool00`2oM000000007Boo`030?ooo`030?oOW018B9`0gooo02L0oooo00<000000?ooo`3o
ool0;03oool700000300oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0U0?ooo`00
:03oool00`3o_g@00000000000040000000307Boo`3oool0oooo02H0oooo0P00000d0?ooo`L00000
:@3oool00`000000oooo0?ooo`360?ooo`8000009`3oool002T0oooo00H0omnL04P0000000000000
0000B02LgolY0?ooo`030000003oool0oooo03X0oooo1P00000S0?ooo`030000003oool0oooo0<L0
oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3oool0@03oool7000001`0oooo
00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?oo
o`170?ooo`P00000503oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo02D0oooo000Z
0?ooo`050;md0000000000000000B02Lgol0:@3oool200000500oooo2000000<0?ooo`030000003o
ool0oooo0<H0oooo0P00000W0?ooo`00:03oool00`3ookl0M000000000040000000307Boo`3oool0
oooo02H0oooo00<000000?ooo`3oool0E`3oool8000000<0oooo00<000000?ooo`3oool0b03oool0
0`000000oooo0?ooo`0U0?ooo`00:03oool00`3OW4P0M;oo0?ooo`030?ooo`030;md0000B9`0gooo
02L0oooo00<000000?ooo`3oool0G`3oool800000<H0oooo00<000000?ooo`3oool09@3oool002P0
oooo00<0_gAd0;ooo`3oool0103oool00`3OW9`0_ooo0?ooo`0V0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool00P3oool900000;d0oooo00<000000?ooo`3oool09@3oool002P0oooo
00<0gia80018W03Oool00`3oool00`3ookl0M4RL0=ooo`0W0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool02@3oool900000;D0oooo00<000000?ooo`3oool09@3oool002P0oooo00<0
oono07@000000000100000000`1d_ol0oooo0?ooo`0;0?ooo`050?oOW018000000000000M02oool0
0`3oool00`3o_g@0000007Boo`040?ooo`030=nLB018W=l0oooo00T0oooo0P00001T0?ooo`030000
003oool0oooo0140oooo2@00002/0?ooo`8000009`3oool002T0oooo00H0oooO09a8000000000000
0000M02oool=0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM0000000
M;oo00@0oooo00<0omnL04Q8W03Oool02@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo01X0oooo2@00002T0?ooo`030000003oool0oooo02D0oooo000l0?ooo`030;md0000B9`0gooo
0080oooo00<0_g@0001d_`3oool0203oool00`3ooml0W4Q809cOo`090?ooo`030000003oool0oooo
06<0oooo00<000000?ooo`3oool08P3oool9000009`0oooo00<000000?ooo`3oool09@3oool002P0
oooo00<0oono07Ad_`3oool0103oool00`3OW9`0_ooo0?ooo`090?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool02@3oool00`3OW4P0B9cO0?ooo`080?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool0:`3oool9000009<0oooo00<000000?ooo`3oool09@3oool00280oooo
00<0oooO09a80000M;l00`3oool00`3o_g@0000000000004000000030000M02oool0oooo00T0oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`090?ooo`030?oOW018B9`0gooo00P0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0c0?ooo`P00000R`3oool00`000000oooo
0?ooo`0U0?ooo`008P3oool00`3ooml0W4P0001d_`030?ooo`030;md00000000000000@0000000<0
001d0;ooo`3oool02@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0
oooO09a8B02Lgol0203oool3000006@0oooo00<000000?ooo`3oool0>`3oool900000800oooo0`00
000W0?ooo`00;`3oool00`3OW9`0_ooo0?ooo`090?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol02P3oool00`3OW4P007Bo0?ooo`070?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0@P3oool;000007P0oooo00<000000?ooo`3oool09@3oool003/0oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?oo_`1d07@0_ooo00L0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`1;0?oooa400000J@3oool00`000000oooo0?ooo`0U0?oo
o`00:03oool00`3ookl0M7Bo0?ooo`040?ooo`030=nLW02oool0oooo00T0oooo00<0oono07@00018
W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030?oOg`3Oool0oooo00<0oooo00<0_g@007Boo`3o
ool01P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo05X0oooo2`00001O0?ooo`03
0000003oool0oooo02D0oooo000X0?ooo`030?noM0000000000000@0000000<0001d0;ooo`3oool0
2P3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oono07A8W03Oool0
0`3oool00`3o_g@007Bo0?ooo`060?ooo`800000J03oool00`000000oooo0?ooo`1R0?ooo`X00000
EP3oool2000002L0oooo000X0?ooo`030;md00000000000000@0000000<0001d0;ooo`3oool02P3o
ool01`3ookl0M00007Boo`3oool0okmd0000M02oool01`3oool00`2oM00000000000000300000003
0000M02oool0oooo00D0oooo00<000000?ooo`3oool0J03oool2000006X0oooo4P0000170?ooo`03
0000003oool0oooo02D0oooo000Y0?ooo`030=nLW02oool0oooo00<0oooo00<0gibL0;ooo`3oool0
2`3oool01@3ookl0M0000000000007@0_ooo00P0oooo00<0okmd000000000000100000000`1d_ol0
oooo0?ooo`040?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0L@3oool@000003l0
oooo00<000000?ooo`3oool09@3oool002P0oooo00<0omnL07BLg`3oool0;@3oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo07/0oooo3@00000g0?ooo`030000003oool0oooo02D0oooo
000X0?ooo`030;md0000M;l0oooo00@0oooo00<0gibL0;ooo`3oool09P3oool00`000000oooo0?oo
o`1/0?ooo`030000003oool0oooo08H0oooo4`00000U0?ooo`030000003oool0oooo02D0oooo000X
0?ooo`030=nLB0000000000000@0000000<0001d0;ooo`3oool09P3oool2000006h0oooo00<00000
0?ooo`3oool0TP3oool>000001`0oooo0P00000W0?ooo`00:03oool00`3ooml0W4P0000000040000
00030000M02oool0oooo02H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`2N0?oo
oa800000303oool00`000000oooo0?ooo`0U0?ooo`00;`3oool00`3OW9`0_ooo0?ooo`0V0?ooo`03
0000003oool0oooo06l0oooo0P00002Z0?ooo`h00000103oool00`000000oooo0?ooo`0U0?ooo`00
:03oool00`2oM7@0_ooo0?ooo`0]0?ooo`030000003oool0oooo0740oooo0P00002d0?ooo`L00000
9`3oool002H0oooo00<0oono07@0000000001P0000000`18W=l0oooo0?ooo`0V0?ooo`030000003o
ool0oooo07<0oooo0P00002h0?ooo`030000003oool0oooo02D0oooo000U0?ooo`030?noM0000000
000000L0000000<0001d0;ooo`3oool09P3oool2000007H0oooo0P00002e0?ooo`8000009`3oool0
02P0oooo00<0_gAd0;ooo`3oool00`3oool00`3ookl0M4RL0=ooo`0W0?ooo`030000003oool0oooo
07L0oooo0P00002d0?ooo`030000003oool0oooo02D0oooo000X0?ooo`030;mdM02oool0oooo00<0
oooo00<0_gA809cOo`3oool09`3oool00`000000oooo0?ooo`1i0?ooo`800000/P3oool00`000000
oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`1k0?ooo`800000/03oool00`000000oooo
0?ooo`0U0?ooo`00?@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol0
0`3oool01@3OW4P00000000000000000B9cO00P0oooo00<000000?ooo`3oool0O@3oool200000:h0
oooo00<000000?ooo`3oool09@3oool003`0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo
0080oooo00<0okmd0000001d_ol00P3oool01`3OW4P0000007Boo`3oool0oooO09a80018W=l01`3o
ool200000800oooo0P00002[0?ooo`8000009`3oool003`0oooo00<0_g@00018W03Oool00P3oool0
0`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03Oool01P3oool0
0`000000oooo0?ooo`210?ooo`800000ZP3oool00`000000oooo0?ooo`0U0?ooo`00>`3oool00`3o
okl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0_g@0001d_`3oool00P3oool00`2o
M00004RL0=ooo`060?ooo`030000003oool0oooo08<0oooo0`00002W0?ooo`030000003oool0oooo
02D0oooo000k0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3ogi`0
B01d0;ooo`3oool0_g@00000001d_ol01`3oool00`000000oooo0?ooo`260?ooo`<00000Y03oool0
0`000000oooo0?ooo`0U0?ooo`00>`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00L0oooo00D0oono07A8B0180000000004RLg`080?ooo`<00000R@3oool3000009l0oooo0`00000W
0?ooo`00>`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00@0omnL04P0
0000000007Bo2@3oool00`000000oooo0?ooo`2<0?ooo`<00000WP3oool00`000000oooo0?ooo`0U
0?ooo`00>`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0omnL04P0
000007@0_ooo0?noM000M;l80?ooo`030000003oool0oooo08l0oooo1000002J0?ooo`030000003o
ool0oooo02D0oooo000k0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool0
0`2oM000001d0;ooo`020?ooo`030;md0018W=l0oooo00H0oooo00<000000?ooo`3oool0T`3oool5
000009D0oooo00<000000?ooo`3oool09@3oool003`0oooo00<0gia80018W03Oool00P3oool00`2o
M00007Bo0?ooo`060?ooo`030;md0000B9`0gooo0080oooo00<0gia8001d_`3oool01P3oool00`00
0000oooo0?ooo`2H0?ooo`@00000T@3oool00`000000oooo0?ooo`0U0?ooo`00?03oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool01`3oool01`3o_g@0000007Boo`3oool0oono07@0001d_ol0
1`3oool2000009d0oooo1000002<0?ooo`8000009`3oool003d0oooo00D0oono07@000000000001d
0;ooo`090?ooo`050?noM0000000000000000018W=l0203oool00`000000oooo0?ooo`2P0?ooo`@0
0000R@3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`2T0?ooo`@00000
Q@3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`2X0?ooo`@00000P@3o
ool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`2/0?ooo`D00000O03oool0
0`000000oooo0?ooo`0U0?ooo`00F03oool200000;80oooo1000001g0?ooo`8000009`3oool005P0
oooo00<000000?ooo`3oool0]@3oool600000780oooo00<000000?ooo`3oool09@3oool005P0oooo
00<000000?ooo`3oool0^`3oool7000006/0oooo00<000000?ooo`3oool09@3oool005P0oooo00<0
00000?ooo`3oool0`P3oool4000006L0oooo00<000000?ooo`3oool09@3oool005P0oooo0P000037
0?ooo`L00000G`3oool2000002L0oooo001H0?ooo`030000003oool0oooo0<d0oooo2000001H0?oo
o`030000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo0=D0oooo2000001@0?ooo`03
0000003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo0=d0oooo2@0000170?ooo`030000
003oool0oooo02D0oooo001H0?ooo`030000003oool0oooo0>H0oooo2000000o0?ooo`030000003o
ool0oooo02D0oooo000m0?ooo`050?oOW018000000000000M02oool00`3oool02@3o_g@0000007Bo
o`3oool0oono07@00000000004RL0=ooo`0:0?ooo`800000k`3oool8000003H0oooo0P00000W0?oo
o`00?03oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`04
0?ooo`030=nLB0000000M;oo00T0oooo00<000000?ooo`3oool0mP3oool9000002h0oooo00<00000
0?ooo`3oool09@3oool003`0oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`090?oo
o`030?oo_`1d0000M;oo00P0oooo00<000000?ooo`3oool0o`3oool9000002D0oooo00<000000?oo
o`3oool09@3oool003/0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0:0?ooo`03
0?oOW01804P0W=oo00L0oooo00<000000?ooo`3oool0o`3oool90?ooo`P000007@3oool00`000000
oooo0?ooo`0U0?ooo`00>`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo
00<0oooO09a8000000000`0000000`00M;l0oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo
4@3ooolA000000`0oooo00<000000?ooo`3oool09@3oool003/0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`060?ooo`080;md00000000M;oo0?ooo`3ooml0W4P00000M02oool60?oo
o`<00000o`3ooolR0?ooo`P000000P3oool3000002L0oooo000k0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0B00004RLg`030?ooo`030?noM00004P0W=oo00H0
oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`D000009`3oool003/0oooo00<0omnL04P0001d_ol0
0`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0
1P3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool09@3oool003/0oooo00<0
oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030?oOW0180000M;oo00<0oooo00<0
gia80000M02oool01P3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool09@3o
ool003`0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB000
M;oo0080oooo00@0oooO09a80000B9`0gooo1P3oool200000?l0oooo;P3oool2000002L0oooo000l
0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`070?ooo`070?noM00007@0_ooo0?ooo`3O
W4P0001809cOo`070?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0U0?oo
o`00?@3oool01@3ookl0M0000000000007@0_ooo00T0oooo00D0okmd000000000000001809cOo`08
0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`00
0000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3o
ool0o`3oool^0?ooo`030000003oool0oooo02D0oooo001H0?ooo`800000o`3oool^0?ooo`800000
9`3oool005P0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo02D0oooo001H
0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`00
0000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool09@3oool005P0oooo00<000000?ooo`3o
ool0o`3oool^0?ooo`030000003oool0oooo02D0oooo001H0?ooo`800000o`3oool^0?ooo`800000
9`3oool005P0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo02D0oooo001H
0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`00
0000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool09@3oool004/0oooo00H0_g@000000000
000000000018W03Oool70?ooo`800000o`3oool^0?ooo`8000009`3oool004`0oooo00<0omnL04P0
001d_ol02@3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool09@3oool004`0
oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3o
ool09@3oool004`0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool09@3oool004`0oooo00<0omnL04P0001d_ol02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0U0?ooo`00C03oool00`3ogi`0B00007Boo`090?ooool00000<P00000W
0?ooo`00C03oool00`3ogi`0B00007Boo`3o0?ooof80oooo001<0?ooo`030?oOW0180000M;oo0?l0
ooooHP3oool004`0oooo00<0omnL04P0001d_ol0o`3ooomR0?ooo`00C03oool00`3ogi`0B00007Bo
o`3o0?ooof80oooo001:0?ooo`050?oog`2LB00000000000001d_ol0o`3ooomR0?ooo`00C03oool0
0`3o_g@0000007Boo`3o0?ooof80oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo002@0?ooo`030?oog`2LB00000000080000000<0001809cOo`3oool00`3oool0
1@3OW4P000000000000007@0M7@00080000000H0001809cOo`3oool0oono0;no_`1d000200000007
07Boo`3oool0oooo0?oOW0180000000004RLg`050?ooo`030;md0000000000000080000000<007Bo
0?ooo`3oool00`3oool02@3OW4P000000000000007@0_ooo0?oOW0180000000004RLg`020?ooo`07
0;md0000000000000000B02Lgol0oooo0=nLB002000000030000B02Lgml0W4P00080000000<007Bo
0?oOW01800000`000000101d_ol0oooo0?ooo`3OW4P30000000407Boo`3oool0oooo0;md00800000
00@0001809cOo`3oool0_g@00P0000000`0004P0W=oo0;md0002000000030000M02oool0oooo0080
oooo00<0oooO09a8000000001P0000001@0007@0_ooo0?ooo`3oool0gia80080000000<0001d0;oO
W01800000`000000101d_ol0oooo0?oo_`1d00020000000504RL_`2LB00004RL0=ooo`2oM0000P00
00000`0004P0W=oo0?ooo`020?ooo`080;md0000000000000000B02Lgol0oooo0?oog`2LB0020000
000:0018W02LM0000000001d_`3oool0omnL04P000000000B9cO0=nLB080000000@0001d0;ooo`3o
ool0gia80`000000101d_ol0oooo0?ooo`2oM002000000030000M02ooml0W4P00080000000<004RL
0=ooo`3oool0H03oool00980oooo00<0omnL04P00018W=l01`3oool01`3OW4P0001d0;ooo`3oool0
gia80000M02oool00P3oool03@3ookl0M01809cOo`3oool0oono07@0B02Lgol0oooo0=nLB00007@0
_ooo0=no_`3Oool01@3oool0103ooml0W4P00018W03Oool70?ooo`0H0=nLB00007@0_ooo0?ooo`3O
W4P0001d0;ooo`3O_kl0gooo0;md0000000004RL0=ooo`3ooml0W4Qd0;ooo`3oool0gia80000M02o
ool0oooo0?oog`2LB00007Bo0P3oool00`3ooml0W4P0001d_`030?ooo`070=nLB0000000B9cO0?oo
o`3ooml0W4P004RLg`020?ooo`030=nLB00007@0_ooo00<0oooo00L0gia80000M02oool0oooo0;md
000004P0W=oo00L0oooo00<0omnL04P00018W=l00`3oool0103ogi`0B0000000001d_ol20?ooo`07
0=nLB00007@0_ooo0?ooo`3ooml0W4P0001d_`030?ooo`050=nLB00007@0_ooo0?ooo`3OW4P00P00
00001@0007@0_ooo0=nLB00007@0_ooo00<0oooo0200_g@000000000B9`0gooo0?oog`2LB7@0_ooo
0?noM0000000M;oo0?ooo`3ogi`0B000001d_`3o_kl0_ooo0=nLB00007@0_ooo0=no_`3Oool0gia8
0000M02oool0oooo0=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`80oooo00L0gia80018W03Oool0
oooo0?oog`2LB00007Bo06<0oooo002B0?ooo`030?oo_`1d0000B9cO00L0oooo00L0gia80000M02o
ool0oooo0=nLB00007@0_ooo0080oooo00/0oono0;noo`3oool0oooo0?noM0000000M;oo0?ooo`3O
W4P004RL0=ooo`070?ooo`030?oog`2LB00007Bo00P0oooo00/0gia80000M02oool0oooo0=nLB000
B9`0gooo0?ooo`3ogi`0B000001d_`030?ooo`0:0?oOW02L_ol0oooo0=nLB00007@0_ooo0?ooo`3o
oml0W4P0001d_`80oooo00<0oooO09a80000M;l00P3oool00`3ogi`0B000001d_`030?ooo`070?no
M00007@0_ooo0?ooo`3OW4P0001d0;ooo`030?ooo`060=nLB00007@0_ooo0=nLB0000000M;oo203o
ool00`3ookl0M00004RLg`040?ooo`0<0?noM000000004RL0=ooo`3oool0gia80000M02oool0oooo
0?oog`2LB00007Bo0`3oool01`2oM00004RL0=ooo`3oool0oooO09a80000M;l00P3oool00`3OW4P0
001d0;ooo`020?ooo`030?oOW018000007Bo00<0oooo00T0omnL09boo`3o_g@0001809cOo`3oool0
oooO09a80000M;l00P3oool00`3OW4P004RL0=ooo`020?ooo`060=nLB00007@0_ooo0?oOW0180000
07Bo0`3oool02`3o_g@0001d0;ooo`3oool0gia80018W03Oool0oooo0?oog`2LB00007Bo06<0oooo
002B0?ooo`030?oo_`1d0000B9cO00L0oooo00L0gia80000M02oool0oooo0=nLB00007@0_ooo00@0
oooo00T0oono07@000000000001d0;ooo`3oool0gia80018W03Oool01`3oool00`3ooml0W4P0001d
_`080?ooo`0;0=nLB00007@0_ooo0?ooo`3OW4P004RL0=ooo`3oool0okmd0000B02Lgol01P3oool0
1`3OW4P0001d0;ooo`3oool0oooO09a80000M;l00P3oool00`3ooml0W4P0001d_`020?ooo`030?no
M0000000M;oo00<0oooo00L0okmd0000001d_ol0oooo0=nLB00007@0_ooo00<0oooo00D0gia80000
M02o_g@0000004RLg`090?ooo`030?oo_`1d0000B9cO00@0oooo00`0omnL04P0000007@0_ooo0?oo
o`3OW4P0001d0;ooo`3oool0oooO09a80000M;l30?ooo`070;md0000B9`0gooo0?ooo`3ooml0W4P0
001d_`020?ooo`030=nLB00007@0_ooo0080oooo00<0okmd0000B02Lgol01P3oool01P3o_g@00000
001d_`3ooml0W4P0001d_`80oooo00<0gia80018W03Oool00P3oool01P3OW4P0001d0;ooo`3o_g@0
000007Boo`<0oooo00/0okmd0000001d_ol0oooo0=nLB000B9`0gooo0?ooo`3ooml0W4P0001d_`1S
0?ooo`00TP3oool00`3ookl0M00004RLg`020?ooo`030?oOW01dW=l0oooo0080oooo00L0gia80000
M02oool0oooo0=nLB00007@0_ooo00<0oooo00@0_g@0000000000000B9cO0`3oool00`3OW4P004RL
0=ooo`070?ooo`030?oog`2LB00007Bo00P0oooo00/0gia80000M02oool0oooo0=nLB000B9`0gooo
0?ooo`3o_g@0001d0;ooo`060?ooo`070=nLB00007@0_ooo0?ooo`3ooml0W4P0001d_`020?ooo`03
0?oog`2LB00007Bo0080oooo00<0okmd0000001d_ol00`3oool01`3o_g@0000007Boo`3oool0gia8
0000M02oool00`3oool0103OW4P0000000000000M;l:0?ooo`030?oo_`1d0000B9cO00@0oooo00<0
okmd00000000M;l00P3oool01`3OW4P0001d0;ooo`3oool0oooO09a80000M;l00`3oool01`2oM000
04RL0=ooo`3oool0oooO09a80000M;l00P3oool00`3OW4P0001d0;ooo`020?ooo`030?noM00007@0
_ooo00P0oooo00@0okmd00000000000007Bo0P3oool00`3OW4P004RL0=ooo`020?ooo`060=nLB000
07@0_ooo0?noM0000000M;oo0`3oool02`3o_g@0000007Boo`3oool0gia80018W03Oool0oooo0?oo
g`2LB00007Bo06<0oooo002B0?ooo`030?oo_`1d0000B9cO0080oooo00<0okmd04RLg`3oool00P3o
ool01`3OW4P0001d0;ooo`3oool0gia80000B02Lgol00P3oool00`3ogi`0B00004RLg`020?ooo`06
0;nLW03Oool0oooo0=nLB000B9`0gooo1`3oool00`3ooml0W4P0000000040000000?07Boo`3oool0
oooo0?ooo`3OW4P0001d0;ooo`3oool0gia80018W03Oool0oooo0?oOW01804P0W=oo0080oooo00/0
okmd0000B02Lgol0oooo0=nLB00007@0_ooo0?ooo`3ooml0W4P0001d_`020?ooo`030?oog`2LB000
07Bo0080oooo00<0oono07@0001d_ol00`3oool01`2oM000001809cOo`3oool0gia80000B02Lgol0
0`3oool01@3OW4P0001d0;ooo`2oM00007Bo00T0oooo00<0oono07@00018W=l00`3oool0103OW4P0
00000000B02Lgol20?ooo`070=nLB00007@0_ooo0?ooo`3ooml0W4P0001d_`030?ooo`070;md0000
B9`0gooo0?ooo`3ooml0W4P0001d_`020?ooo`030=nLB00004P0W=oo0080oooo00<0omnL04P0B02L
gol00P3oool02P3o_g@0001809cOo`3ookl0M00007Boo`3oool0oooO09a80000M;l20?ooo`030=nL
B000B9`0gooo0080oooo00H0gia80000M02oool0oono07@0001d_ol30?ooo`0;0;md000004P0W=oo
0?ooo`2oM000001d0;ooo`3oool0oooO09a80000M;l0H`3oool00980oooo00<0oono07@000000000
0`0000006018W=l0oooo0?oog`2LB00000000000M02ooml0W4P00000000004P0B7BL0=noM00007@0
_ono07@0M02oool0oooo0?noM000B9`0gooo0?ooo`3OW4P004RL0=ooo`L0oooo00<0oooO09a80000
M;l00P3oool03@3ooml0W4P000000018W=l0oooO09a800000000001d0;ooo`3oool0gia80018W03O
ool00P3oool03`2oM00004RL0=ooo`3ooml0W4P00000M02oool0oooo0=nLB0000000001809cOo`3o
okl0M00004RLg`020?ooo`030?oog`2LB00007Bo00<0oooo01H0gia80018W03Oool0oooo0?noM000
000007Bo0?oog`2LB00000000000B018M9`0gkmd0000M02oool0gia80000M02oool0oooo0?noM000
B9`0gooo1`3oool00`3ookl0M000000000040000000<07Boo`3oool0oooo0?oog`2LB00000000000
M02oool0oooo0?oog`2LB00007Bo0`3oool07@2oM00004RL0=ooo`3oool0oooO09a80000M;l0oooO
09a800000000001804QdW03O_g@0001d0;ooo`2oM00004RL0=ooo`3ooml0W4P00000M02oool0oono
07@00018W=l0oooo0?oo_`1d000007Bo0080oooo01T0gia80018W03Oool0oooO09a800000000001d
0;ooo`3oool0gia80018W03Oool0oooo0?noM000000007Bo0?oog`2LB00000000018B01804P0W=oo
0?oo_`1d0000B9cO06<0oooo002B0?ooo`030?oo_`1d0000B9cO0080oooo00<0okmd04RLg`3oool0
0P3oool02`2oM000001d0;ooo`3oool0_g@00000M02ogi`0B0000000M02oool0okmd0080000000@0
07Bo0;nLW03Oool0_g@00`0000000`00B9`0gooo0?ooo`040?ooo`030?oog`2LB00007Bo00<0oooo
00T0oono07@0000007@0_ooo0?ooo`2oM000001d0;ooo`2oM0000`0000001000B9`0gooo0?ooo`3O
W4P20000000=0000B02Lgol0oooo0?ooo`3OW4P0001d0;oog`2LB00000000000M02oool0oooo0?no
M004000000040018W03Oool0oooo0?noM0<0000000l0B9cO0?ooo`3oool0oooo0;md000007@0_mnL
04P0000007@0_ooo0=nLB00007@0_ooo0?oog`2LB0000P0000000`00M;l0oooo0?ooo`040?ooo`03
0?oo_`1d0000B9cO00<0oooo00@0okmd00000000B9`0gooo0P3oool0102oM000001d0;ooo`3o_g@4
000000090018B018000000000018W03Oool0omnL04P00000000007Bo0080oooo00P0_g@00000M02o
gi`0B0000000M02oool0oooo0=nLB080000000H0001809cOo`3oool0oooo0?oo_`1d000200000004
0000M02oool0oooo0;md00<0000000D004RL0=ooo`2oM000001d0;ooo`020?ooo`050?noM0000000
000000000018W=l00`3oool01`2oM00004RL0=oog`2LB00000000000M02oool0H`3oool00980oooo
00<0oono07@00018W=l00P3oool00`3ogi`0M9cO0?ooo`0C0?ooo`030;md0000B9`0gooo00L0oooo
00<0oooO09a80000M;l00`3oool0103ooml0W4P00000B02Lgol50?ooo`030;md0000B9`0gooo00X0
oooo00<0gia80000M02oool01P3oool00`3ooml0W4P0001d_`0B0?ooo`030=nLB00007@0_ooo00/0
oooo00<0oono07@00018W=l0103oool00`2oM000000007Boo`060?ooo`030?oog`2LB00007Bo0280
oooo00<0_g@00018W03Oool0N@3oool00980oooo00<0oono07@00018W=l0103oool00`3OW7@0W=oo
0?ooo`0A0?ooo`030?oo_`1dB9`0gooo00L0oooo00<0oooO09a80000M;l00`3oool0103ogi`0B000
0000M02oool50?ooo`030?oo_`1dB9`0gooo00X0oooo00<0gia80000M02oool01`3oool00`2oM000
07Bo0?ooo`0A0?ooo`030=nLB00007@0_ooo00/0oooo00<0oono07@00018W=l0103oool00`2oM000
000007Boo`070?ooo`030;md0000M;l0oooo0240oooo00<0oono07A8W03Oool0N@3oool00980oooo
00<0omnL04P00018W=l00`3oool00`3ookl0M01d0;ooo`0B0?ooo`030?oog`2LM9`0gooo00L0oooo
00<0oooO09a80000M;l00P3oool0103ookl0M00000000018W=l60?ooo`030?oog`2LM9`0gooo00X0
oooo00<0gia80000M02oool01`3oool00`3OW4P007Bo0?ooo`0A0?ooo`030=nLB00007@0_ooo00/0
oooo00<0omnL04P00018W=l00`3oool0103OW4P000000018W03Oool70?ooo`030=nLB000M;l0oooo
0240oooo00<0oooO09adW03Oool0N@3oool00900oooo00<0oooO09a8000000001P0000001P0007@0
_ooo0?ooo`3OW4P0001809cOoaL0oooo00<0_g@0000000000000100000000`0004P0W=oo0?ooo`02
0?ooo`030=nLB00004P0W=oo00`0oooo00D0oooO09a800000000001d0;ooo`070?ooo`070?oo_`1d
07@0_ooo0?oog`2LB00004RL0=ooo`0;0?ooo`050?oog`2LB00000000000M02oool02@3oool00`3o
oml0W4P0000000060000000304RLg`3oool0oooo0080oooo00<0gia80000B02Lgol00P3oool01`3o
okl0M01d0;ooo`3ooml0W4P00018W03Oool08P3oool00`3OW4P0001809cOo`1d0?ooo`00W03oool0
0`3OW4P0001809cOo`0S0?ooo`030=nLB00004P0W=oo00h0oooo00<0_g@00000M02oool0203oool0
1@3ookl0M0000000000004P0W=oo00h0oooo00<0_g@00000M02oool05`3oool00`3OW4P0001809cO
o`030?ooo`050?oo_`1d000000000000B02Lgol08`3oool00`3OW4P0001809cOo`1d0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {2.06154, -0.0167836, \
0.00740896, 0.00639358}}]
}, Closed]],

Cell[TextData[{
  "However, their slopes decrease with \[Mu] until a new critical point is \
reached where the slopes cross through ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] < \(-1\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Solve[\(slopes[
              2]\)\[LeftDoubleBracket]3\[RightDoubleBracket] \[Equal] \(-1\), \
\[Mu]]\)\[LeftDoubleBracket]2\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({\[Mu] \[Rule] 1 + \@6}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // N\)], "Input"],

Cell[BoxData[
    \({\[Mu] \[Rule] 3.449489742783178`}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "At this point, each fixed point gives birth to two stable offspring as it \
crosses the threshold of instability.  Thus, this second ",
  StyleBox["period doubling",
    FontSlant->"Italic"],
  " produces a stable 4-cycle.  However, numerical evaluation of the fixed \
points is needed for cycles of order 3 or higher.  Nevertheless, the \
solutions can be displayed easily."
}], "Text"],

Cell[BoxData[
    \(\(sol4\  = \ fixedPoints[4] // Simplify;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[{x /. sol2, N[x /. sol4]}], {\[Mu], 2.8, 3.84}, 
        PlotLabel \[Rule] "\<Second Pitchfork Bifurcation\>", 
        Frame \[Rule] True, \ 
        FrameLabel \[Rule] {"\<\[Mu]\>", "\<fixed point\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.54029 0.915751 0.0147151 0.643068 [
[.02381 -0.0125 -9.5 -15.6875 ]
[.02381 -0.0125 9.5 0 ]
[.20696 -0.0125 -5 -15.6875 ]
[.20696 -0.0125 5 0 ]
[.39011 -0.0125 -9.5 -15.6875 ]
[.39011 -0.0125 9.5 0 ]
[.57326 -0.0125 -9.5 -15.6875 ]
[.57326 -0.0125 9.5 0 ]
[.75641 -0.0125 -9.5 -15.6875 ]
[.75641 -0.0125 9.5 0 ]
[.93956 -0.0125 -9.5 -15.6875 ]
[.93956 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.5 -31.375 ]
[.5 -0.0125 5.5 -15.6875 ]
[-0.0125 .01472 -10 -7.84375 ]
[-0.0125 .01472 0 7.84375 ]
[-0.0125 .14333 -19 -7.84375 ]
[-0.0125 .14333 0 7.84375 ]
[-0.0125 .27194 -19 -7.84375 ]
[-0.0125 .27194 0 7.84375 ]
[-0.0125 .40056 -19 -7.84375 ]
[-0.0125 .40056 0 7.84375 ]
[-0.0125 .52917 -19 -7.84375 ]
[-0.0125 .52917 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -28.125 ]
[-0.01875 .30902 -19 28.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -71.9375 0 ]
[.5 .63053 71.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
1.000 setlinewidth
grestore
.20696 0 m
.20696 .00625 L
s
gsave
.20696 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.39011 0 m
.39011 .00625 L
s
gsave
.39011 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
1.000 setlinewidth
grestore
.57326 0 m
.57326 .00625 L
s
gsave
.57326 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
1.000 setlinewidth
grestore
.75641 0 m
.75641 .00625 L
s
gsave
.75641 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
1.000 setlinewidth
grestore
.93956 0 m
.93956 .00625 L
s
gsave
.93956 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.0696 0 m
.0696 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16117 0 m
.16117 .00375 L
s
.25275 0 m
.25275 .00375 L
s
.29853 0 m
.29853 .00375 L
s
.34432 0 m
.34432 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.48168 0 m
.48168 .00375 L
s
.52747 0 m
.52747 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66484 0 m
.66484 .00375 L
s
.71062 0 m
.71062 .00375 L
s
.8022 0 m
.8022 .00375 L
s
.84799 0 m
.84799 .00375 L
s
.89377 0 m
.89377 .00375 L
s
.98535 0 m
.98535 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.563 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
70.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .14333 m
.00625 .14333 L
s
gsave
-0.0125 .14333 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .27194 m
.00625 .27194 L
s
gsave
-0.0125 .27194 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .40056 m
.00625 .40056 L
s
gsave
-0.0125 .40056 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .52917 m
.00625 .52917 L
s
gsave
-0.0125 .52917 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04687 m
.00375 .04687 L
s
0 .07902 m
.00375 .07902 L
s
0 .11118 m
.00375 .11118 L
s
0 .17548 m
.00375 .17548 L
s
0 .20764 m
.00375 .20764 L
s
0 .23979 m
.00375 .23979 L
s
0 .3041 m
.00375 .3041 L
s
0 .33625 m
.00375 .33625 L
s
0 .3684 m
.00375 .3684 L
s
0 .43271 m
.00375 .43271 L
s
0 .46486 m
.00375 .46486 L
s
0 .49702 m
.00375 .49702 L
s
0 .56132 m
.00375 .56132 L
s
0 .59348 m
.00375 .59348 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -115.969 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
89.125 11.8438 translate
90 rotate
-89.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(fixed) show
90.625 15.813 moveto
(point) show
115.250 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.20696 .61178 m
.20696 .61803 L
s
.39011 .61178 m
.39011 .61803 L
s
.57326 .61178 m
.57326 .61803 L
s
.75641 .61178 m
.75641 .61803 L
s
.93956 .61178 m
.93956 .61803 L
s
.125 Mabswid
.0696 .61428 m
.0696 .61803 L
s
.11538 .61428 m
.11538 .61803 L
s
.16117 .61428 m
.16117 .61803 L
s
.25275 .61428 m
.25275 .61803 L
s
.29853 .61428 m
.29853 .61803 L
s
.34432 .61428 m
.34432 .61803 L
s
.4359 .61428 m
.4359 .61803 L
s
.48168 .61428 m
.48168 .61803 L
s
.52747 .61428 m
.52747 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66484 .61428 m
.66484 .61803 L
s
.71062 .61428 m
.71062 .61803 L
s
.8022 .61428 m
.8022 .61803 L
s
.84799 .61428 m
.84799 .61803 L
s
.89377 .61428 m
.89377 .61803 L
s
.98535 .61428 m
.98535 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14333 m
1 .14333 L
s
.99375 .27194 m
1 .27194 L
s
.99375 .40056 m
1 .40056 L
s
.99375 .52917 m
1 .52917 L
s
.125 Mabswid
.99625 .04687 m
1 .04687 L
s
.99625 .07902 m
1 .07902 L
s
.99625 .11118 m
1 .11118 L
s
.99625 .17548 m
1 .17548 L
s
.99625 .20764 m
1 .20764 L
s
.99625 .23979 m
1 .23979 L
s
.99625 .3041 m
1 .3041 L
s
.99625 .33625 m
1 .33625 L
s
.99625 .3684 m
1 .3684 L
s
.99625 .43271 m
1 .43271 L
s
.99625 .46486 m
1 .46486 L
s
.99625 .49702 m
1 .49702 L
s
.99625 .56132 m
1 .56132 L
s
.99625 .59348 m
1 .59348 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -132.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Second) show
101.188 15.813 moveto
(Pitchfork) show
148.625 15.813 moveto
(Bifurcation) show
202.875 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04588 .01472 L
.04652 .01472 L
.04722 .01472 L
.04797 .01472 L
.04862 .01472 L
.04933 .01472 L
.05061 .01472 L
.05186 .01472 L
.05302 .01472 L
.05414 .01472 L
.05519 .01472 L
.05634 .01472 L
.05759 .01472 L
.05882 .01472 L
.06012 .01472 L
.06123 .01472 L
.06244 .01472 L
.06315 .01472 L
.06381 .01472 L
.06453 .01472 L
.06529 .01472 L
.06657 .01472 L
.06729 .01472 L
.06797 .01472 L
.06924 .01472 L
.0704 .01472 L
.07103 .01472 L
.07173 .01472 L
.073 .01472 L
Mistroke
.07376 .01472 L
.07448 .01472 L
.07513 .01472 L
.07583 .01472 L
.0766 .01472 L
.0774 .01472 L
.07809 .01472 L
.07885 .01472 L
.07956 .01472 L
.0802 .01472 L
.08095 .01472 L
.08166 .01472 L
.08291 .01472 L
.08362 .01472 L
.08427 .01472 L
.08544 .01472 L
.08669 .01472 L
.08787 .01472 L
.08896 .01472 L
.09016 .01472 L
.09148 .01472 L
.09214 .01472 L
.09285 .01472 L
.09413 .01472 L
.09483 .01472 L
.09548 .01472 L
.09619 .01472 L
.09695 .01472 L
.09821 .01472 L
.09893 .01472 L
.09961 .01472 L
.10086 .01472 L
.10201 .01472 L
.10333 .01472 L
.10458 .01472 L
.10572 .01472 L
.10694 .01472 L
.1081 .01472 L
.10916 .01472 L
.11033 .01472 L
.11162 .01472 L
.11227 .01472 L
.11297 .01472 L
.11422 .01472 L
.11491 .01472 L
.11554 .01472 L
.11624 .01472 L
.11698 .01472 L
.11822 .01472 L
.11892 .01472 L
Mistroke
.11958 .01472 L
.12081 .01472 L
.12194 .01472 L
.12323 .01472 L
.12446 .01472 L
.12562 .01472 L
.12668 .01472 L
.12789 .01472 L
.12903 .01472 L
.13009 .01472 L
.13107 .01472 L
.13214 .01472 L
.13327 .01472 L
.13441 .01472 L
.13564 .01472 L
.1368 .01472 L
.13785 .01472 L
.13909 .01472 L
.13979 .01472 L
.14043 .01472 L
.14162 .01472 L
.14288 .01472 L
.14402 .01472 L
.14526 .01472 L
.14656 .01472 L
.14777 .01472 L
.14891 .01472 L
.14994 .01472 L
.15113 .01472 L
.15226 .01472 L
.15348 .01472 L
.15478 .01472 L
.15589 .01472 L
.15711 .01472 L
.15842 .01472 L
.15915 .01472 L
.15982 .01472 L
.16113 .01472 L
.16236 .01472 L
.16352 .01472 L
.16456 .01472 L
.16577 .01472 L
.1669 .01472 L
.16796 .01472 L
.16893 .01472 L
.16999 .01472 L
.17111 .01472 L
.17225 .01472 L
.17347 .01472 L
.17462 .01472 L
Mistroke
.17566 .01472 L
.17689 .01472 L
.17758 .01472 L
.17823 .01472 L
.1794 .01472 L
.18065 .01472 L
.18185 .01472 L
.18316 .01472 L
.18441 .01472 L
.18556 .01472 L
.1867 .01472 L
.18773 .01472 L
.18893 .01472 L
.19005 .01472 L
.19128 .01472 L
.19258 .01472 L
.19369 .01472 L
.19491 .01472 L
.19623 .01472 L
.19696 .01472 L
.19763 .01472 L
.19894 .01472 L
.20017 .01472 L
.20122 .01472 L
.20238 .01472 L
.20359 .01472 L
.20472 .01472 L
.20578 .01472 L
.20675 .01472 L
.20781 .01472 L
.20894 .01472 L
.21008 .01472 L
.21129 .01472 L
.21244 .01472 L
.21349 .01472 L
.21472 .01472 L
.21541 .01472 L
.21605 .01472 L
.21723 .01472 L
.21847 .01472 L
.21968 .01472 L
.221 .01472 L
.22224 .01472 L
.2234 .01472 L
.22454 .01472 L
.22558 .01472 L
.22677 .01472 L
.2279 .01472 L
.22914 .01472 L
.23044 .01472 L
Mistroke
.23155 .01472 L
.23277 .01472 L
.23409 .01472 L
.23482 .01472 L
.2355 .01472 L
.2368 .01472 L
.23804 .01472 L
.23909 .01472 L
.24025 .01472 L
.24146 .01472 L
.2426 .01472 L
.24365 .01472 L
.24462 .01472 L
.24569 .01472 L
.24681 .01472 L
.24795 .01472 L
.24917 .01472 L
.25032 .01472 L
.25137 .01472 L
.2526 .01472 L
.25329 .01472 L
.25393 .01472 L
.2551 .01472 L
.25635 .01472 L
.25756 .01472 L
.25888 .01472 L
.26013 .01472 L
.26129 .01472 L
.26233 .01472 L
.26348 .01472 L
.26467 .01472 L
.2658 .01472 L
.26704 .01472 L
.26835 .01472 L
.26946 .01472 L
.27068 .01472 L
.272 .01472 L
.27274 .01472 L
.27341 .01472 L
.27472 .01472 L
.27595 .01472 L
.27701 .01472 L
.27817 .01472 L
.27938 .01472 L
.28052 .01472 L
.28158 .01472 L
.28255 .01472 L
.28367 .01472 L
.28474 .01472 L
.28588 .01472 L
Mistroke
.2871 .01472 L
.28825 .01472 L
.2893 .01472 L
.29053 .01472 L
.29122 .01472 L
.29186 .01472 L
.29303 .01472 L
.29427 .01472 L
.29549 .01472 L
.29618 .01472 L
.29682 .01472 L
.29799 .01472 L
.29923 .01472 L
.30034 .01472 L
.30138 .01472 L
.30252 .01472 L
.30375 .01472 L
.30499 .01472 L
.30569 .01472 L
.30634 .01472 L
.30765 .01472 L
.30839 .01472 L
.30906 .01472 L
.31026 .01472 L
.31156 .01472 L
.31278 .01472 L
.31392 .01472 L
.31497 .01472 L
.31611 .01472 L
.31718 .01472 L
.31816 .01472 L
.3193 .01472 L
.32055 .01472 L
.32173 .01472 L
.32282 .01472 L
.32406 .01472 L
.32522 .01472 L
.32626 .01472 L
.32739 .01472 L
.32862 .01472 L
.32992 .01472 L
.33103 .01472 L
.33225 .01472 L
.33356 .01472 L
.33477 .01472 L
.33541 .01472 L
.3361 .01472 L
.33683 .01472 L
.33751 .01472 L
.33876 .01472 L
Mistroke
.33991 .01472 L
.34123 .01472 L
.34249 .01472 L
.3436 .01472 L
.3448 .01472 L
.34592 .01472 L
.34694 .01472 L
.34814 .01472 L
.34945 .01472 L
.35067 .01472 L
.35181 .01472 L
.35302 .01472 L
.35431 .01472 L
.35554 .01472 L
.35665 .01472 L
.35796 .01472 L
.3587 .01472 L
.35939 .01472 L
.36064 .01472 L
.36128 .01472 L
.36198 .01472 L
.36266 .01472 L
.36337 .01472 L
.36465 .01472 L
.36536 .01472 L
.36602 .01472 L
.36675 .01472 L
.36753 .01472 L
.3682 .01472 L
.36893 .01472 L
.36962 .01472 L
.37026 .01472 L
.37146 .01472 L
.37274 .01472 L
.37394 .01472 L
.37526 .01472 L
.37651 .01472 L
.37766 .01472 L
.3788 .01472 L
.37984 .01472 L
.38103 .01472 L
.38216 .01472 L
.38339 .01472 L
.3847 .01472 L
.38581 .01472 L
.38703 .01472 L
.38834 .01472 L
.38908 .01472 L
.38975 .01472 L
.39106 .01472 L
Mistroke
.39229 .01472 L
.39334 .01472 L
.3945 .01472 L
.39571 .01472 L
.39685 .01472 L
.39791 .01472 L
.39888 .01472 L
.39994 .01472 L
.40106 .01472 L
.40221 .01472 L
.40342 .01472 L
.40457 .01472 L
.40562 .01472 L
.40685 .01472 L
.40754 .01472 L
.40818 .01472 L
.40936 .01472 L
.4106 .01472 L
.41181 .01472 L
.41313 .01472 L
.41438 .01472 L
.41554 .01472 L
.41669 .01472 L
.41772 .01472 L
.41892 .01472 L
.42005 .01472 L
.42129 .01472 L
.42259 .01472 L
.42371 .01472 L
.42493 .01472 L
.42624 .01472 L
.42698 .01472 L
.42765 .01472 L
.42896 .01472 L
.43019 .01472 L
.43125 .01472 L
.43241 .01472 L
.43362 .01472 L
.43476 .01472 L
.43582 .01472 L
.43679 .01472 L
.43791 .01472 L
.43898 .01472 L
.44012 .01472 L
.44134 .01472 L
.44249 .01472 L
.44354 .01472 L
.44477 .01472 L
.44546 .01472 L
.4461 .01472 L
Mistroke
.44727 .01472 L
.44851 .01472 L
.44973 .01472 L
.45042 .01472 L
.45106 .01472 L
.45223 .01472 L
.45347 .01472 L
.45458 .01472 L
.45562 .01472 L
.45676 .01472 L
.45799 .01472 L
.45922 .01472 L
.45992 .01472 L
.46057 .01472 L
.46188 .01472 L
.46262 .01472 L
.46329 .01472 L
.46449 .01472 L
.46579 .01472 L
.46702 .01472 L
.46815 .01472 L
.4692 .01472 L
.47034 .01472 L
.47141 .01472 L
.47239 .01472 L
.47353 .01472 L
.47478 .01472 L
.47596 .01472 L
.47705 .01472 L
.47829 .01472 L
.47945 .01472 L
.48049 .01472 L
.48162 .01472 L
.48285 .01472 L
.48415 .01472 L
.48526 .01472 L
.48648 .01472 L
.48779 .01472 L
.489 .01472 L
.48963 .01472 L
.49033 .01472 L
.49105 .01472 L
.49174 .01472 L
.49299 .01472 L
.49413 .01472 L
.49539 .01472 L
.49671 .01472 L
.49783 .01472 L
.49902 .01472 L
.50014 .01472 L
Mistroke
.50116 .01472 L
.50236 .01472 L
.50366 .01472 L
.50489 .01472 L
.50603 .01472 L
.50723 .01472 L
.50853 .01472 L
.50975 .01472 L
.51087 .01472 L
.51218 .01472 L
.51292 .01472 L
.51361 .01472 L
.51486 .01472 L
.5155 .01472 L
.5162 .01472 L
.51687 .01472 L
.51759 .01472 L
.51886 .01472 L
.51958 .01472 L
.52024 .01472 L
.52096 .01472 L
.52174 .01472 L
.52241 .01472 L
.52314 .01472 L
.52383 .01472 L
.52447 .01472 L
.52568 .01472 L
.52695 .01472 L
.52816 .01472 L
.52947 .01472 L
.53072 .01472 L
.53187 .01472 L
.53301 .01472 L
.53405 .01472 L
.53525 .01472 L
.53637 .01472 L
.5376 .01472 L
.53891 .01472 L
.54002 .01472 L
.54124 .01472 L
.54255 .01472 L
.54329 .01472 L
.54396 .01472 L
.54526 .01472 L
.5465 .01472 L
.54755 .01472 L
.54871 .01472 L
.54992 .01472 L
.55105 .01472 L
.55211 .01472 L
Mistroke
.55308 .01472 L
.55415 .01472 L
.55527 .01472 L
.55641 .01472 L
.55763 .01472 L
.55878 .01472 L
.55982 .01472 L
.56105 .01472 L
.56175 .01472 L
.56238 .01472 L
.56356 .01472 L
.5648 .01472 L
.56601 .01472 L
.56734 .01472 L
.56858 .01472 L
.56974 .01472 L
.57088 .01472 L
.57192 .01472 L
.57312 .01472 L
.57425 .01472 L
.57548 .01472 L
.57679 .01472 L
.5779 .01472 L
.57912 .01472 L
.58044 .01472 L
.58118 .01472 L
.58185 .01472 L
.58315 .01472 L
.58439 .01472 L
.58544 .01472 L
.5866 .01472 L
.58782 .01472 L
.58895 .01472 L
.59001 .01472 L
.59098 .01472 L
.5921 .01472 L
.59317 .01472 L
.59431 .01472 L
.59553 .01472 L
.59668 .01472 L
.59773 .01472 L
.59896 .01472 L
.59965 .01472 L
.60029 .01472 L
.60146 .01472 L
.60271 .01472 L
.60392 .01472 L
.60461 .01472 L
.60525 .01472 L
.60642 .01472 L
Mistroke
.60766 .01472 L
.60876 .01472 L
.6098 .01472 L
.61094 .01472 L
.61217 .01472 L
.61341 .01472 L
.6141 .01472 L
.61475 .01472 L
.61607 .01472 L
.6168 .01472 L
.61747 .01472 L
.61867 .01472 L
.61997 .01472 L
.6212 .01472 L
.62233 .01472 L
.62339 .01472 L
.62452 .01472 L
.62559 .01472 L
.62657 .01472 L
.62771 .01472 L
.62896 .01472 L
.63014 .01472 L
.63123 .01472 L
.63247 .01472 L
.63363 .01472 L
.63467 .01472 L
.6358 .01472 L
.63703 .01472 L
.63833 .01472 L
.63944 .01472 L
.64066 .01472 L
.64197 .01472 L
.64318 .01472 L
.64381 .01472 L
.6445 .01472 L
.64523 .01472 L
.64591 .01472 L
.64716 .01472 L
.64831 .01472 L
.64956 .01472 L
.65088 .01472 L
.652 .01472 L
.65319 .01472 L
.65431 .01472 L
.65533 .01472 L
.65653 .01472 L
.65784 .01472 L
.65906 .01472 L
.6602 .01472 L
.6614 .01472 L
Mistroke
.6627 .01472 L
.66392 .01472 L
.66504 .01472 L
.66635 .01472 L
.66709 .01472 L
.66777 .01472 L
.66903 .01472 L
.66966 .01472 L
.67036 .01472 L
.67104 .01472 L
.67175 .01472 L
.67303 .01472 L
.67374 .01472 L
.6744 .01472 L
.67513 .01472 L
.67591 .01472 L
.67658 .01472 L
.67731 .01472 L
.678 .01472 L
.67864 .01472 L
.67984 .01472 L
.68112 .01472 L
.68232 .01472 L
.68364 .01472 L
.68488 .01472 L
.68603 .01472 L
.68718 .01472 L
.68821 .01472 L
.68941 .01472 L
.69053 .01472 L
.69176 .01472 L
.69307 .01472 L
.69418 .01472 L
.6954 .01472 L
.69671 .01472 L
.69745 .01472 L
.69812 .01472 L
.69942 .01472 L
.70066 .01472 L
.70171 .01472 L
.70286 .01472 L
.70407 .01472 L
.70521 .01472 L
.70627 .01472 L
.70724 .01472 L
.7083 .01472 L
.70942 .01472 L
.71056 .01472 L
.71178 .01472 L
.71293 .01472 L
Mistroke
.71398 .01472 L
.71521 .01472 L
.7159 .01472 L
.71654 .01472 L
.71771 .01472 L
.71896 .01472 L
.72017 .01472 L
.72149 .01472 L
.72273 .01472 L
.72389 .01472 L
.72503 .01472 L
.72607 .01472 L
.72727 .01472 L
.7284 .01472 L
.72963 .01472 L
.73094 .01472 L
.73205 .01472 L
.73327 .01472 L
.73458 .01472 L
.73532 .01472 L
.73599 .01472 L
.7373 .01472 L
.73853 .01472 L
.73959 .01472 L
.74075 .01472 L
.74196 .01472 L
.7431 .01472 L
.74416 .01472 L
.74513 .01472 L
.74619 .01472 L
.74731 .01472 L
.74846 .01472 L
.74967 .01472 L
.75083 .01472 L
.75187 .01472 L
.7531 .01472 L
.75379 .01472 L
.75443 .01472 L
.75561 .01472 L
.75685 .01472 L
.75806 .01472 L
.75875 .01472 L
.75939 .01472 L
.76056 .01472 L
.7618 .01472 L
.7629 .01472 L
.76394 .01472 L
.76508 .01472 L
.76631 .01472 L
.76754 .01472 L
Mistroke
.76824 .01472 L
.76889 .01472 L
.7702 .01472 L
.77094 .01472 L
.77161 .01472 L
.7728 .01472 L
.7741 .01472 L
.77533 .01472 L
.77646 .01472 L
.77752 .01472 L
.77865 .01472 L
.77972 .01472 L
.7807 .01472 L
.78184 .01472 L
.78309 .01472 L
.78427 .01472 L
.78536 .01472 L
.7866 .01472 L
.78776 .01472 L
.7888 .01472 L
.78993 .01472 L
.79116 .01472 L
.79246 .01472 L
.79357 .01472 L
.79479 .01472 L
.7961 .01472 L
.7973 .01472 L
.79793 .01472 L
.79863 .01472 L
.79936 .01472 L
.80004 .01472 L
.80129 .01472 L
.80243 .01472 L
.80369 .01472 L
.80501 .01472 L
.80612 .01472 L
.80731 .01472 L
.80843 .01472 L
.80945 .01472 L
.81066 .01472 L
.81196 .01472 L
.81318 .01472 L
.81432 .01472 L
.81552 .01472 L
.81682 .01472 L
.81804 .01472 L
.81916 .01472 L
.82047 .01472 L
.8212 .01472 L
.82189 .01472 L
Mistroke
.82315 .01472 L
.82385 .01472 L
.82448 .01472 L
.82516 .01472 L
.82587 .01472 L
.82715 .01472 L
.82786 .01472 L
.82852 .01472 L
.82925 .01472 L
.83002 .01472 L
.8307 .01472 L
.83143 .01472 L
.83212 .01472 L
.83275 .01472 L
.83396 .01472 L
.83524 .01472 L
.83644 .01472 L
.83775 .01472 L
.839 .01472 L
.84015 .01472 L
.84129 .01472 L
.84232 .01472 L
.84352 .01472 L
.84464 .01472 L
.84587 .01472 L
.84718 .01472 L
.84829 .01472 L
.8495 .01472 L
.85082 .01472 L
.85155 .01472 L
.85222 .01472 L
.85353 .01472 L
.85476 .01472 L
.85581 .01472 L
.85697 .01472 L
.85818 .01472 L
.85932 .01472 L
.86037 .01472 L
.86134 .01472 L
.86241 .01472 L
.86353 .01472 L
.86467 .01472 L
.86589 .01472 L
.86704 .01472 L
.86808 .01472 L
.86931 .01472 L
.87 .01472 L
.87064 .01472 L
.87182 .01472 L
.87306 .01472 L
Mistroke
.87427 .01472 L
.87559 .01472 L
.87684 .01472 L
.87799 .01472 L
.87914 .01472 L
.88017 .01472 L
.88137 .01472 L
.88249 .01472 L
.88373 .01472 L
.88503 .01472 L
.88615 .01472 L
.88737 .01472 L
.88868 .01472 L
.88942 .01472 L
.89009 .01472 L
.89139 .01472 L
.89263 .01472 L
.89368 .01472 L
.89484 .01472 L
.89605 .01472 L
.89719 .01472 L
.89825 .01472 L
.89922 .01472 L
.90029 .01472 L
.90141 .01472 L
.90255 .01472 L
.90377 .01472 L
.90492 .01472 L
.90596 .01472 L
.90719 .01472 L
.90789 .01472 L
.90852 .01472 L
.9097 .01472 L
.91094 .01472 L
.91216 .01472 L
.91284 .01472 L
.91348 .01472 L
.91464 .01472 L
.91589 .01472 L
.91699 .01472 L
.91803 .01472 L
.91917 .01472 L
.9204 .01472 L
.92163 .01472 L
.92233 .01472 L
.92297 .01472 L
.92429 .01472 L
.92502 .01472 L
.92569 .01472 L
.92689 .01472 L
Mistroke
.92819 .01472 L
.92941 .01472 L
.93055 .01472 L
.9316 .01472 L
.93273 .01472 L
.9338 .01472 L
.93478 .01472 L
.93592 .01472 L
.93717 .01472 L
.93835 .01472 L
.93944 .01472 L
.94068 .01472 L
.94184 .01472 L
.94288 .01472 L
.94401 .01472 L
.94524 .01472 L
.94654 .01472 L
.94765 .01472 L
.94887 .01472 L
.94975 .01472 L
.95057 .01472 L
.95146 .01472 L
.95241 .01472 L
.95324 .01472 L
.95401 .01472 L
.95486 .01472 L
.95577 .01472 L
.95653 .01472 L
.95737 .01472 L
.95824 .01472 L
.95905 .01472 L
.95981 .01472 L
.9605 .01472 L
.9613 .01472 L
.96206 .01472 L
.96287 .01472 L
.96377 .01472 L
.96471 .01472 L
.96559 .01472 L
.96641 .01472 L
.96716 .01472 L
.96802 .01472 L
.96884 .01472 L
.96972 .01472 L
.97067 .01472 L
.97155 .01472 L
.97236 .01472 L
.97331 .01472 L
.97433 .01472 L
.9753 .01472 L
Mistroke
.97619 .01472 L
Mfstroke
.02381 .42812 m
.06244 .43152 L
.10458 .43513 L
.14415 .43841 L
.18221 .44148 L
.22272 .44465 L
.26171 .44762 L
.30316 .45068 L
.34309 .45355 L
.3815 .45623 L
.42237 .45901 L
.46172 .46162 L
.49955 .46406 L
.53984 .46659 L
.57861 .46897 L
.61984 .47143 L
.65954 .47375 L
.69774 .47592 L
.73838 .47817 L
.77751 .48029 L
.81909 .48249 L
.85916 .48455 L
.89771 .48649 L
.93871 .48851 L
.97619 .49032 L
s
.207 .44199 m
.20818 .43557 L
.20944 .43217 L
.21063 .42972 L
.21334 .42531 L
.21786 .41968 L
.22272 .4148 L
.24308 .39981 L
.26171 .38956 L
.30142 .37246 L
.33961 .35927 L
.38026 .3473 L
.41939 .33716 L
.46097 .32749 L
.50104 .31902 L
.53959 .3115 L
.58059 .30407 L
.62008 .29739 L
.65805 .29136 L
.69847 .2853 L
.73738 .27978 L
.77874 .27422 L
.81859 .26913 L
.85692 .26446 L
.8977 .25971 L
.93697 .25534 L
.97472 .2513 L
.97619 .25115 L
s
.207 .44486 m
.20818 .45119 L
.20944 .45449 L
.21063 .45685 L
.21334 .46104 L
.21786 .46633 L
.22272 .47083 L
.24308 .48426 L
.26171 .4931 L
.30142 .50727 L
.33961 .51771 L
.38026 .52683 L
.41939 .5343 L
.46097 .54122 L
.50104 .54711 L
.53959 .55221 L
.58059 .55712 L
.62008 .56144 L
.65805 .56526 L
.69847 .56903 L
.73738 .57239 L
.77874 .57571 L
.81859 .57869 L
.85692 .58139 L
.8977 .58408 L
.93697 .58652 L
.97472 .58873 L
.97619 .58881 L
s
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04588 .01472 L
.04652 .01472 L
.04722 .01472 L
.04797 .01472 L
.04862 .01472 L
.04933 .01472 L
.05061 .01472 L
.05186 .01472 L
.05302 .01472 L
.05414 .01472 L
.05519 .01472 L
.05634 .01472 L
.05759 .01472 L
.05882 .01472 L
.06012 .01472 L
.06123 .01472 L
.06244 .01472 L
.06315 .01472 L
.06381 .01472 L
.06453 .01472 L
.06529 .01472 L
.06657 .01472 L
.06729 .01472 L
.06797 .01472 L
.06924 .01472 L
.0704 .01472 L
.07103 .01472 L
.07173 .01472 L
.073 .01472 L
Mistroke
.07376 .01472 L
.07448 .01472 L
.07513 .01472 L
.07583 .01472 L
.0766 .01472 L
.0774 .01472 L
.07809 .01472 L
.07885 .01472 L
.07956 .01472 L
.0802 .01472 L
.08095 .01472 L
.08166 .01472 L
.08291 .01472 L
.08362 .01472 L
.08427 .01472 L
.08544 .01472 L
.08669 .01472 L
.08787 .01472 L
.08896 .01472 L
.09016 .01472 L
.09148 .01472 L
.09214 .01472 L
.09285 .01472 L
.09413 .01472 L
.09483 .01472 L
.09548 .01472 L
.09619 .01472 L
.09695 .01472 L
.09821 .01472 L
.09893 .01472 L
.09961 .01472 L
.10086 .01472 L
.10201 .01472 L
.10333 .01472 L
.10458 .01472 L
.10572 .01472 L
.10694 .01472 L
.1081 .01472 L
.10916 .01472 L
.11033 .01472 L
.11162 .01472 L
.11227 .01472 L
.11297 .01472 L
.11422 .01472 L
.11491 .01472 L
.11554 .01472 L
.11624 .01472 L
.11698 .01472 L
.11822 .01472 L
.11892 .01472 L
Mistroke
.11958 .01472 L
.12081 .01472 L
.12194 .01472 L
.12323 .01472 L
.12446 .01472 L
.12562 .01472 L
.12668 .01472 L
.12789 .01472 L
.12903 .01472 L
.13009 .01472 L
.13107 .01472 L
.13214 .01472 L
.13327 .01472 L
.13441 .01472 L
.13564 .01472 L
.1368 .01472 L
.13785 .01472 L
.13909 .01472 L
.13979 .01472 L
.14043 .01472 L
.14162 .01472 L
.14288 .01472 L
.14402 .01472 L
.14526 .01472 L
.14656 .01472 L
.14777 .01472 L
.14891 .01472 L
.14994 .01472 L
.15113 .01472 L
.15226 .01472 L
.15348 .01472 L
.15478 .01472 L
.15589 .01472 L
.15711 .01472 L
.15842 .01472 L
.15915 .01472 L
.15982 .01472 L
.16113 .01472 L
.16236 .01472 L
.16352 .01472 L
.16456 .01472 L
.16577 .01472 L
.1669 .01472 L
.16796 .01472 L
.16893 .01472 L
.16999 .01472 L
.17111 .01472 L
.17225 .01472 L
.17347 .01472 L
.17462 .01472 L
Mistroke
.17566 .01472 L
.17689 .01472 L
.17758 .01472 L
.17823 .01472 L
.1794 .01472 L
.18065 .01472 L
.18185 .01472 L
.18316 .01472 L
.18441 .01472 L
.18556 .01472 L
.1867 .01472 L
.18773 .01472 L
.18893 .01472 L
.19005 .01472 L
.19128 .01472 L
.19258 .01472 L
.19369 .01472 L
.19491 .01472 L
.19623 .01472 L
.19696 .01472 L
.19763 .01472 L
.19894 .01472 L
.20017 .01472 L
.20122 .01472 L
.20238 .01472 L
.20359 .01472 L
.20472 .01472 L
.20578 .01472 L
.20675 .01472 L
.20781 .01472 L
.20894 .01472 L
.21008 .01472 L
.21129 .01472 L
.21244 .01472 L
.21349 .01472 L
.21472 .01472 L
.21541 .01472 L
.21605 .01472 L
.21723 .01472 L
.21847 .01472 L
.21968 .01472 L
.221 .01472 L
.22224 .01472 L
.2234 .01472 L
.22454 .01472 L
.22558 .01472 L
.22677 .01472 L
.2279 .01472 L
.22914 .01472 L
.23044 .01472 L
Mistroke
.23155 .01472 L
.23277 .01472 L
.23409 .01472 L
.23482 .01472 L
.2355 .01472 L
.2368 .01472 L
.23804 .01472 L
.23909 .01472 L
.24025 .01472 L
.24146 .01472 L
.2426 .01472 L
.24365 .01472 L
.24462 .01472 L
.24569 .01472 L
.24681 .01472 L
.24795 .01472 L
.24917 .01472 L
.25032 .01472 L
.25137 .01472 L
.2526 .01472 L
.25329 .01472 L
.25393 .01472 L
.2551 .01472 L
.25635 .01472 L
.25756 .01472 L
.25888 .01472 L
.26013 .01472 L
.26129 .01472 L
.26233 .01472 L
.26348 .01472 L
.26467 .01472 L
.2658 .01472 L
.26704 .01472 L
.26835 .01472 L
.26946 .01472 L
.27068 .01472 L
.272 .01472 L
.27274 .01472 L
.27341 .01472 L
.27472 .01472 L
.27595 .01472 L
.27701 .01472 L
.27817 .01472 L
.27938 .01472 L
.28052 .01472 L
.28158 .01472 L
.28255 .01472 L
.28367 .01472 L
.28474 .01472 L
.28588 .01472 L
Mistroke
.2871 .01472 L
.28825 .01472 L
.2893 .01472 L
.29053 .01472 L
.29122 .01472 L
.29186 .01472 L
.29303 .01472 L
.29427 .01472 L
.29549 .01472 L
.29618 .01472 L
.29682 .01472 L
.29799 .01472 L
.29923 .01472 L
.30034 .01472 L
.30138 .01472 L
.30252 .01472 L
.30375 .01472 L
.30499 .01472 L
.30569 .01472 L
.30634 .01472 L
.30765 .01472 L
.30839 .01472 L
.30906 .01472 L
.31026 .01472 L
.31156 .01472 L
.31278 .01472 L
.31392 .01472 L
.31497 .01472 L
.31611 .01472 L
.31718 .01472 L
.31816 .01472 L
.3193 .01472 L
.32055 .01472 L
.32173 .01472 L
.32282 .01472 L
.32406 .01472 L
.32522 .01472 L
.32626 .01472 L
.32739 .01472 L
.32862 .01472 L
.32992 .01472 L
.33103 .01472 L
.33225 .01472 L
.33356 .01472 L
.33477 .01472 L
.33541 .01472 L
.3361 .01472 L
.33683 .01472 L
.33751 .01472 L
.33876 .01472 L
Mistroke
.33991 .01472 L
.34123 .01472 L
.34249 .01472 L
.3436 .01472 L
.3448 .01472 L
.34592 .01472 L
.34694 .01472 L
.34814 .01472 L
.34945 .01472 L
.35067 .01472 L
.35181 .01472 L
.35302 .01472 L
.35431 .01472 L
.35554 .01472 L
.35665 .01472 L
.35796 .01472 L
.3587 .01472 L
.35939 .01472 L
.36064 .01472 L
.36128 .01472 L
.36198 .01472 L
.36266 .01472 L
.36337 .01472 L
.36465 .01472 L
.36536 .01472 L
.36602 .01472 L
.36675 .01472 L
.36753 .01472 L
.3682 .01472 L
.36893 .01472 L
.36962 .01472 L
.37026 .01472 L
.37146 .01472 L
.37274 .01472 L
.37394 .01472 L
.37526 .01472 L
.37651 .01472 L
.37766 .01472 L
.3788 .01472 L
.37984 .01472 L
.38103 .01472 L
.38216 .01472 L
.38339 .01472 L
.3847 .01472 L
.38581 .01472 L
.38703 .01472 L
.38834 .01472 L
.38908 .01472 L
.38975 .01472 L
.39106 .01472 L
Mistroke
.39229 .01472 L
.39334 .01472 L
.3945 .01472 L
.39571 .01472 L
.39685 .01472 L
.39791 .01472 L
.39888 .01472 L
.39994 .01472 L
.40106 .01472 L
.40221 .01472 L
.40342 .01472 L
.40457 .01472 L
.40562 .01472 L
.40685 .01472 L
.40754 .01472 L
.40818 .01472 L
.40936 .01472 L
.4106 .01472 L
.41181 .01472 L
.41313 .01472 L
.41438 .01472 L
.41554 .01472 L
.41669 .01472 L
.41772 .01472 L
.41892 .01472 L
.42005 .01472 L
.42129 .01472 L
.42259 .01472 L
.42371 .01472 L
.42493 .01472 L
.42624 .01472 L
.42698 .01472 L
.42765 .01472 L
.42896 .01472 L
.43019 .01472 L
.43125 .01472 L
.43241 .01472 L
.43362 .01472 L
.43476 .01472 L
.43582 .01472 L
.43679 .01472 L
.43791 .01472 L
.43898 .01472 L
.44012 .01472 L
.44134 .01472 L
.44249 .01472 L
.44354 .01472 L
.44477 .01472 L
.44546 .01472 L
.4461 .01472 L
Mistroke
.44727 .01472 L
.44851 .01472 L
.44973 .01472 L
.45042 .01472 L
.45106 .01472 L
.45223 .01472 L
.45347 .01472 L
.45458 .01472 L
.45562 .01472 L
.45676 .01472 L
.45799 .01472 L
.45922 .01472 L
.45992 .01472 L
.46057 .01472 L
.46188 .01472 L
.46262 .01472 L
.46329 .01472 L
.46449 .01472 L
.46579 .01472 L
.46702 .01472 L
.46815 .01472 L
.4692 .01472 L
.47034 .01472 L
.47141 .01472 L
.47239 .01472 L
.47353 .01472 L
.47478 .01472 L
.47596 .01472 L
.47705 .01472 L
.47829 .01472 L
.47945 .01472 L
.48049 .01472 L
.48162 .01472 L
.48285 .01472 L
.48415 .01472 L
.48526 .01472 L
.48648 .01472 L
.48779 .01472 L
.489 .01472 L
.48963 .01472 L
.49033 .01472 L
.49105 .01472 L
.49174 .01472 L
.49299 .01472 L
.49413 .01472 L
.49539 .01472 L
.49671 .01472 L
.49783 .01472 L
.49902 .01472 L
.50014 .01472 L
Mistroke
.50116 .01472 L
.50236 .01472 L
.50366 .01472 L
.50489 .01472 L
.50603 .01472 L
.50723 .01472 L
.50853 .01472 L
.50975 .01472 L
.51087 .01472 L
.51218 .01472 L
.51292 .01472 L
.51361 .01472 L
.51486 .01472 L
.5155 .01472 L
.5162 .01472 L
.51687 .01472 L
.51759 .01472 L
.51886 .01472 L
.51958 .01472 L
.52024 .01472 L
.52096 .01472 L
.52174 .01472 L
.52241 .01472 L
.52314 .01472 L
.52383 .01472 L
.52447 .01472 L
.52568 .01472 L
.52695 .01472 L
.52816 .01472 L
.52947 .01472 L
.53072 .01472 L
.53187 .01472 L
.53301 .01472 L
.53405 .01472 L
.53525 .01472 L
.53637 .01472 L
.5376 .01472 L
.53891 .01472 L
.54002 .01472 L
.54124 .01472 L
.54255 .01472 L
.54329 .01472 L
.54396 .01472 L
.54526 .01472 L
.5465 .01472 L
.54755 .01472 L
.54871 .01472 L
.54992 .01472 L
.55105 .01472 L
.55211 .01472 L
Mistroke
.55308 .01472 L
.55415 .01472 L
.55527 .01472 L
.55641 .01472 L
.55763 .01472 L
.55878 .01472 L
.55982 .01472 L
.56105 .01472 L
.56175 .01472 L
.56238 .01472 L
.56356 .01472 L
.5648 .01472 L
.56601 .01472 L
.56734 .01472 L
.56858 .01472 L
.56974 .01472 L
.57088 .01472 L
.57192 .01472 L
.57312 .01472 L
.57425 .01472 L
.57548 .01472 L
.57679 .01472 L
.5779 .01472 L
.57912 .01472 L
.58044 .01472 L
.58118 .01472 L
.58185 .01472 L
.58315 .01472 L
.58439 .01472 L
.58544 .01472 L
.5866 .01472 L
.58782 .01472 L
.58895 .01472 L
.59001 .01472 L
.59098 .01472 L
.5921 .01472 L
.59317 .01472 L
.59431 .01472 L
.59553 .01472 L
.59668 .01472 L
.59773 .01472 L
.59896 .01472 L
.59965 .01472 L
.60029 .01472 L
.60146 .01472 L
.60271 .01472 L
.60392 .01472 L
.60461 .01472 L
.60525 .01472 L
.60642 .01472 L
Mistroke
.60766 .01472 L
.60876 .01472 L
.6098 .01472 L
.61094 .01472 L
.61217 .01472 L
.61341 .01472 L
.6141 .01472 L
.61475 .01472 L
.61607 .01472 L
.6168 .01472 L
.61747 .01472 L
.61867 .01472 L
.61997 .01472 L
.6212 .01472 L
.62233 .01472 L
.62339 .01472 L
.62452 .01472 L
.62559 .01472 L
.62657 .01472 L
.62771 .01472 L
.62896 .01472 L
.63014 .01472 L
.63123 .01472 L
.63247 .01472 L
.63363 .01472 L
.63467 .01472 L
.6358 .01472 L
.63703 .01472 L
.63833 .01472 L
.63944 .01472 L
.64066 .01472 L
.64197 .01472 L
.64318 .01472 L
.64381 .01472 L
.6445 .01472 L
.64523 .01472 L
.64591 .01472 L
.64716 .01472 L
.64831 .01472 L
.64956 .01472 L
.65088 .01472 L
.652 .01472 L
.65319 .01472 L
.65431 .01472 L
.65533 .01472 L
.65653 .01472 L
.65784 .01472 L
.65906 .01472 L
.6602 .01472 L
.6614 .01472 L
Mistroke
.6627 .01472 L
.66392 .01472 L
.66504 .01472 L
.66635 .01472 L
.66709 .01472 L
.66777 .01472 L
.66903 .01472 L
.66966 .01472 L
.67036 .01472 L
.67104 .01472 L
.67175 .01472 L
.67303 .01472 L
.67374 .01472 L
.6744 .01472 L
.67513 .01472 L
.67591 .01472 L
.67658 .01472 L
.67731 .01472 L
.678 .01472 L
.67864 .01472 L
.67984 .01472 L
.68112 .01472 L
.68232 .01472 L
.68364 .01472 L
.68488 .01472 L
.68603 .01472 L
.68718 .01472 L
.68821 .01472 L
.68941 .01472 L
.69053 .01472 L
.69176 .01472 L
.69307 .01472 L
.69418 .01472 L
.6954 .01472 L
.69671 .01472 L
.69745 .01472 L
.69812 .01472 L
.69942 .01472 L
.70066 .01472 L
.70171 .01472 L
.70286 .01472 L
.70407 .01472 L
.70521 .01472 L
.70627 .01472 L
.70724 .01472 L
.7083 .01472 L
.70942 .01472 L
.71056 .01472 L
.71178 .01472 L
.71293 .01472 L
Mistroke
.71398 .01472 L
.71521 .01472 L
.7159 .01472 L
.71654 .01472 L
.71771 .01472 L
.71896 .01472 L
.72017 .01472 L
.72149 .01472 L
.72273 .01472 L
.72389 .01472 L
.72503 .01472 L
.72607 .01472 L
.72727 .01472 L
.7284 .01472 L
.72963 .01472 L
.73094 .01472 L
.73205 .01472 L
.73327 .01472 L
.73458 .01472 L
.73532 .01472 L
.73599 .01472 L
.7373 .01472 L
.73853 .01472 L
.73959 .01472 L
.74075 .01472 L
.74196 .01472 L
.7431 .01472 L
.74416 .01472 L
.74513 .01472 L
.74619 .01472 L
.74731 .01472 L
.74846 .01472 L
.74967 .01472 L
.75083 .01472 L
.75187 .01472 L
.7531 .01472 L
.75379 .01472 L
.75443 .01472 L
.75561 .01472 L
.75685 .01472 L
.75806 .01472 L
.75875 .01472 L
.75939 .01472 L
.76056 .01472 L
.7618 .01472 L
.7629 .01472 L
.76394 .01472 L
.76508 .01472 L
.76631 .01472 L
.76754 .01472 L
Mistroke
.76824 .01472 L
.76889 .01472 L
.7702 .01472 L
.77094 .01472 L
.77161 .01472 L
.7728 .01472 L
.7741 .01472 L
.77533 .01472 L
.77646 .01472 L
.77752 .01472 L
.77865 .01472 L
.77972 .01472 L
.7807 .01472 L
.78184 .01472 L
.78309 .01472 L
.78427 .01472 L
.78536 .01472 L
.7866 .01472 L
.78776 .01472 L
.7888 .01472 L
.78993 .01472 L
.79116 .01472 L
.79246 .01472 L
.79357 .01472 L
.79479 .01472 L
.7961 .01472 L
.7973 .01472 L
.79793 .01472 L
.79863 .01472 L
.79936 .01472 L
.80004 .01472 L
.80129 .01472 L
.80243 .01472 L
.80369 .01472 L
.80501 .01472 L
.80612 .01472 L
.80731 .01472 L
.80843 .01472 L
.80945 .01472 L
.81066 .01472 L
.81196 .01472 L
.81318 .01472 L
.81432 .01472 L
.81552 .01472 L
.81682 .01472 L
.81804 .01472 L
.81916 .01472 L
.82047 .01472 L
.8212 .01472 L
.82189 .01472 L
Mistroke
.82315 .01472 L
.82385 .01472 L
.82448 .01472 L
.82516 .01472 L
.82587 .01472 L
.82715 .01472 L
.82786 .01472 L
.82852 .01472 L
.82925 .01472 L
.83002 .01472 L
.8307 .01472 L
.83143 .01472 L
.83212 .01472 L
.83275 .01472 L
.83396 .01472 L
.83524 .01472 L
.83644 .01472 L
.83775 .01472 L
.839 .01472 L
.84015 .01472 L
.84129 .01472 L
.84232 .01472 L
.84352 .01472 L
.84464 .01472 L
.84587 .01472 L
.84718 .01472 L
.84829 .01472 L
.8495 .01472 L
.85082 .01472 L
.85155 .01472 L
.85222 .01472 L
.85353 .01472 L
.85476 .01472 L
.85581 .01472 L
.85697 .01472 L
.85818 .01472 L
.85932 .01472 L
.86037 .01472 L
.86134 .01472 L
.86241 .01472 L
.86353 .01472 L
.86467 .01472 L
.86589 .01472 L
.86704 .01472 L
.86808 .01472 L
.86931 .01472 L
.87 .01472 L
.87064 .01472 L
.87182 .01472 L
.87306 .01472 L
Mistroke
.87427 .01472 L
.87559 .01472 L
.87684 .01472 L
.87799 .01472 L
.87914 .01472 L
.88017 .01472 L
.88137 .01472 L
.88249 .01472 L
.88373 .01472 L
.88503 .01472 L
.88615 .01472 L
.88737 .01472 L
.88868 .01472 L
.88942 .01472 L
.89009 .01472 L
.89139 .01472 L
.89263 .01472 L
.89368 .01472 L
.89484 .01472 L
.89605 .01472 L
.89719 .01472 L
.89825 .01472 L
.89922 .01472 L
.90029 .01472 L
.90141 .01472 L
.90255 .01472 L
.90377 .01472 L
.90492 .01472 L
.90596 .01472 L
.90719 .01472 L
.90789 .01472 L
.90852 .01472 L
.9097 .01472 L
.91094 .01472 L
.91216 .01472 L
.91284 .01472 L
.91348 .01472 L
.91464 .01472 L
.91589 .01472 L
.91699 .01472 L
.91803 .01472 L
.91917 .01472 L
.9204 .01472 L
.92163 .01472 L
.92233 .01472 L
.92297 .01472 L
.92429 .01472 L
.92502 .01472 L
.92569 .01472 L
.92689 .01472 L
Mistroke
.92819 .01472 L
.92941 .01472 L
.93055 .01472 L
.9316 .01472 L
.93273 .01472 L
.9338 .01472 L
.93478 .01472 L
.93592 .01472 L
.93717 .01472 L
.93835 .01472 L
.93944 .01472 L
.94068 .01472 L
.94184 .01472 L
.94288 .01472 L
.94401 .01472 L
.94524 .01472 L
.94654 .01472 L
.94765 .01472 L
.94887 .01472 L
.94975 .01472 L
.95057 .01472 L
.95146 .01472 L
.95241 .01472 L
.95324 .01472 L
.95401 .01472 L
.95486 .01472 L
.95577 .01472 L
.95653 .01472 L
.95737 .01472 L
.95824 .01472 L
.95905 .01472 L
.95981 .01472 L
.9605 .01472 L
.9613 .01472 L
.96206 .01472 L
.96287 .01472 L
.96377 .01472 L
.96471 .01472 L
.96559 .01472 L
.96641 .01472 L
.96716 .01472 L
.96802 .01472 L
.96884 .01472 L
.96972 .01472 L
.97067 .01472 L
.97155 .01472 L
.97236 .01472 L
.97331 .01472 L
.97433 .01472 L
.9753 .01472 L
Mistroke
.97619 .01472 L
Mfstroke
.02381 .42812 m
.06244 .43152 L
.10458 .43513 L
.14415 .43841 L
.18221 .44148 L
.22272 .44465 L
.26171 .44762 L
.30316 .45068 L
.34309 .45355 L
.3815 .45623 L
.42237 .45901 L
.46172 .46162 L
.49955 .46406 L
.53984 .46659 L
.57861 .46897 L
.61984 .47143 L
.65954 .47375 L
.69774 .47592 L
.73838 .47817 L
.77751 .48029 L
.81909 .48249 L
.85916 .48455 L
.89771 .48649 L
.93871 .48851 L
.97619 .49032 L
s
.207 .44199 m
.20818 .43557 L
.20944 .43217 L
.21063 .42972 L
.21334 .42531 L
.21786 .41968 L
.22272 .4148 L
.24308 .39981 L
.26171 .38956 L
.30142 .37246 L
.33961 .35927 L
.38026 .3473 L
.41939 .33716 L
.46097 .32749 L
.50104 .31902 L
.53959 .3115 L
.58059 .30407 L
.62008 .29739 L
.65805 .29136 L
.69847 .2853 L
.73738 .27978 L
.77874 .27422 L
.81859 .26913 L
.85692 .26446 L
.8977 .25971 L
.93697 .25534 L
.97472 .2513 L
.97619 .25115 L
s
.207 .44486 m
.20818 .45119 L
.20944 .45449 L
.21063 .45685 L
.21334 .46104 L
.21786 .46633 L
.22272 .47083 L
.24308 .48426 L
.26171 .4931 L
.30142 .50727 L
.33961 .51771 L
.38026 .52683 L
.41939 .5343 L
.46097 .54122 L
.50104 .54711 L
.53959 .55221 L
.58059 .55712 L
.62008 .56144 L
.65805 .56526 L
.69847 .56903 L
.73738 .57239 L
.77874 .57571 L
.81859 .57869 L
.85692 .58139 L
.8977 .58408 L
.93697 .58652 L
.97472 .58873 L
.97619 .58881 L
s
.6186 .2968 m
.61984 .29136 L
.62103 .2889 L
.62214 .28712 L
.62467 .28392 L
.62977 .27914 L
.63891 .27288 L
.64887 .26762 L
.65954 .26296 L
.70091 .24948 L
.74075 .23996 L
.77908 .23248 L
.81986 .2257 L
.85913 .21999 L
.89688 .21508 L
.93708 .21035 L
.97577 .20619 L
.97619 .20614 L
s
.6186 .29848 m
.61984 .30398 L
.62103 .30651 L
.62214 .30835 L
.62467 .31168 L
.62977 .31674 L
.63891 .32348 L
.65954 .33448 L
.69845 .34927 L
.73981 .3613 L
.77966 .37097 L
.81799 .37912 L
.85877 .38687 L
.89804 .39365 L
.93579 .39966 L
.97599 .4056 L
.97619 .40563 L
s
.6186 .56093 m
.61984 .55869 L
.62103 .55767 L
.62214 .55694 L
.62467 .55563 L
.62977 .55368 L
.63891 .55117 L
.64887 .54909 L
.65954 .54728 L
.67936 .5446 L
.70091 .5423 L
.74075 .53906 L
.78153 .53663 L
.8208 .53484 L
.85855 .53351 L
.89875 .5324 L
.93744 .53159 L
.97619 .53098 L
s
.6186 .56163 m
.61984 .56391 L
.62103 .56496 L
.62214 .56572 L
.62467 .5671 L
.62977 .56919 L
.63891 .57197 L
.65954 .57645 L
.6799 .57981 L
.69845 .58237 L
.7383 .58691 L
.77663 .5905 L
.81741 .59376 L
.85668 .59652 L
.89443 .59889 L
.93463 .60117 L
.97332 .60318 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00k@3oool0103ooml0W4P00018W03Ooono0?ooo`00kP3oool00`3o_g@0
001d0;ooo`2o0?ooo`00kP3oool00`3ookl0M00007Boo`2o0?ooo`00k`3oool00`2oM00007Bo0?oo
o`2n0?ooo`00k`3oool02P3OW4P004Qd07A800000000001809cOo`2oM00000000000B02Lgong0?oo
o`00k`3oool02P3ogi`0B000001d_`3oool0oooO09a800000000B9cO0?oog`2o_mng0?ooo`00k`3o
ool00`3ookl0M00004RLg`020?ooo`030?oog`2LB00007Bo0;T0oooo003`0?ooo`030;md0000M;l0
oooo0080oooo00<0_g@00000M02oool0^03oool00?00oooo00<0okmd0018W03Oool00P3oool00`3o
_g@0001809cOo`2h0?ooo`00l03oool00`3ogi`0B01809cOo`020?ooo`030?oo_`1d0000B9cO0;P0
oooo003`0?ooo`030?oog`2LB000M;oo0080oooo00<0oooO09a80000M;l0^03oool00?40oooo00<0
_g@0001d_`3oool00P3oool00`3OW4P0001d0;ooo`2g0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00F03oool00`2o
M0000000000000040000000604RLg`3oool0oooo0?noM0000000M;oo0`3oool01@3OW4P000000000
00000000B9cO02T0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0Y0?ooo`030?oo
_`1d000000000080000000<0M;oo0?ooo`3oool00P3oool01@3o_g@0000007Boo`3oool0_g@000H0
000000<0B9cO0?ooo`3oool0803oool00`3ookl0M000000000020000000307Boo`3oool0oooo0080
oooo00<0okmd0000001d_ol01@3oool0103ooml0W4P00018W03OoolQ0?ooo`030?oo_`1d00000000
0080000000<0M;oo0?ooo`3oool00P3oool00`3o_g@0000007Boo`030?ooo`050?oOW01800000000
0000001d_ol08`3oool00`3ookl0M000000000020000000307Boo`3oool0oooo0080oooo00<0okmd
0000001d_ol00`3oool01@3OW4P00000000000000000B9cO02d0oooo001I0?ooo`030=nLB0000000
000000<0000000H004RL0=ooo`3oool0okmd0000001d_ol20?ooo`070=nLB0000000M;oo0?ooo`3o
oml0W4P004RLg`0X0?ooo`030?oOW0180000B9cO0080oooo00<0_g@004RLg`3oool0:@3oool00`3o
gi`0B00004RLg`020?ooo`030;md0018W=l0oooo0080oooo00<0okmd0000001d_ol00P3oool00`3O
W4P0000000000003000000030018W03Oool0oooo0200oooo00<0omnL04P00018W=l00P3oool00`2o
M000B9cO0?ooo`020?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo8@3oool0
0`3ogi`0B00004RLg`020?ooo`030;md0018W=l0oooo0080oooo00<0okmd0000001d_ol00P3oool0
1`3ogi`0B00004RLg`3oool0oono07@0001d_ol08P3oool00`3ogi`0B00004RLg`020?ooo`030;md
0018W=l0oooo0080oooo00<0okmd0000001d_ol00P3oool01`3OW4P0000007Boo`3oool0oooO09a8
0018W=l0;03oool005X0oooo00<0gia804RLg`3oool00P3oool00`3OW7@0W=oo0?ooo`040?ooo`03
0?oog`2LB00007Bo00<0oooo00<0okmd0018W03Oool0;03oool00`3ookl0M01809cOo`0^0?ooo`03
0?oo_`1d04P0W=oo00P0oooo00<0gia804RLg`3oool00P3oool00`3OW7@0W=oo0?ooo`0U0?ooo`03
0?oo_`1d04P0W=oo00X0oooo00@0oooO09a80000B9`0gooo9P3oool00`3ookl0M01809cOo`060?oo
o`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03Oool09P3oool00`3ookl0M01809cOo`060?oo
o`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03Oool0:`3oool005/0oooo00<0gia807Boo`3o
ool02@3oool00`2oM00007Bo0?ooo`020?ooo`030;md0000B9`0gooo02`0oooo00<0oono07@0001d
_ol0;P3oool00`3ookl0M00007Boo`090?ooo`030=nLB01d_ol0oooo02T0oooo00<0oono07@0001d
_ol01P3oool00`2oM0000000000000050000000307Boo`3oool0oooo02<0oooo00<0oono07@0001d
_ol01P3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo02H0oooo00<0oono07@0001d
_ol01`3oool00`2oM00007Bo0?ooo`020?ooo`030;md0000B9`0gooo02/0oooo001L0?ooo`030;md
B02Lgol0oooo00P0oooo00L0omnL04P0M02oool0oooo0;md00000000M;oo02d0oooo00<0okmd0000
001d_ol0;P3oool00`3o_g@0000007Boo`0:0?ooo`030;mdB02Lgol0oooo02P0oooo00<0okmd0000
001d_ol01P3oool0203ogi`0M9cO0?ooo`3oool0oooO09a80000B9`0gooo9P3oool00`3o_g@00000
07Boo`060?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol09P3oool00`3o_g@00000
07Boo`070?ooo`070?oOW01807@0_ooo0?ooo`2oM000000007Boo`0/0?ooo`00G03oool00`3ooml0
W4Qd0;ooo`090?ooo`050?oo_`1dB4P0B00000000018W=l0;@3oool0103ogi`0B0000000B02Lgol]
0?ooo`040?oOW0180000001809cOo`X0oooo00<0oooO09a8M02oool09`3oool0103ogi`0B0000000
B02Lgol70?ooo`070=nLB01d_ol0oooo0?oog`2LB00004RL0=ooo`0U0?ooo`040?oOW01800000018
09cOo`H0oooo00<0omnL04P0001d_ol00`3oool00`2oM000001809cOo`0U0?ooo`040?oOW0180000
001809cOo`P0oooo00D0oono07A8B0180000000004RLg`0]0?ooo`00G@3oool00`3o_g@007Bo0?oo
o`080?ooo`040?oOW01800000000001d_b`0oooo00D0okmd000000000000001809cOo`0/0?ooo`05
0?noM000000000000000B02Lgol0303oool00`3o_g@007Bo0?ooo`0T0?ooo`050?noM00000000000
0000B02Lgol0203oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool08`3oool01@3o_g@00000
0000000004P0W=oo00L0oooo00P0oono07@000000000B9cO0?ooo`3o_g@00000001d_b@0oooo00D0
okmd000000000000001809cOo`090?ooo`040?oOW01800000000001d_bh0oooo001M0?ooo`030?oo
_`1d04P0W=oo00L0oooo00H0omnL04P0000007@0_ooo0?noM000M;l]0?ooo`030;md0000M;l0oooo
02h0oooo00<0_g@0001d_`3oool0303oool00`3ookl0M01809cOo`0V0?ooo`030;md0000M;l0oooo
00T0oooo00H0omnL04Qd_`3ooml0W4P00018W03OoolU0?ooo`030;md0000M;l0oooo00P0oooo00<0
_g@00018W02oW4P00P0000000`00B9`0gooo0?ooo`0U0?ooo`030;md0000M;l0oooo00P0oooo00H0
omnL04P0000007@0_ooo0?noM000M;l]0?ooo`00G@3oool00`3ookl0M00004RLg`070?ooo`030;md
000007@0_ooo0080oooo00<0_g@004RLg`3oool0;03oool00`2oM000B9cO0?ooo`0^0?ooo`030;md
0018W=l0oooo00/0oooo00<0oono07@00018W=l09`3oool00`2oM000B9cO0?ooo`090?ooo`050=nL
B01d_ml0W4P00018W03Oool09P3oool00`2oM000B9cO0?ooo`070?ooo`030?oOW0180000M;oo02/0
oooo00<0_g@004RLg`3oool01`3oool00`2oM000001d0;ooo`020?ooo`030;md0018W=l0oooo02/0
oooo001H0?ooo`030?noW02Lgol0oooo0080oooo00<0omnL04P00018W=l01`3oool00`2oM00004RL
0=ooo`020?ooo`030=nLB000M;l0oooo02L0oooo00<0oooO09bL_`3oool00P3oool00`3OW4P0001d
0;ooo`0Y0?ooo`030?oog`2LW;l0oooo0080oooo00<0gia80000M02oool01P3oool00`3o_i`0W=oo
0?ooo`020?ooo`030?oOW0180000B9cO0280oooo00<0oooO09bL_`3oool00P3oool00`3OW4P0001d
0;ooo`090?ooo`050?oog`2LB4P0B4P00018W03Oool08@3oool00`3ooml0W9bo0?ooo`020?ooo`03
0=nLB00007@0_ooo00P0oooo00<0gia80000B02Lgol09@3oool00`3ooml0W9bo0?ooo`020?ooo`03
0=nLB00007@0_ooo00L0oooo00<0_g@00018W03Oool00P3oool00`3OW4P007Bo0?ooo`0[0?ooo`00
F03oool0203ooml0W4Q809cOo`3oool0oono07@0000007@0_ooo1`3oool01`3o_g@0000007Boo`3o
ool0oono07@0001d_ol0:@3oool01P3o_g@0B9cO0?ooo`3ookl0M000001d_b/0oooo00H0okmd04RL
g`3oool0oono07@00000M;l70?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02ooolS0?oo
o`060?noM018W=l0oooo0?oo_`1d000007Bo2`3oool0103ogi`0B0000018W03OoolR0?ooo`060?no
M018W=l0oooo0?oo_`1d000007Bo2P3oool00`3o_g@00000001d_`0U0?ooo`060?noM018W=l0oooo
0?oo_`1d000007Bo203oool01`3o_g@0000007Boo`3oool0oono07@0001d_ol0;03oool005T0oooo
00H0oooO09a80000000000000000M02oool90?ooo`050?noM0000000000000000018W=l0:`3oool0
1@3OW4P000000000000007@0_ooo02`0oooo00D0gia8000000000000001d0;ooo`080?ooo`060?oo
g`2LB00000000000000007@0_ooo9@3oool01@3OW4P000000000000007@0_ooo00`0oooo00<0gia8
0018W03Oool08`3oool01@3OW4P000000000000007@0_ooo00/0oooo00D0oooO09a800000000001d
0;ooo`0S0?ooo`050=nLB000000000000000M02oool02@3oool01@3o_g@00000000000000000B9cO
02d0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001>0?ooo`050?oOW0180000
00000000M02oool02@3ooooo0000038000008`3oool004d0oooo00L0oono07@0001d_ol0oooo0?no
M00007@0_ooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0240oooo001=0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3o
ool004`0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`070?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00C03oool00`3ogi`0B00007Boo`030?oo
o`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo
0240oooo001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool3000000@0
ooooo`00000S000000D0oooo0`00000S0?ooo`00C03oool00`3ogi`0B00007Boo`030?ooo`030?no
M00004P0W=oo00L0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo
001<0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool00`000000oooo0?oo
o`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool004`0oooo00<0oono07@00018W=l00`3oool0
0`3OW4P0001d0;ooo`070?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q
0?ooo`00C@3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00L0oooo00<000000?oo
o`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001=0?ooo`070?oo_`1d0000M;oo0?oo
o`3o_g@0001d0;ooo`080?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q
0?ooo`00CP3oool01@3ookl0M0000000000007@0_ooo00T0oooo00<000000?ooo`3oool0o`3oool^
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3o
ool08@3oool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo
001L0?ooo`800000o`3oool]0?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool0o`3oool^
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3o
ool08@3oool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo
001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool0
0`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?oo
o`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool200000?l0oooo;@3oool3000002<0oooo
001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool0
0`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?oo
o`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo
00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q
0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0
oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000
o`3oool]0?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q
0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0
oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo00110?ooo`050?oO
W018000000000000M02oool00`3oool01@3o_g@0000007Boo`3oool0_g@000H0000000<0B9cO0?oo
o`3oool01@3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool00400
oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool0
0`3OW4P0000000000003000000030018W03Oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool^
0?ooo`030000003oool0oooo0240oooo00100?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d
_`3oool01`3oool00`3OW4P0B9cO0?ooo`020?ooo`030=nLM02Lgol0oooo00D0oooo00<000000?oo
o`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool0203oool00`3OW4P0M;oo0?ooo`090?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?no
M00004P0W=oo00T0oooo00<0_gA809cOo`3oool0203oool00`000000oooo0?ooo`3o0?ooobh0oooo
00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cO
o`090?ooo`030?oog`2LB7@0_ooo00P0oooo0`00003o0?ooob`0oooo0`00000S0?ooo`00?`3oool0
0`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo00<0okmd001d_`3oool01`3oool0
0`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?oo_`1d04P0W=oo00L0oooo00<000000?oo
o`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gia80000M02oool02P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`3OW4P004RL0=ooo`020?ooo`030;md
0000M;l0oooo00D0oooo00<0oknL09cOo`3oool00P3oool00`3ogi`0B00004RLg`070?ooo`030000
003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M00007Bo
o`3oool0okmd0000M02oool01P3oool0203ooml0W4Q809cOo`3oool0oono07@0000007@0_ooo1`3o
ool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool00440oooo00D0oono
07@000000000001d0;ooo`080?ooo`060?oog`2LB00000000000000007@0_ooo203oool00`000000
oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0
o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3o
ool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<00000
0?ooo`3oool08@3oool005`0oooo0P00003o0?ooobd0oooo0`00000S0?ooo`00G03oool00`000000
oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0_gAd0;ooo`3oool0
103oool00`3OW9`0_ooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo
0?ooo`0Q0?ooo`00;03oool00`2oM7@0_ooo0?ooo`040?ooo`030;mdM02oool0oooo02H0oooo00<0
00000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo000X0?ooo`030?oo_`1d0000
000000P0000000<0001d0;ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<00000
0?ooo`3oool08@3oool002L0oooo00<0omnL04P0000000002@0000000`0007@0_ooo0?ooo`0V0?oo
o`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`009P3oool00`3ooml0
W7BL0=ooo`030?ooo`030;mdM02oool0oooo00@0oooo00<0_gAd0;ooo`3oool09P3oool00`000000
oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool002H0oooo00<0oono07Ad_`3oool0
0`3oool00`2oM7@0_ooo0?ooo`040?ooo`030=nLW02oool0oooo02H0oooo00<000000?ooo`3oool0
o`3oool^0?ooo`030000003oool0oooo0240oooo000V0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0oono07Ad_`3oool0103oool00`3OW9`0_ooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo
;P3oool00`000000oooo0?ooo`0Q0?ooo`009P3oool0103ooml0W3H000000018W=l20?ooo`030?no
M0000000000000@0000000<0001d0;ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooob40oooo
1P0000070?ooo`030000003oool0oooo0240oooo000V0?ooo`030?oog`2LB00007Bo00<0oooo00<0
_g@0000000000000100000000`0007@0_ooo0?ooo`0V0?ooo`800000o`3ooolI0?ooo`T000002`3o
ool3000002<0oooo000c0?ooo`030=nLW02oool0oooo02H0oooo00<000000?ooo`3oool0o`3ooolB
0?ooo`H000005P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?oo
o`T0oooo2@00000L0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;mdM02oool0oooo00@0
oooo00<0_gAd0;ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooo`40oooo2000000U0?ooo`03
0000003oool0oooo0240oooo000/0?ooo`030;md0018W=l0oooo00<0oooo00<0gia80000M02oool0
9`3oool00`000000oooo0?ooo`3j0?ooo`H00000;@3oool00`000000oooo0?ooo`0Q0?ooo`00;03o
ool02@2oM00000000000M02oool0oooO09a80018W=l0gibL0;ooo`0W0?ooo`030000003oool0oooo
0?@0oooo1P00000c0?ooo`030000003oool0oooo0240oooo000/0?ooo`060;nLW03Ogi`0B0000000
000004P0W=oo:P3oool00`000000oooo0?ooo`3^0?ooo`H00000>@3oool00`000000oooo0?ooo`0Q
0?ooo`00;03oool00`2oM7@0_mnL04P00002000000040000B02Lgol0gibL0;ooobL0oooo00<00000
0?ooo`3oool0j03oool6000003l0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0_g@00018
W03Oool00P3oool0102oM00000000000M02ooolW0?ooo`030000003oool0oooo0>80oooo1P000015
0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;mdB02Lgol0oooo00<0oooo00<0okmd0000
M02oool09`3oool200000=h0oooo1@0000190?ooo`<000008`3oool002`0oooo00<0_ibL0=ooo`3o
ool0103oool00`3OW9`0_ooo0?ooo`0V0?ooo`030000003oool0oooo0=T0oooo1000001@0?ooo`03
0000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0=D0oooo1000001D0?ooo`030000
003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0=40oooo1000001H0?ooo`030000003o
ool0oooo0240oooo000]0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool09`3oool0
0`000000oooo0?ooo`3>0?ooo`<00000C`3oool6000000L0oooo00<000000?ooo`3oool08@3oool0
02`0oooo00<0omnL04P000000000100000000`18W=l0oooo0?ooo`0;0?ooo`050?oOW01800000000
0000M02oool00`3oool00`3o_g@0000007Boo`050?ooo`040?oog`2LB00004RL0=ooo`L0oooo00<0
00000?ooo`3oool0bP3oool4000004H0oooo3000000=0?ooo`030000003oool0oooo0240oooo000/
0?ooo`090=nLM02Lgol0okmd07Boo`3oool0okmd0000000007@0_ooo00/0oooo00L0oono07@0001d
_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol01@3oool0103ooml0W4P00018W03O
ool70?ooo`030000003oool0oooo0<L0oooo0`0000110?ooo`T000006@3oool00`000000oooo0?oo
o`0Q0?ooo`00;03oool0102oM4P0W=oo0?noM01d_ol20?ooo`030=nLB00007@0_ooo00/0oooo00<0
_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`090?ooo`040?oog`2LB00004RL0=ooo`L0oooo
00<000000?ooo`3oool0a@3oool2000003h0oooo1P00000R0?ooo`030000003oool0oooo0240oooo
000/0?ooo`040?noM0000000000007Boo`80oooo00<0_g@0001d_`3oool02P3oool00`3ookl0M000
04RLg`030?ooo`030=nLB00007@0_ooo00D0oooo00<0_g@00000000000001@0000000`1d_ol0oooo
0?ooo`040?ooo`030000003oool0oooo0<<0oooo0P00000g0?ooo`T00000:03oool00`000000oooo
0?ooo`0Q0?ooo`00;@3oool01P3OW4P0000007Boo`3o_g@00000001d_``0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`050?ooo`080?oOW01dW=l0oooo0?ooo`3ooml0W4P00018W03O
ool70?ooo`030000003oool0oooo0<40oooo0P00000`0?ooo`T00000<@3oool00`000000oooo0?oo
o`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0gia8
07Boo`3oool0oooO09a80000B9`0gooo00L0oooo0`00002o0?ooo`800000;03oool6000003P0oooo
0`00000S0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0
oooO09a8M02oool0oooO09a80000B9`0gooo00L0oooo00<000000?ooo`3oool0_@3oool2000002D0
oooo2@0000100?ooo`030000003oool0oooo0240oooo000^0?ooo`050;md00000000000000000018
W=l0303oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00H0omnL04Qd_`3o
oml0W4P00018W03Oool70?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0703oool9
000004T0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0oono07@000000000100000000`18
W=l0oooo0?ooo`090?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool01@3O
W4P0M;oO09a80000B9`0gooo00L0oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G
0?ooo`H00000DP3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`3OW4P007Bo0?ooo`020?oo
o`040?oo_`1d0000001d0;ooo`/0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`08
0?ooo`050?oog`2LB4P0B4P00018W03Oool01`3oool00`000000oooo0?ooo`2k0?ooo`030000003o
ool0oooo0140oooo1P00001H0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;mdM02oool0
oooo00<0oooo00<0oono07@0M02oool02`3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool0
2P3oool0103ogi`0B0000018W03Oool70?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0303oool6000005h0oooo00<000000?ooo`3oool08@3oool002L0oooo00<0oknL09cOo`3oool0
0P3oool00`3ogi`0W;oo0?ooo`030?ooo`030?noW02Lgol0oooo00`0oooo00D0oono07@000000000
001d0;ooo`0<0?ooo`030=nLB000B9`0gooo00L0oooo00<000000?ooo`3oool0^@3oool00`000000
oooo0?ooo`070?ooo`H00000I03oool00`000000oooo0?ooo`0Q0?ooo`009`3oool00`2oM0000000
00000009000000030000M02oool0oooo02H0oooo00<000000?ooo`3oool0^@3oool010000000oooo
0?ooo`3oool6000006X0oooo00<000000?ooo`3oool08@3oool002H0oooo00<0oono07@000000000
2P0000000`00M;l0oooo0?ooo`0V0?ooo`030000003oool0oooo0;L0oooo1P00001`0?ooo`030000
003oool0oooo0240oooo000b0?ooo`030?oOW02L_ol0oooo02L0oooo00<000000?ooo`3oool0/@3o
ool600000080oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool2
00000:`0oooo1P0000080?ooo`030000003oool0oooo06l0oooo0`00000S0?ooo`00G03oool00`00
0000oooo0?ooo`2U0?ooo`H000003`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo09l0oooo1P00000F0?ooo`030000003oool0oooo06l0
oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0V@3oool6000001`0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?oo
o`2D0?ooo`D000008`3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0240oooo000/
0?ooo`030?oog`2LW;l0oooo00P0oooo00<0_ibL0=ooo`3oool08P3oool00`000000oooo0?ooo`2@
0?ooo`@00000:@3oool2000006h0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0omnL04P0
00000000200000000`00B9`0gooo0?ooo`0R0?ooo`030000003oool0oooo08`0oooo1000000_0?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0gia800000000
0000200000000`00B9`0gooo0?ooo`0R0?ooo`030000003oool0oooo08L0oooo1@00000d0?ooo`80
0000J`3oool00`000000oooo0?ooo`0Q0?ooo`00;@3oool00`2oM7@0_ooo0?ooo`020?ooo`030?oo
g`2LW;l0oooo0080oooo00<0_ibL0=ooo`3oool08P3oool00`000000oooo0?ooo`230?ooo`@00000
>`3oool2000006T0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0gia8001d_`3oool0103o
ool00`3OW9`0_ooo0?ooo`0V0?ooo`030000003oool0oooo07l0oooo100000110?ooo`<00000IP3o
ool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`2oM000000007Boo`030?ooo`030?oOW018B9`0
gooo02L0oooo0P00001l0?ooo`@00000B03oool200000680oooo0`00000S0?ooo`00;03oool00`3o
_g@00000000000040000000307Boo`3oool0oooo02H0oooo00<000000?ooo`3oool0M`3oool40000
04h0oooo0P00001R0?ooo`030000003oool0oooo0240oooo000]0?ooo`060?oOW018000000000000
000004P0W=oo:@3oool00`000000oooo0?ooo`1c0?ooo`@00000E03oool3000005l0oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0K`3oool4000005/0oooo0P00001M0?oo
o`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo06`0oooo0`00001Q0?ooo`@0
0000F@3oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool01@2oM00000000000000004P0W=oo02T0
oooo00<000000?ooo`3oool0J@3oool3000006P0oooo1000001E0?ooo`030000003oool0oooo0240
oooo000/0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool09P3oool00`000000oooo
0?ooo`1V0?ooo`<00000K`3oool400000540oooo00<000000?ooo`3oool08@3oool002`0oooo00<0
gia807Boo`3oool00`3oool00`2oM00004RL0=ooo`0W0?ooo`030000003oool0oooo06<0oooo0`00
001f0?ooo`@00000C@3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`2oM7@0_ooo0?ooo`04
0?ooo`030=nLW02oool0oooo02H0oooo00<000000?ooo`3oool0H03oool3000007d0oooo10000019
0?ooo`030000003oool0oooo0240oooo000/0?ooo`030=nLB000B9`0gooo00<0oooo00<0oono07A8
W03Oool09`3oool2000005h0oooo0`0000240?ooo`@00000@`3oool3000002<0oooo000/0?ooo`03
0?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool09P3oool00`000000oooo0?ooo`1J0?ooo`<0
0000R`3oool400000440oooo00<000000?ooo`3oool08@3oool002d0oooo00H0oooO09a800000000
00000000M02ooolY0?ooo`030000003oool0oooo05L0oooo0`00002B0?ooo`@00000?@3oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1E0?ooo`800000V@3oool4000003T0
oooo00<000000?ooo`3oool08@3oool002`0oooo00<0oono07Ad_`3oool0103oool00`3OW9`0_ooo
0?ooo`0V0?ooo`030000003oool0oooo05<0oooo0P00002O0?ooo`D00000=03oool00`000000oooo
0?ooo`0Q0?ooo`009P3oool00`3ooml0W4P0001d_`030?ooo`030?noM0000000000000@0000000<0
001d0;ooo`3oool02`3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol0
0`3oool01@3ogi`0B000000000000000M;oo00P0oooo00<000000?ooo`3oool0D03oool300000:H0
oooo1P00000^0?ooo`030000003oool0oooo0240oooo000V0?ooo`030?oog`2LB00007Bo00<0oooo
00<0_g@0000000000000100000000`0007@0_ooo0?ooo`0:0?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`020?ooo`030?noM0000000M;oo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d
0000M;oo00L0oooo00<000000?ooo`3oool0CP3oool200000:l0oooo1P00000X0?ooo`030000003o
ool0oooo0240oooo000c0?ooo`030=nLW02oool0oooo00X0oooo00<0_g@00018W03Oool00P3oool0
0`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03Oool01P3oool0
0`000000oooo0?ooo`1<0?ooo`800000]`3oool600000280oooo00<000000?ooo`3oool08@3oool0
03l0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030?oOW0180000M;oo
00<0oooo00<0okmd0000B02Lgol01P3oool00`000000oooo0?ooo`1:0?ooo`800000_`3oool60000
01`0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0oono07Ad_`3oool0103oool00`3OW9`0
_ooo0?ooo`090?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00<000000?ooo`3oool0B03oool200000<L0
oooo1P00000F0?ooo`030000003oool0oooo0240oooo000/0?ooo`030?noM0000000000000@00000
00<0001d0;ooo`3oool02@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo
00<0omnL04P0001d_ol00`3oool00`2oM000001809cOo`060?ooo`<00000A`3oool00`000000oooo
0?ooo`3=0?ooo`D000003`3oool3000002<0oooo000/0?ooo`030;md00000000000000@0000000<0
001d0;ooo`3oool02@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0
oono07@000000000B9cO0?ooo`3o_g@00000001d_`L0oooo00<000000?ooo`3oool0A@3oool20000
0=D0oooo1P00000;0?ooo`030000003oool0oooo0240oooo000]0?ooo`030=nLW02oool0oooo00<0
oooo00<0gibL0;ooo`3oool02@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0
oooo00<0_g@00018W02oW4P00P0000000`00B9`0gooo0?ooo`060?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0f`3oool4000000L0oooo00<000000?ooo`3oool08@3oool002`0oooo
00<0omnL07BLg`3oool0403oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo
00<0omnL04P0001d_ol02`3oool00`000000oooo0?ooo`120?ooo`800000j@3oool00`000000oooo
0?ooo`0Q0?ooo`00;03oool00`2oM00007Bo0?ooo`040?ooo`030=nLW02oool0oooo00X0oooo00<0
gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030=nLB00004P0W=oo00X0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo0240oooo000/
0?ooo`030=nLB0000000000000@0000000<0001d0;ooo`3oool02P3oool01`3ookl0M00007Boo`3o
ool0okmd0000M02oool02@3oool00`3o_g@00000001d_`090?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`3ooml0W4P00000
0004000000030000M02oool0oooo00/0oooo00D0oono07@000000000001d0;ooo`0;0?ooo`050?oo
g`2LB00000000000M02oool01P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0>/0
oooo00<000000?ooo`3oool08@3oool003<0oooo00<0gibL0;ooo`3oool09P3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0
_gAd0;ooo`3oool0;@3oool00`000000oooo0?ooo`040?ooo`<00000=`3oool00`000000oooo0?oo
o`3/0?ooo`030000003oool0oooo0240oooo000Z0?ooo`030?oo_`1d0000000000H0000000<0B9cO
0?ooo`3oool09P3oool00`000000oooo0?ooo`070?ooo`H00000<03oool00`000000oooo0?ooo`3]
0?ooo`030000003oool0oooo0240oooo000Y0?ooo`030?noM0000000000000L0000000<0001d0;oo
o`3oool09P3oool2000000h0oooo2P00000V0?ooo`030000003oool0oooo0>/0oooo0`00000S0?oo
o`00;03oool00`2oM7@0_ooo0?ooo`030?ooo`030?oo_`1dB9`0gooo02L0oooo00<000000?ooo`3o
ool05`3oool<000001T0oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`0Q0?ooo`00
;03oool00`2oM7@0_ooo0?ooo`030?ooo`030;mdB02Lgol0oooo02L0oooo00<000000?ooo`3oool0
8`3oool<000000d0oooo00<000000?ooo`3oool0kP3oool00`000000oooo0?ooo`0Q0?ooo`00G03o
ool00`000000oooo0?ooo`0_0?ooo``0000000<0oooo0000003oool0k`3oool00`000000oooo0?oo
o`0Q0?ooo`00G03oool00`000000oooo0?ooo`0k0?oooaP00000fP3oool00`000000oooo0?ooo`0Q
0?ooo`00G03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01@0oooo3000003>0?oo
o`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0803oool<00000<80oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0[0?ooo``00000]P3oool00`000000oooo0?ooo`0Q0?ooo`00G03o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03H0oooo3000002Z0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0@P3ooolH
00000980oooo00<000000?ooo`3oool08@3oool005`0oooo0P0000100?ooo`030000003oool0oooo
05T0oooo300000240?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool0@03oool2000006D0
oooo3000001j0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool0KP3ooolH00000680oooo00<000000?ooo`3oool08@3oool005`0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`250?ooo``00000EP3oool00`000000oooo0?oo
o`0Q0?ooo`00G03oool00`000000oooo0?ooo`140?ooo`800000T@3ooolI000003d0oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2W0?oo
o``00000<@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`170?ooo`80
0000/`3ooolH000001T0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0
B@3oool200000<T0oooo4P0000070?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003o
ool0oooo04/0oooo0`00003O0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000C`3oool2
00000=/0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`1@0?ooo`800000f`3oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1B0?ooo`<00000f03oool00`000000
oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1E0?ooo`800000eP3oool00`000000oooo
0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`1G0?ooo`<00000d`3oool00`000000oooo0?oo
o`0Q0?ooo`00@@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol00`3o
ool01@3OW4P00000000000000000B9cO00P0oooo00<000000?ooo`3oool0FP3oool400000<l0oooo
00<000000?ooo`3oool08@3oool00400oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080
oooo00<0okmd0000001d_ol00P3oool01`3OW4P0000007Boo`3oool0oooO09a80018W=l01`3oool0
0`000000oooo0?ooo`1N0?ooo`@00000b`3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`2o
M00004RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o
_g@004RL0=ooo`060?ooo`030000003oool0oooo0680oooo1@0000360?ooo`030000003oool0oooo
0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool01P3oool00`2oM000
07Bo0?ooo`020?ooo`030;md0000B9`0gooo00H0oooo00<000000?ooo`3oool0I`3oool600000<00
oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`060?ooo`070?oOW01807@0_ooo0?ooo`2oM000000007Boo`070?ooo`030000003oool0oooo
06d0oooo1@00002k0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol01`3oool01@3ookl0M4Q804P000000000B9cO00P0oooo0`00001b0?oo
o`@00000]@3oool3000002<0oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01`3oool0103ogi`0B00000000000M;l90?ooo`030000003oool0oooo07H0oooo1000002?0?oo
oad000001`3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`03
0?noM00004P0W=oo00H0oooo00H0omnL04P0000007@0_ooo0?noM000M;l80?ooo`030000003oool0
oooo07X0oooo1P00001U0?ooob@00000903oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3o
okl0M00004RLg`030?ooo`030=nLB00007@0_ooo00H0oooo00<0_g@00000M02oool00P3oool00`2o
M000B9cO0?ooo`060?ooo`030000003oool0oooo0800oooo1P00001C0?ooo``00000B03oool00`00
0000oooo0?ooo`0Q0?ooo`00@03oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00H0
oooo00<0_g@00018W03Oool00P3oool00`3OW4P007Bo0?ooo`060?ooo`030000003oool0oooo08H0
oooo1P0000130?ooo`X00000E03oool00`000000oooo0?ooo`0Q0?ooo`00@03oool01`3ookl0M000
07Boo`3oool0okmd0000M02oool01`3oool01`3o_g@0000007Boo`3oool0oono07@0001d_ol01`3o
ool00`000000oooo0?ooo`2<0?ooo`H00000=`3oool6000005h0oooo00<000000?ooo`3oool08@3o
ool00440oooo00D0oono07@000000000001d0;ooo`090?ooo`050?noM0000000000000000018W=l0
203oool00`000000oooo0?ooo`2B0?ooo`T000009P3oool8000006@0oooo00<000000?ooo`3oool0
8@3oool005`0oooo00<000000?ooo`3oool0V`3oool9000001X0oooo0`00001/0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`030000003oool0oooo0:@0oooo1P00000A0?ooo`<00000K`3oool0
0`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`2Z0?ooo`T000001P3oool20000
0780oooo00<000000?ooo`3oool08@3oool005`0oooo0P00002d0?ooo``00000K03oool3000002<0
oooo001L0?ooo`030000003oool0oooo0;T0oooo0P0000040?ooo``00000HP3oool00`000000oooo
0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`2k0?ooo`<000003@3oool<000005H0oooo00<0
00000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0_P3oool3000001H0oooo3000001:
0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0<40oooo0`00000O0?oo
o`d00000?@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`340?ooo`@0
0000:03oool<00000340oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0
b03oool<000002P0oooo3000000U0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003o
ool0oooo0=@0oooo1P00000^0?ooo``000006@3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool0
0`000000oooo0?ooo`3J0?ooo`T00000<@3ooolB000000L0oooo00<000000?ooo`3oool08@3oool0
05`0oooo00<000000?ooo`3oool0h`3oool<000003h0oooo00<000000?ooo`3oool08@3oool005`0
oooo0P00003`0?ooo``00000<03oool3000002<0oooo001L0?ooo`030000003oool0oooo0?/0oooo
6000000J0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo503o
ool<000000h0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3ooolP
0?ooo`L000001`3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?oo
obh0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool08@3oool005`0ooooo`00000b000002<0oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo002;0?ooo`040?oog`2LM9`0
gooO09a800<0000000<0M;oo0?ooo`3oool00P3oool01@2oM00000000000000007@0_ooo00<0oooo
00D0_g@0000000000000001809cOo`030?ooo`050=nLB000000000000000001d_ol00P3oool01P2o
M00000000000000007@0_ooO09a80080000000@004RL0=ooo`3ooml0W4P00P000000100004P0B4P0
0018W03Oool40?ooo`030;md0000000000000080000000<007Bo0?ooo`3oool00`3oool02@3OW4P0
00000000000007@0_ooo0?oOW0180000000004RLg`020?ooo`070;md0000000000000000B02Lgol0
oooo0=nLB002000000030000B02Lgml0W4P00080000000<007Bo0?oOW01800000`000000101d_ol0
oooo0?ooo`3OW4P30000000407Boo`3oool0oooo0;md0080000000@0001809cOo`3oool0_g@00P00
00000`0004P0W=oo0;md0002000000060000M02oool0oooo0?ooo`3ooml0W4P01`0000001@0007@0
_ooo0?ooo`3oool0gia80080000000<0001d0;oOW01800000`000000101d_ol0oooo0?oo_`1d0002
0000000504RL_`2LB00004RL0=ooo`2oM0000P0000000`0004P0W=oo0?ooo`020?ooo`080;md0000
000000000000B02Lgol0oooo0?oog`2LB0020000000:0018W02LM0000000001d_`3oool0omnL04P0
00000000B9cO0=nLB080000000@0001d0;ooo`3oool0gia80`000000101d_ol0oooo0?ooo`2oM002
000000030000M02ooml0W4P00080000000<004RL0=ooo`3oool0D`3oool008/0oooo00@0oooO09a8
000004P0W=oo0P3oool00`3ogi`0B00007Boo`020?ooo`0G0;md0000000007Bo0?ooo`3ogi`0B01d
0;ooo`3oool0_g@000000000B9`0gooo0?oog`2LB7@0_ooo0?ooo`3OW4P0000004RLg`3oool0oooO
09a80018W=l00P3oool04P3OW4P004RL0=ooo`3oool0oooO09a80000M;l0oooo0?oog`2LB0000000
07Boo`3oool0oono07@000000000001d0;ooo`@0oooo00@0oooO09a80000B9`0gooo1`3oool0603O
W4P0001d0;ooo`3oool0gia80000M02oool0gkno0=ooo`2oM00000000018W03Oool0oooO09a8M02o
ool0oooo0=nLB00007@0_ooo0?ooo`3ooml0W4P0001d_`80oooo00<0oooO09a80000M;l00`3oool0
1`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool00`3OW4P0001d0;ooo`030?ooo`070=nL
B00007@0_ooo0?ooo`2oM000001809cOo`060?ooo`030?oOW0180000B9cO00<0oooo00@0omnL04P0
00000000M;oo0P3oool01`3OW4P0001d0;ooo`3oool0oooO09a80000M;l00`3oool01@3OW4P0001d
0;ooo`3oool0gia80080000000D0001d0;ooo`3OW4P0001d0;ooo`030?ooo`0P0;md0000000004RL
0=ooo`3ooml0W4Qd0;ooo`3o_g@0000007Boo`3oool0omnL04P00000M;l0okno0;ooo`3OW4P0001d
0;ooo`3O_kl0gooo0=nLB00007@0_ooo0?ooo`3OW4P0000004RLg`3oool0oooO09a80018W=l20?oo
o`070=nLB000B9`0gooo0?ooo`3ooml0W4P0001d_`1F0?ooo`00R`3oool00`3ooml0W4Q809cOo`04
0?ooo`060;md0000B9`0gooo0?oOW0180000B9cO0`3oool01@3ogi`0M9cO0?oOW018000007Bo00<0
oooo00D0omnL09boo`3ogi`0B000001d_`030?ooo`0?0?noM00007@0_ooo0?ooo`3OW4P004RL0=oo
o`3oool0oooO09a80000M;l0oooo0?oOW0180000B9cO0080oooo00<0oooO09a80000M;l01P3oool0
0`3ooml0W4P0001d_`080?ooo`0;0=nLB00007@0_ooo0?ooo`3OW4P004RL0=ooo`3oool0omnL04P0
0000M;l00`3oool02P3ogi`0W;oo0?ooo`3OW4P0001d0;ooo`3oool0oooO09a80000M;l20?ooo`03
0?oog`2LB00007Bo0080oooo00<0omnL04P00000M;l00`3oool01`3o_g@0001d0;ooo`3oool0gia8
0000M02oool00`3oool01P3OW4P0001d0;ooo`3OW4P0000007Boo`L0oooo00<0oono07@00018W=l0
103oool0303o_g@000000018W03Oool0oooo0=nLB00007@0_ooo0?ooo`3ooml0W4P0001d_`<0oooo
00L0_g@00018W03Oool0oooo0?oog`2LB00007Bo0080oooo00<0gia80000M02oool00P3oool00`3o
gi`0B000001d_`030?ooo`090?oOW02L_ol0okmd0000B02Lgol0oooo0?oog`2LB00007Bo0080oooo
00<0gia80018W03Oool00P3oool01P3OW4P0001d0;ooo`3ogi`0B000001d_`<0oooo00/0okmd0000
M02oool0oooo0=nLB000B9`0gooo0?ooo`3ooml0W4P0001d_`1F0?ooo`00R`3oool00`3ooml0W7BL
0=ooo`030?ooo`070?oog`2LB00004RL0=ooo`3o_g@0001809cOo`050?ooo`030?noM00004P0W=oo
00D0oooo00<0okmd0000001d_ol00`3oool03`3o_g@0000007Boo`3oool0gia80018W03Oool0oooo
0?oog`2LB00007Bo0?ooo`3o_g@0000007Boo`020?ooo`030?oog`2LB00007Bo00H0oooo00<0oooO
09a80000M;l0203oool02`3OW4P0001d0;ooo`3oool0gia80018W03Oool0oooo0?noM00004P0W=oo
00H0oooo00L0gia80000M02oool0oooo0?oog`2LB00007Bo0080oooo00<0oooO09a80000M;l00P3o
ool00`3o_g@0000007Boo`030?ooo`070?noM0000000M;oo0?ooo`3OW4P0001d0;ooo`030?ooo`05
0=nLB00007@0_kmd00000018W=l0203oool00`3ookl0M00004RLg`040?ooo`0<0?oOW0180000001d
0;ooo`3oool0gia80000M02oool0oooo0?oog`2LB00007Bo0`3oool01`2oM00004RL0=ooo`3oool0
oooO09a80000M;l00P3oool00`3OW4P0001d0;ooo`020?ooo`030?noM00004P0W=oo00H0oooo00H0
okmd00000000M;l0oooO09a80000M;l20?ooo`030=nLB000B9`0gooo0080oooo00H0gia80000M02o
ool0okmd0000001d_ol30?ooo`0;0?noM0000000M;oo0?ooo`3OW4P004RL0=ooo`3oool0oooO09a8
0000M;l0EP3oool00900oooo00P0oono07@00000000007Bo0?ooo`3o_g@0001d0;ooo`D0oooo00<0
okmd0000M02oool01@3oool00`3o_g@0000007Boo`030?ooo`0?0?noM0000000M;oo0?ooo`3OW4P0
04RL0=ooo`3oool0oooO09a80000M;l0oooo0?noM0000000M;oo0080oooo00<0oooO09a80000M;l0
1P3oool00`3ooml0W4P0001d_`080?ooo`0;0=nLB00007@0_ooo0?ooo`3OW4P004RL0=ooo`3oool0
okmd0000M02oool01P3oool01`3OW4P0001d0;ooo`3oool0oooO09a80000M;l00P3oool00`3ooml0
W4P0001d_`020?ooo`030?noM0000000M;oo00<0oooo00L0okmd0000001d_ol0oooo0=nLB00007@0
_ooo00<0oooo00@0gia800000000000007Bo2@3oool00`3ookl0M00004RLg`040?ooo`030?noM000
000007Bo0080oooo00L0gia80000M02oool0oooo0?oog`2LB00007Bo00<0oooo00L0_g@00018W03O
ool0oooo0?oog`2LB00007Bo0080oooo00<0gia80000M02oool00P3oool00`3o_g@0001d0;ooo`08
0?ooo`040?noM00000000000001d_`80oooo00<0gia80018W03Oool00P3oool01P3OW4P0001d0;oo
o`3o_g@0000007Boo`<0oooo00/0okmd0000001d_ol0oooo0=nLB000B9`0gooo0?ooo`3ooml0W4P0
001d_`1F0?ooo`00SP3oool02@3ookl0M00000000000000004RL0=ooo`3oool0omnL04P000050000
000404RLg`3ogi`0B01809cOo`80oooo00H0okmd0000B02Lgol0oono07@0001d_ol30?ooo`0?0;md
000004P0W=oo0?ooo`2oM000001d0;ooo`3oool0oooO09a80000M;l0oooo0?oo_`1d0000B9cO0080
oooo00<0oooO09a80000M;l01P3oool00`3ooml0W4P0000000040000000?07Boo`3oool0oooo0?oo
o`3OW4P0001d0;ooo`3oool0gia80018W03Oool0oooo0?oOW01804P0W=oo0080oooo00/0okmd0000
B02Lgol0oooo0=nLB00007@0_ooo0?ooo`3ooml0W4P0001d_`020?ooo`030?oog`2LB00007Bo0080
oooo00<0oono07@0001d_ol00`3oool01`2oM000001809cOo`3oool0gia80000B02Lgol00`3oool0
1@3OW4P0001d0;ooo`2oM00007Bo00P0oooo00<0oono07@00018W=l00`3oool0103OW4P000000000
B02Lgol20?ooo`070=nLB00007@0_ooo0?ooo`3ooml0W4P0001d_`030?ooo`070;md0000B9`0gooo
0?ooo`3ooml0W4P0001d_`020?ooo`030=nLB00004P0W=oo0080oooo00<0omnL04P0B02Lgol00P3o
ool02P3o_g@0001809cOo`3ookl0M00007Boo`3oool0oooO09a80000M;l20?ooo`030=nLB000B9`0
gooo0080oooo00H0gia80000M02oool0oono07@0001d_ol30?ooo`0;0;md000004P0W=oo0?ooo`2o
M000001d0;ooo`3oool0oooO09a80000M;l0EP3oool008d0oooo00D0_g@0000000000000001809cO
o`040?ooo`0P0;md0018W=l0oooo0?ooo`3OW4P0001809cOo`3oool0_g@00018W03Oool0oooO09a8
000007@0_ooo0?ooo`3OW4P004RL0=ooo`3oool0okmd00000000M;l0oooO09a80000000004Q804P0
B02Lgol0oono07@00018W=l20?ooo`070?noM00004P0W=oo0?ooo`3o_g@00000001d_`060?ooo`03
0?oog`2LB00007Bo0080oooo00d0oooO09a800000000B9cO0?oog`2LB00000000000M02oool0oooo
0=nLB000B9`0gooo0080oooo00l0_g@00018W03Oool0oooO09a8000007@0_ooo0?ooo`3OW4P00000
0000B02Lgol0oono07@00018W=l00P3oool00`3ooml0W4P0001d_`030?ooo`0F0=nLB000B9`0gooo
0?ooo`3o_g@00000001d_`3ooml0W4P00000000004P0B7BL0=noM00007@0_ooo0=nLB00007@0_ooo
0?ooo`3o_g@004RL0=ooo`H0oooo00<0oono07@00000000010000000301d_ol0oooo0?ooo`3ooml0
W4P00000000007@0_ooo0?ooo`3ooml0W4P0001d_`<0oooo01d0_g@00018W03Oool0oooo0?oog`2L
B00007Bo0?oog`2LB00000000000B018M9`0gkmd0000M02oool0_g@00018W03Oool0oooO09a80000
07@0_ooo0?oo_`1d0000B9cO0?ooo`3ookl0M000001d_`020?ooo`0I0=nLB000B9`0gooo0?oog`2L
B00000000000M02oool0oooo0=nLB000B9`0gooo0?ooo`3o_g@00000001d_`3ooml0W4P000000000
B4P0B01809cOo`3ookl0M00004RLg`1F0?ooo`00S03oool0103OW4P000000000001d_ol70?ooo`05
0=nLB000000000000000B02Lgol00`3oool01@3OW4P000000000000004P0W=oo00<0oooo00D0okmd
000000000000000004RLg`030?ooo`070;md0000B9`0gooO09a800000000001d0;ooo`030?ooo`03
0?noM000000000000080000000<007Bo0?ooo`3oool0103oool00`3ooml0W4P0001d_`030?ooo`09
0?oo_`1d0000001d0;ooo`3oool0_g@00000M02oool0_g@000<0000000@004RL0=ooo`3oool0gia8
0P0000003@0004P0W=oo0?ooo`3oool0gia80000M02ooml0W4P00000000007@0_ooo0?ooo`3o_g@0
100000001000B9`0gooo0?ooo`3o_g@30000000?04RLg`3oool0oooo0?ooo`2oM000001d0;oOW018
0000001d0;ooo`3OW4P0001d0;ooo`3ooml0W4P00080000000<007Bo0?ooo`3oool00`3oool00`3o
okl0M00004RLg`030?ooo`040?noM000000004RL0=ooo`80oooo00@0_g@00000M02oool0okmd1000
00002@00B4P0B00000000000B9`0gooo0?oOW01800000000001d_`020?ooo`080;md000007@0_mnL
04P0000007@0_ooo0?ooo`3OW4P2000000060000B02Lgol0oooo0?ooo`3ookl0M0000P0000001000
07@0_ooo0?ooo`2oM003000000050018W03Oool0_g@00000M02oool00P3oool01@3o_g@000000000
00000000B9cO00<0oooo00L0_g@00018W03Ooml0W4P00000000007@0_ooo05H0oooo002;0?ooo`04
0?oog`2LB000001d0;ooo`<0oooo00<0oknL09cOo`3oool09`3oool00`3ooml0W4P0001d_`060?oo
o`030?oog`2LB00007Bo00<0oooo00@0oooO09a8000004P0W=oo1@3oool00`2oM00004RL0=ooo`0:
0?ooo`030=nLB00007@0_ooo00H0oooo00<0oooO09a80000M;l04P3oool00`3OW4P0001d0;ooo`0:
0?ooo`030?oo_`1d0000B9cO00@0oooo00<0_g@00000001d_ol01P3oool00`3ooml0W4P0001d_`0R
0?ooo`030;md0000B9`0gooo06`0oooo002;0?ooo`030?oog`2LB00007Bo00<0oooo00<0oooO09a8
B02Lgol0:03oool00`3ooml0W4P0001d_`060?ooo`030?oog`2LB00007Bo00<0oooo00@0omnL04P0
000007@0_ooo1@3oool00`3ookl0M4RL0=ooo`0:0?ooo`030=nLB00007@0_ooo00L0oooo00<0_g@0
001d_`3oool04@3oool00`3OW4P0001d0;ooo`0:0?ooo`030?oo_`1d0000B9cO00@0oooo00<0_g@0
0000001d_ol01`3oool00`2oM00007Bo0?ooo`0Q0?ooo`030?oo_`1dB9`0gooo06`0oooo002<0?oo
o`080=nLB00004P0W=oo0?ooo`3ooml0W4P00000B02LgolX0?ooo`030?oog`2LB00007Bo00H0oooo
00<0oooO09a80000M;l00P3oool0103ookl0M00000000018W=l60?ooo`030?oog`2LM9`0gooo00X0
oooo00<0gia80000M02oool01`3oool00`3OW4P007Bo0?ooo`0A0?ooo`030=nLB00007@0_ooo00X0
oooo00<0omnL04P00018W=l00`3oool0103OW4P000000018W03Oool70?ooo`030=nLB000M;l0oooo
0240oooo00<0oooO09adW03Oool0K03oool008d0oooo00L0okmd000000000000001809cOo`3OW7@0
W=oo02L0oooo00@0oono07@00000000007Bo1@3oool00`2oM000000000000004000000030000B02L
gol0oooo0080oooo00<0gia80000B02Lgol0303oool01@3ooml0W4P00000000007@0_ooo00L0oooo
00L0oono07@0M02oool0oooO09a80000B9`0gooo00/0oooo00D0oooO09a800000000001d0;ooo`08
0?ooo`030?oog`2LB000000000H0000000<0B9cO0?ooo`3oool00P3oool00`3OW4P0001809cOo`02
0?ooo`070?oo_`1d07@0_ooo0?oog`2LB00004RL0=ooo`0R0?ooo`030=nLB00004P0W=oo06L0oooo
002l0?ooo`030?oog`2LB00007Bo0140oooo00<0gia80000B02Lgol03P3oool00`2oM000001d0;oo
o`080?ooo`050?oo_`1d000000000000B02Lgol03P3oool00`2oM000001d0;ooo`0F0?ooo`030=nL
B00004P0W=oo00<0oooo00D0oono07@000000000001809cOo`0S0?ooo`030=nLB00004P0W=oo06L0
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {2.44165, -0.283312, \
0.00539373, 0.00768085}}]
}, Closed]],

Cell["\<\
The interval between successive bifurcations decreases as we approach the \
chaotic regime.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tangent bifurcation and the onset of chaos", "Section"],

Cell[TextData[{
  "Sarkovskii proved a theorem for one-dimensional discrete maps that if \
there exists a stable 3-cycle for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_c \[LessEqual] \[Mu] \[LessEqual] \
\[Mu]\_p\)]],
  ", then ",
  StyleBox["aperiodic",
    FontSlant->"Italic"],
  " or ",
  StyleBox["chaotic",
    FontSlant->"Italic"],
  " solutions exist in this range.  The bifurcation pattern appears to be \
random within the chaotic regime.  Also note that if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_p\)]],
  " is finite, order re-emerges for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] > \[Mu]\_p\)]],
  ", but is usually confined to a narrow range before the another transition \
to chaos is encountered.  The order to chaos to order pattern then repeats \
with increasing frequency."
}], "Text"],

Cell[TextData[{
  "The condition that must be satisfied for the emergence of a stable 3-cycle \
is the existence of three fixed points in ",
  Cell[BoxData[
      \(TraditionalForm\`f\_3[\[Mu]\_c, x] \[Equal] x\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 1\)]],
  ", such that ",
  Cell[BoxData[
      \(TraditionalForm\`f\_3\)]],
  " is tangent to the diagonal at three places.  As illustrated below, this \
condition is satisfied for the logistic map when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_c \[TildeTilde] 3.828\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[{x, Table[f\_3[\[Mu], x], {\[Mu], 3.728, 3.928, 0.1}]}], {x, 
          0, 1}, Frame \[Rule] True, \ 
        FrameLabel \[Rule] {\*"\"\<\!\(x\_i\)\>\"", \ \*"\"\<\!\(x\_\(i + 3\)\
\)\>\""}, PlotRange \[Rule] {{0, 1}, {0, 1}}, AspectRatio \[Rule] Automatic, 
        PlotPoints \[Rule] 50];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9.5 -15.6875 ]
[.2 -0.0125 9.5 0 ]
[.4 -0.0125 -9.5 -15.6875 ]
[.4 -0.0125 9.5 0 ]
[.6 -0.0125 -9.5 -15.6875 ]
[.6 -0.0125 9.5 0 ]
[.8 -0.0125 -9.5 -15.6875 ]
[.8 -0.0125 9.5 0 ]
[1 -0.0125 -5 -15.6875 ]
[1 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.5 -31.375 ]
[.5 -0.0125 6.5 -15.6875 ]
[-0.0125 .2 -19 -7.84375 ]
[-0.0125 .2 0 7.84375 ]
[-0.0125 .4 -19 -7.84375 ]
[-0.0125 .4 0 7.84375 ]
[-0.0125 .6 -19 -7.84375 ]
[-0.0125 .6 0 7.84375 ]
[-0.0125 .8 -19 -7.84375 ]
[-0.0125 .8 0 7.84375 ]
[-0.0125 1 -10 -7.84375 ]
[-0.0125 1 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -34.6875 -11.4063 ]
[-0.01875 .5 -19 11.4063 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .4 m
.00625 .4 L
s
gsave
-0.0125 .4 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .6 m
.00625 .6 L
s
gsave
-0.0125 .6 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .8 m
.00625 .8 L
s
gsave
-0.0125 .8 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 1 m
.00625 1 L
s
gsave
-0.0125 1 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -99.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
72.4063 11.8438 translate
90 rotate
-72.4063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
71.500 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.000 17.688 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
81.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.2 .99375 m
.2 1 L
s
.4 .99375 m
.4 1 L
s
.6 .99375 m
.6 1 L
s
.8 .99375 m
.8 1 L
s
.125 Mabswid
.05 .99625 m
.05 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.25 .99625 m
.25 1 L
s
.3 .99625 m
.3 1 L
s
.35 .99625 m
.35 1 L
s
.45 .99625 m
.45 1 L
s
.5 .99625 m
.5 1 L
s
.55 .99625 m
.55 1 L
s
.65 .99625 m
.65 1 L
s
.7 .99625 m
.7 1 L
s
.75 .99625 m
.75 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .2 m
1 .2 L
s
.99375 .4 m
1 .4 L
s
.99375 .6 m
1 .6 L
s
.99375 .8 m
1 .8 L
s
.125 Mabswid
.99625 .05 m
1 .05 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .25 m
1 .25 L
s
.99625 .3 m
1 .3 L
s
.99625 .35 m
1 .35 L
s
.99625 .45 m
1 .45 L
s
.99625 .5 m
1 .5 L
s
.99625 .55 m
1 .55 L
s
.99625 .65 m
1 .65 L
s
.99625 .7 m
1 .7 L
s
.99625 .75 m
1 .75 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .95 m
1 .95 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.01987 .01987 L
.04154 .04154 L
.06189 .06189 L
.08146 .08146 L
.1023 .1023 L
.12235 .12235 L
.14366 .14366 L
.1642 .1642 L
.18395 .18395 L
.20497 .20497 L
.22521 .22521 L
.24467 .24467 L
.26539 .26539 L
.28533 .28533 L
.30653 .30653 L
.32695 .32695 L
.34659 .34659 L
.36749 .36749 L
.38762 .38762 L
.409 .409 L
.42961 .42961 L
.44944 .44944 L
.47052 .47052 L
.49083 .49083 L
.51036 .51036 L
.53115 .53115 L
.55116 .55116 L
.57243 .57243 L
.59292 .59292 L
.61263 .61263 L
.63361 .63361 L
.6538 .6538 L
.67322 .67322 L
.69389 .69389 L
.71379 .71379 L
.73495 .73495 L
.75532 .75532 L
.77492 .77492 L
.79578 .79578 L
.81586 .81586 L
.83721 .83721 L
.85777 .85777 L
.87755 .87755 L
.89859 .89859 L
.91886 .91886 L
.93834 .93834 L
.95909 .95909 L
.97906 .97906 L
1 1 L
Mistroke
Mfstroke
0 0 m
.00462 .21931 L
.00967 .41714 L
.01501 .58332 L
.01987 .70088 L
.02529 .79898 L
.02827 .83975 L
.03109 .87056 L
.03369 .89289 L
.0361 .90865 L
.03874 .92101 L
.04007 .9254 L
.04083 .92739 L
.04154 .92891 L
.04221 .93006 L
.04282 .93087 L
.04349 .93151 L
.04386 .93175 L
.04421 .9319 L
.04485 .932 L
.04543 .9319 L
.04607 .93157 L
.04675 .93099 L
.04732 .93032 L
.04793 .92942 L
.04903 .92735 L
.05033 .92414 L
.05152 .92055 L
.05416 .91047 L
.05703 .89649 L
.06226 .86426 L
.08323 .68229 L
.10343 .4928 L
.12284 .34747 L
.13279 .29498 L
.13839 .27275 L
.14352 .25704 L
.14595 .25115 L
.14856 .24595 L
.15102 .24208 L
.15325 .23943 L
.15462 .23821 L
.15588 .23734 L
.15654 .23699 L
.15726 .23669 L
.15762 .23657 L
.15802 .23646 L
.15839 .23638 L
.15872 .23632 L
.15938 .23627 L
Mistroke
.15999 .23628 L
.16066 .23635 L
.16104 .23643 L
.16138 .23651 L
.162 .23671 L
.16267 .237 L
.16389 .23768 L
.16512 .23859 L
.16643 .23981 L
.1688 .24263 L
.17161 .24701 L
.17417 .25192 L
.17974 .26553 L
.18501 .28182 L
.20475 .36699 L
.22575 .48488 L
.24597 .60671 L
.26541 .71696 L
.28611 .81499 L
.29564 .85101 L
.30604 .88297 L
.31636 .90676 L
.32199 .91638 L
.32722 .92321 L
.32983 .92587 L
.33265 .9282 L
.33531 .92988 L
.33658 .93051 L
.33776 .93099 L
.33892 .93138 L
.33998 .93164 L
.34058 .93176 L
.34115 .93185 L
.34176 .93193 L
.34241 .93198 L
.343 .932 L
.34365 .93199 L
.34433 .93196 L
.34497 .9319 L
.34556 .93183 L
.3461 .93174 L
.34733 .93146 L
.3486 .93108 L
.34976 .93064 L
.35236 .92936 L
.35477 .92781 L
.35705 .92604 L
.36215 .92102 L
.36769 .91404 L
.3779 .89748 L
Mistroke
.38872 .87562 L
.40819 .82903 L
.42892 .77627 L
.44887 .73015 L
.45901 .71059 L
.47008 .69333 L
.47521 .68697 L
.48067 .68143 L
.48583 .67741 L
.48806 .67605 L
.49051 .67482 L
.49302 .67385 L
.49439 .67344 L
.49567 .67314 L
.49628 .67302 L
.49687 .67293 L
.4974 .67286 L
.49796 .67279 L
.49857 .67274 L
.49914 .67271 L
.49974 .6727 L
.50041 .6727 L
.50109 .67272 L
.50143 .67274 L
.5018 .67277 L
.50246 .67284 L
.50307 .67292 L
.50446 .67317 L
.50594 .67353 L
.50866 .67446 L
.51112 .67561 L
.51626 .6789 L
.521 .68298 L
.5317 .69578 L
.54135 .71123 L
.55197 .7319 L
.57273 .78038 L
.59271 .83129 L
.61394 .88134 L
.62456 .90187 L
.62973 .91028 L
.6344 .91686 L
.63899 .92226 L
.64394 .92684 L
.64666 .92877 L
.64916 .93016 L
.65156 .93113 L
.65276 .93149 L
.65345 .93165 L
.65408 .93177 L
Mistroke
.65471 .93187 L
.65538 .93194 L
.65605 .93198 L
.65643 .932 L
.65679 .932 L
.65743 .93198 L
.65802 .93195 L
.6587 .93187 L
.65935 .93178 L
.66054 .93152 L
.66164 .9312 L
.66285 .93075 L
.66414 .93017 L
.66705 .92842 L
.66979 .92622 L
.67491 .92067 L
.67993 .91337 L
.68523 .90361 L
.69473 .88089 L
.70482 .84942 L
.71425 .8135 L
.73425 .71874 L
.75552 .59783 L
.776 .47445 L
.79571 .36466 L
.80567 .31778 L
.81097 .29629 L
.81668 .27626 L
.82211 .26059 L
.82709 .2494 L
.82955 .24507 L
.83185 .24178 L
.83424 .23915 L
.83551 .23809 L
.83616 .23765 L
.83687 .23723 L
.83751 .23691 L
.8382 .23664 L
.83858 .23653 L
.83892 .23644 L
.83927 .23637 L
.8396 .23632 L
.84023 .23627 L
.84081 .23628 L
.84145 .23635 L
.84213 .2365 L
.84252 .23661 L
.84287 .23674 L
.84367 .2371 L
.84513 .23801 L
Mistroke
.84645 .23913 L
.84784 .24062 L
.8504 .24418 L
.85278 .24848 L
.8582 .2618 L
.86359 .27998 L
.86868 .30172 L
.87823 .35408 L
.89796 .505 L
.91896 .70332 L
.92939 .79895 L
.9345 .84058 L
.93917 .87388 L
.94373 .90052 L
.94605 .9114 L
.94853 .92072 L
.94984 .9246 L
.95103 .92746 L
.9516 .9286 L
.95222 .92966 L
.9528 .93048 L
.95335 .93109 L
.95398 .93161 L
.95432 .93179 L
.95468 .93193 L
.95505 .932 L
.95541 .93199 L
.95609 .93177 L
.95671 .93134 L
.95729 .93074 L
.95793 .92984 L
.95861 .92862 L
.95983 .92569 L
.96111 .92155 L
.96342 .9113 L
.96589 .89592 L
.9686 .87349 L
.97347 .81703 L
.978 .74335 L
.9834 .62509 L
.9885 .4786 L
.99806 .09707 L
1 0 L
Mfstroke
0 0 m
.00462 .23647 L
.00967 .44763 L
.01495 .62081 L
.01987 .74398 L
.02269 .79977 L
.02535 .84352 L
.02777 .87626 L
.03034 .90419 L
.03313 .92725 L
.03571 .94232 L
.03714 .94829 L
.03848 .95242 L
.03925 .95418 L
.03996 .9554 L
.04034 .95593 L
.04077 .95638 L
.04117 .95669 L
.04154 .95688 L
.0422 .957 L
.04253 .95695 L
.0429 .95681 L
.04355 .95635 L
.04415 .95569 L
.04486 .95462 L
.04551 .95339 L
.04697 .94973 L
.04823 .94564 L
.0496 .94025 L
.05209 .92815 L
.05706 .89616 L
.06166 .85892 L
.08186 .64724 L
.10127 .43569 L
.11206 .33625 L
.12195 .26258 L
.13164 .20886 L
.13651 .18906 L
.13926 .18006 L
.14184 .17297 L
.14438 .16734 L
.14571 .1649 L
.14713 .16269 L
.14832 .16115 L
.14963 .15976 L
.15082 .1588 L
.15193 .15814 L
.1526 .15786 L
.15297 .15774 L
.15332 .15765 L
Mistroke
.15396 .15755 L
.15432 .15753 L
.15464 .15753 L
.15526 .15758 L
.15592 .15772 L
.15655 .15792 L
.15712 .15818 L
.15842 .15896 L
.15984 .16017 L
.16132 .16182 L
.1627 .1637 L
.16529 .16809 L
.16809 .17413 L
.17319 .18828 L
.18274 .22489 L
.19293 .27632 L
.20374 .34165 L
.22318 .47605 L
.24389 .62453 L
.26381 .75428 L
.27393 .81069 L
.28499 .86288 L
.29557 .90253 L
.3054 .92981 L
.31082 .94083 L
.31349 .94518 L
.31594 .94858 L
.31813 .95113 L
.32053 .95339 L
.32295 .95511 L
.32427 .95581 L
.32551 .95632 L
.32615 .95653 L
.32684 .95671 L
.32743 .95683 L
.32807 .95693 L
.32844 .95696 L
.32877 .95698 L
.32913 .957 L
.32952 .957 L
.33016 .95697 L
.33053 .95694 L
.33087 .95689 L
.33153 .95678 L
.33216 .95664 L
.33333 .95628 L
.33459 .95576 L
.33596 .95503 L
.33837 .95335 L
.34092 .95104 L
Mistroke
.3455 .94553 L
.35034 .9379 L
.35555 .92773 L
.36497 .90468 L
.38618 .8352 L
.40661 .75462 L
.42626 .67522 L
.44718 .59964 L
.45685 .57055 L
.46731 .5446 L
.47305 .53309 L
.47833 .52433 L
.48338 .51766 L
.48616 .51471 L
.48871 .51249 L
.49104 .51083 L
.49359 .50946 L
.49498 .5089 L
.49627 .50851 L
.49691 .50836 L
.4975 .50824 L
.49813 .50814 L
.49846 .5081 L
.49881 .50807 L
.49941 .50803 L
.49996 .50802 L
.50056 .50803 L
.50121 .50807 L
.50154 .5081 L
.50189 .50815 L
.50253 .50825 L
.50373 .50851 L
.50487 .50885 L
.50608 .50932 L
.50824 .5104 L
.51078 .51209 L
.5131 .51402 L
.51832 .51971 L
.52315 .52661 L
.52774 .53455 L
.54742 .58283 L
.56836 .6545 L
.58852 .73472 L
.60994 .82058 L
.6207 .85992 L
.63059 .89191 L
.64087 .91964 L
.65045 .93927 L
.65514 .9464 L
.66016 .95208 L
Mistroke
.66153 .95327 L
.66302 .95438 L
.66433 .9552 L
.66573 .9559 L
.66698 .95639 L
.66769 .9566 L
.66836 .95676 L
.66897 .95687 L
.66953 .95694 L
.67018 .95699 L
.67079 .957 L
.67143 .95697 L
.67179 .95694 L
.67212 .9569 L
.67273 .9568 L
.67338 .95666 L
.67449 .95632 L
.67572 .95581 L
.67703 .95512 L
.67844 .95419 L
.68097 .95204 L
.68351 .94926 L
.68592 .94606 L
.69043 .93854 L
.69539 .92796 L
.70066 .91409 L
.71013 .88244 L
.72954 .79219 L
.75021 .66503 L
.7701 .52461 L
.79125 .37469 L
.80181 .30695 L
.81163 .25192 L
.8211 .2087 L
.82636 .18971 L
.83122 .1758 L
.83372 .17007 L
.83648 .16496 L
.83926 .16113 L
.84077 .15961 L
.84145 .15906 L
.84219 .15855 L
.84289 .15817 L
.84353 .15789 L
.84415 .1577 L
.8448 .15757 L
.84545 .15753 L
.84605 .15755 L
.8466 .15764 L
.84719 .15779 L
Mistroke
.84784 .15803 L
.84855 .15839 L
.84998 .15942 L
.85131 .16072 L
.85255 .16225 L
.85513 .16641 L
.85794 .17244 L
.86304 .18747 L
.868 .20722 L
.87258 .22994 L
.8822 .29124 L
.8928 .37879 L
.9135 .59462 L
.93341 .81281 L
.93876 .86262 L
.94373 .90193 L
.94892 .93343 L
.95166 .94526 L
.9532 .95022 L
.95392 .9521 L
.95459 .9536 L
.95521 .95475 L
.95578 .9556 L
.95641 .95631 L
.95709 .9568 L
.95774 .95699 L
.95811 .95698 L
.95845 .95689 L
.95907 .95652 L
.95973 .95583 L
.96029 .95501 L
.96089 .95387 L
.96198 .95114 L
.96328 .9467 L
.96447 .94145 L
.96696 .92662 L
.96968 .90399 L
.97252 .87258 L
.97517 .83557 L
.98057 .73428 L
.98568 .60255 L
.99026 .45021 L
.99523 .24357 L
1 0 L
Mfstroke
0 0 m
.00462 .25442 L
.00967 .47923 L
.01495 .66092 L
.01987 .78753 L
.02269 .84363 L
.02535 .8867 L
.02777 .91807 L
.03034 .94386 L
.03167 .95438 L
.03313 .96387 L
.03446 .97067 L
.03571 .97554 L
.03646 .97779 L
.03718 .97947 L
.03782 .98061 L
.03818 .9811 L
.03852 .98146 L
.03891 .98176 L
.03928 .98194 L
.03962 .982 L
.03998 .98197 L
.04037 .98182 L
.04079 .98153 L
.04115 .98118 L
.04154 .9807 L
.04221 .9796 L
.04283 .9783 L
.04423 .9744 L
.04547 .96989 L
.04679 .96407 L
.05157 .93474 L
.05669 .89156 L
.06233 .83305 L
.083 .57151 L
.1029 .32862 L
.11321 .22793 L
.11845 .1855 L
.12406 .14729 L
.12938 .11803 L
.13421 .09745 L
.13654 .08956 L
.13907 .08251 L
.14146 .07725 L
.14366 .07361 L
.14491 .07205 L
.14606 .07094 L
.14669 .07046 L
.14739 .07004 L
.14804 .06974 L
Mistroke
.14864 .06956 L
.14925 .06945 L
.14983 .06943 L
.15034 .06948 L
.1509 .06959 L
.15151 .0698 L
.15216 .0701 L
.15331 .07088 L
.15457 .07206 L
.15593 .07371 L
.15837 .07767 L
.16128 .08397 L
.16392 .09116 L
.17376 .1292 L
.17931 .15776 L
.18444 .18809 L
.20466 .33551 L
.2241 .49958 L
.24481 .67177 L
.26473 .81362 L
.27485 .87158 L
.28591 .92177 L
.29103 .94003 L
.29649 .95592 L
.30164 .96747 L
.30632 .97504 L
.30882 .97795 L
.31019 .97921 L
.31147 .98018 L
.31265 .98088 L
.31372 .98138 L
.31434 .9816 L
.31492 .98176 L
.31554 .98189 L
.3162 .98197 L
.31686 .982 L
.31748 .98198 L
.31816 .9819 L
.31855 .98183 L
.3189 .98175 L
.31956 .98156 L
.32029 .98129 L
.32176 .98055 L
.32305 .97969 L
.32443 .97854 L
.32691 .97592 L
.32964 .9722 L
.33217 .968 L
.33787 .95592 L
.34823 .92531 L
Mistroke
.35787 .88783 L
.36848 .83807 L
.38921 .72229 L
.40916 .59973 L
.43037 .47326 L
.4508 .36937 L
.46111 .32744 L
.47046 .29689 L
.47532 .28404 L
.48058 .27261 L
.48348 .26745 L
.48614 .26342 L
.48866 .26024 L
.49137 .25753 L
.49272 .25646 L
.49399 .25561 L
.49523 .25493 L
.49638 .25445 L
.49747 .25411 L
.49802 .25399 L
.49862 .25389 L
.49923 .25382 L
.49988 .25379 L
.50049 .2538 L
.50106 .25385 L
.50168 .25393 L
.50234 .25407 L
.50296 .25423 L
.50353 .25442 L
.50492 .25501 L
.50624 .25575 L
.50885 .25773 L
.51169 .26064 L
.51656 .26751 L
.52192 .27771 L
.53274 .3065 L
.54275 .34219 L
.5535 .38915 L
.57474 .50252 L
.59519 .62669 L
.61487 .74651 L
.63581 .85917 L
.64551 .90188 L
.65598 .93903 L
.66173 .95495 L
.66702 .96649 L
.67207 .97463 L
.67461 .97761 L
.67595 .97888 L
.6774 .98001 L
Mistroke
.6788 .98087 L
.67942 .98117 L
.6801 .98145 L
.6807 .98164 L
.68135 .98181 L
.68203 .98193 L
.68266 .98199 L
.68328 .982 L
.68395 .98196 L
.68458 .98187 L
.68517 .98174 L
.68575 .98157 L
.68628 .98138 L
.68746 .98083 L
.68884 .97996 L
.69012 .97895 L
.693 .97591 L
.69554 .97236 L
.69822 .96772 L
.7031 .95697 L
.70832 .94212 L
.71775 .90676 L
.72866 .85268 L
.73901 .78958 L
.75872 .6437 L
.77968 .46708 L
.79987 .29944 L
.81928 .16573 L
.82923 .11588 L
.83482 .09506 L
.8373 .08767 L
.83995 .0811 L
.84259 .07597 L
.84499 .07256 L
.84615 .07135 L
.84676 .07083 L
.8474 .07037 L
.84796 .07004 L
.84859 .06976 L
.84915 .06958 L
.84968 .06947 L
.85034 .06943 L
.85071 .06945 L
.85105 .0695 L
.85169 .06965 L
.85236 .06991 L
.85302 .07027 L
.85364 .0707 L
.85481 .07175 L
.85619 .0734 L
Mistroke
.85746 .07532 L
.86032 .08104 L
.86274 .08742 L
.86534 .09583 L
.87002 .11515 L
.87558 .1451 L
.88065 .17889 L
.89048 .26144 L
.90116 .37392 L
.92216 .63955 L
.93259 .77338 L
.94237 .88248 L
.94693 .92325 L
.95173 .95628 L
.95424 .96872 L
.95567 .97407 L
.95635 .97618 L
.95699 .97788 L
.95758 .97918 L
.95821 .98032 L
.95879 .98111 L
.95932 .98162 L
.9599 .98193 L
.96053 .98198 L
.96119 .9817 L
.96181 .98112 L
.96245 .98017 L
.96314 .97878 L
.96437 .97525 L
.9657 .96992 L
.96717 .96209 L
.96979 .94272 L
.97226 .91774 L
.97684 .8519 L
.97942 .80265 L
.98179 .74896 L
.99048 .47307 L
.99541 .25307 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{341.5, 341.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400080000202000`400?l00000o`00003oo`3ooooo
0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooolL0?ooo`050?oog`2LB0000000
0018W03Oool0h03oool00?l0oooo7@3oool00`3ogi`0B01809cOo`3Q0?ooo`00o`3ooolM0?ooo`03
0?oOW01804P0W=oo0>40oooo003o0?oooa@0oooo00D0_g@000000000M;l0oooo0=nLB00200000005
0018W03Oool0omnL04P0B02Lgol0h@3oool00?l0oooo503oool0303ooml0W4Qd0;ooo`3oool0oooO
09a80000B9`0gooo0?oo_`1d0000001809cOon40oooo003o0?oooaD0oooo00H0oono07A8W03Oool0
_g@00000M02oool20?ooo`030?oOW01804P0W=oo0>40oooo003o0?oooaH0oooo00@0omnL07A8B000
0000M;ooi`3oool00?l0oooo5P3oool00`3ookl0M00004RLg`3X0?ooo`00o`3ooolE0?ooo`050?oo
g`2LB00004RL09adB02Lgol00`3oool00`3ookl0M00007Boo`3Q0?ooo`00o`3ooolE0?ooo`060;md
000004P0W=oo0?oog`2LB7@0_oooiP3oool00?l0oooo4`3oool02@3ooml0W4P000000000000007Bo
0?noM0000000001d0;ooo`3U0?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0
ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool2
0?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3o
oooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80
oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00R`3oool01@3ogi`0B00000000000
07@0_ooo00<0oooo00D0okmd0000001d_ol0oooo0;md00060000000304RLg`3oool0oooo04<0oooo
00D0omnL04P000000000001d0;ooo`030?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000
B9`0goooA@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol00`3oool0
1@3ogi`0B000000000000000M;oo04D0oooo00D0omnL04P000000000001d0;ooo`030?ooo`030?no
M0000000M;oo00<0oooo00D0gia8000000000000000004RLg`1=0?ooo`060;md0000000000000000
0000B9`0gooo1@3oool008X0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0
okmd0000001d_ol00P3oool00`3OW4P0000000000003000000030018W03Oool0oooo0480oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol01@3oool0103ooml0
W4P00018W03Ooom40?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM000
0000M;oo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000M;oo04<0oooo00L0oono07@0001d
_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool01`3OW4P0000007Boo`3o
ool0oooO09a80018W=l0C@3oool00`3ogi`0B00007Boo`070?ooo`00RP3oool00`2oM00004RL0=oo
o`020?ooo`030;md0000M;l0oooo00L0oooo00<0gia804RLg`3oool00P3oool00`3OW7@0W=oo0?oo
o`120?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool02@3oool0103ooml0W4P00018
W03Ooom40?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01@3oool00`3ooml0W4P0
001d_`030?ooo`030?noM000B9`0gooo0480oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo
0?ooo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03Oool0C03oool00`3ogi`0B000
07Boo`070?ooo`00R@3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00P0oooo00<0
gia807Boo`3oool0A@3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00D0oooo00<0
_g@00000000000001@0000000`1d_ol0oooo0?ooo`100?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool01@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo0440oooo00<0
oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030;md0000M;l0oooo0080oooo00<0
_g@00018W03Oool0C03oool00`3ogi`0B00007Boo`070?ooo`00R@3oool00`3ogi`0B00007Boo`03
0?ooo`030?noM00004P0W=oo00T0oooo00<0_gA809cOo`3oool0A03oool00`3ogi`0B00007Boo`03
0?ooo`030?noM00004P0W=oo00D0oooo00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL0=oood<0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd0000B02Lgol0@@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0
oooo00L0omnL04P0M02oool0oooo0;md00000000M;oo04d0oooo00<0omnL04P0001d_ol01`3oool0
08T0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`090?ooo`030?oog`2LB7@0_ooo
04@0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`070=nLB01d_ol0oooo
0?oog`2LB00004RL0=ooo`130?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3o
ool00`3ogi`0B00007Boo`030?ooo`030;md000004P0W=oo0440oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`070?ooo`050?oo_`1dB4P0B00000000018W=l0CP3oool00`3ogi`0B000
07Boo`070?ooo`00R@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00X0oooo00<0
okmd001d_`3oool0@`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0
oooO09a8M02oool0oooO09a80000B9`0gooo04<0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`050?ooo`080?oo_`1d0000000004RLg`3oool0okmd00000000M;m20?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool0103ogi`0B00000000000M;m?0?ooo`030?oO
W0180000M;oo00L0oooo00290?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol02P3o
ool00`3ookl0M01809cOo`130?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3o
ool01P3ogi`0B7Bo0?oog`2LB00004RL0=oood<0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`060?ooo`030;md0000B9`0_ia80080000000<004RL0=ooo`3oool0@@3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00H0omnL04P0000007@0_ooo0?noM000M;m>
0?ooo`030?oOW0180000M;oo00L0oooo00290?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000
M02oool02P3oool00`3ookl0M00004RLg`130?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000
M02oool0203oool01@3OW4P0M;oO09a80000B9`0gooo04<0oooo00<0oono07@00018W=l00`3oool0
0`3OW4P0001d0;ooo`060?ooo`030?oOW0180000M;oo04H0oooo00<0oono07@00018W=l00`3oool0
0`3OW4P0001d0;ooo`060?ooo`030;md000007@0_ooo0080oooo00<0_g@004RLg`3oool0C03oool0
0`3ogi`0B00007Boo`070?ooo`00RP3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo
00D0oooo00<0oknL09cOo`3oool00P3oool00`3ogi`0B00004RLg`140?ooo`030=nLB000B9`0gooo
0080oooo00<0_g@0001d_`3oool0203oool01@3ooml0W4Q804Q80000B9`0gooo04@0oooo00<0gia8
0018W03Oool00P3oool00`2oM00007Bo0?ooo`070?ooo`030=nLB00004P0W=oo04H0oooo00<0gia8
0018W03Oool00P3oool00`2oM00007Bo0?ooo`060?ooo`030;md0000B9`0gooo0080oooo00<0gia8
001d_`3oool0C03oool00`3ogi`0B00007Boo`070?ooo`00RP3oool01`3ookl0M00007Boo`3oool0
okmd0000M02oool01P3oool0203ooml0W4Q809cOo`3oool0oono07@0000007@0_oooA03oool01`3o
okl0M00007Boo`3oool0okmd0000M02oool02P3oool0103ogi`0B0000018W03Ooom40?ooo`070?oo
_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`090?ooo`030?noM000000007Bo04D0oooo00L0oono07@0
001d_ol0oooo0?noM00007@0_ooo00L0oooo00L0okmd0000001d_ol0oooo0?oo_`1d0000M;oo04/0
oooo00D0oooO09a800000000000007Boo`070?ooo`00R`3oool01@3ookl0M0000000000007@0_ooo
00P0oooo00H0oooO09a80000000000000000M02ooom60?ooo`050?oo_`1d000000000000M02oool0
303oool00`3OW4P004RL0=ooo`150?ooo`050?oo_`1d000000000000M02oool02`3oool01@3ooml0
W4P00000000007@0_ooo04<0oooo00D0oono07@000000000001d0;ooo`090?ooo`050?noM0000000
000000000018W=l0CP3oool00`3o_g@0000007Boo`070?ooo`00o`3ooooo0?ooo`80oooo003o0?oo
ool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3o
ool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0oooo
o`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool003`0ooooo`00002m0000
00P0oooo000l0?ooo`800000503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0
oooo000l0?ooo`030000003oool0000005H0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`060?ooo`00?03oool010000000oooo0?ooo`00003o0?oookP0oooo00<000000?ooo`3oool0
1P3oool003`0oooo00@000000?ooo`3oool0oooo0P00003o0?oookH0oooo00<000000?ooo`3oool0
1P3oool003`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oook<0oooo00<0
00000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o
0?oook80oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?oook40oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`3o0?oook00oooo00<000000?ooo`3oool01P3oool003`0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooojl0oooo00<000000?ooo`3oool0
1P3oool003`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooojh0oooo00<0
00000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o
0?ooojd0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`3o0?oooj`0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?oooj`0oooo00<000000?ooo`3oool01P3oool003`0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooj/0oooo00<000000?ooo`3oool0
1P3oool003`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooojX0oooo00<0
00000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o
0?ooojT0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`3o0?ooojP0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3o0?ooojL0oooo00<000000?ooo`3oool01P3oool003`0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooojH0oooo00<000000?ooo`3oool0
1P3oool003`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooojD0oooo00<0
00000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o
0?oooj@0oooo00<000000?ooo`3oool01P3oool003`0oooo0`00000C0?ooo`030000003oool0oooo
0?l0ooooXP3oool2000000P0oooo000l0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0o`3ooonQ0?ooo`800000203oool003`0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`3o0?oooj00oooo0P0000080?ooo`00?03oool2000001L0oooo00<000000?ooo`3oool0o`3o
oonO0?ooo`800000203oool003`0oooo0P00000H0?ooo`030000003oool0oooo0?l0ooooWP3oool2
000000P0oooo000l0?ooo`8000006@3oool00`000000oooo0?ooo`3o0?oooid0oooo0P0000080?oo
o`00?03oool2000001X0oooo00<000000?ooo`3oool0o`3ooonL0?ooo`800000203oool003`0oooo
0P00000K0?ooo`030000003oool0oooo0?l0ooooV`3oool2000000P0oooo000l0?ooo`800000703o
ool00`000000oooo0?ooo`0Q0?ooo`800000o`3ooole0?ooo`800000@03oool2000000P0oooo000l
0?ooo`8000007@3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0000000000?l0oooo<`3o
ool2000000030?ooo`000000000003h0oooo0P0000080?ooo`00?03oool2000001h0oooo00<00000
0?ooo`3oool07@3oool010000000oooo0?ooo`3oool200000?l0oooo<P3oool01@000000oooo0?oo
o`3oool0000003h0oooo0P0000080?ooo`00?03oool2000001l0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo;P3oool2000000D0oooo00<0
00000?ooo`3oool0>`3oool2000000P0oooo000l0?ooo`800000803oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0>`3oool2000000P0oooo000l0?ooo`8000008@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool/0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>P3oool2000000P0oooo000l0?ooo`80
00008P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3oool[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>P3oool2000000P0
oooo000l0?ooo`8000008`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0o`3ooolZ0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
>P3oool2000000P0oooo000l0?ooo`800000903oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0>@3oool2000000P0oooo000l0?ooo`8000009@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0>@3oool2000000P0oooo000l0?ooo`8000009P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolW0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0>03oool2000000P0oooo000l0?ooo`80
00009`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0o`3ooolW0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0>03oool2000000P0
oooo000l0?ooo`800000:03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
=`3oool2000000P0oooo000l0?ooo`800000:@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0=`3oool2000000P0oooo000l0?ooo`<00000:@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0=`3oool2000000P0oooo000l0?ooo`800000:`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolU0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=P3oool2000000P0oooo000l0?ooo`80
0000;03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0o`3ooolU0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=P3oool2000000P0
oooo000l0?ooo`800000;@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
=P3oool2000000P0oooo000l0?ooo`800000;P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0=P3oool2000000P0oooo000l0?ooo`800000;`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0=@3oool2000000P0oooo000l0?ooo`800000<03oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolS0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0=@3oool2000000P0oooo000l0?ooo`80
0000<@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0o`3ooolR0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0=@3oool2000000P0
oooo000l0?ooo`800000<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0o`3ooolR0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
=@3oool2000000P0oooo000l0?ooo`800000<`3oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool0o`3ooolR0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
=@3oool2000000P0oooo000l0?ooo`800000=03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0oooo0?l0oooo8@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03D0oooo
0P0000080?ooo`00?03oool2000003D0oooo00<000000?ooo`0000004`3oool00`000000oooo0?oo
o`3o0?ooob00oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`800000203o
ool003`0oooo0P00000f0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooolP
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03oool2000000P0oooo000l0?oo
o`800000=P3oool2000001<0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0=03oool2000000P0oooo000l0?ooo`800000=P3oool00`000000
oooo0000000B0?ooo`030000003oool0oooo0?l0oooo7`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03@0oooo0P0000080?ooo`00?03oool2000003H0oooo00<000000?ooo`3oool0
0P00000@0?ooo`030000003oool0oooo0?l0oooo7`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo03@0oooo0P0000080?ooo`00?03oool2000003H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo7`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo03@0oooo0P0000080?ooo`00?03oool2000003H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo7P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03<0oooo0P0000080?ooo`00?03oool20000
03D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0?l0oooo7@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03<0oooo0P0000080?oo
o`00?03oool2000003D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0?l0oooo7@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03<0
oooo0P0000080?ooo`00?03oool2000003D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo03<0oooo0P0000080?ooo`00?03oool2000003D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0380oooo0`0000080?ooo`00?03oool3000003@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo7@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0380oooo0`0000080?ooo`00?03oool20000
03D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0oooo6`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0380oooo0`0000080?oo
o`00?03oool2000003@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0340
oooo0`0000080?ooo`00?03oool2000003@0oooo00<000000?ooo`3oool02`3oool3000000P0oooo
00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo00L0oooo0P00000=0?ooo`030000
003oool0oooo0340oooo0`0000080?ooo`00?03oool2000003@0oooo00<000000?ooo`3oool02@3o
ool6000000L0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo00H0oooo1@00
000;0?ooo`030000003oool0oooo0340oooo0`0000080?ooo`00?03oool2000003@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`3o
0?oooaX0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0<@3oool3000000P0oooo000l0?ooo`800000=03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo
0?l0oooo6P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0a0?ooo`<00000203oool003`0oooo0`00000c0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000050?ooo`03
0000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0a0?ooo`<00000203oool003`0oooo
0`00000b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
000000040?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0a0?ooo`<00000
203oool003`0oooo0`00000b0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0a0?ooo`<00000203oool003`0oooo0`00000b0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?l0oooo
6@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0`0?ooo`<00000203oool003`0oooo0`00000b0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo0?l0oooo5`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0`0?ooo`<00000203oool003`0oooo0`00
000b0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0o`3ooolG0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0300oooo
0`0000080?ooo`00?03oool300000380oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0:0?ooo`070000003oool0oooo0?ooo`000000oooo0000003o0?oooaT0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0<03oool3000000P0oooo000l0?ooo`<00000<@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool200000?l0oooo6@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0`0?ooo`<00000203oool003`0oooo0`00000a0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`800000o`3ooolH0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0300oooo0`0000080?ooo`00?03oool300000340oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0300oooo0`0000080?ooo`007`3oool01@3ogi`0B0000000000007@0
_ooo00<0oooo00D0okmd0000001d_ol0oooo0;md00060000000304RLg`3oool0oooo00L0oooo0`00
000a0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`020?ooo`800000o`3ooolG0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02l0oooo0`0000080?ooo`007P3oool01`3ookl0M00007Bo
o`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?ooo`030=nLB0000000000000<0
000000<004RL0=ooo`3oool01`3oool300000340oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000o`3ooolF0?ooo`05
0000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`000000203oool001h0oooo00<0_g@00018W03Oool00P3oool00`2oM000
07Bo0?ooo`070?ooo`030=nLB018W=l0oooo0080oooo00<0giad09cOo`3oool01`3oool00`000000
oooo0000000a0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000?l0oooo503oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0000000P0oooo000M0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02o
ool0203oool00`3OW4P0M;oo0?ooo`0;0?ooo`030000003oool000000340oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
0?l0oooo4P3oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0000000P0oooo000M0?ooo`030?oOW0180000M;oo
00<0oooo00<0okmd0000B02Lgol02@3oool00`2oM4P0W=oo0?ooo`0:0?ooo`030000003oool00000
0300oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00D000000?oo
o`3oool0oooo0000000B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo000000080?ooo`007@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00T0oooo00<0oooO09a8M02oool02P3oool4000002l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`h0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0;P3oool4000000P0oooo000M0?ooo`030?oOW0180000M;oo
00<0oooo00<0okmd0000B02Lgol02P3oool00`3o_g@007Bo0?ooo`090?ooo`030000003oool00000
0300oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`d0oooo00D000000?oo
o`3oool0oooo0000000B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo000000080?ooo`007@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00X0oooo00<0oono07@0B02Lgol02@3oool00`000000oooo0000000`0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`3oool0o`3oool<0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0000000P0oooo000M0?ooo`030?oo_`1d0000
B9cO00<0oooo00<0gia80000M02oool02P3oool00`3ookl0M00004RLg`090?ooo`030000003oool0
00000300oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`050000003oool0
oooo0?ooo`000000203oool00`000000oooo0?ooo`3o0?ooo`/0oooo00@000000?ooo`3oool00000
503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02h0oooo00<000000?ooo`000000
203oool001h0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?noW02L
gol0oooo0080oooo00<0omnL04P00018W=l02@3oool00`000000oooo0000000`0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool0o`3oool90?ooo`050000003oool0oooo0?ooo`000000503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02h0oooo00<000000?ooo`000000203oool001h0oooo
00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00H0oooo00P0oooO09a8B02Lgol0oooo0?oo_`1d
0000001d0;ooo`T0oooo00<000000?ooo`000000<03oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0?l0
oooo203oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0000000P0oooo000O0?ooo`050?oo_`1d000000000000
M02oool0203oool01P3ooml0W4P0000000000000001d0;ooo`X0oooo00<000000?ooo`000000<03o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0oooo0?l0oooo1`3oool01@000000oooo0?ooo`3oool0000001D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0000000P0
oooo000l0?ooo`030000003oool000000300oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`3o0?ooo`H0
oooo00@000000?ooo`3oool000005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`000000203oool003`0oooo00<000000?ooo`000000<03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000<0?oo
o`030000003oool0oooo0?l0oooo1@3oool010000000oooo0?ooo`00000F0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo000000080?ooo`00?03oool00`00
0000oooo0000000_0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0503oool01@00
0000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool0o`3oool40?ooo`040000003oool0
oooo000001H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0000000P0oooo000l0?ooo`030000003oool0000002l0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0E0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`040000003oool0oooo000001H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0000000P0oooo000l0?ooo`030000003oool0000002l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo000000l0oooo
00<000000?ooo`3oool0o`3oool10?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02d0oooo00<000000?ooo`000000203oool003`0oooo
00<000000?ooo`000000;`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo
00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`3o0?ooo`040000003oool0oooo0000
01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool00000
00P0oooo000l0?ooo`030000003oool0000002l0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0F0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0oP3oool01000
0000oooo0?ooo`00000H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo000000080?ooo`00?03oool00`000000oooo0000000_0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo0?d0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`000000203oool003`0oooo00<000000?ooo`000000;`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`3l0?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0000000P0oooo000l0?ooo`030000003o
ool0000002l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`8000002P3o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`000000
2P3oool2000000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0000000P0oooo000l0?ooo`030000003oool0000002l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`<0000000<0oooo000000000000203oool010000000oooo0?oo
o`00000C0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`000000203oool6000000/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0/0?ooo`030000003oool0000000P0oooo
000l0?ooo`030000003oool0000002h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?oo
o`00000D0?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`000000203oool00`000000oooo
0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`000000203oool003`0oooo00<000000?ooo`000000;P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool0n03oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo0P0000000`3oool000000?ooo`070?ooo`00
?03oool00`000000oooo0000000^0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000
5P3oool00`000000oooo0?ooo`3g0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0:`3oool2000000030?ooo`000000oooo00L0oooo000l0?ooo`030000003oool0000002h0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo0?H0
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?ooo`80000000<0oooo0000003o
ool01`3oool003`0oooo0`00000^0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
00005`3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0000000H0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0:`3oool4000000P0oooo000l0?ooo`030000003oool0000002h0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0[0?ooo`80000000<0oooo0000003oool01`3oool003`0oooo
00<000000?ooo`000000;P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000001T0
oooo00<000000?ooo`3oool0J@3oool4000008H0oooo00<000000?ooo`0000001@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0[0?ooo`80000000<0oooo0000003oool01`3oool003`0oooo00<000000?ooo`000000
;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001X0oooo0P00001W0?ooo`80
0000103oool00`000000oooo0?ooo`230?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0:P3oool2000000030?ooo`000000oooo00L0oooo000l0?ooo`030000003oool0000002h0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0000000L0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`210?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0:P3oool2000000030?ooo`000000oooo00L0oooo000l0?ooo`030000003o
ool0000002d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000M0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool01P3oool200000840oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0Z0?ooo`80000000<0oooo0000003oool01`3oool003`0oooo00<00000
0?ooo`000000;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001d0oooo00<0
00000?ooo`3oool0G`3oool2000000/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0000
00040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02X0oooo0P0000000`3oool000000?ooo`070?ooo`00?03oool0
0`000000oooo0000000]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:P3oool2000000030?ooo`00
0000oooo00L0oooo000l0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0Z0?ooo`80000000<0oooo0000003oool01`3oool003`0oooo00<000000?ooo`000000;@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O@3oool2000000@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0:P3oool2000000030?ooo`000000oooo00L0oooo000l0?ooo`040000003oool0
0000000002`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0140oooo00L000000?ooo`3oool0oooo0000003oool000000240oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07`0oooo0P0000040?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02X0oooo0P0000000`3oool000000?ooo`070?ooo`00?03oool010000000oooo
00000000000/0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0A0?ooo`070000003oool0oooo0?ooo`000000oooo0000000R0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0:P3oool2000000030?ooo`000000oooo00L0oooo000l0?oo
o`040000003oool00000000002`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0140oooo00L000000?ooo`3oool0oooo0000003oool000000280oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`80000000<0oooo0000003oool0
1`3oool003`0oooo00@000000?ooo`0000000000:`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0NP3oool00`000000oooo000000030?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02T0
oooo0P0000000`3oool000000?ooo`070?ooo`00?03oool010000000oooo00000000000[0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0NP3oool2000000<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0:@3oool2000000030?ooo`000000oooo00L0oooo000l0?ooo`040000003oool000000000
02/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01<0oooo00L000000?ooo`3oool0oooo0000003oool0000002@0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07T0oooo0P0000030?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02T0oooo0P0000000`3oool000000?ooo`070?ooo`00?03oool010000000oooo00000000
000[0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0C0?ooo`070000003oool0oooo0?ooo`000000oooo0000000U0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1i0?ooo`8000000`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0Y0?ooo`80000000<0oooo0000003oool01`3oool003`0oooo00@000000?ooo`000000
0000:`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool04`3oool01`000000oooo0?ooo`3oool000000?ooo`0000009P3oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0N03oool200000080oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:@3oool2000000030?ooo`000000oooo00L0oooo000l0?ooo`040000003oool00000
000002/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01D0oooo00H000000?ooo`3oool000000?ooo`00000W0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1h0?ooo`8000000P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0Y0?ooo`80000000<0oooo0000003oool01`3oool003`0oooo00@000000?ooo`0000000000
:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
5@3oool01P000000oooo0?ooo`000000oooo000002P0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo07L0oooo0P0000030?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02T0oooo0P0000000`3oool000000?ooo`070?ooo`00?03oool010000000oooo00000000000[0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0MP3oool200000080oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:@3oool2000000030?ooo`000000oooo00L0oooo000l0?ooo`040000003oool00000
000002/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01D0oooo00L000000?ooo`3oool0oooo0000003oool0000002T0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo07H0oooo0P0000020?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo02T0oooo0P0000000`3oool000000?ooo`070?ooo`00?03oool010000000oooo0000
0000000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0F0?ooo`060000003oool0oooo0000003oool00000:P3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0M@3oool200000080oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0:@3oool2000000030?ooo`000000oooo00L0oooo000l0?ooo`@00000:P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool01P000000
oooo0?ooo`000000oooo000002/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo07D0oooo0P0000020?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000002/0oooo100000080?ooo`00?03oool0
10000000oooo00000000000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0G0?ooo`060000003oool0oooo0000003oool00000;03oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0M03oool010000000
oooo0?ooo`00000J0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`80000000<0oooo0000003oool01`3oool003`0oooo00@000000?ooo`0000000000:P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool0
1P000000oooo0?ooo`000000oooo000002d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo07@0oooo00@000000?ooo`3oool000006P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:03oool200000003
0?ooo`000000oooo00L0oooo000l0?ooo`040000003oool00000000002X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00D000000?ooo`00
0000oooo0000000^0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1d0?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo0P0000000`3oool000000?ooo`07
0?ooo`00?03oool010000000oooo00000000000Z0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00800000;`3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0LP3oool2
00000080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`0000080?ooo`00?03oool0
10000000oooo0?ooo`00000Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0I0?ooo`060000003oool0oooo0000003oool00000;`3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0LP3oool200000003
0?ooo`000000oooo01/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02P0oooo00@000000?ooo`3oool00000203oool003`0oooo00@000000?ooo`3o
ool00000:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool06@3oool01P000000oooo0?ooo`000000oooo00000300oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0780oooo0P0000000`3oool000000?oo
o`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0X0?ooo`040000003oool0oooo000000P0oooo000l0?ooo`040000003oool0oooo000002X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo
00D000000?ooo`000000oooo0000000a0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`1a0?ooo`040000003oool0oooo000001`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00@000000?oo
o`3oool00000203oool003`0oooo00@000000?ooo`3oool00000:@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool01@000000oooo0000003o
ool000000380oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0740oooo00@000000?ooo`3oool00000703oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`000000:P3oool010000000oooo0?ooo`0000080?ooo`00?03oool010000000
oooo0?ooo`00000Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0K0?ooo`050000003oool000000?ooo`000000<`3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0L@3oool010000000oooo0?ooo`00
000L0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000Z0?ooo`040000
003oool0oooo000000P0oooo000l0?ooo`040000003oool0oooo000002T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool00P00000d0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0000001h0oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool0000002X0oooo00@000000?ooo`3oool00000203oool003`0oooo00@000000?oo
o`3oool00000:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0703oool010000000oooo00000000000e0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1`0?ooo`030000003oool0000001h0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000002X0oooo00@000000?ooo`3oool0
0000203oool003`0oooo00@000000?ooo`3oool00000:@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool01@000000oooo0000003oool00000
03D0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
06l0oooo0P0000000`3oool000000?ooo`0M0?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo0000000Z0?ooo`040000003oool0oooo000000P0oooo000l0?ooo`040000003oool0
oooo000002T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01`0oooo00D000000?ooo`000000oooo0000000f0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1_0?ooo`80000000<0oooo0000003oool0
7@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000:P3oool010000000
oooo0?ooo`0000080?ooo`00?03oool010000000oooo0?ooo`00000Y0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`050000003oool00000
0?ooo`000000=`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0KP3oool2000000030?ooo`000000oooo01d0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool00000203o
ool003`0oooo00@000000?ooo`3oool00000:@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool07P3oool2000000030?ooo`000000oooo03L0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`0000007`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool09`3oool010000000oooo0?ooo`0000080?ooo`00?03oool010000000oooo0?oo
o`00000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0N0?ooo`040000003oool00000000003T0oooo0P00000d0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0KP3oool00`000000oooo0000000P0?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo0000000X0?ooo`8000000P3oool00`000000oooo0?ooo`060?oo
o`00?03oool010000000oooo0?ooo`00000Y0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`040000003oool00000000003/0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo00<00000
0?ooo`000000803oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000:03o
ool200000080oooo00<000000?ooo`3oool01P3oool003`0oooo00@000000?ooo`3oool00000:@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3o
ool010000000oooo00000000000l0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool000000200oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000002P0oooo0P0000020?ooo`030000003oool0oooo00H0
oooo000l0?ooo`040000003oool0oooo000002P0oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool000000280oooo0`00000m0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`1]0?ooo`030000003oool000000200oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000002P0oooo0P0000020?ooo`030000003oool0
oooo00H0oooo000l0?ooo`040000003oool0oooo000002P0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000280oooo0P0000000`3oool000000?ooo`0l0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1/0?ooo`80000000<0
oooo0000003oool07`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000
:03oool200000080oooo00<000000?ooo`3oool01P3oool003`0oooo00@000000?ooo`3oool00000
:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
803oool2000000030?ooo`000000oooo03d0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo06/0oooo0`00000Q0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo0000000X0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`00
?03oool4000002P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0200oooo00@000000?ooo`0000000000?`3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0000000R0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000X0?ooo`80000000<0oooo0000
00000000203oool003`0oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool300000400oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`0000008P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000:03oool2
00000080oooo00<000000?ooo`3oool01P3oool003`0oooo00@000000?ooo`3oool00000:03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool3
00000440oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo06/0oooo00<000000?ooo`0000008P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000002P0oooo0P0000020?ooo`030000003oool0oooo00H0oooo000l0?ooo`040000003oool0
oooo000002P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000002@0oooo
0`0000110?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`1[0?ooo`030000003oool000000280oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`00000X0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`00?03oool010000000oooo
0?ooo`00000X0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000T0?oo
o`<00000@P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0JP3oool2000002<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000002L0oooo0P0000020?ooo`030000003oool0oooo00H0oooo000l0?ooo`040000003oool0oooo
000002P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000002D0oooo0P00
00130?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`1Z0?ooo`8000008`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000
9`3oool200000080oooo00<000000?ooo`3oool01P3oool003`0oooo00@000000?ooo`3oool00000
:03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000009@3oool2000004@0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo06X0
oooo0P00000T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000W0?oo
o`8000000P3oool00`000000oooo0?ooo`060?ooo`00?03oool010000000oooo0?ooo`00000X0?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000U0?ooo`<00000A03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0J@3oool3
000002@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000002L0oooo0P00
00020?ooo`030000003oool0oooo00H0oooo000l0?ooo`040000003oool0oooo000002P0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02<0oooo0`0000150?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0000002@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000002L0
oooo0P0000020?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00800000
9`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool08`3oool3000004H0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo06T0
oooo0P00000U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000W0?oo
o`8000000P3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`02000002L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02@0oooo0P0000170?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1X0?oo
o`8000009@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000002L0oooo0P000002
0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo008000009P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000009`3oool2000004P0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo06P0oooo0P00000U
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000009`3oool200000080oooo00<0
00000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool00P00000V0?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo0000000W0?ooo`800000B@3oool2000001h0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`1X0?ooo`8000009@3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000002L0oooo0P0000020?ooo`030000003oool0oooo00H0oooo
000l0?ooo`030000003oool0oooo008000009P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000009`3oool2000004/0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo06P0oooo0P00000U0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000009`3oool200000080oooo00<000000?ooo`3oool01P3oool003`0oooo
00<000000?ooo`3oool00P00000V0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo0000000W0?ooo`800000C03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0J03oool2000002H0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`00000W0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000
oooo0?ooo`02000002H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
02L0oooo0P00001=0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`1V0?ooo`8000009`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000002L0oooo0P0000020?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo
008000009P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool09P3oool2
000004d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo06H0oooo0P00000W0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
000V0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`007`3oool01@3ogi`0B00000000000
07@0_ooo00<0oooo00<0okmd0000001d_ol01@3oool0103ooml0W4P00018W03Oool90?ooo`030000
003oool0oooo008000009P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool09P3oool2000004h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo06H0oooo0P00000W0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000V0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`007P3oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`050?ooo`040?oog`2LB000
04RL0=ooo`T0oooo00<000000?ooo`3oool00P00000V0?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`0V0?ooo`800000C`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0IP3oool2000002L0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000002H0oooo0P0000020?ooo`030000003oool0oooo00H0
oooo000N0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool02@3oool0103ooml0W4P0
0018W03Oool90?ooo`030000003oool0oooo008000009P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool09`3oool200000500oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo06H0oooo0P00000W0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000009P3oool200000080oooo00<000000?ooo`3oool01P3oool0
01d0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030;md000000000000
00D0000000<0M;oo0?ooo`3oool01P3oool00`000000oooo0?ooo`02000002H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo02L0oooo0P00001A0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000V0?ooo`8000000P3o
ool00`000000oooo0?ooo`060?ooo`007@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00D0oooo00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL0=ooo`T0oooo00<000000?ooo`3o
ool00P00000V0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0W0?oo
o`800000D@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0I03oool2000002T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000V
0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`007@3oool00`3ogi`0B00007Boo`030?oo
o`030?noM00004P0W=oo00H0oooo00L0gia807Boo`3oool0oooO09a80000B9`0gooo00T0oooo1@00
000V0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo06@0oooo0P00000Y0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00009P3oool5000000P0oooo000M0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0
1P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03Oool02@3oool00`000000oooo0?ooo`020000
02H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0I03oool2000002T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000V0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`007@3oool00`3ogi`0B00007Boo`03
0?ooo`030?noM00004P0W=oo00L0oooo00H0omnL04Qd_`3ooml0W4P00018W03Oool90?ooo`030000
003oool0oooo008000009@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000:P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`1T0?ooo`800000:@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000002H0oooo0P0000020?ooo`030000003oool0oooo00H0oooo000M0?ooo`03
0?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool01@3OW4P0M;oO09a80000B9`0gooo
00T0oooo00<000000?ooo`3oool00P00000U0?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`0X0?ooo`800000E03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0H`3oool2000002T0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`00000V0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`007P3oool0
0`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00P0oooo00D0oooO09a8B018B00004RL0=oo
o`090?ooo`030000003oool0oooo008000009@3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0:03oool2000005D0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000002H0oooo0P0000020?ooo`030000003oool0oooo00H0
oooo000N0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0:0?ooo`040?oOW018000004RL
0=ooo`T0oooo00<000000?ooo`3oool00P00000U0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`0Y0?ooo`800000EP3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000009P3oool200000080oooo00<000000?ooo`3oool0
1P3oool001l0oooo00D0oono07@000000000001d0;ooo`0<0?ooo`030=nLB000B9`0gooo00T0oooo
00<000000?ooo`3oool00P00000U0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0680oooo0P00000Z0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo0000000U0?ooo`8000000P3oool00`000000oooo0?ooo`060?oo
o`00?03oool00`000000oooo0?ooo`02000002D0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0HP3oool2000002/0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`8000000P3oool00`000000oooo0?ooo`06
0?ooo`00?03oool00`000000oooo0?ooo`02000002D0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0H@3oool2000002/0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`050000003oool0oooo0?ooo`000000
203oool003`0oooo00<000000?ooo`3oool00P00000U0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0640oooo0P00000[0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000009@3oool01@000000oooo0?ooo`3oool00000
00P0oooo000l0?ooo`030000003oool0oooo008000009@3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`050000003oool0
oooo0?ooo`000000203oool003`0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0Z0?ooo`800000F`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000009@3oool01@000000
oooo0?ooo`3oool0000000P0oooo000l0?ooo`050000003oool0oooo0?ooo`0000009@3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo02X0oooo0P00001L0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`050000003o
ool0oooo0?ooo`000000203oool003`0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1O0?ooo`80
0000;03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000002D0oooo00D000000?oo
o`3oool0oooo000000080?ooo`00?03oool01@000000oooo0?ooo`3oool0000002D0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05`0oooo00D0
00000?ooo`3oool0oooo0000000e0?ooo`030000003oool0oooo05l0oooo0P00000]0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0R0?ooo`8000000`3oool00`000000
oooo0?ooo`060?ooo`00?03oool01@000000oooo0?ooo`3oool0000002D0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`000000=P3oool00`000000oooo0?ooo`1O0?ooo`800000;@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool08P3oool2000000<0oooo00<000000?ooo`3oool01P3oool0
03`0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05h0oooo0P00000f0?ooo`030000003o
ool0oooo05l0oooo0P00000]0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0R0?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`00?03oool01@000000oooo0?oo
o`3oool0000002@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo05l0
oooo0P00000]0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0R0?oo
o`8000000`3oool00`000000oooo0?ooo`060?ooo`00?03oool01@000000oooo0?ooo`3oool00000
02@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo02`0oooo0P00001P
0?ooo`800000=P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00000S0?ooo`8000000`3oool00`000000oooo0?oo
o`060?ooo`00?03oool01@000000oooo0?ooo`3oool0000002@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo02`0oooo0P00001P0?ooo`030000003oool0000003D0oooo
00<000000?ooo`3oool0G@3oool2000002h0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000S0?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`00?03oool01@000000oooo
0?ooo`3oool0000002@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
02`0oooo0P00001O0?ooo`050000003oool0oooo0?ooo`000000=03oool00`000000oooo0?ooo`1M
0?ooo`800000;P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000002<0oooo0P00
00030?ooo`030000003oool0oooo00H0oooo000l0?ooo`040000003oool0oooo0?ooo`8000008`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0;@3oool2000005l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05d0oooo
0P00000_0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0Q0?ooo`80
00000`3oool00`000000oooo0?ooo`060?ooo`00?03oool3000000030?ooo`000000000002<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05d0
oooo0P00000_0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0Q0?oo
o`8000000P3oool2000000P0oooo000l0?ooo`040000003oool0oooo0?ooo`8000008`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0G03oool2
000002l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0240oooo0P00
00030?ooo`030000003oool0oooo00H0oooo000l0?ooo`040000003oool0oooo0?ooo`8000008`3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02h0oooo0P00001N0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1L0?ooo`800000
;`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool08@3oool2000000<0
oooo00<000000?ooo`3oool01P3oool003`0oooo00@000000?ooo`3oool0oooo0P00000S0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0;P3oool2000005d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05/0oooo0`00000_0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0Q0?ooo`8000000`3oool0
0`000000oooo0?ooo`060?ooo`00?03oool010000000oooo0?ooo`3oool2000002<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0^0?ooo`800000G@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0F`3oool200000300oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0240oooo0P0000030?ooo`030000
003oool0oooo00H0oooo000l0?ooo`040000003oool0oooo0?ooo`8000008`3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo02h0oooo0P00001M0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1K0?ooo`800000<03oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool08@3oool2000000<0oooo00<000000?oo
o`3oool01P3oool003`0oooo00@000000?ooo`3oool0oooo0P00000S0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0;P3oool2000005d0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05X0oooo0P00000`0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000008`3oool2000000<0oooo00<000000?ooo`3oool01P3oool0
03`0oooo00@000000?ooo`3oool0oooo0P00000R0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0_0?ooo`800000G@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0FP3oool200000340oooo00L000000?ooo`3oool0oooo
0000003oool0000002<0oooo0P0000030?ooo`030000003oool0oooo00H0oooo000l0?ooo`040000
003oool0oooo0?ooo`8000008P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0;`3oool3000005/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo05X0oooo0P00000a0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0P0?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`002@3oool00`2o
M7@0_ooo0?ooo`040?ooo`030;mdM02oool0oooo02T0oooo00@000000?ooo`3oool0oooo0P00000R
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0`0?ooo`800000F`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0F@3o
ool300000340oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0200oooo
0P0000030?ooo`030000003oool0oooo00H0oooo00090?ooo`030;md0018W=l0oooo00<0oooo00<0
gia80000M02oool0:P3oool010000000oooo0?ooo`3oool200000280oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0`0?ooo`800000F`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0000000a0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0P0?ooo`8000000`3oool00`00
0000oooo0?ooo`060?ooo`002@3oool02@2oM00000000000M02oool0oooO09a80018W=l0gibL0;oo
o`0Z0?ooo`040000003oool0oooo0?ooo`8000008P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo0300oooo0P00001K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`1H0?ooo`030000003oool000000340oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0200oooo0P0000030?ooo`030000003oool0oooo
00H0oooo00090?ooo`060;nLW03Ogi`0B0000000000004P0W=oo;@3oool010000000oooo0?ooo`3o
ool200000280oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0`0?ooo`800000
F`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
F03oool200000380oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0200
oooo0P0000030?ooo`030000003oool0oooo00H0oooo00090?ooo`030;mdM02ogi`0B00000800000
00@0001809cOo`3OW9`0_ooo:P3oool010000000oooo0?ooo`3oool200000280oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0`0?ooo`800000FP3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0F03oool200000380oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0200oooo0P0000030?ooo`030000003o
ool0oooo00H0oooo00090?ooo`030;md0000B9`0gooo0080oooo00@0_g@00000000007@0_ooo:P3o
ool010000000oooo0?ooo`3oool200000280oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0`0?ooo`<00000F@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0F03oool2000003<0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0P0?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`002@3oool00`2oM4P0
W=oo0?ooo`030?ooo`030?noM00007@0_ooo02X0oooo00@000000?ooo`3oool0oooo0P00000R0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0<@3oool3000005T0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05L0oooo0`00000c
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0803oool2000000<0oooo00<0
00000?ooo`3oool01P3oool000T0oooo00<0_ibL0=ooo`3oool0103oool00`3OW9`0_ooo0?ooo`0Y
0?ooo`040000003oool0oooo0?ooo`8000008P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0340oooo00<000000?ooo`000000F@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0EP3oool3000003<0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0P0?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`00
?03oool010000000oooo0?ooo`3oool200000280oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0000005T0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`000000<`3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000008P3oool2000000<0oooo00<000000?ooo`3oool01P3o
ool000h0oooo00<0_ibL0=ooo`3oool00P3oool00`3OW9`0_ooo0?ooo`0V0?ooo`040000003oool0
oooo0?ooo`8000008P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0380oooo
0P00001I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0000003<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0280oooo0P0000030?ooo`030000003oool0oooo00H0oooo000:0?ooo`050?oo_`1d04P0W=oo0?oo
_`1d0000100000000`0007@0_ooo0?ooo`0V0?ooo`040000003oool0oooo0?ooo`8000008P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0380oooo0P00001H0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0000003<0oooo00L000000?ooo`3oool0oooo0000003oool000000280oooo0P0000030?ooo`03
0000003oool0oooo00H0oooo000C0?ooo`030=nLW02oool0oooo02H0oooo00@000000?ooo`3oool0
oooo0P00000R0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0<P3oool30000
05L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
05H0oooo0P00000d0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0O
0?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`00?03oool010000000oooo0?ooo`3oool2
00000240oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0b0?ooo`<00000E`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0E03o
ool3000003@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01l0oooo
0P0000030?ooo`030000003oool0oooo00H0oooo000l0?ooo`<0000000<0oooo0000000000008@3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0380oooo0`00001G0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1D0?ooo`<00000
=@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo0P0000020?ooo`80
0000203oool00100oooo00<0_gAd0;ooo`3oool0:@3oool010000000oooo0?ooo`3oool300000200
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0b0?ooo`<00000E`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0E03oool30000
03D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`8000000`3oool0
0`000000oooo0?ooo`060?ooo`00403oool00`2oM7@0_ooo0?ooo`0Y0?ooo`040000003oool0oooo
0?ooo`<00000803oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`000000E`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0000000e0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool07`3oool2000000<0oooo00<000000?ooo`3oool01P3oool00100oooo00<0
_gAd0;ooo`3oool0:@3oool010000000oooo0?ooo`3oool300000200oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0000005H0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`00
0000=@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo0P0000030?oo
o`030000003oool0oooo00H0oooo000=0?ooo`030;md00000000000000<0000000<0001d0;ooo`3o
ool09P3oool010000000oooo0?ooo`3oool300000200oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0c0?ooo`040000003oool00000000005D0oooo00<000000?ooo`3oool0703o
ool7000001d0oooo00<000000?ooo`3oool0E03oool00`000000oooo0000000e0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo000@0?ooo`030;mdM02oool0oooo02T0oooo00@000000?ooo`3oool0oooo
0`00000P0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0=03oool3000005D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`8000007@3oool00`000000
oooo0?ooo`1B0?ooo`80000000<0oooo0000003oool0=03oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`00403oool00`2oM7@0_ooo0?ooo`0Y0?ooo`040000003oool0oooo0?ooo`<00000803oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo03@0oooo0`00001E0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01P3oool2000001`0oooo00<000000?ooo`3oool0DP3oool3
000003H0oooo00L000000?ooo`3oool0oooo0000003oool000000240oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`00403oool00`2oM7@0_ooo0?ooo`0Y0?ooo`040000003o
ool0oooo0?ooo`<00000803oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03@0
oooo0`00001E0?ooo`030000003oool0oooo01P0oooo0P00000:0?ooo`8000006`3oool00`000000
oooo0?ooo`1B0?ooo`<00000=P3oool01`000000oooo0?ooo`3oool000000?ooo`0000008@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo000<0?ooo`030=nLM02Lgol0oooo
00<0oooo00<0omnL04Q8W03Oool09`3oool010000000oooo0?ooo`3oool300000200oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`<00000E03oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00/0oooo0P00000J0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`000000=`3oool01P000000oooo0?ooo`000000oooo00000200oooo0P0000040?ooo`03
0000003oool0oooo00H0oooo000;0?ooo`030?noM018W=l0oooo00D0oooo00<0_gAd0;ooo`3oool0
9P3oool010000000oooo0?ooo`3oool300000200oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0000005@0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0000000g0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool07@3oool20000
00@0oooo00<000000?ooo`3oool01P3oool000/0oooo00H0gia807Boo`3oool0okmd0018W03Oool2
0?ooo`030=no_`3Oool0oooo02H0oooo00@000000?ooo`3oool0oooo0`00000P0?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool0=03oool010000000oooo00000000001C0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`000000=`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo01d0oooo0P0000040?ooo`030000003oool0oooo00H0oooo000;0?ooo`090=nL
B000M;l0oono07AdW02LB000B9cO0?ooo`3o_g@0B9cO02P0oooo00@000000?ooo`3oool0oooo0`00
000P0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0=@3oool010000000oooo0000
0000001C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0403oool2000001P0oooo
00<000000?ooo`3oool0D03oool2000000030?ooo`000000oooo03H0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0M0?ooo`800000103oool00`000000oooo0?ooo`060?ooo`00
2`3oool0203ookl0M0000000M02oool0omnL04P00000000007Bo:@3oool00`000000oooo0?ooo`02
0?ooo`8000007`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03D0oooo00@0
00000?ooo`0000000000D`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo
0P00000G0?ooo`030000003oool0oooo0500oooo0P0000000`3oool000000?ooo`0f0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool07@3oool2000000@0oooo00<000000?ooo`3o
ool01P3oool003`0oooo00<000000?ooo`3oool00P3oool2000001l0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0f0?ooo`<00000D`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`0000005P3oool00`000000oooo0?ooo`1@0?ooo`80
000000<0oooo0000003oool0=P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01d0oooo0P0000040?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo0080
oooo0P00000O0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0=P3oool30000
0580oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool00000
01D0oooo00<000000?ooo`3oool0D03oool3000003P0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0M0?ooo`800000103oool00`000000oooo0?ooo`060?ooo`00?03oool00`00
0000oooo0?ooo`020?ooo`8000007`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo03H0oooo0`00001B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool0
10000000oooo0?ooo`00000D0?ooo`030000003oool0oooo0500oooo00<000000?ooo`000000>03o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01d0oooo0P0000040?ooo`030000
003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo0080oooo0P00000O0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0=P3oool010000000oooo00000000001A0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00000C0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`000000>03oool01`000000oooo0?ooo`3oool0
00000?ooo`0000007`3oool2000000@0oooo00<000000?ooo`3oool01P3oool003`0oooo00<00000
0?ooo`3oool00P3oool2000001l0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0f0?ooo`040000003oool0000000000540oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000004`3oool00`000000oooo0?ooo`1>0?ooo`80
000000<0oooo0000003oool0=`3oool01`000000oooo0?ooo`3oool000000?ooo`0000007`3oool2
000000@0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool00P3oool20000
01l0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0f0?ooo`040000003oool0
000000000540oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0H0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`1>0?ooo`80000000<0oooo0000003oool0
>03oool01P000000oooo0?ooo`000000oooo000001l0oooo0P0000040?ooo`030000003oool0oooo
00H0oooo000l0?ooo`030000003oool0oooo0080oooo0P00000O0?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool0=P3oool010000000oooo00000000001A0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0CP3oool2000000030?ooo`000000oooo03P0oooo00H000000?oo
o`3oool000000?ooo`00000O0?ooo`800000103oool00`000000oooo0?ooo`060?ooo`00?03oool0
0`000000oooo0?ooo`020?ooo`8000007`3oool00`000000oooo000000030?ooo`030000003oool0
oooo03H0oooo00@000000?ooo`0000000000D03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo04h0oooo0P0000000`3oool000000?ooo`0h0?ooo`060000003oool0oooo0000003oool0
00007`3oool2000000@0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool0
0P3oool2000001l0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0g0?ooo`040000
003oool0000000000500oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1>0?ooo`80
000000<0oooo0000003oool0>03oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01`0oooo0P0000040?ooo`030000003oool0oooo00H0oooo000l0?ooo`<000000P3oool2000001l0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0h0?ooo`80000000<0oooo0000003o
ool0CP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`00
0000>P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01`0oooo0P0000030?oo
o`800000203oool003`0oooo00<000000?ooo`3oool00P3oool2000001l0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`0h0?ooo`80000000<0oooo0000003oool0CP3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo04`0oooo0P0000000`3oool000000?ooo`0i0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0703oool2000000@0oooo00<000000?oo
o`3oool01P3oool003`0oooo00<000000?ooo`3oool00P3oool2000001l0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`0h0?ooo`040000003oool00000000004l0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1<0?ooo`80000000<0oooo0000003oool0>@3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01`0oooo0P0000040?ooo`030000003oool0
oooo00H0oooo000l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000007P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo03P0oooo00@000000?ooo`0000000000C`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04`0oooo0P0000000`3oool000000?ooo`0i
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0703oool2000000@0oooo00<0
00000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000M
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0>03oool010000000oooo0000
0000001>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0C03oool2000000030?oo
o`000000oooo03T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0L0?ooo`80
0000103oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`020?ooo`030000
003oool0000001d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0h0?ooo`04
0000003oool00000000004h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1<0?oo
o`80000000<0oooo0000003oool0>@3oool01`000000oooo0?ooo`3oool000000?ooo`0000007P3o
ool2000000@0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000M0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0>03o
ool01@000000oooo0000003oool0000004d0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`030000003oool0oooo04`0oooo
0P0000000`3oool000000?ooo`0j0?ooo`060000003oool0oooo0000003oool000007P3oool20000
00@0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000M0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0>03oool01@00
0000oooo0000003oool0000004d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1:
0?ooo`80000000<0oooo0000003oool0>`3oool01P000000oooo0?ooo`000000oooo000001h0oooo
0P0000040?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000007@3oool00`000000oooo000000020?ooo`030000003oool0oooo03X0oooo0P00
00000`3oool000000?ooo`1<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0BP3o
ool2000000030?ooo`000000oooo03/0oooo00H000000?ooo`3oool000000?ooo`00000N0?ooo`80
0000103oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`020?ooo`030000
003oool0000001d0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0j0?ooo`040000
003oool00000000004`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1:0?ooo`80
000000<0oooo0000003oool0>`3oool01P000000oooo0?ooo`000000oooo000001h0oooo0P000004
0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000007@3oool00`000000oooo000000020?ooo`030000003oool0oooo03X0oooo00@000000?oo
o`0000000000C03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04X0oooo0P000000
0`3oool000000?ooo`0k0?ooo`060000003oool0oooo0000003oool000007P3oool2000000@0oooo
00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000M0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0>P3oool010000000oooo0000
0000001<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0BP3oool2000000030?oo
o`000000oooo03/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0K0?ooo`80
0000103oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`020?ooo`030000
003oool0000001d0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0j0?ooo`050000
003oool000000?ooo`000000B`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000004`0oooo0P0000000`3o
ool000000?ooo`0k0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool06`3oool2
000000@0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool00P3oool30000
01d0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0j0?ooo`050000003oool00000
0?ooo`000000B`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000004X0oooo00D000000?ooo`000000oooo
0000000l0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo0080oooo
0`00000M0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0>P3oool01@000000oooo
0000003oool0000004/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo00`0oooo00@000000?ooo`3oool00000BP3oool200000080oooo00<000000?oo
o`3oool0>P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`020?oo
o`<000007@3oool00`000000oooo000000020?ooo`030000003oool0oooo03X0oooo00D000000?oo
o`000000oooo0000001:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0000004X0oooo0P0000000`3oool000000?ooo`0m
0?ooo`060000003oool0oooo0000003oool000007@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo0080oooo0`00000L0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`02000004X0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00h0oooo
0P00001:0?ooo`80000000<0oooo0000003oool0?@3oool01P000000oooo0?ooo`000000oooo0000
01d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000
oooo0?ooo`020?ooo`<00000703oool01P000000oooo0?ooo`000000oooo000003h0oooo00@00000
0?ooo`0000000000BP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`180?ooo`80000000<0oooo0000003oool0?@3o
ool01P000000oooo0?ooo`000000oooo000001d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`007`3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d
_ol00`3oool01@3ogi`0B000000000000000M;oo00X0oooo00<000000?ooo`3oool00P3oool30000
01`0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0l0?ooo`050000003oool00000
0?ooo`000000B@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool03P3oool2000004T0oooo0P0000000`3oool000000?ooo`0m0?ooo`060000003oool0
oooo0000003oool00000703oool2000000D0oooo00<000000?ooo`3oool01P3oool001h0oooo00L0
oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00<0okmd0000001d_ol00P3oool01`3ogi`0
B00004RLg`3oool0oono07@0001d_ol02@3oool00`000000oooo0?ooo`020?ooo`<00000703oool0
0`000000oooo000000020?ooo`030000003oool0oooo03`0oooo00D000000?ooo`000000oooo0000
00190?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0?0?ooo`800000A`3oool01@000000oooo0000003oool0000003h0oooo00H000000?ooo`3oool0
00000?ooo`00000L0?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`007P3oool00`2oM000
04RL0=ooo`020?ooo`030;md0000M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@0
04RL0=ooo`080?ooo`030000003oool0oooo0080oooo0`00000L0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool0?03oool01@000000oooo0000003oool0000004T0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`000000AP3oool200000080oooo00<000000?ooo`3oool0?03oool01P000000oooo0?ooo`000000
oooo000001`0oooo0P0000050?ooo`030000003oool0oooo00H0oooo000M0?ooo`030?oo_`1d0000
B9cO00<0oooo00<0gia80000M02oool01@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0
W=oo00P0oooo00<000000?ooo`3oool00P3oool3000001`0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0l0?ooo`050000003oool000000?ooo`000000B03oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool03P3oool010000000oooo0?oo
o`0000150?ooo`8000000P3oool00`000000oooo0?ooo`0l0?ooo`060000003oool0oooo0000003o
ool00000703oool2000000D0oooo00<000000?ooo`3oool01P3oool001d0oooo00<0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol0203oool00`000000oooo0?ooo`020?ooo`<00000703oool00`000000oooo000000020?ooo`03
0000003oool0oooo03`0oooo00D000000?ooo`000000oooo000000180?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo
0?ooo`000000A03oool200000080oooo00<000000?ooo`3oool0?03oool01P000000oooo0?ooo`00
0000oooo000001`0oooo0P0000050?ooo`030000003oool0oooo00H0oooo000M0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0B00007Boo`030?ooo`030;md0000
04P0W=oo00P0oooo10000000103oool0000000000000000L0?ooo`030000003oool000000080oooo
00<000000?ooo`3oool0?03oool01@000000oooo0000003oool0000004P0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`110?ooo`80000000<0oooo0000003oool0?P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo01T0oooo0P0000020?ooo`@00000203oool001d0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`080?oo_`1d0000000004RL
g`3oool0okmd00000000M;l90?ooo`030000003oool0oooo0080oooo0`00000L0?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool0?03oool01P000000oooo0?ooo`000000oooo000004L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`80000000<0oooo0000003o
ool0?P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01T0oooo0P0000050?oo
o`030000003oool0oooo00H0oooo000M0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01P3oool00`2oM00004RL0;nLB002000000030018W03Oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool3000001`0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0m0?ooo`05
0000003oool000000?ooo`000000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03l0oooo00D000000?ooo`000000oooo000000100?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool06@3oool2000000D0oooo00<000000?ooo`3oool01P3oool001d0oooo00<0oono07@0
0018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030?oOW0180000M;oo00d0oooo00<000000?oo
o`3oool00P3oool3000001`0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0m0?oo
o`050000003oool000000?ooo`000000AP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo03h0oooo00D000000?ooo`000000oooo000000100?ooo`060000003oool0oooo0000003oool0
00006`3oool2000000D0oooo00<000000?ooo`3oool01P3oool001h0oooo00<0gia80018W03Oool0
0P3oool00`2oM00007Bo0?ooo`070?ooo`030=nLB00004P0W=oo00`0oooo00<000000?ooo`3oool0
0P3oool3000001`0oooo00D000000?ooo`000000oooo000000100?ooo`050000003oool000000?oo
o`000000AP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03d0oooo0P0000020?oo
o`030000003oool0oooo03h0oooo00H000000?ooo`3oool000000?ooo`00000K0?ooo`8000001@3o
ool00`000000oooo0?ooo`060?ooo`007P3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool0
2@3oool00`3o_g@00000001d_`0;0?ooo`030000003oool0oooo0080oooo0`00000K0?ooo`060000
003oool0oooo0000003oool00000@03oool01@000000oooo0000003oool0000004H0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0l0?ooo`8000000P3oool00`000000oooo0?ooo`0n
0?ooo`060000003oool0oooo0000003oool000006`3oool2000000D0oooo00<000000?ooo`3oool0
1P3oool001l0oooo00D0oono07@000000000001d0;ooo`0;0?ooo`050?oog`2LB00000000000M02o
ool0203oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool06@3oool00`000000
oooo000000020?ooo`030000003oool0oooo03h0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>`3oool200000080
oooo00<000000?ooo`3oool0?P3oool01P000000oooo0?ooo`000000oooo000001/0oooo0P000005
0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000006P3oool00`000000oooo000000020?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo000000020?ooo`030000003oool0oooo03h0oooo00H000000?oo
o`3oool000000?ooo`00000K0?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`00?03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000001X0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0n0?ooo`060000003oool0oooo0000003oool00000A@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo03P0oooo00D000000?ooo`000000oooo000000110?ooo`06
0000003oool0oooo0000003oool000006`3oool2000000D0oooo00<000000?ooo`3oool01P3oool0
03`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000J0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool0?P3oool01P000000oooo0?ooo`000000oooo000004@0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0g0?ooo`050000003oool000000?ooo`000000
@@3oool01P000000oooo0?ooo`000000oooo000001/0oooo0P0000050?ooo`030000003oool0oooo
00H0oooo000l0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000006P3oool00`000000
oooo000000020?ooo`030000003oool0oooo03l0oooo00D000000?ooo`000000oooo000000140?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=P3oool01@000000oooo0000003oool0
00000440oooo00H000000?ooo`3oool000000?ooo`00000K0?ooo`8000001@3oool00`000000oooo
0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`030?ooo`030000003oool0000001X0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`0o0?ooo`050000003oool000000?ooo`000000
A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03D0oooo0P0000020?ooo`030000
003oool0oooo03l0oooo00H000000?ooo`3oool000000?ooo`00000K0?ooo`8000001@3oool00`00
0000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`030?ooo`030000003oool0000001X0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03@0
oooo0P0000020?ooo`030000003oool0oooo0400oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`0H0?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo
0?ooo`030?ooo`030000003oool0000001X0oooo00D000000?ooo`000000oooo000000120?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`100?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool0603oool2000000D0oooo00<000000?ooo`3o
ool01P3oool003`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000J0?ooo`050000
003oool000000?ooo`000000@P3oool00`000000oooo000000020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool0@03oool01P000000oooo0?ooo`000000oooo000001X0oooo0P000005
0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000006P3oool01@000000oooo0000003oool000000480oooo00H000000?ooo`3oool000000?oo
o`0000120?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000oooo
000000020?ooo`030000003oool0oooo0400oooo00H000000?ooo`3oool000000?ooo`00000J0?oo
o`8000001@3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000001T0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`100?ooo`06
0000003oool0oooo0000003oool00000@P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02l0oooo00D000000?ooo`000000oooo000000130?ooo`060000003oool0oooo0000003oool0
00006P3oool2000000D0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0000000I0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
@03oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0^0?ooo`050000003oool000000?ooo`000000@`3oool01P00
0000oooo0?ooo`000000oooo000001X0oooo0P0000050?ooo`030000003oool0oooo00H0oooo000l
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000006@3oool00`000000oooo00000002
0?ooo`030000003oool0oooo0400oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;03oool00`000000oooo0000
00020?ooo`030000003oool0oooo0440oooo00H000000?ooo`3oool000000?ooo`00000J0?ooo`80
00001@3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`030?ooo`<00000
6@3oool00`000000oooo000000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo0P00000/0?ooo`030000
003oool000000080oooo00<000000?ooo`3oool0@@3oool01P000000oooo0?ooo`000000oooo0000
01X0oooo0P0000050?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00<0
oooo0`00000I0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0@@3oool00`000000
oooo000000020?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0@@3oool01P000000
oooo0?ooo`000000oooo000001T0oooo0P0000060?ooo`030000003oool0oooo00H0oooo000l0?oo
o`030000003oool0oooo00<0oooo0`00000I0?ooo`030000003oool000000080oooo00<000000?oo
o`3oool0@@3oool01P000000oooo0?ooo`000000oooo00000400oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0@P3o
ool01@000000oooo0000003oool0000001T0oooo0P0000060?ooo`030000003oool0oooo00H0oooo
000l0?ooo`<000000`3oool3000001T0oooo00D000000?ooo`000000oooo000000140?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`120?ooo`05
0000003oool000000?ooo`0000006@3oool2000000D0oooo0P0000080?ooo`00?03oool00`000000
oooo0?ooo`030?ooo`<000006@3oool01@000000oooo0000003oool0000004@0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool09@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0480oooo00D0
00000?ooo`000000oooo0000000I0?ooo`8000001P3oool00`000000oooo0?ooo`060?ooo`00?03o
ool00`000000oooo0?ooo`030?ooo`<000006@3oool01@000000oooo0000003oool0000004@0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0903oool01P000000oooo0?ooo`000000oooo000004D0oooo00<00000
0?ooo`3oool00P00000I0?ooo`8000001P3oool00`000000oooo0?ooo`060?ooo`00?03oool00`00
0000oooo0?ooo`030?ooo`<000006@3oool01@000000oooo0000003oool0000004@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo000000020?ooo`030000003oool0oooo04<0oooo00H0
00000?ooo`3oool000000?ooo`00000H0?ooo`8000001P3oool00`000000oooo0?ooo`060?ooo`00
?03oool00`000000oooo0?ooo`030?ooo`<000006@3oool01@000000oooo0000003oool0000004@0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool08P3oool00`000000oooo000000020?ooo`030000003oool0oooo
04<0oooo00H000000?ooo`3oool000000?ooo`00000H0?ooo`8000001P3oool00`000000oooo0?oo
o`060?ooo`00?03oool00`000000oooo0?ooo`030?ooo`<000006@3oool200000080oooo00<00000
0?ooo`3oool0@`3oool01P000000oooo0?ooo`000000oooo000003h0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
@`3oool01P000000oooo0?ooo`000000oooo000001P0oooo0P0000060?ooo`030000003oool0oooo
00H0oooo000l0?ooo`030000003oool0oooo00<0oooo0`00000H0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool0@`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0Q0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool0@`3oool01P000000oooo0?ooo`000000oooo000001P0oooo0P00
00060?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00<0oooo0`00000H
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0@`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0O0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0@`3oool01P000000oooo
0?ooo`000000oooo000001P0oooo0P0000060?ooo`030000003oool0oooo00H0oooo000l0?ooo`03
0000003oool0oooo00<0oooo0`00000H0?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool0@`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0@`3oool01P000000oooo0?ooo`000000oooo000001P0oooo0P0000060?ooo`030000
003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00<0oooo0`00000H0?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool0@`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0A03oool01@000000oooo0000003oool00000
01P0oooo0P0000060?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00<0
oooo0P0000000`3oool000000?ooo`0F0?ooo`050000003oool000000?ooo`000000AP3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0J0?ooo`L000007@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo000000020?ooo`030000003oool0
oooo04D0oooo00D000000?ooo`000000oooo0000000H0?ooo`8000001P3oool00`000000oooo0?oo
o`060?ooo`00?03oool00`000000oooo0?ooo`030?ooo`80000000<0oooo0000003oool05P3oool0
1@000000oooo0000003oool0000004H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0603oool2000000L0oooo
0P00000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0A@3oool01@000000oooo
0000003oool0000001P0oooo0P0000060?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000
003oool0oooo00<0oooo0P0000000`3oool000000?ooo`0F0?ooo`050000003oool000000?ooo`00
0000AP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool20000
01X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`150?ooo`050000003oool0
00000?ooo`000000603oool2000000H0oooo00<000000?ooo`3oool01P3oool003`0oooo00<00000
0?ooo`3oool00`3oool2000000030?ooo`000000oooo01H0oooo00D000000?ooo`000000oooo0000
00170?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0H0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`02000001P0oooo0P0000060?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000
003oool0oooo00<0oooo0P0000000`3oool000000?ooo`0F0?ooo`050000003oool000000?ooo`00
0000A`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo0P00000G0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0G0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`02
000001P0oooo0P0000060?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo
00@0oooo0`00000G0?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0803oool2000001L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo008000005`3oool00`000000oooo0000
00060?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00@0oooo0`00000G
0?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`02000001L0oooo00<000000?ooo`0000001P3o
ool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`040?ooo`<000005`3oool2
00000080oooo00<000000?ooo`3oool0A@3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool00P00000G0?ooo`030000003oool0000000H0oooo
00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool0103oool3000001H0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`150?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`160?ooo`060000003oool0oooo0000003oool000005P3oool0
0`000000oooo000000060?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo
00@0oooo0`00000F0?ooo`050000003oool000000?ooo`000000B03oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0@0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0A`3oool01@000000oooo0000003oool0000001H0
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo
0?ooo`040?ooo`<000005P3oool01@000000oooo0000003oool0000004T0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00l0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`170?ooo`050000003oool000000?ooo`0000005P3o
ool00`000000oooo000000060?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0
oooo00@0oooo0`00000F0?ooo`050000003oool000000?ooo`000000B@3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool03P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo04L0oooo00D000000?ooo`000000oooo0000000F0?oo
o`030000003oool0000000H0oooo00<000000?ooo`3oool01P3oool003`0oooo0`0000040?ooo`<0
00005P3oool01@000000oooo0000003oool0000004T0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`170?ooo`050000003oool000000?ooo`0000005P3oool00`000000oooo0000
00050?ooo`800000203oool003`0oooo00<000000?ooo`3oool0103oool3000001H0oooo00D00000
0?ooo`000000oooo000000190?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0A`3oool01@000000oooo0000003oool0000001H0oooo0`0000060?ooo`030000003oool0oooo
00H0oooo000l0?ooo`030000003oool0oooo00@0oooo0`00000F0?ooo`050000003oool000000?oo
o`000000B@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`02000001H0oooo0`0000060?ooo`030000003oool0oooo00H0oooo000l
0?ooo`030000003oool0oooo00@0oooo0`00000F0?ooo`8000000P3oool00`000000oooo0?ooo`17
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo008000005P3oool3000000H0oooo00<000000?ooo`3oool01P3oool003`0oooo00<0
00000?ooo`3oool0103oool3000001H0oooo0P0000020?ooo`030000003oool0oooo04L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
2@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool00P00000F0?ooo`<000001P3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo
0?ooo`040?ooo`<000005P3oool2000000030?ooo`000000oooo04X0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo008000005P3oool30000
00H0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool0103oool3000001H0
oooo0P0000000`3oool000000?ooo`1:0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`190?ooo`040000003oool00000000001H0oooo0`0000060?ooo`030000003o
ool0oooo00H0oooo000l0?ooo`030000003oool0oooo00@0oooo0`00000E0?ooo`050000003oool0
00000?ooo`000000B`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo04T0
oooo00@000000?ooo`00000000005P3oool2000000L0oooo00<000000?ooo`3oool01P3oool003`0
oooo00<000000?ooo`3oool0103oool3000001D0oooo00D000000?ooo`000000oooo0000001;0?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0B@3oool010000000oooo0000
0000000F0?ooo`8000001`3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?oo
o`040?ooo`<000005@3oool01@000000oooo0000003oool0000004/0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo04T0oooo00@000000?ooo`00000000005P3oool2
000000L0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool0103oool30000
01D0oooo00D000000?ooo`000000oooo0000001;0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`190?ooo`040000003oool00000000001H0oooo0P0000070?ooo`03
0000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
5@3oool01@000000oooo0000003oool0000004/0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo02l0oooo0P0000000`3oool000000?ooo`020?ooo`050000003oool0oooo
0?ooo`000000B`3oool01@000000oooo0000003oool0000001@0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`050?ooo`<00000503oool0
1@000000oooo0000003oool0000004`0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0a0?ooo`8000000`3oool010000000oooo0?ooo`00001<0?ooo`050000003oool000000?oo
o`000000503oool00`000000oooo000000070?ooo`030000003oool0oooo00H0oooo000l0?ooo`03
0000003oool0oooo00D0oooo0`00000D0?ooo`040000003oool00000000004d0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0b0?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`02000001@0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`050?ooo`<00000503oool2
000000030?ooo`000000oooo04`0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0b0?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`1;0?ooo`040000003o
ool00000000001@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`00?03o
ool00`000000oooo0?ooo`050?ooo`<00000503oool2000000030?ooo`000000oooo04`0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0380oooo00@000000?ooo`000000
00000`3oool00`000000oooo0?ooo`1;0?ooo`040000003oool00000000001@0oooo00<000000?oo
o`0000001`3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`050?ooo`<0
0000503oool2000000030?ooo`000000oooo04`0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0340oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo04/0oooo00@000000?ooo`0000000000503oool00`000000oooo000000070?ooo`030000003o
ool0oooo00H0oooo000l0?ooo`030000003oool0oooo00D0oooo0`00000D0?ooo`80000000<0oooo
0000003oool0C03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<@3o
ool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool0B`3oool010000000oooo
00000000000D0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01P3oool003`0oooo
00<000000?ooo`3oool01@3oool3000001@0oooo0P0000000`3oool000000?ooo`1<0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0`0?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000004d0oooo00@000000?ooo`0000000000503oool00`000000oooo
000000070?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00D0oooo0`00
000C0?ooo`050000003oool000000?ooo`000000CP3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0300oooo00@000000?ooo`3oool000000`3oool2000004d0oooo00@000000?oo
o`0000000000503oool00`000000oooo000000070?ooo`030000003oool0oooo00H0oooo000l0?oo
o`030000003oool0oooo00D0oooo0`00000C0?ooo`050000003oool000000?ooo`000000CP3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0300oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`1<0?ooo`040000003oool00000000001@0oooo00<000000?ooo`00
00001`3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`050?ooo`<00000
4`3oool010000000oooo00000000001?0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0`0?ooo`040000003oool0oooo000000<0oooo0P00001=0?ooo`040000003oool0
0000000001@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`00?03oool3
000000D0oooo0`00000C0?ooo`040000003oool00000000004l0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02l0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0000004`0oooo00@000000?ooo`0000000000503oool00`000000oooo000000060?oo
o`800000203oool003`0oooo00<000000?ooo`3oool01@3oool3000001<0oooo00@000000?ooo`00
00000000C`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000C03oool3000001@0oooo
0`0000070?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00D0oooo0`00
000C0?ooo`80000000<0oooo0000003oool0CP3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0;P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo0000001;0?ooo`030000003oool0000001@0oooo0`0000070?ooo`030000003oool0oooo
00H0oooo000l0?ooo`030000003oool0oooo00D0oooo0`00000C0?ooo`80000000<0oooo0000003o
ool0CP3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0;P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0000001@0oooo0`0000070?ooo`030000003oool0oooo00H0oooo000l0?oo
o`030000003oool0oooo00D0oooo0`00000C0?ooo`80000000<0oooo0000003oool0C`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04L0oooo00@000000?ooo`0000000000
4`3oool3000000L0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool01@3o
ool3000001<0oooo0P0000000`3oool000000?ooo`1?0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0;@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`160?ooo`040000003oool00000000001<0oooo0`0000070?oo
o`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00D0oooo0`00000C0?ooo`80
000000<0oooo0000003oool0C`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0;@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`150?ooo`040000003oool0000000000180oooo00@000000?ooo`0000000000
1`3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`050?ooo`<000004`3o
ool300000540oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02`0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0A03oool010000000oooo00000000000B0?ooo`040000003oool00000000000L0oooo00<00000
0?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool01P3oool200000180oooo00@000000?oo
o`0000000000D@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;03o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`130?ooo`040000003oool0000000000180oooo00@000000?ooo`00000000001`3oool00`00
0000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`060?ooo`8000004P3oool010000000
oooo00000000001A0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0/
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0480oooo00@000000?ooo`00000000004P3oool010000000oooo0000000000070?ooo`03
0000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00H0oooo0P00000B0?ooo`040000
003oool0000000000540oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
02/0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0@P3oool300000180oooo00@000000?ooo`00000000001`3oool00`000000oooo0?oo
o`060?ooo`00?03oool00`000000oooo0?ooo`060?ooo`8000004P3oool010000000oooo00000000
001B0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`110?ooo`<0
00004P3oool010000000oooo0000000000070?ooo`030000003oool0oooo00H0oooo000l0?ooo`03
0000003oool0oooo00H0oooo0`00000A0?ooo`80000000<0oooo0000003oool0D@3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`100?ooo`030000003oool0
00000180oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`060?ooo`00?03oool00`00
0000oooo0?ooo`060?ooo`<000004@3oool2000000030?ooo`000000oooo0540oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo02X0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0000
000B0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool01P3oool003`0oooo00<00000
0?ooo`3oool01P3oool300000140oooo0P0000000`3oool000000?ooo`1A0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`000000
4P3oool00`000000oooo000000080?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003o
ool0oooo00H0oooo0`00000A0?ooo`<00000D`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00004P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool000000180oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`060?ooo`<00000
4@3oool3000005<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02T0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0140oooo0P00000m0?oo
o`040000003oool0000000000140oooo0`0000080?ooo`030000003oool0oooo00H0oooo000O0?oo
o`050?oOW018000000000000M02oool00`3oool00`3o_g@0000007Boo`030?ooo`050=nLB0000000
000000000018W=l02P3oool00`000000oooo0?ooo`060?ooo`<000004@3oool3000005<0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>P3oool010000000
oooo00000000000A0?ooo`<00000203oool00`000000oooo0?ooo`060?ooo`007P3oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?ooo`070=nLB0000000
M;oo0?ooo`3ooml0W4P004RLg`090?ooo`030000003oool0oooo00H0oooo0`00000A0?ooo`<00000
E03oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:03oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0j0?oo
o`<000004@3oool3000000P0oooo00<000000?ooo`3oool01P3oool001h0oooo00<0_g@00018W03O
ool00P3oool00`2oM00007Bo0?ooo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03O
ool0203oool00`000000oooo0?ooo`060?ooo`<000004@3oool3000005@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>@3oool300000140oooo0`000008
0?ooo`030000003oool0oooo00H0oooo000M0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000
M02oool01P3oool00`2oM00007Bo0?ooo`020?ooo`030;md0000B9`0gooo00P0oooo00<000000?oo
o`3oool01P3oool300000100oooo00@000000?ooo`0000000000E03oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0h0?ooo`<000004@3oool3000000P0oooo
00<000000?ooo`3oool01P3oool001d0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cO
o`060?ooo`070?oOW01807@0_ooo0?ooo`2oM000000007Boo`090?ooo`030000003oool0oooo00H0
oooo0`00000@0?ooo`040000003oool00000000005@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000001X0oooo00<000000?ooo`3oool0=`3oool300000140oooo0`0000080?ooo`030000003o
ool0oooo00H0oooo000M0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01`3oool0
1@3ookl0M4Q804P000000000B9cO00X0oooo100000050?ooo`<00000403oool010000000oooo0000
0000001D0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0V0?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
03H0oooo0`00000@0?ooo`040000003oool00000000000D0oooo100000080?ooo`007@3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00L0oooo00@0omnL04P00000000007Bo2`3oool0
0`000000oooo0?ooo`060?ooo`<00000403oool3000005D0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0000000@0?ooo`040000
003oool00000000000P0oooo00<000000?ooo`3oool01P3oool001d0oooo00<0omnL04P0001d_ol0
0`3oool00`3o_g@0001809cOo`060?ooo`060?oOW0180000001d0;ooo`3o_g@007Bo2P3oool00`00
0000oooo0?ooo`060?ooo`<00000403oool3000005D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0=03oool00`000000oooo0000000@
0?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool01P3oool001d0oooo00<0oono
07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030;md000007@0_ooo0080oooo00<0_g@0
04RLg`3oool0203oool00`000000oooo0?ooo`060?ooo`<00000403oool3000005H0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0000000@0?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool01P3oool001h0oooo
00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`060?ooo`030;md0000B9`0gooo0080oooo
00<0gia8001d_`3oool0203oool00`000000oooo0?ooo`060?ooo`<00000403oool3000005H0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0<P3oool010000000oooo00000000000?0?ooo`040000003oool00000000000P0oooo00<00000
0?ooo`3oool01P3oool001h0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00L0oooo00L0
okmd0000001d_ol0oooo0?oo_`1d0000M;oo00T0oooo00<000000?ooo`3oool01P3oool300000100
oooo0`00001F0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0T0?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0380oooo0`00000?0?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool01P3o
ool001l0oooo00D0oono07@000000000001d0;ooo`090?ooo`050?noM0000000000000000018W=l0
2P3oool00`000000oooo0?ooo`060?ooo`<00000403oool3000005H0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0<@3oool3000000l0oooo00@000000?oo
o`0000000000203oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`060?oo
o`<00000403oool3000005H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0<03oool3000000l0oooo00@000000?ooo`0000000000203oool00`000000oooo
0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`070?ooo`800000403oool3000005H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0;`3oool3000000l0oooo00@000000?ooo`0000000000203oool00`000000oooo
0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`070?ooo`800000403oool2000005P0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
;P3oool3000000l0oooo0P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo00H0oooo
000l0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000003P3oool00`000000oooo0000
001H0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02d0
oooo0`00000?0?ooo`80000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`060?ooo`00
?03oool00`000000oooo0?ooo`070?ooo`<000003P3oool3000005P0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0;03oool3000000l0
oooo0P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000
003oool0oooo00L0oooo0`00000>0?ooo`<00000F03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0000000l0oooo0`0000090?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003o
ool0oooo00L0oooo0`00000>0?ooo`<00000F03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0000000l0oooo0`0000090?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0
oooo00L0oooo0`00000>0?ooo`<00000F@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0[0?ooo`<000003P3oool3000000T0oooo00<0
00000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool01`3oool3000000h0oooo0`00001I
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02X0oooo0`00000=0?ooo`040000003oool00000000000T0oooo00<000000?ooo`3oool0
1P3oool003`0oooo00<000000?ooo`3oool01`3oool3000000h0oooo0`00001I0?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02T0oooo
0`00000=0?ooo`040000003oool00000000000T0oooo00<000000?ooo`3oool01P3oool003`0oooo
00<000000?ooo`3oool01`3oool3000000h0oooo0P00001J0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02P0oooo
0`00000=0?ooo`040000003oool00000000000T0oooo00<000000?ooo`3oool01P3oool003`0oooo
00<000000?ooo`3oool01`3oool3000000h0oooo0P00001J0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02L0oooo
0`00000=0?ooo`040000003oool00000000000T0oooo00<000000?ooo`3oool01P3oool003`0oooo
00<000000?ooo`3oool01`3oool3000000h0oooo0P00001J0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02H0oooo
0`00000=0?ooo`040000003oool00000000000T0oooo00<000000?ooo`3oool01P3oool003`0oooo
00<000000?ooo`3oool01`3oool3000000h0oooo0P00001K0?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02D0oooo0`00000=0?ooo`04
0000003oool00000000000T0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3o
ool01`3oool3000000h0oooo0P00001K0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo02@0oooo0`00000=0?ooo`040000003oool00000
000000T0oooo00<000000?ooo`3oool01P3oool003`0oooo0`0000070?ooo`80000000<0oooo0000
003oool02`3oool3000005/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0903oool2000000d0oooo00@000000?oo
o`0000000000203oool2000000P0oooo000l0?ooo`030000003oool0oooo00L0oooo0P0000000`3o
ool000000?ooo`0;0?ooo`<00000F`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0S0?ooo`<00000303oool01000
0000oooo0000000000090?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo
00L0oooo0P0000000`3oool000000?ooo`0;0?ooo`<00000F`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0R0?oo
o`<00000303oool2000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool01P3oool003`0
oooo00<000000?ooo`3oool01`3oool2000000030?ooo`000000oooo00/0oooo0P00001M0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
0240oooo0`00000<0?ooo`80000000<0oooo0000003oool0203oool00`000000oooo0?ooo`060?oo
o`00?03oool00`000000oooo0?ooo`070?ooo`80000000<0oooo0000003oool02`3oool2000005d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0803oool3000000`0oooo0P0000000`3oool000000?ooo`080?ooo`03
0000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00L0oooo0P0000000`3oool00000
0?ooo`0;0?ooo`800000G@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0O0?ooo`<000002`3oool01@000000oooo
0000003oool0000000T0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool0
1`3oool010000000oooo00000000000<0?ooo`800000G@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0N0?ooo`<0
00002`3oool01@000000oooo0000003oool0000000T0oooo00<000000?ooo`3oool01P3oool003`0
oooo00<000000?ooo`3oool01`3oool01@000000oooo0000003oool0000000/0oooo0P00001M0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1L0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo01d0oooo0`00000;0?ooo`050000003oool000000?ooo`0000002@3oool0
0`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000
003oool02P3oool2000005h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool07@3oool2000000/0oooo00D000000?oo
o`000000oooo000000090?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo
00P0oooo0P0000000`3oool000000?ooo`0:0?ooo`800000GP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0L0?oo
o`8000002`3oool010000000oooo00000000000:0?ooo`030000003oool0oooo00H0oooo000l0?oo
o`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`0:0?ooo`800000GP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0K0?ooo`8000002`3oool010000000oooo00000000000:0?ooo`030000003oool0
oooo00H0oooo000l0?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`0:0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool06P3oool3000000X0oooo00@000000?oo
o`00000000002P3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`080?oo
o`80000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
01T0oooo0`00000:0?ooo`040000003oool00000000000X0oooo00<000000?ooo`3oool01P3oool0
03`0oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo00T0oooo0P00001P0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1R0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo01P0oooo0`00000:0?ooo`040000003oool00000000000X0oooo00<00000
0?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo
00T0oooo0P00001P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo01L0oooo0`00000:0?ooo`040000003oool00000
000000X0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool0203oool20000
00030?ooo`000000oooo00T0oooo0P00001P0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01L0oooo0P00000:0?oo
o`040000003oool00000000000X0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?oo
o`3oool0203oool200000080oooo00<000000?ooo`3oool01`3oool200000600oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool05P3oool2000000T0oooo00<000000?ooo`3oool00P00000:0?ooo`030000003oool0oooo
00H0oooo000l0?ooo`030000003oool0oooo00P0oooo0P0000020?ooo`030000003oool0oooo00L0
oooo0P00001Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1V0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo01D0oooo0P0000090?ooo`050000003oool000000?ooo`0000002P3oool0
0`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`080?ooo`8000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0503oool20000
00T0oooo00D000000?ooo`000000oooo0000000:0?ooo`030000003oool0oooo00H0oooo000l0?oo
o`030000003oool0oooo00P0oooo00D000000?ooo`000000oooo000000090?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000006X0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
4`3oool2000000T0oooo00D000000?ooo`000000oooo0000000:0?ooo`030000003oool0oooo00H0
oooo000l0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`000000oooo000000090?ooo`03
0000003oool0oooo0600oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06P0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool04P3oool3000000P0oooo00D000000?ooo`000000oooo0000000:
0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`000000oooo000000090?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000006`0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool04P3oool2000000P0oooo00D000000?ooo`000000
oooo0000000:0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00P0oooo
00D000000?ooo`000000oooo000000090?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000006`0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool04@3oool2000000P0oooo00D00000
0?ooo`000000oooo0000000:0?ooo`030000003oool0oooo00H0oooo000l0?ooo`<00000203oool0
1@000000oooo0000003oool0000000T0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000006h0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool2000000P0oooo00D000000?ooo`00
0000oooo000000090?ooo`800000203oool003`0oooo00<000000?ooo`3oool0203oool00`000000
oooo000000020?ooo`030000003oool0oooo00D0oooo0P00001S0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo0000001^0?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00l0oooo0P0000080?ooo`040000003oool0
0000000000/0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool02@3oool2
00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000L03oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool03P3oool2000000L0oooo00<000000?ooo`3oool0
0P00000;0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00T0oooo0P00
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000700oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool03@3oool2000000L0oooo00<000000?ooo`3o
ool00P00000;0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00T0oooo
0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000780oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`02000000/0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3o
ool02@3oool01@000000oooo0000003oool0000000L0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000007<0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`02000000/0oooo00<000000?ooo`3oool01P3oool003`0oooo00<00000
0?ooo`3oool02@3oool01@000000oooo0000003oool0000000L0oooo00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000007@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00/0oooo0P0000060?ooo`05
0000003oool000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000
oooo0?ooo`090?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool2000006H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0000001f0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0:0?ooo`8000001@3oool01P00
0000oooo0?ooo`000000oooo000000/0oooo00<000000?ooo`3oool01P3oool003`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo0P00001V
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo0P00001h0?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00H00000
0?ooo`3oool000000?ooo`00000;0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`800000IP3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`3oool2000007T0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool01P000000oooo
0?ooo`000000oooo000000/0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3o
ool02@3oool01P000000oooo0?ooo`000000oooo000000@0oooo0`00001V0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0N@3oool00`000000oooo000000030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`070000003oool0
oooo0?ooo`000000oooo0000000;0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003o
ool0oooo00T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool2000006L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo0000001m0?ooo`8000000`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo00L0oooo0P0000030?ooo`070000003oool0oooo0?ooo`000000oooo0000
000;0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`3oool2000006P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P00001n0?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00H0oooo
0`0000020?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`030000003oool0oooo
00H0oooo000l0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000`3oool01@00
0000oooo0000003oool0000006P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:
0?ooo`<000000P3oool500000800oooo00<000000?ooo`0000000P0000020?ooo`<00000303oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool01@3oool6
00000080oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`060?ooo`00?03oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0000000<0oooo0P0000020?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`D0000000<0oooo
0000003oool0P@3oool00`000000oooo00000004000000d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`00000000000`3o
ool00`000000oooo0000000<0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`0000001P3oool2000006P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0>0?ooo`040000003oool0oooo00000880oooo00@000000?ooo`3oool00000
403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0
1P3oool003`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000050?ooo`800000
J@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool0
0000Q03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`000000303oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`0:0?ooo`04
0000003oool0oooo000000D0oooo0P00001Y0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0303oool00`000000oooo000000250?ooo`040000003oool0oooo000000h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00H0oooo000l
0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000001@3oool2000006T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000008H0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06@0oooo00@0
00000?ooo`3oool0oooo0P0000040?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3o
ool01P3oool003`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000040?ooo`80
0000J`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo0P0000270?ooo`04
0000003oool0oooo000000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo00800000103oool010000000oooo0?ooo`00000<0?ooo`030000003oool0
oooo00H0oooo000l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000103oool2
000006/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
000008P0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo06L0oooo00@000000?ooo`0000000000103oool010000000oooo0?ooo`00000<0?ooo`030000
003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000
103oool2000006/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`800000
RP3oool2000000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1X0?ooo`<00000
0`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01P3oool003`0oooo
0`00000;0?ooo`030000003oool0000000@0oooo0P00001[0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1Y0?ooo`8000000`3oool01@000000oooo
0?ooo`3oool0000000/0oooo0P0000080?ooo`00?03oool00`000000oooo0?ooo`0;0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`000000K03oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0JP3oool200000080oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00@0000000<0oooo0000003oool0J`3oool00`000000oooo0?ooo`090?ooo`80
00000`3oool3000008h0oooo0`0000030?ooo`<000002P3oool00`000000oooo0?ooo`1[0?ooo`D0
00000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000
003oool0oooo00/0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`1/0?ooo`03
0000003oool0oooo00X0oooo1P00002@0?ooo`030000003oool0000000<00000303oool00`000000
oooo0?ooo`1[0?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1/0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0K03oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`1/0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06h0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000d0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0KP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01P3oool003`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2B0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`020?ooo`80
00003@3oool00`000000oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1`0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`060?ooo`00?03o
ool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000L`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1a0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`060?ooo`00?03oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000007@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0LP3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool03@3oool010000000
oooo0?ooo`00001e0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0V03oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo07<0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo
00d0oooo1000001e0?ooo`800000103oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
0080oooo0P00001e0?ooo`80000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo000l0?ooo`030000003oool0oooo00h0oooo0P00001g0?ooo`D0
0000WP3oool4000007P0oooo0P0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool003`0oooo00<000000?ooo`3oool0o`3ooonb0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool003`0oooo00<000000?ooo`3oool0o`3ooonc0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool002`0oooo00H0_g@000000000000000000018
W03Oool:0?ooo`030000003oool0oooo0?l0oooo]03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo000]0?ooo`030?oOW0180000M;oo00`0oooo00<000000?ooo`3oool0o`3o
oone0?ooo`050000003oool0oooo0?ooo`000000203oool002d0oooo00<0omnL04P0001d_ol0303o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0580oooo00@000000?ooo`3oool00000
203oool002d0oooo00<0omnL04P0001d_ol0303oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`000000203oool002d0oooo00<0omnL04P0001d_ol0303oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo0P0000080?ooo`00;@3oool00`3o
gi`0B00007Boo`0<0?ooool00000_@0000080?ooo`00;@3oool00`3ogi`0B00007Boo`3o0?ooom40
oooo000]0?ooo`030?oOW0180000M;oo0?l0ooood@3oool002d0oooo00<0omnL04P0001d_ol0o`3o
oooA0?ooo`00;@3oool00`3ogi`0B00007Boo`3o0?ooom40oooo000[0?ooo`050?oog`2LB0000000
0000001d_ol0o`3ooooA0?ooo`00;@3oool00`3o_g@0000007Boo`3o0?ooom40oooo003o0?ooool0
oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool0
0?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00001\
\>"],
  ImageRangeCache->{{{0, 511.25}, {511.25, 0}} -> {-0.136101, -0.122563, \
0.00338295, 0.00338295}}]
}, Closed]],

Cell[TextData[{
  "For larger \[Mu] each of the tangent points bifurcates, but unlike the \
pitchfork bifurcation, fixed points that emerge via ",
  StyleBox["tangent bifurcation ",
    FontSlant->"Italic"],
  "are not preceded by an earlier fixed point that loses its stability at the \
bifurcation point.  Furthermore, unlike ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \(-1\)\)]],
  " bifurcations, bifurcations at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \(+1\)\)]],
  " typically produce unstable, aperiodic solutions."
}], "Text"],

Cell[BoxData[
    \(\(sol3\  = \ fixedPoints[3] // Simplify;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[N[x /. sol3]], {\[Mu], 3.8, 4.0}, 
        PlotRange \[Rule] {Automatic, {0, 1}}, 
        PlotLabel \[Rule] "\<Tangent Bifurcation\>", Frame \[Rule] True, \ 
        FrameLabel \[Rule] {"\<\[Mu]\>", "\<fixed point\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-18.0714 4.76191 0 0.618034 [
[.02381 -0.0125 -9.5 -15.6875 ]
[.02381 -0.0125 9.5 0 ]
[.2619 -0.0125 -12.5 -15.6875 ]
[.2619 -0.0125 12.5 0 ]
[.5 -0.0125 -9.5 -15.6875 ]
[.5 -0.0125 9.5 0 ]
[.7381 -0.0125 -12.5 -15.6875 ]
[.7381 -0.0125 12.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.5 -31.375 ]
[.5 -0.0125 5.5 -15.6875 ]
[-0.0125 .12361 -19 -7.84375 ]
[-0.0125 .12361 0 7.84375 ]
[-0.0125 .24721 -19 -7.84375 ]
[-0.0125 .24721 0 7.84375 ]
[-0.0125 .37082 -19 -7.84375 ]
[-0.0125 .37082 0 7.84375 ]
[-0.0125 .49443 -19 -7.84375 ]
[-0.0125 .49443 0 7.84375 ]
[-0.0125 .61803 -10 -7.84375 ]
[-0.0125 .61803 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -28.125 ]
[-0.01875 .30902 -19 28.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -50.125 0 ]
[.5 .63053 50.125 15.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -73.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.85) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.9) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -73.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.95) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.5 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.563 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
70.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -115.969 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
89.125 11.8438 translate
90 rotate
-89.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(fixed) show
90.625 15.813 moveto
(point) show
115.250 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -111.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tangent) show
105.000 15.813 moveto
(Bifurcation) show
159.250 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04722 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 0 L
.05186 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06453 0 L
.06529 0 L
.06657 0 L
.06729 0 L
.06797 0 L
.06924 0 L
.0704 0 L
.07103 0 L
.07173 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07513 0 L
.07583 0 L
.0766 0 L
.0774 0 L
.07809 0 L
.07885 0 L
.07956 0 L
.0802 0 L
.08095 0 L
.08166 0 L
.08291 0 L
.08362 0 L
.08427 0 L
.08544 0 L
.08669 0 L
.08787 0 L
.08896 0 L
.09016 0 L
.09148 0 L
.09214 0 L
.09285 0 L
.09413 0 L
.09483 0 L
.09548 0 L
.09619 0 L
.09695 0 L
.09821 0 L
.09893 0 L
.09961 0 L
.10086 0 L
.10201 0 L
.10333 0 L
.10458 0 L
.10572 0 L
.10694 0 L
.1081 0 L
.10916 0 L
.11033 0 L
.11162 0 L
.11227 0 L
.11297 0 L
.11422 0 L
.11491 0 L
.11554 0 L
.11624 0 L
.11698 0 L
.11822 0 L
.11892 0 L
Mistroke
.11958 0 L
.12081 0 L
.12194 0 L
.12323 0 L
.12446 0 L
.12562 0 L
.12668 0 L
.12789 0 L
.12903 0 L
.13009 0 L
.13107 0 L
.13214 0 L
.13327 0 L
.13441 0 L
.13564 0 L
.1368 0 L
.13785 0 L
.13909 0 L
.13979 0 L
.14043 0 L
.14162 0 L
.14288 0 L
.14402 0 L
.14526 0 L
.14656 0 L
.14777 0 L
.14891 0 L
.14994 0 L
.15113 0 L
.15226 0 L
.15348 0 L
.15478 0 L
.15589 0 L
.15711 0 L
.15842 0 L
.15915 0 L
.15982 0 L
.16113 0 L
.16236 0 L
.16352 0 L
.16456 0 L
.16577 0 L
.1669 0 L
.16796 0 L
.16893 0 L
.16999 0 L
.17111 0 L
.17225 0 L
.17347 0 L
.17462 0 L
Mistroke
.17566 0 L
.17689 0 L
.17758 0 L
.17823 0 L
.1794 0 L
.18065 0 L
.18185 0 L
.18316 0 L
.18441 0 L
.18556 0 L
.1867 0 L
.18773 0 L
.18893 0 L
.19005 0 L
.19128 0 L
.19258 0 L
.19369 0 L
.19491 0 L
.19623 0 L
.19696 0 L
.19763 0 L
.19894 0 L
.20017 0 L
.20122 0 L
.20238 0 L
.20359 0 L
.20472 0 L
.20578 0 L
.20675 0 L
.20781 0 L
.20894 0 L
.21008 0 L
.21129 0 L
.21244 0 L
.21349 0 L
.21472 0 L
.21541 0 L
.21605 0 L
.21723 0 L
.21847 0 L
.21968 0 L
.221 0 L
.22224 0 L
.2234 0 L
.22454 0 L
.22558 0 L
.22677 0 L
.2279 0 L
.22914 0 L
.23044 0 L
Mistroke
.23155 0 L
.23277 0 L
.23409 0 L
.23482 0 L
.2355 0 L
.2368 0 L
.23804 0 L
.23909 0 L
.24025 0 L
.24146 0 L
.2426 0 L
.24365 0 L
.24462 0 L
.24569 0 L
.24681 0 L
.24795 0 L
.24917 0 L
.25032 0 L
.25137 0 L
.2526 0 L
.25329 0 L
.25393 0 L
.2551 0 L
.25635 0 L
.25756 0 L
.25888 0 L
.26013 0 L
.26129 0 L
.26233 0 L
.26348 0 L
.26467 0 L
.2658 0 L
.26704 0 L
.26835 0 L
.26946 0 L
.27068 0 L
.272 0 L
.27274 0 L
.27341 0 L
.27472 0 L
.27595 0 L
.27701 0 L
.27817 0 L
.27938 0 L
.28052 0 L
.28158 0 L
.28255 0 L
.28367 0 L
.28474 0 L
.28588 0 L
Mistroke
.2871 0 L
.28825 0 L
.2893 0 L
.29053 0 L
.29122 0 L
.29186 0 L
.29303 0 L
.29427 0 L
.29549 0 L
.29618 0 L
.29682 0 L
.29799 0 L
.29923 0 L
.30034 0 L
.30138 0 L
.30252 0 L
.30375 0 L
.30499 0 L
.30569 0 L
.30634 0 L
.30765 0 L
.30839 0 L
.30906 0 L
.31026 0 L
.31156 0 L
.31278 0 L
.31392 0 L
.31497 0 L
.31611 0 L
.31718 0 L
.31816 0 L
.3193 0 L
.32055 0 L
.32173 0 L
.32282 0 L
.32406 0 L
.32522 0 L
.32626 0 L
.32739 0 L
.32862 0 L
.32992 0 L
.33103 0 L
.33225 0 L
.33356 0 L
.33477 0 L
.33541 0 L
.3361 0 L
.33683 0 L
.33751 0 L
.33876 0 L
Mistroke
.33991 0 L
.34123 0 L
.34249 0 L
.3436 0 L
.3448 0 L
.34592 0 L
.34694 0 L
.34814 0 L
.34945 0 L
.35067 0 L
.35181 0 L
.35302 0 L
.35431 0 L
.35554 0 L
.35665 0 L
.35796 0 L
.3587 0 L
.35939 0 L
.36064 0 L
.36128 0 L
.36198 0 L
.36266 0 L
.36337 0 L
.36465 0 L
.36536 0 L
.36602 0 L
.36675 0 L
.36753 0 L
.3682 0 L
.36893 0 L
.36962 0 L
.37026 0 L
.37146 0 L
.37274 0 L
.37394 0 L
.37526 0 L
.37651 0 L
.37766 0 L
.3788 0 L
.37984 0 L
.38103 0 L
.38216 0 L
.38339 0 L
.3847 0 L
.38581 0 L
.38703 0 L
.38834 0 L
.38908 0 L
.38975 0 L
.39106 0 L
Mistroke
.39229 0 L
.39334 0 L
.3945 0 L
.39571 0 L
.39685 0 L
.39791 0 L
.39888 0 L
.39994 0 L
.40106 0 L
.40221 0 L
.40342 0 L
.40457 0 L
.40562 0 L
.40685 0 L
.40754 0 L
.40818 0 L
.40936 0 L
.4106 0 L
.41181 0 L
.41313 0 L
.41438 0 L
.41554 0 L
.41669 0 L
.41772 0 L
.41892 0 L
.42005 0 L
.42129 0 L
.42259 0 L
.42371 0 L
.42493 0 L
.42624 0 L
.42698 0 L
.42765 0 L
.42896 0 L
.43019 0 L
.43125 0 L
.43241 0 L
.43362 0 L
.43476 0 L
.43582 0 L
.43679 0 L
.43791 0 L
.43898 0 L
.44012 0 L
.44134 0 L
.44249 0 L
.44354 0 L
.44477 0 L
.44546 0 L
.4461 0 L
Mistroke
.44727 0 L
.44851 0 L
.44973 0 L
.45042 0 L
.45106 0 L
.45223 0 L
.45347 0 L
.45458 0 L
.45562 0 L
.45676 0 L
.45799 0 L
.45922 0 L
.45992 0 L
.46057 0 L
.46188 0 L
.46262 0 L
.46329 0 L
.46449 0 L
.46579 0 L
.46702 0 L
.46815 0 L
.4692 0 L
.47034 0 L
.47141 0 L
.47239 0 L
.47353 0 L
.47478 0 L
.47596 0 L
.47705 0 L
.47829 0 L
.47945 0 L
.48049 0 L
.48162 0 L
.48285 0 L
.48415 0 L
.48526 0 L
.48648 0 L
.48779 0 L
.489 0 L
.48963 0 L
.49033 0 L
.49105 0 L
.49174 0 L
.49299 0 L
.49413 0 L
.49539 0 L
.49671 0 L
.49783 0 L
.49902 0 L
.50014 0 L
Mistroke
.50116 0 L
.50236 0 L
.50366 0 L
.50489 0 L
.50603 0 L
.50723 0 L
.50853 0 L
.50975 0 L
.51087 0 L
.51218 0 L
.51292 0 L
.51361 0 L
.51486 0 L
.5155 0 L
.5162 0 L
.51687 0 L
.51759 0 L
.51886 0 L
.51958 0 L
.52024 0 L
.52096 0 L
.52174 0 L
.52241 0 L
.52314 0 L
.52383 0 L
.52447 0 L
.52568 0 L
.52695 0 L
.52816 0 L
.52947 0 L
.53072 0 L
.53187 0 L
.53301 0 L
.53405 0 L
.53525 0 L
.53637 0 L
.5376 0 L
.53891 0 L
.54002 0 L
.54124 0 L
.54255 0 L
.54329 0 L
.54396 0 L
.54526 0 L
.5465 0 L
.54755 0 L
.54871 0 L
.54992 0 L
.55105 0 L
.55211 0 L
Mistroke
.55308 0 L
.55415 0 L
.55527 0 L
.55641 0 L
.55763 0 L
.55878 0 L
.55982 0 L
.56105 0 L
.56175 0 L
.56238 0 L
.56356 0 L
.5648 0 L
.56601 0 L
.56734 0 L
.56858 0 L
.56974 0 L
.57088 0 L
.57192 0 L
.57312 0 L
.57425 0 L
.57548 0 L
.57679 0 L
.5779 0 L
.57912 0 L
.58044 0 L
.58118 0 L
.58185 0 L
.58315 0 L
.58439 0 L
.58544 0 L
.5866 0 L
.58782 0 L
.58895 0 L
.59001 0 L
.59098 0 L
.5921 0 L
.59317 0 L
.59431 0 L
.59553 0 L
.59668 0 L
.59773 0 L
.59896 0 L
.59965 0 L
.60029 0 L
.60146 0 L
.60271 0 L
.60392 0 L
.60461 0 L
.60525 0 L
.60642 0 L
Mistroke
.60766 0 L
.60876 0 L
.6098 0 L
.61094 0 L
.61217 0 L
.61341 0 L
.6141 0 L
.61475 0 L
.61607 0 L
.6168 0 L
.61747 0 L
.61867 0 L
.61997 0 L
.6212 0 L
.62233 0 L
.62339 0 L
.62452 0 L
.62559 0 L
.62657 0 L
.62771 0 L
.62896 0 L
.63014 0 L
.63123 0 L
.63247 0 L
.63363 0 L
.63467 0 L
.6358 0 L
.63703 0 L
.63833 0 L
.63944 0 L
.64066 0 L
.64197 0 L
.64318 0 L
.64381 0 L
.6445 0 L
.64523 0 L
.64591 0 L
.64716 0 L
.64831 0 L
.64956 0 L
.65088 0 L
.652 0 L
.65319 0 L
.65431 0 L
.65533 0 L
.65653 0 L
.65784 0 L
.65906 0 L
.6602 0 L
.6614 0 L
Mistroke
.6627 0 L
.66392 0 L
.66504 0 L
.66635 0 L
.66709 0 L
.66777 0 L
.66903 0 L
.66966 0 L
.67036 0 L
.67104 0 L
.67175 0 L
.67303 0 L
.67374 0 L
.6744 0 L
.67513 0 L
.67591 0 L
.67658 0 L
.67731 0 L
.678 0 L
.67864 0 L
.67984 0 L
.68112 0 L
.68232 0 L
.68364 0 L
.68488 0 L
.68603 0 L
.68718 0 L
.68821 0 L
.68941 0 L
.69053 0 L
.69176 0 L
.69307 0 L
.69418 0 L
.6954 0 L
.69671 0 L
.69745 0 L
.69812 0 L
.69942 0 L
.70066 0 L
.70171 0 L
.70286 0 L
.70407 0 L
.70521 0 L
.70627 0 L
.70724 0 L
.7083 0 L
.70942 0 L
.71056 0 L
.71178 0 L
.71293 0 L
Mistroke
.71398 0 L
.71521 0 L
.7159 0 L
.71654 0 L
.71771 0 L
.71896 0 L
.72017 0 L
.72149 0 L
.72273 0 L
.72389 0 L
.72503 0 L
.72607 0 L
.72727 0 L
.7284 0 L
.72963 0 L
.73094 0 L
.73205 0 L
.73327 0 L
.73458 0 L
.73532 0 L
.73599 0 L
.7373 0 L
.73853 0 L
.73959 0 L
.74075 0 L
.74196 0 L
.7431 0 L
.74416 0 L
.74513 0 L
.74619 0 L
.74731 0 L
.74846 0 L
.74967 0 L
.75083 0 L
.75187 0 L
.7531 0 L
.75379 0 L
.75443 0 L
.75561 0 L
.75685 0 L
.75806 0 L
.75875 0 L
.75939 0 L
.76056 0 L
.7618 0 L
.7629 0 L
.76394 0 L
.76508 0 L
.76631 0 L
.76754 0 L
Mistroke
.76824 0 L
.76889 0 L
.7702 0 L
.77094 0 L
.77161 0 L
.7728 0 L
.7741 0 L
.77533 0 L
.77646 0 L
.77752 0 L
.77865 0 L
.77972 0 L
.7807 0 L
.78184 0 L
.78309 0 L
.78427 0 L
.78536 0 L
.7866 0 L
.78776 0 L
.7888 0 L
.78993 0 L
.79116 0 L
.79246 0 L
.79357 0 L
.79479 0 L
.7961 0 L
.7973 0 L
.79793 0 L
.79863 0 L
.79936 0 L
.80004 0 L
.80129 0 L
.80243 0 L
.80369 0 L
.80501 0 L
.80612 0 L
.80731 0 L
.80843 0 L
.80945 0 L
.81066 0 L
.81196 0 L
.81318 0 L
.81432 0 L
.81552 0 L
.81682 0 L
.81804 0 L
.81916 0 L
.82047 0 L
.8212 0 L
.82189 0 L
Mistroke
.82315 0 L
.82385 0 L
.82448 0 L
.82516 0 L
.82587 0 L
.82715 0 L
.82786 0 L
.82852 0 L
.82925 0 L
.83002 0 L
.8307 0 L
.83143 0 L
.83212 0 L
.83275 0 L
.83396 0 L
.83524 0 L
.83644 0 L
.83775 0 L
.839 0 L
.84015 0 L
.84129 0 L
.84232 0 L
.84352 0 L
.84464 0 L
.84587 0 L
.84718 0 L
.84829 0 L
.8495 0 L
.85082 0 L
.85155 0 L
.85222 0 L
.85353 0 L
.85476 0 L
.85581 0 L
.85697 0 L
.85818 0 L
.85932 0 L
.86037 0 L
.86134 0 L
.86241 0 L
.86353 0 L
.86467 0 L
.86589 0 L
.86704 0 L
.86808 0 L
.86931 0 L
.87 0 L
.87064 0 L
.87182 0 L
.87306 0 L
Mistroke
.87427 0 L
.87559 0 L
.87684 0 L
.87799 0 L
.87914 0 L
.88017 0 L
.88137 0 L
.88249 0 L
.88373 0 L
.88503 0 L
.88615 0 L
.88737 0 L
.88868 0 L
.88942 0 L
.89009 0 L
.89139 0 L
.89263 0 L
.89368 0 L
.89484 0 L
.89605 0 L
.89719 0 L
.89825 0 L
.89922 0 L
.90029 0 L
.90141 0 L
.90255 0 L
.90377 0 L
.90492 0 L
.90596 0 L
.90719 0 L
.90789 0 L
.90852 0 L
.9097 0 L
.91094 0 L
.91216 0 L
.91284 0 L
.91348 0 L
.91464 0 L
.91589 0 L
.91699 0 L
.91803 0 L
.91917 0 L
.9204 0 L
.92163 0 L
.92233 0 L
.92297 0 L
.92429 0 L
.92502 0 L
.92569 0 L
.92689 0 L
Mistroke
.92819 0 L
.92941 0 L
.93055 0 L
.9316 0 L
.93273 0 L
.9338 0 L
.93478 0 L
.93592 0 L
.93717 0 L
.93835 0 L
.93944 0 L
.94068 0 L
.94184 0 L
.94288 0 L
.94401 0 L
.94524 0 L
.94654 0 L
.94765 0 L
.94887 0 L
.94975 0 L
.95057 0 L
.95146 0 L
.95241 0 L
.95324 0 L
.95401 0 L
.95486 0 L
.95577 0 L
.95653 0 L
.95737 0 L
.95824 0 L
.95905 0 L
.95981 0 L
.9605 0 L
.9613 0 L
.96206 0 L
.96287 0 L
.96377 0 L
.96471 0 L
.96559 0 L
.96641 0 L
.96716 0 L
.96802 0 L
.96884 0 L
.96972 0 L
.97067 0 L
.97155 0 L
.97236 0 L
.97331 0 L
.97433 0 L
.9753 0 L
Mistroke
.97619 0 L
Mfstroke
.02381 .45539 m
.06244 .45574 L
.10458 .45612 L
.14415 .45647 L
.18221 .4568 L
.22272 .45716 L
.26171 .4575 L
.30316 .45787 L
.34309 .45821 L
.3815 .45855 L
.42237 .4589 L
.46172 .45924 L
.49955 .45956 L
.53984 .4599 L
.57861 .46023 L
.61984 .46058 L
.65954 .46091 L
.69774 .46123 L
.73838 .46157 L
.77751 .4619 L
.81909 .46224 L
.85916 .46257 L
.89771 .46289 L
.93871 .46322 L
.97619 .46353 L
s
.15934 .0985 m
.16032 .09794 L
.1614 .09758 L
.16254 .09729 L
.16737 .0964 L
.1719 .09578 L
.18221 .0947 L
.20172 .09315 L
.22272 .09184 L
.26394 .08976 L
.30365 .08809 L
.34184 .08669 L
.38249 .08534 L
.42162 .08414 L
.4632 .08296 L
.50327 .0819 L
.54182 .08093 L
.58282 .07995 L
.62231 .07905 L
.66028 .07822 L
.7007 .07737 L
.73961 .07658 L
.78097 .07578 L
.82082 .07502 L
.85915 .07432 L
.89993 .0736 L
.9392 .07292 L
.97619 .0723 L
s
.15934 .09918 m
.16032 .09973 L
.1614 .10008 L
.16254 .10036 L
.16487 .10081 L
.16737 .10119 L
.1719 .10176 L
.18221 .10272 L
.20336 .10414 L
.22272 .10512 L
.26243 .10668 L
.30062 .10786 L
.34126 .10891 L
.38039 .10977 L
.42198 .11058 L
.46204 .11127 L
.50059 .11186 L
.5416 .11244 L
.58108 .11295 L
.61906 .1134 L
.65948 .11384 L
.69839 .11423 L
.73975 .11462 L
.77959 .11496 L
.81792 .11527 L
.85871 .11558 L
.89797 .11585 L
.93572 .1161 L
.97593 .11635 L
.97619 .11635 L
s
.15934 .317 m
.16032 .31555 L
.1614 .31463 L
.16254 .31388 L
.16737 .31163 L
.1719 .31008 L
.18221 .30737 L
.20172 .30359 L
.22272 .3004 L
.26394 .29541 L
.30365 .29148 L
.34184 .28819 L
.38249 .28505 L
.42162 .28228 L
.4632 .27957 L
.50327 .27713 L
.54182 .27491 L
.58282 .27268 L
.62231 .27064 L
.66028 .26875 L
.7007 .26683 L
.73961 .26504 L
.78097 .26321 L
.82082 .26151 L
.85915 .25993 L
.89993 .25829 L
.9392 .25676 L
.97619 .25536 L
s
.15934 .31878 m
.16032 .32022 L
.1614 .32114 L
.16254 .32189 L
.16737 .32412 L
.1719 .32565 L
.18221 .32832 L
.20172 .33204 L
.22272 .33515 L
.26394 .34 L
.30365 .34379 L
.34184 .34695 L
.38249 .34995 L
.42162 .35258 L
.4632 .35516 L
.50327 .35747 L
.54182 .35956 L
.58282 .36166 L
.62231 .36358 L
.66028 .36534 L
.7007 .36714 L
.73961 .3688 L
.78097 .3705 L
.82082 .37208 L
.85915 .37355 L
.89993 .37507 L
.9392 .37648 L
.97619 .37778 L
s
.15934 .59094 m
.16032 .59078 L
.1614 .59069 L
.16254 .59061 L
.16487 .59048 L
.16737 .59038 L
.1719 .59022 L
.18221 .58996 L
.19305 .58975 L
.20336 .58959 L
.22272 .58934 L
.26091 .58897 L
.30156 .58868 L
.34068 .58846 L
.38227 .58826 L
.42233 .58811 L
.46088 .58799 L
.50189 .58788 L
.54137 .58779 L
.57935 .58771 L
.61977 .58765 L
.65868 .58759 L
.70004 .58755 L
.73989 .58751 L
.77822 .58748 L
.819 .58746 L
.83925 .58745 L
.85826 .58745 L
.87665 .58744 L
.89601 .58744 L
.90565 .58744 L
.9162 .58743 L
.92578 .58743 L
.9347 .58743 L
.93975 .58743 L
.94241 .58743 L
.94522 .58743 L
.94769 .58743 L
.94899 .58743 L
.95039 .58743 L
.95168 .58743 L
.95286 .58743 L
.95404 .58743 L
.95516 .58743 L
.95633 .58743 L
.95739 .58743 L
.95862 .58743 L
.95977 .58743 L
.96085 .58743 L
.96183 .58743 L
Mistroke
.96291 .58743 L
.96405 .58743 L
.96645 .58743 L
.96868 .58743 L
.97375 .58743 L
.97619 .58743 L
Mfstroke
.15934 .59114 m
.16032 .5913 L
.1614 .5914 L
.16254 .59149 L
.16737 .59175 L
.1719 .59193 L
.18221 .59226 L
.20172 .59272 L
.22272 .59312 L
.26394 .59377 L
.30365 .59429 L
.34184 .59474 L
.38249 .59517 L
.42162 .59555 L
.4632 .59593 L
.50327 .59627 L
.54182 .59658 L
.58282 .5969 L
.62231 .59719 L
.66028 .59746 L
.7007 .59774 L
.73961 .598 L
.78097 .59826 L
.82082 .59851 L
.85915 .59874 L
.89993 .59897 L
.9392 .59919 L
.97619 .5994 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00k@3oool0103ooml0W4P00018W03Ooono0?ooo`00kP3oool00`3o_g@0
001d0;ooo`2o0?ooo`00kP3oool00`3ookl0M00007Boo`2o0?ooo`00k`3oool00`2oM00007Bo0?oo
o`2n0?ooo`00k`3oool02P3OW4P004Qd07A800000000001809cOo`2oM00000000000B02Lgong0?oo
o`00k`3oool02P3ogi`0B000001d_`3oool0oooO09a800000000B9cO0?oog`2o_mng0?ooo`00k`3o
ool00`3ookl0M00004RLg`020?ooo`030?oog`2LB00007Bo0;T0oooo003`0?ooo`030;md0000M;l0
oooo0080oooo00<0_g@00000M02oool0^03oool00?00oooo00<0okmd0018W03Oool00P3oool00`3o
_g@0001809cOo`2h0?ooo`00l03oool00`3ogi`0B01809cOo`020?ooo`030?oo_`1d0000B9cO0;P0
oooo003`0?ooo`030?oog`2LB000M;oo0080oooo00<0oooO09a80000M;l0^03oool00?40oooo00<0
_g@0001d_`3oool00P3oool00`3OW4P0001d0;ooo`2g0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00F03oool00`3o
okl0M000000000020000000307Boo`3oool0oooo0080oooo00<0okmd0000001d_ol00`3oool01@3O
W4P00000000000000000B9cO02l0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`02
0?ooo`030?noM0000000M;oo00<0oooo00D0gia8000000000000000004RLg`020?ooo`030?oog`2L
B00000000080000000<0M;oo0?ooo`3oool0;@3oool00`3ookl0M000000000020000000307Boo`3o
ool0oooo0080oooo00T0okmd0000001d_ol0oooo0?oo_`1d000000000018W03Oool0<@3oool00`3o
okl0M000000000020000000307Boo`3oool0oooo0080oooo00T0okmd0000001d_ol0oooo0?oo_`1d
000000000018W03Oool0103oool00`3ooml0W4P0000000020000000307Boo`3oool0oooo03T0oooo
00@0oooO09a80000B9`0gooo:03oool005P0oooo00<0omnL04P00018W=l00P3oool00`2oM000B9cO
0?ooo`020?ooo`030?noM0000000M;oo0080oooo00L0gia80000001d_ol0oooo0?oog`2LB000B9cO
02h0oooo00<0omnL04P00018W=l00P3oool00`2oM000B9cO0?ooo`020?ooo`030?noM0000000M;oo
0080oooo00/0gia80000001d_ol0oooo0?oog`2LB000B9cO0?ooo`3ooml0W4Qd0;ooo`020?ooo`03
0;md001d_ol0oooo02d0oooo00<0omnL04P00018W=l00P3oool00`2oM000B9cO0?ooo`020?ooo`03
0?noM0000000M;oo00@0oooo00<0gia80000001d_ol0<03oool00`3ogi`0B00004RLg`020?ooo`03
0;md0018W=l0oooo0080oooo00<0okmd0000001d_ol0103oool00`3OW4P0000007Boo`030?ooo`03
0?oog`2LB7@0_ooo0080oooo00<0_g@007Boo`3oool0>@3oool0103ooml0W4P00018W03OoolX0?oo
o`00G@3oool00`3ookl0M01809cOo`060?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03O
ool0<P3oool00`3ookl0M01809cOo`060?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0018W03O
ool01@3oool00`3ooml0W4Qd0;ooo`0b0?ooo`030?oo_`1d04P0W=oo00X0oooo00<0oono07@0001d
_ol0=03oool00`3ookl0M01809cOo`0:0?ooo`030?oo_`1d0000M;oo00L0oooo00<0oooO09a8M02o
ool0>@3oool0103ooml0W4P00018W03OoolX0?ooo`00G@3oool00`3ookl0M00007Boo`070?ooo`03
0;md0000M;l0oooo0080oooo00<0_g@00018W03Oool0<P3oool00`3ookl0M00007Boo`070?ooo`03
0;md0000M;l0oooo0080oooo00<0_g@00018W03Oool01P3oool00`2oM000M;oo0?ooo`0a0?ooo`03
0?oo_`1d0000M;oo00/0oooo00<0omnL04P0B02Lgol0<`3oool00`3ookl0M00007Boo`0;0?ooo`03
0?oOW01804P0W=oo00L0oooo00<0_g@007Boo`3oool0=03oool00`2oM00000000000000500000003
07Boo`3oool0oooo02D0oooo001M0?ooo`030?noM0000000M;oo00L0oooo00L0omnL04P0M02oool0
oooo0;md00000000M;oo03<0oooo00<0okmd0000001d_ol01`3oool01`3ogi`0B01d0;ooo`3oool0
_g@00000001d_ol01P3oool00`3ooml0W4P004RLg`0b0?ooo`030?noM0000000M;oo00L0oooo00<0
oooO09a8000000000`0000000`00M;l0oooo0?ooo`0a0?ooo`030?noM0000000M;oo00L0oooo00<0
oooO09a8000000000`0000000`00M;l0oooo0?ooo`040?ooo`030?oog`2LB000B9cO03D0oooo00P0
omnL07BLg`3oool0oooo0?oog`2LB00004RL0=ooobP0oooo001L0?ooo`040?oOW0180000001809cO
o`P0oooo00D0oono07A8B0180000000004RLg`0c0?ooo`040?oOW0180000001809cOo`P0oooo00D0
oono07A8B0180000000004RLg`070?ooo`030=nLB0000000M;oo0340oooo00@0omnL04P0000004P0
W=oo1`3oool0202oM000000007Boo`3oool0oooO09a8000007@0_ooo<@3oool0103ogi`0B0000000
B02Lgol70?ooo`080;md00000000M;oo0?ooo`3ooml0W4P00000M02oool50?ooo`030=nLB0000000
M;oo03H0oooo00L0gia807Boo`3oool0oooO09a80000B9`0gooo02P0oooo001J0?ooo`050?noM000
000000000000B02Lgol02@3oool0103ogi`0B00000000000M;lb0?ooo`050?noM000000000000000
B02Lgol02@3oool0103ogi`0B00000000000M;l40?ooo`070=oOg`3oool0oono07@000000000001d
0;ooo`0_0?ooo`050?noM000000000000000B02Lgol01`3oool00`3ogi`0B00004RLg`030?ooo`03
0?noM00004P0W=oo02l0oooo00D0okmd000000000000001809cOo`070?ooo`030?oOW0180000B9cO
00<0oooo00/0okmd0000B02Lgol0oooo0=oOg`3oool0oono07@000000000001d0;ooo`0f0?ooo`07
0?oog`2LB7@0_ooo0?oog`2LB00004RL0=ooo`0X0?ooo`00G03oool00`2oM00007Bo0?ooo`080?oo
o`060?oOW0180000001d0;ooo`3o_g@007Bo<`3oool00`2oM00007Bo0?ooo`080?ooo`060?oOW018
0000001d0;ooo`3o_g@007Bo0`3oool01P3OW4P00000000000000000001809cOoc80oooo00<0_g@0
001d_`3oool01`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo0340oooo00<0_g@0
001d_`3oool01`3oool00`3ogi`0B00007Boo`030?ooo`050?noM00004P0W=oo0?ooo`3OW4P00`00
00000`0004P0W=oo0?ooo`0g0?ooo`060?oOW018M;l0oooO09a80000B9`0gooo:03oool005d0oooo
00<0_g@004RLg`3oool01`3oool00`2oM000001d0;ooo`020?ooo`030;md0018W=l0oooo0380oooo
00<0_g@004RLg`3oool01`3oool00`2oM000001d0;ooo`020?ooo`080;md0018W=l0oooo0?ooo`3o
okl0M00000000018W=le0?ooo`030;md0018W=l0oooo00H0oooo00<0omnL04P0001d_ol00`3oool0
0`3OW4P0001d0;ooo`0b0?ooo`030;md0018W=l0oooo00H0oooo00<0omnL04P0001d_ol00`3oool0
203OW4P0001d0;ooo`3oool0oono07@000000000B9cO>`3oool01@3OW4P0M;oO09a80000B9`0gooo
02P0oooo001H0?ooo`030?oog`2LW;l0oooo0080oooo00<0gia80000M02oool01`3oool00`2oM000
04RL0=ooo`020?ooo`030=nLB000M;l0oooo02d0oooo00<0oooO09bL_`3oool00P3oool00`3OW4P0
001d0;ooo`070?ooo`030;md0000B9`0gooo0080oooo00<0gia8001d_`3oool00P3oool00`2oM000
M;oo0?ooo`0`0?ooo`030?oog`2LW;l0oooo0080oooo00<0gia80000M02oool01P3oool00`3ooml0
W4P007Boo`020?ooo`040?oog`2LB00004RL0=ooobd0oooo00<0oooO09bL_`3oool00P3oool00`3O
W4P0001d0;ooo`060?ooo`030?oog`2LB000M;oo0080oooo00@0oooO09a80000B9`0gooo0P3oool0
0`2oM000M;oo0?ooo`0k0?ooo`050?oog`2LB4P0B4P00018W03Oool0:03oool005T0oooo00H0okmd
04RLg`3oool0oono07@00000M;l80?ooo`070?noM0000000M;oo0?ooo`3ookl0M00007Boo`0_0?oo
o`060?noM018W=l0oooo0?oo_`1d000007Bo203oool01`3o_g@0000007Boo`3oool0oono07@0001d
_ol00`3oool01P3ogi`0B000000000000000001809cOobh0oooo00H0okmd04RLg`3oool0oono07@0
0000M;l80?ooo`070?noM00007@0_ooo0?ooo`3OW4P0001809cOo`0_0?ooo`060?noM018W=l0oooo
0?oo_`1d000007Bo203oool01`3o_g@0001d0;ooo`3oool0gia80000B02Lgol00`3oool01P3ogi`0
B000000000000000001809cOocT0oooo00@0omnL04P00000B9`0gooo:03oool005X0oooo00D0gia8
000000000000001d0;ooo`090?ooo`050?noM0000000000000000018W=l0<@3oool01@3OW4P00000
0000000007@0_ooo00T0oooo00D0okmd000000000000000004RLg`050?ooo`050;md000000000000
00000018W=l0;`3oool01@3OW4P000000000000007@0_ooo00T0oooo00D0okmd0000000000000018
09cOo`0a0?ooo`050=nLB000000000000000M02oool02@3oool01@3o_g@000000000000004P0W=oo
00D0oooo00D0_g@0000000000000000004RLg`0j0?ooo`030=nLB000B9`0gooo02P0oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo001L0?ooool00000<P00000S0?ooo`00G03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`03
0000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo
0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3o
ool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?oo
o`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000
oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0
o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`800000o`3oool]0?ooo`<000008`3o
ool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?oo
o`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000
oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0
o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3o
ool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool200000?l0oooo;@3oool3000002<0oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3o
ool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`H000001`3oool00`00
0000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3T0?oooc`000003@3oool00`000000
oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`2e0?ooobl00000B@3oool00`000000oooo
0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`2A0?ooob@00000N03oool00`000000oooo0?oo
o`0Q0?ooo`00G03oool00`000000oooo0?ooo`1/0?ooobD00000W03oool00`000000oooo0?ooo`0Q
0?ooo`00G03oool00`000000oooo0?ooo`1D0?oooaP00000`@3oool00`000000oooo0?ooo`0Q0?oo
o`00G03oool00`000000oooo0?ooo`0n0?oooaH00000f@3oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool2000003@0oooo2`00003]0?ooo`<000008`3oool005`0oooo00<000000?ooo`3oool0;@3o
ool600000?X0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0;@3oool6
00000?X0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0<`3ooolD0000
0>H0oooo00<000000?ooo`3oool08@3oool00440oooo00D0omnL04P000000000001d0;ooo`030?oo
o`050?noM0000000M;oo0?ooo`2oM0001P0000000`18W=l0oooo0?ooo`050?ooo`030000003oool0
oooo04L0oooo6000003>0?ooo`030000003oool0oooo0240oooo00100?ooo`070?oo_`1d0000M;oo
0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM0000000M;oo0080oooo00<0gia80000000000000`00
00000`00B9`0gooo0?ooo`050?ooo`030000003oool0oooo05l0oooo?000002B0?ooo`030000003o
ool0oooo0240oooo00100?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool0
0`3OW4P0B9cO0?ooo`020?ooo`030=nLM02Lgol0oooo00D0oooo00<000000?ooo`3oool0V`3ooomQ
00000340oooo00<000000?ooo`3oool08@3oool003l0oooo00<0oono07@00018W=l00`3oool00`3O
W4P0001d0;ooo`080?ooo`030=nLB01d_ol0oooo00T0oooo00<000000?ooo`3oool0o03ooolZ0000
00L0oooo00<000000?ooo`3oool08@3oool003l0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`090?ooo`030;mdB02Lgol0oooo00P0oooo00<000000?ooo`3oool0o`3oool^0?ooo`03
0000003oool0oooo0240oooo000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0
2@3oool00`3ooml0W4Qd0;ooo`080?ooo`<00000o`3oool/0?ooo`<000008`3oool003l0oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?noM000M;l0oooo00L0oooo00<0
00000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3ookl0M01809cOo`070?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`030?oo
o`030=nLB00007@0_ooo00X0oooo00<0oono07@00018W=l01`3oool00`000000oooo0?ooo`3o0?oo
obh0oooo00<000000?ooo`3oool08@3oool00400oooo00<0gia80018W03Oool00P3oool00`2oM000
07Bo0?ooo`050?ooo`030?noW02Lgol0oooo0080oooo00<0omnL04P00018W=l01`3oool00`000000
oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool00400oooo00L0oono07@0001d_ol0
oooo0?noM00007@0_ooo00H0oooo00P0oooO09a8B02Lgol0oooo0?oo_`1d0000001d0;ooo`L0oooo
00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo00110?ooo`050?oo_`1d
000000000000M02oool0203oool01P3ooml0W4P0000000000000001d0;ooo`P0oooo00<000000?oo
o`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo
00<000000?ooo`3oool08@3oool005`0oooo0P00003o0?ooobd0oooo0`00000S0?ooo`00G03oool0
0`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?oo
o`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo
00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003o
ool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q
0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0
oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;md
M02oool0oooo00@0oooo00<0gibL0;ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooobh0oooo
00<000000?ooo`3oool08@3oool002`0oooo00<0_gAd0;ooo`3oool0103oool00`2oM7@0_ooo0?oo
o`0V0?ooo`800000o`3oool]0?ooo`<000008`3oool002P0oooo00<0oono07@00000000020000000
0`0007@0_ooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q
0?ooo`009`3oool00`3ogi`0B00000000009000000030000M02oool0oooo02H0oooo00<000000?oo
o`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo000V0?ooo`030?oog`2LM9`0gooo00<0
oooo00<0_gAd0;ooo`3oool0103oool00`2oM7@0_ooo0?ooo`0V0?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`009P3oool00`3ookl0M7Bo0?ooo`030?ooo`030;md
M02oool0oooo00@0oooo00<0gibL0;ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooobh0oooo
00<000000?ooo`3oool08@3oool002H0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ookl0M7Bo
0?ooo`040?ooo`030=nLW02oool0oooo02H0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000
003oool0oooo0240oooo000V0?ooo`040?oog`2L=P00000004RLg`80oooo00<0okmd000000000000
100000000`0007@0_ooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo
0?ooo`0Q0?ooo`009P3oool00`3ooml0W4P0001d_`030?ooo`030;md00000000000000@0000000<0
001d0;ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3o
ool003<0oooo00<0gibL0;ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<00000
0?ooo`3oool08@3oool005`0oooo0P00003o0?ooobd0oooo0`00000S0?ooo`00;03oool00`2oM7@0
_ooo0?ooo`040?ooo`030;mdM02oool0oooo02H0oooo00<000000?ooo`3oool0o`3oool^0?ooo`03
0000003oool0oooo0240oooo000/0?ooo`030;md0018W=l0oooo00<0oooo00<0gia80000M02oool0
9`3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool002`0oooo00T0
_g@00000000007@0_ooo0?oog`2LB000B9cO0=nLW02oool09`3oool00`000000oooo0?ooo`3o0?oo
obh0oooo00<000000?ooo`3oool08@3oool002`0oooo00H0_ibL0=oOW018000000000000B02LgolZ
0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`2o
M7@0_mnL04P00002000000040000B02Lgol0gibL0;ooo``0oooo00D0omnL04P000000000001d0;oo
o`030?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo
0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0_g@00018W03Oool00P3o
ool0102oM00000000000M02oool;0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?oo
o`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`3o
0?ooobh0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0_gA809cOo`3oool00`3oool00`3o
_g@0001d0;ooo`0;0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool02@3oool0103o
oml0W4P00018W03Oool70?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q
0?ooo`00;03oool00`2oW9`0gooo0?ooo`040?ooo`030=nLW02oool0oooo00T0oooo00<0oono07@0
0018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030;md00000000000000D0000000<0M;oo0?oo
o`3oool0103oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool003l0
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`080?oOW01dW=l0oooo0?oo
o`3ooml0W4P00018W03Oool70?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?oo
o`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0gia8
07Boo`3oool0oooO09a80000B9`0gooo00L0oooo0`00003o0?ooob`0oooo0`00000S0?ooo`00;@3o
ool00`3ookl0M000000000020000000304RLg`3oool0oooo00X0oooo00<0omnL04P0001d_ol00`3o
ool00`3o_g@0001809cOo`060?ooo`070?oog`2LB7@0_ooo0?oog`2LB00004RL0=ooo`070?ooo`03
0000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`3ogi`0B000
000000040000000304RLg`3oool0oooo00T0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@00018
09cOo`070?ooo`060?oOW018M;l0oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`3o0?oo
oaH0oooo4@0000070?ooo`030000003oool0oooo0240oooo000/0?ooo`090=nLM02Lgol0okmd07Bo
o`3oool0okmd0000000007@0_ooo00X0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;oo
o`080?ooo`050=nLB01d_ml0W4P00018W03Oool01`3oool00`000000oooo0?ooo`3m0?oooaP00000
603oool00`000000oooo0?ooo`0Q0?ooo`00;03oool0102oM4P0W=oo0?noM01d_ol20?ooo`030=nL
B00007@0_ooo00/0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`050?oo
g`2LB4P0B4P00018W03Oool01`3oool00`000000oooo0?ooo`3T0?oooaT00000<03oool00`000000
oooo0?ooo`0Q0?ooo`00;03oool0103o_g@000000000001d_ol20?ooo`030;md0000M;l0oooo00/0
oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00X0oooo00@0omnL04P00000B9`0gooo1`3o
ool00`000000oooo0?ooo`3H0?ooo``00000B@3oool00`000000oooo0?ooo`0Q0?ooo`00;@3oool0
1P3OW4P0000007Boo`3o_g@00000001d_`h0oooo00D0oono07@000000000001d0;ooo`0<0?ooo`03
0=nLB000B9`0gooo00L0oooo00<000000?ooo`3oool0`03ooolH000005D0oooo00<000000?ooo`3o
ool08@3oool005`0oooo00<000000?ooo`3oool0Z03ooolH000006d0oooo00<000000?ooo`3oool0
8@3oool005`0oooo00<000000?ooo`3oool0W03oool<000008D0oooo00<000000?ooo`3oool08@3o
ool002h0oooo00D0_g@0000000000000000004RLg`0Y0?ooo`800000Q@3ooolH000008l0oooo0`00
000S0?ooo`00;03oool00`3ookl0M000000000040000000304RLg`3oool0oooo02H0oooo00<00000
0?ooo`3oool0N03oool<00000:T0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0gia8001d
_`3oool00P3oool0103ookl0M0000000M02ooolW0?ooo`030000003oool0oooo06`0oooo3000002e
0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;mdM02oool0oooo00<0oooo00<0oono07@0
M02oool09`3oool00`000000oooo0?ooo`1P0?ooo``00000`@3oool00`000000oooo0?ooo`0Q0?oo
o`009`3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW02L_ol0oooo00<0oooo00<0oknL09cOo`3o
ool09`3oool00`000000oooo0?ooo`1D0?ooo``00000c@3oool00`000000oooo0?ooo`0Q0?ooo`00
9`3oool00`2oM000000000000009000000030000M02oool0oooo02H0oooo00<000000?ooo`3oool0
B`3oool900000=T0oooo00<000000?ooo`3oool08@3oool002H0oooo00<0oono07@0000000002P00
00000`00M;l0oooo0?ooo`0V0?ooo`030000003oool0oooo04D0oooo1P00003R0?ooo`030000003o
ool0oooo0240oooo000b0?ooo`030?oOW02L_ol0oooo02L0oooo00<000000?ooo`3oool0?P3oool7
00000>P0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0>03oool60000
0>l0oooo00<000000?ooo`3oool08@3oool005`0oooo0P00000d0?ooo`D00000l`3oool3000002<0
oooo001L0?ooo`030000003oool0oooo0300oooo0`00003j0?ooo`030000003oool0oooo0240oooo
001L0?ooo`030000003oool0oooo02h0oooo0P00003m0?ooo`030000003oool0oooo0240oooo001L
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0Q
0?ooo`00;03oool00`3ooml0W9bo0?ooo`080?ooo`030;nLW03Oool0oooo0280oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo0240oooo000/0?ooo`03
0?oOW0180000000000P0000000<004RL0=ooo`3oool08P3oool00`000000oooo0?ooo`0_0?ooo`@0
0000nP3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`3OW4P0000000000008000000030018
W03Oool0oooo0280oooo00<000000?ooo`3oool0<`3oool400000?H0oooo00<000000?ooo`3oool0
8@3oool002d0oooo00<0_gAd0;ooo`3oool00P3oool00`3ooml0W9bo0?ooo`020?ooo`030;nLW03O
ool0oooo0280oooo00<000000?ooo`3oool0=`3oool700000>l0oooo00<000000?ooo`3oool08@3o
ool002`0oooo00<0gia8001d_`3oool0103oool00`3OW9`0_ooo0?ooo`0V0?ooo`030000003oool0
oooo03h0oooo1P00003Y0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;md00000000M;oo
00<0oooo00<0omnL04Q8W03Oool09`3oool00`000000oooo0?ooo`140?ooo`H00000h`3oool00`00
0000oooo0?ooo`0Q0?ooo`00;03oool00`3o_g@00000000000040000000307Boo`3oool0oooo02H0
oooo0P00001;0?ooo`T00000f03oool3000002<0oooo000]0?ooo`060?oOW0180000000000000000
04P0W=oo:@3oool00`000000oooo0?ooo`1C0?ooo``00000cP3oool00`000000oooo0?ooo`0Q0?oo
o`00G03oool00`000000oooo0?ooo`1O0?ooo``00000`P3oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool00`000000oooo0?ooo`1[0?ooo``00000]P3oool00`000000oooo0?ooo`0Q0?ooo`00;P3o
ool01@2oM00000000000000004P0W=oo00h0oooo00D0omnL04P000000000001d0;ooo`030?ooo`03
0?noM0000000M;oo00<0oooo00D0omnL04P000000000000007Boo`080?ooo`030000003oool0oooo
07L0oooo6@00002M0?ooo`030000003oool0oooo0240oooo000/0?ooo`030?oo_`1d0000000000@0
000000<0M;oo0?ooo`3oool02P3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool0
0`3o_g@0000007Boo`020?ooo`070?oOW0180000B9cO0?ooo`3ookl0M00007Boo`070?ooo`030000
003oool0oooo0900oooo3000002A0?ooo`030000003oool0oooo0240oooo000/0?ooo`030=nLB01d
_ol0oooo00<0oooo00<0_g@00018W03Oool02`3oool00`2oM00004RL0=ooo`020?ooo`030;md0000
M;l0oooo00D0oooo00<0oooO09a80000M;l00`3oool00`3o_g@004RL0=ooo`060?ooo`030000003o
ool0oooo09`0oooo6000001i0?ooo`030000003oool0oooo0240oooo000/0?ooo`030;mdM02oool0
oooo00@0oooo00<0gibL0;ooo`3oool02@3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0
_ooo00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`030000003oool0
oooo0;@0oooo6000001Q0?ooo`030000003oool0oooo0240oooo000/0?ooo`030=nLB000B9`0gooo
00<0oooo00<0oono07A8W03Oool02P3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`060?ooo`030000003oool0oooo
0<`0oooo600000190?ooo`030000003oool0oooo0240oooo000/0?ooo`030?oo_`1d0000000000@0
000000<0M;oo0?ooo`3oool02@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0
oooo00<0omnL04P0001d_ol00`3oool00`2oM000001809cOo`060?ooo`<00000i03ooolH000002l0
oooo0`00000S0?ooo`00;@3oool01P3ooml0W4P0000000000000001d0;ooo``0oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`080?oo_`1d0000000004RLg`3oool0okmd0000
0000M;l70?ooo`030000003oool0oooo0?`0oooo6000000I0?ooo`030000003oool0oooo0240oooo
000o0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool00`2oM00004RL0;nL
B002000000030018W03Oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolE0?oooa8000001`3o
ool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`3ookl0M7Bo0?ooo`040?ooo`030=nLW02oool0
oooo00T0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`060?ooo`030?oOW0180000
M;oo00/0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo000V0?oo
o`030?oog`2LB00007Bo00<0oooo00<0okmd000000000000100000000`0007@0_ooo0?ooo`0:0?oo
o`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`3OW4P0001809cOo`0:0?oo
o`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`009P3oool00`3ooml0
W4P0001d_`030?ooo`030;md00000000000000@0000000<0001d0;ooo`3oool02P3oool01`3ookl0
M00007Boo`3oool0okmd0000M02oool02@3oool00`3o_g@00000001d_`090?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00<`3oool00`3OW9`0_ooo0?ooo`0;0?oo
o`050?oo_`1d000000000000M02oool02`3oool01@3ooml0W4P00000000007@0_ooo00H0oooo00<0
00000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`3ookl0M7Bo0?ooo`040?oo
o`030=nLW02oool0oooo02H0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo
0240oooo000/0?ooo`030?noM0000000000000@0000000<0001d0;ooo`3oool09P3oool200000?l0
oooo;@3oool3000002<0oooo000/0?ooo`030;md00000000000000@0000000<0001d0;ooo`3oool0
9P3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool002d0oooo00<0
gibL0;ooo`3oool00`3oool00`3OW9`0_ooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo;P3o
ool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`3ogi`0M9cO0?ooo`0]0?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`2oM00007Bo0?ooo`040?oo
o`030=nLW02oool0oooo02H0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo
0240oooo000/0?ooo`030=nLB0000000000000@0000000<0001d0;ooo`3oool09P3oool00`000000
oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0oooO09a800000000
100000000`0007@0_ooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo
0?ooo`0Q0?ooo`00<`3oool00`3OW9`0_ooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo;P3o
ool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`2oM7@0_ooo0?ooo`0]0?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00:P3oool00`3ookl0M000000000060000
000304RLg`3oool0oooo02H0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo
0240oooo000Y0?ooo`030?noM0000000000000L0000000<0001d0;ooo`3oool09P3oool200000?l0
oooo;@3oool3000002<0oooo000/0?ooo`030;mdM02oool0oooo00<0oooo00<0oono07A8W03Oool0
9`3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool002`0oooo00<0
_gAd0;ooo`3oool00`3oool00`2oM4P0W=oo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo;P3o
ool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<00000
0?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo
0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0oooo00<0
00000?ooo`3oool0103ooom?00000=X0oooo00<000000?ooo`3oool08@3oool005`0oooo00<00000
0?ooo`3oool0D`3ooomh00000680oooo00<000000?ooo`3oool08@3oool005`0oooo0P00003<0?oo
oe/000001@3oool3000002<0oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000
oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool0
8@3oool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L
0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00@@3oool01@3o
gi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3OW4P0000000000000
0000B9cO00P0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo0010
0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM0000000M;oo0080oooo
00L0gia80000001d_ol0oooo0?oog`2LB000B9cO00L0oooo00<000000?ooo`3oool0o`3oool^0?oo
o`030000003oool0oooo0240oooo00100?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3o
ool01@3oool00`3ooml0W4P0001d_`030?ooo`030?noM000B9`0gooo00H0oooo00<000000?ooo`3o
ool0o`3oool^0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oo_`1d0000B9cO00<0oooo
00<0gia80000M02oool01P3oool00`2oM00007Bo0?ooo`020?ooo`030;md0000B9`0gooo00H0oooo
00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo000o0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3ogi`0B01d0;ooo`3oool0_g@00000001d
_ol01`3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool003l0oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`050?oo_`1dB4P0B00000000018
W=l0203oool300000?l0oooo;03oool3000002<0oooo000o0?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol01`3oool0103ogi`0B00000000000M;l90?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ogi`0B00007Boo`030?ooo`030?no
M00004P0W=oo00H0oooo00H0omnL04P0000007@0_ooo0?noM000M;l80?ooo`030000003oool0oooo
0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool00`3ookl0M00004RLg`030?ooo`03
0=nLB00007@0_ooo00H0oooo00<0_g@00000M02oool00P3oool00`2oM000B9cO0?ooo`060?ooo`03
0000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool00`3OW4P004RL
0=ooo`020?ooo`030;md0000M;l0oooo00H0oooo00<0_g@00018W03Oool00P3oool00`3OW4P007Bo
0?ooo`060?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00@03o
ool01`3ookl0M00007Boo`3oool0okmd0000M02oool01`3oool01`3o_g@0000007Boo`3oool0oono
07@0001d_ol01`3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool0
0440oooo00D0oono07@000000000001d0;ooo`090?ooo`050?noM0000000000000000018W=l0203o
ool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0oooo00<00000
0?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo
0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool200000?l0oooo;@3oool3000002<0
oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03o
ool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0oooo00<00000
0?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo
0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0
oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000
003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?oo
o`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool0
05`0oooo0P00003o0?ooobd0oooo0`00000S0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0
oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000
003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?oo
o`0Q0?ooo`00G03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool0
05`0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`03
0000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00G03oool00`000000oooo
0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool005`0oooo00<000000?ooo`3oool0o`3o
ool^0?ooo`030000003oool0oooo0240oooo001L0?ooo`030000003oool0oooo0?l0oooo;P3oool0
0`000000oooo0?ooo`0Q0?ooo`00G03oool200000400ooooi`0000050?ooo`<000008`3oool005`0
oooo00<000000?ooo`3oool0;@3ooolB00000>h0oooo00<000000?ooo`3oool08@3oool005`0oooo
00<000000?ooo`3oool0?P3ooomB000009d0oooo00<000000?ooo`3oool08@3oool005`0oooo00<0
00000?ooo`3oool0T03ooon@000000d0oooo00<000000?ooo`3oool08@3oool004h0oooo00H0_g@0
00000000000000000018W03Oool80?ooo`030000003oool0oooo0?l0oooo8@3oool6000000L0oooo
00<000000?ooo`3oool08@3oool004l0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?oo
o`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool004l0oooo00<0omnL04P0001d_ol02P3oool0
0`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool08@3oool004l0oooo00<0omnL04P0
001d_ol02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool00`3ogi`0B00007Boo`0:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool004l0oooo00<0omnL04P0001d_ol0
2P3ooooo0000038000008`3oool004l0oooo00<0omnL04P0001d_ol0o`3ooomO0?ooo`00C`3oool0
0`3ogi`0B00007Boo`3o0?oooel0oooo001?0?ooo`030?oOW0180000M;oo0?l0ooooG`3oool004l0
oooo00<0omnL04P0001d_ol0o`3ooomO0?ooo`00C@3oool01@3ooml0W4P0000000000000M;oo0?l0
ooooG`3oool004l0oooo00<0okmd0000001d_ol0o`3ooomO0?ooo`00b@3oool00`3ooml0W4P00000
00030000000304RLg`3oool0oooo0=h0oooo00390?ooo`030;md0000B9`0gooo00<0oooo00<0gibL
0;ooo`3oool0gP3oool00<T0oooo00<0oooO09adW03Oool00`3oool00`3ookl0W9cO0?ooo`3N0?oo
o`00bP3oool00`2oM0000000000000030000000304RLg`3oool0oooo0=d0oooo002_0?ooo`030;md
0000000000000080000000H007Bo0?ooo`3oool0oooo0?oog`2LB002000000050018W02LM0000000
001d_`2oM0000P0000000`0007@0_ooO09a80002000000030018W03Ookl0M00000@0000000D0001d
0;ooo`3oool0oooo0;md0002000000040000M02oool0oooo0;md0080000000<0001d0;oog`2LB000
0P0000001P00B9`0gooo0?oOW0180000000004RLg`<0oooo00<0oooO09a8000000001P0000001@00
07@0_ooo0?ooo`3oool0gia80080000000<0001d0;oOW01800000`000000101d_ol0oooo0?oo_`1d
00020000000504RL_`2LB00004RL0=ooo`2oM0000P0000000`0004P0W=oo0?ooo`020?ooo`080;md
0000000000000000B02Lgol0oooo0?oog`2LB0020000000:0018W02LM0000000001d_`3oool0omnL
04P000000000B9cO0=nLB080000000@0001d0;ooo`3oool0gia80`000000101d_ol0oooo0?ooo`2o
M002000000030000M02ooml0W4P00080000000<004RL0=ooo`3oool0L`3oool00;00oooo00@0oooO
09a80000B9`0gooo103oool0403o_g@0000007Boo`3oool0omnL04P00000M;l0okno0;ooo`3OW4P0
04RL0=ooo`3oool0oooO09a80000M;l20?ooo`030;mdB02Lgol0oooo00D0oooo00l0_g@000000000
M;l0oooo0?oOW01807@0_ooo0?ooo`3OW4P004RL0=ooo`3oool0oooO09a80000M;l00P3oool01@3O
W4P0001d0;ooo`3O_kl0gooo00@0oooo00<0omnL04P00018W=l00`3oool0103ogi`0B0000000001d
_ol20?ooo`070=nLB00007@0_ooo0?ooo`3ooml0W4P0001d_`030?ooo`050=nLB00007@0_ooo0?oo
o`3OW4P00P0000001@0007@0_ooo0=nLB00007@0_ooo00<0oooo0200_g@000000000B9`0gooo0?oo
g`2LB7@0_ooo0?noM0000000M;oo0?ooo`3ogi`0B000001d_`3o_kl0_ooo0=nLB00007@0_ooo0=no
_`3Oool0gia80000M02oool0oooo0=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`80oooo00L0gia8
0018W03Oool0oooo0?oog`2LB00007Bo07H0oooo002`0?ooo`030?oog`2LB00007Bo00D0oooo00L0
okmd0000B02Lgol0oooo0?oog`2LB00007Bo0080oooo00L0gia80018W03Oool0oooo0?oog`2LB000
07Bo0080oooo00D0oono07@0000000000000001d_`020?ooo`030?oOW0180000B9cO00<0oooo00X0
omnL07BLg`3oool0gia80018W03Oool0oooo0?oog`2LB00007Bo0P3oool00`3OW4P004RL0=ooo`06
0?ooo`030?oo_`1d0000B9cO00@0oooo00`0okmd00000000B9`0gooo0?ooo`3OW4P0001d0;ooo`3o
ool0oooO09a80000M;l30?ooo`070;md0000B9`0gooo0?ooo`3ooml0W4P0001d_`020?ooo`030=nL
B00007@0_ooo0080oooo00<0omnL04P00000M;l00`3oool02@3ogi`0W;oo0?noM00004P0W=oo0?oo
o`3ooml0W4P0001d_`020?ooo`030=nLB000B9`0gooo0080oooo00H0gia80000M02oool0omnL04P0
0000M;l30?ooo`0;0?noM00007@0_ooo0?ooo`3OW4P004RL0=ooo`3oool0oooO09a80000M;l0MP3o
ool00;00oooo00<0oooO09a80000M;l01P3oool01P3o_g@00000001d_`3ooml0W4P0001d_`80oooo
00L0gia80018W03Oool0oooo0?oog`2LB00007Bo0080oooo00X0gia80000M02oool0oono07@00018
W=l0oooo0?noM00004P0W=oo1P3oool01`3OW4P004RL0=ooo`3oool0oooO09a80000M;l00P3oool0
0`3OW4P004RL0=ooo`060?ooo`030?oo_`1d0000B9cO00@0oooo00`0omnL04P0000007@0_ooo0?oo
o`3OW4P0001d0;ooo`3oool0oooO09a80000M;l30?ooo`070;md0000B9`0gooo0?ooo`3ooml0W4P0
001d_`020?ooo`030=nLB00007@0_ooo0080oooo00<0okmd0000B02Lgol01P3oool01P3o_g@00000
001d_`3ooml0W4P0001d_`80oooo00<0gia80018W03Oool00P3oool01P3OW4P0001d0;ooo`3o_g@0
000007Boo`<0oooo00/0okmd0000001d_ol0oooo0=nLB000B9`0gooo0?ooo`3ooml0W4P0001d_`1f
0?ooo`00/03oool00`3ooml0W4P0001d_`080?ooo`040?noM00000000000001d_`80oooo01<0gia8
0018W03Oool0oooo0?oog`2LB00007Bo0?ooo`3ookl0M00004RLg`3oool0oooO09a80000M;l0oooo
0?noM00007@0_ooo00H0oooo00L0gia80018W03Oool0oooo0?oog`2LB00007Bo0080oooo00<0gia8
0018W03Oool01P3oool00`3ookl0M00004RLg`040?ooo`030?noM000000007Bo0080oooo00L0gia8
0000M02oool0oooo0?oog`2LB00007Bo00<0oooo00L0_g@00018W03Oool0oooo0?oog`2LB00007Bo
0080oooo00<0gia80000M02oool00P3oool00`3o_g@0001d0;ooo`080?ooo`040?noM00000000000
001d_`80oooo00<0gia80018W03Oool00P3oool01P3OW4P0001d0;ooo`3o_g@0000007Boo`<0oooo
00/0okmd0000001d_ol0oooo0=nLB000B9`0gooo0?ooo`3ooml0W4P0001d_`1f0?ooo`00/03oool0
0`3ooml0W4P0001d_`050?ooo`070?oo_`1d0000M;oo0?ooo`3ooml0W4P0001d_`020?ooo`0B0;md
000007@0_ooo0?ooo`3ooml0W4P0001d_`3oool0oono07@00018W=l0oooo0?oog`2LB000B9cO0?oo
o`3ogi`0B0001@0000002@18W=l0oooo0;md000007@0_ooo0?ooo`3ooml0W4P0001d_`020?ooo`03
0=nLB000B9`0gooo00H0oooo00<0oono07@00018W=l00`3oool0103OW4P000000000B02Lgol20?oo
o`070=nLB00007@0_ooo0?ooo`3ooml0W4P0001d_`030?ooo`070;md0000B9`0gooo0?ooo`3ooml0
W4P0001d_`020?ooo`030=nLB00004P0W=oo0080oooo00<0omnL04P0B02Lgol00P3oool02P3o_g@0
001809cOo`3ookl0M00007Boo`3oool0oooO09a80000M;l20?ooo`030=nLB000B9`0gooo0080oooo
00H0gia80000M02oool0oono07@0001d_ol30?ooo`0;0;md000004P0W=oo0?ooo`2oM000001d0;oo
o`3oool0oooO09a80000M;l0MP3oool00;00oooo00<0oooO09a80000M;l01@3oool0403ookl0M000
04RLg`3oool0oono07@00000M;l0oooO09a80000000004Q804P0B02Lgol0oono07@00018W=l20?oo
o`040;md0000M;l0oooo0?noM080000000@004RL0=ooo`2oM000B9cO0P3oool02`3OW4P0001809cO
g`2LB00000000018B01804P0W=oo0?oo_`1d0000B9cO0080oooo00<0gia80018W03Oool01P3oool0
0`3ookl0M000000000040000000<07Boo`3oool0oooo0?oog`2LB00000000000M02oool0oooo0?oo
g`2LB00007Bo0`3oool07@2oM00004RL0=ooo`3oool0oooO09a80000M;l0oooO09a8000000000018
04QdW03O_g@0001d0;ooo`2oM00004RL0=ooo`3ooml0W4P00000M02oool0oono07@00018W=l0oooo
0?oo_`1d000007Bo0080oooo01T0gia80018W03Oool0oooO09a800000000001d0;ooo`3oool0gia8
0018W03Oool0oooo0?noM000000007Bo0?oog`2LB00000000018B01804P0W=oo0?oo_`1d0000B9cO
07H0oooo002`0?ooo`030?oog`2LB00007Bo00H0oooo00H0oono07@00000000000000000M02oool2
0?ooo`070;md0000B9`0gooO09a800000000001d0;ooo`020?ooo`050?oog`2LB00000000000001d
_ol0103oool01@3OW4P000000000000004P0W=oo0080oooo00T0_g@00018W03Ooml0W4P000000000
07@0_ooo0?ooo`2oM0000`0000000`00B9`0gooo0?ooo`030?ooo`030?oo_`1d0000B9cO00<0oooo
00@0okmd00000000B9`0gooo0P3oool0102oM000001d0;ooo`3o_g@4000000090018B01800000000
0018W03Oool0omnL04P00000000007Bo0080oooo00P0_g@00000M02ogi`0B0000000M02oool0oooo
0=nLB080000000H0001809cOo`3oool0oooo0?oo_`1d0002000000040000M02oool0oooo0;md00<0
000000D004RL0=ooo`2oM000001d0;ooo`020?ooo`050?noM0000000000000000018W=l00`3oool0
1`2oM00004RL0=oog`2LB00000000000M02oool0MP3oool00;00oooo00<0oooO09a80000M;l0<03o
ool00`2oM00004RL0=ooo`060?ooo`030?oo_`1d0000B9cO00@0oooo00<0_g@00000001d_ol01P3o
ool00`3ooml0W4P0001d_`0R0?ooo`030;md0000B9`0gooo08`0oooo002/0?ooo`070?noW02Lgol0
oooo0?ooo`3ooml0W4P0001d_`030?ooo`030?noM01d_ol0oooo02X0oooo00<0oono07A8W03Oool0
1P3oool00`3ookl0M00004RLg`040?ooo`030;md00000000M;oo00L0oooo00<0_g@0001d_`3oool0
8@3oool00`3ookl0M4RL0=ooo`2<0?ooo`00[03oool01`3o_g@004RL0=ooo`3oool0oooO09a80000
M;l00P3oool00`3ooml0W4P007Boo`0[0?ooo`030?oog`2LM9`0gooo00H0oooo00<0omnL04P00018
W=l00`3oool0103OW4P000000018W03Oool70?ooo`030=nLB000M;l0oooo0240oooo00<0oooO09ad
W03Oool0S03oool00:`0oooo00<0okmd000000000000200000000`1d_ol0oooo0?ooo`0`0?ooo`03
0?oog`2LB000000000H0000000<0B9cO0?ooo`3oool00P3oool00`3OW4P0001809cOo`020?ooo`07
0?oo_`1d07@0_ooo0?oog`2LB00004RL0=ooo`0R0?ooo`030=nLB00004P0W=oo08L0oooo003h0?oo
o`030=nLB00004P0W=oo00<0oooo00D0oono07@000000000001809cOo`0S0?ooo`030=nLB00004P0
W=oo08L0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {3.73111, -0.270979, \
0.00103725, 0.00799197}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseMain"],

Cell[CellGroupData[{

Cell["Cobweb diagrams for typical population models", "ExerciseTitle"],

Cell[TextData[{
  "The following discrete maps have been used to analyze population dynamics \
in realistic situations.  Produce and describe cobweb diagrams for \
representative parameters and analyze the expected behaviors.\na) ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\  \[Equal] \ x\_\(n - 1\)\%2\  - \ \[Mu]\)]],
  "\nb) ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\  \[Equal] \ 
        x\_\(n - 1\)\ Exp[\[Mu](1\  - \ x\_\(n - 1\))]\)]]
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Cobweb diagram for positive root of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + 2  x \[Equal] 1\)]]
}], "ExerciseTitle"],

Cell[TextData[{
  "In ",
  StyleBox["getting started",
    FontSlant->"Italic"],
  " we based an exercise on a iterative algorithm for computing ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\)]],
  " that employs the equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + 2  x \[Equal] 1\)]],
  " whose positive root is ",
  Cell[BoxData[
      \(TraditionalForm\`\@2 - 1\)]],
  ".  Expressing this equation in the form ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Equal] 1\/\(2 + x\)\)]],
  " suggests the iterative procedure ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + 1\) \[Equal] 1\/\(2 + x\_i\)\)]],
  ".\na) Determine the fixed points of ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + 1\) \[Equal] 1\/\(2 + x\_i\)\)]],
  ", their eigenvalues, and classify them (stable, unstable, neutral).\nb) \
Produce cobweb diagrams for a variety of seeds that suggest that the \
iterative process converges to the stable fixed point for any ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0 \[NotEqual] \(-2\)\)]],
  ".\nc) Provide a formal proof of convergence for any ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0 \[NotEqual] \(-2\)\)]],
  ".\nd) Under what conditions will iteration converge to one of the roots of \
",
  Cell[BoxData[
      \(TraditionalForm\`a\ x\^2 + b\ x + c \[Equal] 0\)]],
  "?"
}], "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Presentation",
WindowToolbars->"EditBar",
WindowSize->{1392, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowCellLabel->False,
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}, {
        Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->0.5,
    CellMargins->{{25, 0}, {6, 6}},
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 1, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 76, 2, 81, "Title"],
Cell[1855, 57, 455, 15, 85, "Author"],

Cell[CellGroupData[{
Cell[2335, 76, 31, 0, 83, "Section"],
Cell[2369, 78, 109, 3, 41, "Text"],
Cell[2481, 83, 116, 4, 41, "Text"],
Cell[2600, 89, 665, 17, 68, "Text"],
Cell[3268, 108, 525, 11, 93, "Text"],
Cell[3796, 121, 1099, 21, 145, "Text"],
Cell[4898, 144, 721, 14, 119, "Text"],
Cell[5622, 160, 90, 2, 41, "Text"],
Cell[5715, 164, 204, 7, 41, "Text"],
Cell[5922, 173, 199, 6, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6158, 184, 33, 0, 51, "Section"],
Cell[6194, 186, 232, 4, 125, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6463, 195, 30, 0, 51, "Section"],
Cell[6496, 197, 141, 3, 41, "Text"],
Cell[6640, 202, 228, 11, 41, "Text"],
Cell[6871, 215, 120, 4, 41, "Text"],
Cell[6994, 221, 107, 4, 41, "Text"],
Cell[7104, 227, 109, 4, 41, "Text"],
Cell[7216, 233, 33, 0, 41, "Text"],
Cell[7252, 235, 740, 23, 67, "Text"],
Cell[7995, 260, 1102, 32, 122, "Text"],
Cell[9100, 294, 1327, 23, 333, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10464, 322, 40, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[10529, 326, 56, 0, 68, "Subsection"],
Cell[10588, 328, 166, 5, 42, "Text"],
Cell[10757, 335, 158, 2, 73, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10952, 342, 54, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[11031, 346, 69, 1, 73, "Input"],
Cell[11103, 349, 72288, 1806, 279, 25468, 1223, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[83428, 2160, 69, 1, 73, "Input"],
Cell[83500, 2163, 72679, 1808, 279, 25475, 1221, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[156228, 3977, 75, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[156328, 3981, 69, 1, 73, "Input"],
Cell[156400, 3984, 73236, 1875, 279, 26866, 1298, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[229673, 5864, 114, 2, 73, "Input"],
Cell[229790, 5868, 67344, 1673, 279, 22776, 1118, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[297183, 7547, 86, 1, 68, "Subsection"],

Cell[CellGroupData[{
Cell[297294, 7552, 69, 1, 73, "Input"],
Cell[297366, 7555, 74724, 1816, 279, 25325, 1202, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[372105, 9374, 205, 6, 41, "Text"],

Cell[CellGroupData[{
Cell[372335, 9384, 71, 1, 73, "Input"],
Cell[372409, 9387, 86656, 2063, 312, 26806, 1320, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[459080, 11453, 181, 5, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[459298, 11463, 27, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[459350, 11467, 72, 1, 73, "Input"],
Cell[459425, 11470, 152923, 3051, 334, 29279, 1520, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[612363, 14524, 542, 14, 67, "Text"],

Cell[CellGroupData[{
Cell[612930, 14542, 73, 1, 73, "Input"],
Cell[613006, 14545, 84826, 2210, 279, 29291, 1520, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[697893, 16762, 42, 0, 51, "Section"],
Cell[697938, 16764, 928, 30, 93, "Text"],
Cell[698869, 16796, 121, 2, 102, "Input"],

Cell[CellGroupData[{
Cell[699015, 16802, 101, 2, 73, "Input"],
Cell[699119, 16806, 2756, 81, 156, "Output"]
}, Closed]],
Cell[701890, 16890, 320, 11, 41, "Text"],
Cell[702213, 16903, 81, 1, 73, "Input"],
Cell[702297, 16906, 117, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[702439, 16912, 276, 5, 99, "Input"],
Cell[702718, 16919, 129488, 2671, 426, 27269, 1405, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[832221, 19593, 336, 9, 41, "Text"],

Cell[CellGroupData[{
Cell[832582, 19606, 54, 1, 73, "Input"],
Cell[832639, 19609, 88, 1, 78, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[832776, 19616, 44, 0, 51, "Section"],
Cell[832823, 19618, 3296, 73, 275, "Text"],
Cell[836122, 19693, 472, 9, 93, "Text"],
Cell[836597, 19704, 123, 3, 41, "Text"],
Cell[836723, 19709, 115, 2, 75, "Input"],
Cell[836841, 19713, 71, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[836937, 19717, 52, 1, 73, "Input"],
Cell[836992, 19720, 52, 1, 59, "Output"]
}, Closed]],
Cell[837059, 19724, 690, 17, 94, "Text"],
Cell[837752, 19743, 136, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[837913, 19749, 127, 3, 73, "Input"],
Cell[838043, 19754, 53, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[838133, 19760, 162, 3, 73, "Input"],
Cell[838298, 19765, 112898, 2470, 472, 27008, 1405, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[951211, 22238, 143, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[951379, 22244, 127, 3, 73, "Input"],
Cell[951509, 22249, 41, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[951587, 22255, 162, 3, 73, "Input"],
Cell[951752, 22260, 122492, 2280, 444, 20888, 1021, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1074293, 24546, 50, 0, 51, "Section"],
Cell[1074346, 24548, 573, 12, 93, "Text"],

Cell[CellGroupData[{
Cell[1074944, 24564, 274, 5, 99, "Input"],
Cell[1075221, 24571, 133613, 2817, 444, 29154, 1523, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1208849, 27391, 641, 14, 93, "Text"],

Cell[CellGroupData[{
Cell[1209515, 27409, 66, 1, 73, "Input"],
Cell[1209584, 27412, 259, 4, 86, "Output"]
}, Closed]],
Cell[1209858, 27419, 968, 24, 119, "Text"],

Cell[CellGroupData[{
Cell[1210851, 27447, 76, 1, 73, "Input"],
Cell[1210930, 27450, 126, 2, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1211093, 27457, 61, 1, 73, "Input"],
Cell[1211157, 27460, 46, 1, 59, "Output"]
}, Closed]],
Cell[1211218, 27464, 557, 13, 67, "Text"],

Cell[CellGroupData[{
Cell[1211800, 27481, 492, 9, 151, "Input"],
Cell[1212295, 27492, 73271, 1918, 279, 27121, 1344, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1285581, 29413, 219, 6, 41, "Text"],

Cell[CellGroupData[{
Cell[1285825, 29423, 181, 3, 73, "Input"],
Cell[1286009, 29428, 57, 1, 64, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1286103, 29434, 39, 1, 73, "Input"],
Cell[1286145, 29437, 68, 1, 59, "Output"]
}, Closed]],
Cell[1286228, 29441, 406, 8, 67, "Text"],
Cell[1286637, 29451, 75, 1, 73, "Input"],

Cell[CellGroupData[{
Cell[1286737, 29456, 306, 5, 99, "Input"],
Cell[1287046, 29463, 94631, 3503, 279, 51791, 2970, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1381692, 32969, 115, 3, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1381844, 32977, 61, 0, 51, "Section"],
Cell[1381908, 32979, 831, 22, 93, "Text"],
Cell[1382742, 33003, 579, 16, 67, "Text"],

Cell[CellGroupData[{
Cell[1383346, 33023, 350, 6, 99, "Input"],
Cell[1383699, 33031, 195470, 3687, 525, 29344, 1632, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1579184, 36721, 563, 13, 67, "Text"],
Cell[1579750, 36736, 75, 1, 73, "Input"],

Cell[CellGroupData[{
Cell[1579850, 36741, 322, 5, 99, "Input"],
Cell[1580175, 36748, 68896, 2466, 279, 31555, 2000, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1649120, 39220, 33, 0, 54, "ExerciseMain"],

Cell[CellGroupData[{
Cell[1649178, 39224, 70, 0, 58, "ExerciseTitle"],
Cell[1649251, 39226, 474, 10, 135, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1649762, 39241, 146, 4, 58, "ExerciseTitle"],
Cell[1649911, 39247, 1345, 35, 219, "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

